'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var graphql = require('graphql');
var graphql__default = _interopDefault(graphql);

function unwrapExports (x) {
	return x && x.__esModule && Object.prototype.hasOwnProperty.call(x, 'default') ? x['default'] : x;
}

function createCommonjsModule(fn, module) {
	return module = { exports: {} }, fn(module, module.exports), module.exports;
}

var connection = createCommonjsModule(function (module, exports) {

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.connectionArgs = exports.backwardConnectionArgs = exports.forwardConnectionArgs = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; /**
                                                                                                                                                                                                                                                                   * Copyright (c) 2015-present, Facebook, Inc.
                                                                                                                                                                                                                                                                   *
                                                                                                                                                                                                                                                                   * This source code is licensed under the MIT license found in the
                                                                                                                                                                                                                                                                   * LICENSE file in the root directory of this source tree.
                                                                                                                                                                                                                                                                   *
                                                                                                                                                                                                                                                                   * 
                                                                                                                                                                                                                                                                   */

exports.connectionDefinitions = connectionDefinitions;



/**
 * Returns a GraphQLFieldConfigArgumentMap appropriate to include on a field
 * whose return type is a connection type with forward pagination.
 */
var forwardConnectionArgs = exports.forwardConnectionArgs = {
  after: {
    type: graphql__default.GraphQLString
  },
  first: {
    type: graphql__default.GraphQLInt
  }
};

/**
 * Returns a GraphQLFieldConfigArgumentMap appropriate to include on a field
 * whose return type is a connection type with backward pagination.
 */
var backwardConnectionArgs = exports.backwardConnectionArgs = {
  before: {
    type: graphql__default.GraphQLString
  },
  last: {
    type: graphql__default.GraphQLInt
  }
};

/**
 * Returns a GraphQLFieldConfigArgumentMap appropriate to include on a field
 * whose return type is a connection type with bidirectional pagination.
 */
var connectionArgs = exports.connectionArgs = _extends({}, forwardConnectionArgs, backwardConnectionArgs);

function resolveMaybeThunk(thingOrThunk) {
  return typeof thingOrThunk === 'function' ? // $FlowFixMe - if it's a function, we assume a thunk without arguments
  thingOrThunk() : thingOrThunk;
}

/**
 * Returns a GraphQLObjectType for a connection with the given name,
 * and whose nodes are of the specified type.
 */
function connectionDefinitions(config) {
  var nodeType = config.nodeType;

  var name = config.name || nodeType.name;
  var edgeFields = config.edgeFields || {};
  var connectionFields = config.connectionFields || {};
  var resolveNode = config.resolveNode;
  var resolveCursor = config.resolveCursor;
  var edgeType = new graphql__default.GraphQLObjectType({
    name: name + 'Edge',
    description: 'An edge in a connection.',
    fields: function fields() {
      return _extends({
        node: {
          type: nodeType,
          resolve: resolveNode,
          description: 'The item at the end of the edge'
        },
        cursor: {
          type: new graphql__default.GraphQLNonNull(graphql__default.GraphQLString),
          resolve: resolveCursor,
          description: 'A cursor for use in pagination'
        }
      }, resolveMaybeThunk(edgeFields));
    }
  });

  var connectionType = new graphql__default.GraphQLObjectType({
    name: name + 'Connection',
    description: 'A connection to a list of items.',
    fields: function fields() {
      return _extends({
        pageInfo: {
          type: new graphql__default.GraphQLNonNull(pageInfoType),
          description: 'Information to aid in pagination.'
        },
        edges: {
          type: new graphql__default.GraphQLList(edgeType),
          description: 'A list of edges.'
        }
      }, resolveMaybeThunk(connectionFields));
    }
  });

  return { edgeType: edgeType, connectionType: connectionType };
}

/**
 * The common page info type used by all connections.
 */
var pageInfoType = new graphql__default.GraphQLObjectType({
  name: 'PageInfo',
  description: 'Information about pagination in a connection.',
  fields: function fields() {
    return {
      hasNextPage: {
        type: new graphql__default.GraphQLNonNull(graphql__default.GraphQLBoolean),
        description: 'When paginating forwards, are there more items?'
      },
      hasPreviousPage: {
        type: new graphql__default.GraphQLNonNull(graphql__default.GraphQLBoolean),
        description: 'When paginating backwards, are there more items?'
      },
      startCursor: {
        type: graphql__default.GraphQLString,
        description: 'When paginating backwards, the cursor to continue.'
      },
      endCursor: {
        type: graphql__default.GraphQLString,
        description: 'When paginating forwards, the cursor to continue.'
      }
    };
  }
});
});

unwrapExports(connection);
var connection_1 = connection.connectionArgs;
var connection_2 = connection.backwardConnectionArgs;
var connection_3 = connection.forwardConnectionArgs;
var connection_4 = connection.connectionDefinitions;

var base64_1 = createCommonjsModule(function (module, exports) {

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.base64 = base64;
exports.unbase64 = unbase64;
function base64(i) {
  return Buffer.from(i, 'utf8').toString('base64');
} /**
   * Copyright (c) 2015-present, Facebook, Inc.
   *
   * This source code is licensed under the MIT license found in the
   * LICENSE file in the root directory of this source tree.
   *
   * 
   */

function unbase64(i) {
  return Buffer.from(i, 'base64').toString('utf8');
}
});

unwrapExports(base64_1);
var base64_2 = base64_1.base64;
var base64_3 = base64_1.unbase64;

var arrayconnection = createCommonjsModule(function (module, exports) {

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.connectionFromArray = connectionFromArray;
exports.connectionFromPromisedArray = connectionFromPromisedArray;
exports.connectionFromArraySlice = connectionFromArraySlice;
exports.connectionFromPromisedArraySlice = connectionFromPromisedArraySlice;
exports.offsetToCursor = offsetToCursor;
exports.cursorToOffset = cursorToOffset;
exports.cursorForObjectInConnection = cursorForObjectInConnection;
exports.getOffsetWithDefault = getOffsetWithDefault;



/**
 * A simple function that accepts an array and connection arguments, and returns
 * a connection object for use in GraphQL. It uses array offsets as pagination,
 * so pagination will only work if the array is static.
 */
/**
 * Copyright (c) 2015-present, Facebook, Inc.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * 
 */

function connectionFromArray(data, args) {
  return connectionFromArraySlice(data, args, {
    sliceStart: 0,
    arrayLength: data.length
  });
}

/**
 * A version of `connectionFromArray` that takes a promised array, and returns a
 * promised connection.
 */
function connectionFromPromisedArray(dataPromise, args) {
  return dataPromise.then(function (data) {
    return connectionFromArray(data, args);
  });
}

/**
 * Given a slice (subset) of an array, returns a connection object for use in
 * GraphQL.
 *
 * This function is similar to `connectionFromArray`, but is intended for use
 * cases where you know the cardinality of the connection, consider it too large
 * to materialize the entire array, and instead wish pass in a slice of the
 * total result large enough to cover the range specified in `args`.
 */
function connectionFromArraySlice(arraySlice, args, meta) {
  var after = args.after,
      before = args.before,
      first = args.first,
      last = args.last;
  var sliceStart = meta.sliceStart,
      arrayLength = meta.arrayLength;

  var sliceEnd = sliceStart + arraySlice.length;
  var beforeOffset = getOffsetWithDefault(before, arrayLength);
  var afterOffset = getOffsetWithDefault(after, -1);

  var startOffset = Math.max(sliceStart - 1, afterOffset, -1) + 1;
  var endOffset = Math.min(sliceEnd, beforeOffset, arrayLength);
  if (typeof first === 'number') {
    if (first < 0) {
      throw new Error('Argument "first" must be a non-negative integer');
    }

    endOffset = Math.min(endOffset, startOffset + first);
  }
  if (typeof last === 'number') {
    if (last < 0) {
      throw new Error('Argument "last" must be a non-negative integer');
    }

    startOffset = Math.max(startOffset, endOffset - last);
  }

  // If supplied slice is too large, trim it down before mapping over it.
  var slice = arraySlice.slice(Math.max(startOffset - sliceStart, 0), arraySlice.length - (sliceEnd - endOffset));

  var edges = slice.map(function (value, index) {
    return {
      cursor: offsetToCursor(startOffset + index),
      node: value
    };
  });

  var firstEdge = edges[0];
  var lastEdge = edges[edges.length - 1];
  var lowerBound = after ? afterOffset + 1 : 0;
  var upperBound = before ? beforeOffset : arrayLength;
  return {
    edges: edges,
    pageInfo: {
      startCursor: firstEdge ? firstEdge.cursor : null,
      endCursor: lastEdge ? lastEdge.cursor : null,
      hasPreviousPage: typeof last === 'number' ? startOffset > lowerBound : false,
      hasNextPage: typeof first === 'number' ? endOffset < upperBound : false
    }
  };
}

/**
 * A version of `connectionFromArraySlice` that takes a promised array slice,
 * and returns a promised connection.
 */
function connectionFromPromisedArraySlice(dataPromise, args, arrayInfo) {
  return dataPromise.then(function (data) {
    return connectionFromArraySlice(data, args, arrayInfo);
  });
}

var PREFIX = 'arrayconnection:';

/**
 * Creates the cursor string from an offset.
 */
function offsetToCursor(offset) {
  return (0, base64_1.base64)(PREFIX + offset);
}

/**
 * Rederives the offset from the cursor string.
 */
function cursorToOffset(cursor) {
  return parseInt((0, base64_1.unbase64)(cursor).substring(PREFIX.length), 10);
}

/**
 * Return the cursor associated with an object in an array.
 */
function cursorForObjectInConnection(data, object) {
  var offset = data.indexOf(object);
  if (offset === -1) {
    return null;
  }
  return offsetToCursor(offset);
}

/**
 * Given an optional cursor and a default offset, returns the offset
 * to use; if the cursor contains a valid offset, that will be used,
 * otherwise it will be the default.
 */
function getOffsetWithDefault(cursor, defaultOffset) {
  if (typeof cursor !== 'string') {
    return defaultOffset;
  }
  var offset = cursorToOffset(cursor);
  return isNaN(offset) ? defaultOffset : offset;
}
});

unwrapExports(arrayconnection);
var arrayconnection_1 = arrayconnection.connectionFromArray;
var arrayconnection_2 = arrayconnection.connectionFromPromisedArray;
var arrayconnection_3 = arrayconnection.connectionFromArraySlice;
var arrayconnection_4 = arrayconnection.connectionFromPromisedArraySlice;
var arrayconnection_5 = arrayconnection.offsetToCursor;
var arrayconnection_6 = arrayconnection.cursorToOffset;
var arrayconnection_7 = arrayconnection.cursorForObjectInConnection;
var arrayconnection_8 = arrayconnection.getOffsetWithDefault;

var mutation = createCommonjsModule(function (module, exports) {

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; /**
                                                                                                                                                                                                                                                                   * Copyright (c) 2015-present, Facebook, Inc.
                                                                                                                                                                                                                                                                   *
                                                                                                                                                                                                                                                                   * This source code is licensed under the MIT license found in the
                                                                                                                                                                                                                                                                   * LICENSE file in the root directory of this source tree.
                                                                                                                                                                                                                                                                   *
                                                                                                                                                                                                                                                                   * 
                                                                                                                                                                                                                                                                   */

exports.mutationWithClientMutationId = mutationWithClientMutationId;



function resolveMaybeThunk(thingOrThunk) {
  return typeof thingOrThunk === 'function' ? // $FlowFixMe - if it's a function, we assume a thunk without arguments
  thingOrThunk() : thingOrThunk;
}

/**
 * A description of a mutation consumable by mutationWithClientMutationId
 * to create a GraphQLFieldConfig for that mutation.
 *
 * The inputFields and outputFields should not include `clientMutationId`,
 * as this will be provided automatically.
 *
 * An input object will be created containing the input fields, and an
 * object will be created containing the output fields.
 *
 * mutateAndGetPayload will receive an Object with a key for each
 * input field, and it should return an Object with a key for each
 * output field. It may return synchronously, or return a Promise.
 */


/**
 * Returns a GraphQLFieldConfig for the mutation described by the
 * provided MutationConfig.
 */
function mutationWithClientMutationId(config) {
  var name = config.name,
      description = config.description,
      deprecationReason = config.deprecationReason,
      inputFields = config.inputFields,
      outputFields = config.outputFields,
      mutateAndGetPayload = config.mutateAndGetPayload;

  var augmentedInputFields = function augmentedInputFields() {
    return _extends({}, resolveMaybeThunk(inputFields), {
      clientMutationId: {
        type: graphql__default.GraphQLString
      }
    });
  };
  var augmentedOutputFields = function augmentedOutputFields() {
    return _extends({}, resolveMaybeThunk(outputFields), {
      clientMutationId: {
        type: graphql__default.GraphQLString
      }
    });
  };

  var outputType = new graphql__default.GraphQLObjectType({
    name: name + 'Payload',
    fields: augmentedOutputFields
  });

  var inputType = new graphql__default.GraphQLInputObjectType({
    name: name + 'Input',
    fields: augmentedInputFields
  });

  return {
    type: outputType,
    description: description,
    deprecationReason: deprecationReason,
    args: {
      input: { type: new graphql__default.GraphQLNonNull(inputType) }
    },
    resolve: function resolve(_, _ref, context, info) {
      var input = _ref.input;

      return Promise.resolve(mutateAndGetPayload(input, context, info)).then(function (payload) {
        payload.clientMutationId = input.clientMutationId;
        return payload;
      });
    }
  };
}
});

unwrapExports(mutation);
var mutation_1 = mutation.mutationWithClientMutationId;

var node = createCommonjsModule(function (module, exports) {

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.nodeDefinitions = nodeDefinitions;
exports.toGlobalId = toGlobalId;
exports.fromGlobalId = fromGlobalId;
exports.globalIdField = globalIdField;





/**
 * Given a function to map from an ID to an underlying object, and a function
 * to map from an underlying object to the concrete GraphQLObjectType it
 * corresponds to, constructs a `Node` interface that objects can implement,
 * and a field config for a `node` root field.
 *
 * If the typeResolver is omitted, object resolution on the interface will be
 * handled with the `isTypeOf` method on object types, as with any GraphQL
 * interface without a provided `resolveType` method.
 */
/**
 * Copyright (c) 2015-present, Facebook, Inc.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * 
 */

function nodeDefinitions(idFetcher, typeResolver) {
  var nodeInterface = new graphql__default.GraphQLInterfaceType({
    name: 'Node',
    description: 'An object with an ID',
    fields: function fields() {
      return {
        id: {
          type: new graphql__default.GraphQLNonNull(graphql__default.GraphQLID),
          description: 'The id of the object.'
        }
      };
    },
    resolveType: typeResolver
  });

  var nodeField = {
    description: 'Fetches an object given its ID',
    type: nodeInterface,
    args: {
      id: {
        type: new graphql__default.GraphQLNonNull(graphql__default.GraphQLID),
        description: 'The ID of an object'
      }
    },
    resolve: function resolve(obj, _ref, context, info) {
      var id = _ref.id;
      return idFetcher(id, context, info);
    }
  };

  var nodesField = {
    description: 'Fetches objects given their IDs',
    type: new graphql__default.GraphQLNonNull(new graphql__default.GraphQLList(nodeInterface)),
    args: {
      ids: {
        type: new graphql__default.GraphQLNonNull(new graphql__default.GraphQLList(new graphql__default.GraphQLNonNull(graphql__default.GraphQLID))),
        description: 'The IDs of objects'
      }
    },
    resolve: function resolve(obj, _ref2, context, info) {
      var ids = _ref2.ids;
      return Promise.all(ids.map(function (id) {
        return Promise.resolve(idFetcher(id, context, info));
      }));
    }
  };

  return { nodeInterface: nodeInterface, nodeField: nodeField, nodesField: nodesField };
}

/**
 * Takes a type name and an ID specific to that type name, and returns a
 * "global ID" that is unique among all types.
 */
function toGlobalId(type, id) {
  return (0, base64_1.base64)([type, id].join(':'));
}

/**
 * Takes the "global ID" created by toGlobalID, and returns the type name and ID
 * used to create it.
 */
function fromGlobalId(globalId) {
  var unbasedGlobalId = (0, base64_1.unbase64)(globalId);
  var delimiterPos = unbasedGlobalId.indexOf(':');
  return {
    type: unbasedGlobalId.substring(0, delimiterPos),
    id: unbasedGlobalId.substring(delimiterPos + 1)
  };
}

/**
 * Creates the configuration for an id field on a node, using `toGlobalId` to
 * construct the ID from the provided typename. The type-specific ID is fetched
 * by calling idFetcher on the object, or if not provided, by accessing the `id`
 * property on the object.
 */
function globalIdField(typeName, idFetcher) {
  return {
    description: 'The ID of an object',
    type: new graphql__default.GraphQLNonNull(graphql__default.GraphQLID),
    resolve: function resolve(obj, args, context, info) {
      return toGlobalId(typeName || info.parentType.name, idFetcher ? idFetcher(obj, context, info) : obj.id);
    }
  };
}
});

unwrapExports(node);
var node_1 = node.nodeDefinitions;
var node_2 = node.toGlobalId;
var node_3 = node.fromGlobalId;
var node_4 = node.globalIdField;

var plural = createCommonjsModule(function (module, exports) {

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.pluralIdentifyingRootField = pluralIdentifyingRootField;



function pluralIdentifyingRootField(config) {
  var inputArgs = {};
  var inputType = config.inputType;
  if (inputType instanceof graphql__default.GraphQLNonNull) {
    inputType = inputType.ofType;
  }
  inputArgs[config.argName] = {
    type: new graphql__default.GraphQLNonNull(new graphql__default.GraphQLList(new graphql__default.GraphQLNonNull(inputType)))
  };
  return {
    description: config.description,
    type: new graphql__default.GraphQLList(config.outputType),
    args: inputArgs,
    resolve: function resolve(obj, args, context, info) {
      var inputs = args[config.argName];
      return Promise.all(inputs.map(function (input) {
        return Promise.resolve(config.resolveSingleInput(input, context, info));
      }));
    }
  };
} /**
   * Copyright (c) 2015-present, Facebook, Inc.
   *
   * This source code is licensed under the MIT license found in the
   * LICENSE file in the root directory of this source tree.
   *
   * 
   */
});

unwrapExports(plural);
var plural_1 = plural.pluralIdentifyingRootField;

var lib = createCommonjsModule(function (module, exports) {

Object.defineProperty(exports, "__esModule", {
  value: true
});



Object.defineProperty(exports, 'backwardConnectionArgs', {
  enumerable: true,
  get: function get() {
    return connection.backwardConnectionArgs;
  }
});
Object.defineProperty(exports, 'connectionArgs', {
  enumerable: true,
  get: function get() {
    return connection.connectionArgs;
  }
});
Object.defineProperty(exports, 'connectionDefinitions', {
  enumerable: true,
  get: function get() {
    return connection.connectionDefinitions;
  }
});
Object.defineProperty(exports, 'forwardConnectionArgs', {
  enumerable: true,
  get: function get() {
    return connection.forwardConnectionArgs;
  }
});



Object.defineProperty(exports, 'connectionFromArray', {
  enumerable: true,
  get: function get() {
    return arrayconnection.connectionFromArray;
  }
});
Object.defineProperty(exports, 'connectionFromArraySlice', {
  enumerable: true,
  get: function get() {
    return arrayconnection.connectionFromArraySlice;
  }
});
Object.defineProperty(exports, 'connectionFromPromisedArray', {
  enumerable: true,
  get: function get() {
    return arrayconnection.connectionFromPromisedArray;
  }
});
Object.defineProperty(exports, 'connectionFromPromisedArraySlice', {
  enumerable: true,
  get: function get() {
    return arrayconnection.connectionFromPromisedArraySlice;
  }
});
Object.defineProperty(exports, 'cursorForObjectInConnection', {
  enumerable: true,
  get: function get() {
    return arrayconnection.cursorForObjectInConnection;
  }
});
Object.defineProperty(exports, 'cursorToOffset', {
  enumerable: true,
  get: function get() {
    return arrayconnection.cursorToOffset;
  }
});
Object.defineProperty(exports, 'getOffsetWithDefault', {
  enumerable: true,
  get: function get() {
    return arrayconnection.getOffsetWithDefault;
  }
});
Object.defineProperty(exports, 'offsetToCursor', {
  enumerable: true,
  get: function get() {
    return arrayconnection.offsetToCursor;
  }
});



Object.defineProperty(exports, 'mutationWithClientMutationId', {
  enumerable: true,
  get: function get() {
    return mutation.mutationWithClientMutationId;
  }
});



Object.defineProperty(exports, 'nodeDefinitions', {
  enumerable: true,
  get: function get() {
    return node.nodeDefinitions;
  }
});



Object.defineProperty(exports, 'pluralIdentifyingRootField', {
  enumerable: true,
  get: function get() {
    return plural.pluralIdentifyingRootField;
  }
});
Object.defineProperty(exports, 'fromGlobalId', {
  enumerable: true,
  get: function get() {
    return node.fromGlobalId;
  }
});
Object.defineProperty(exports, 'globalIdField', {
  enumerable: true,
  get: function get() {
    return node.globalIdField;
  }
});
Object.defineProperty(exports, 'toGlobalId', {
  enumerable: true,
  get: function get() {
    return node.toGlobalId;
  }
});
});

unwrapExports(lib);
var lib_1 = lib.nodeDefinitions;
var lib_2 = lib.fromGlobalId;
var lib_3 = lib.connectionDefinitions;
var lib_4 = lib.connectionArgs;
var lib_5 = lib.connectionFromArray;
var lib_6 = lib.globalIdField;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

/**
 * A `DataLoader` creates a public API for loading data from a particular
 * data back-end with unique keys such as the `id` column of a SQL table or
 * document name in a MongoDB database, given a batch loading function.
 *
 * Each `DataLoader` instance contains a unique memoized cache. Use caution when
 * used in long-lived applications or those which serve many users with
 * different access permissions and consider creating a new instance per
 * web request.
 */


// Optionally turn off batching or caching or provide a cache key function or a
// custom cache instance.
var DataLoader = function () {
  function DataLoader(batchLoadFn, options) {
    _classCallCheck(this, DataLoader);

    if (typeof batchLoadFn !== 'function') {
      throw new TypeError('DataLoader must be constructed with a function which accepts ' + ('Array<key> and returns Promise<Array<value>>, but got: ' + batchLoadFn + '.'));
    }
    this._batchLoadFn = batchLoadFn;
    this._options = options;
    this._promiseCache = getValidCacheMap(options);
    this._queue = [];
  }

  // Private


  /**
   * Loads a key, returning a `Promise` for the value represented by that key.
   */
  DataLoader.prototype.load = function load(key) {
    var _this = this;

    if (key === null || key === undefined) {
      throw new TypeError('The loader.load() function must be called with a value,' + ('but got: ' + String(key) + '.'));
    }

    // Determine options
    var options = this._options;
    var shouldBatch = !options || options.batch !== false;
    var shouldCache = !options || options.cache !== false;
    var cacheKeyFn = options && options.cacheKeyFn;
    var cacheKey = cacheKeyFn ? cacheKeyFn(key) : key;

    // If caching and there is a cache-hit, return cached Promise.
    if (shouldCache) {
      var cachedPromise = this._promiseCache.get(cacheKey);
      if (cachedPromise) {
        return cachedPromise;
      }
    }

    // Otherwise, produce a new Promise for this value.
    var promise = new Promise(function (resolve, reject) {
      // Enqueue this Promise to be dispatched.
      _this._queue.push({ key: key, resolve: resolve, reject: reject });

      // Determine if a dispatch of this queue should be scheduled.
      // A single dispatch should be scheduled per queue at the time when the
      // queue changes from "empty" to "full".
      if (_this._queue.length === 1) {
        if (shouldBatch) {
          // If batching, schedule a task to dispatch the queue.
          enqueuePostPromiseJob(function () {
            return dispatchQueue(_this);
          });
        } else {
          // Otherwise dispatch the (queue of one) immediately.
          dispatchQueue(_this);
        }
      }
    });

    // If caching, cache this promise.
    if (shouldCache) {
      this._promiseCache.set(cacheKey, promise);
    }

    return promise;
  };

  /**
   * Loads multiple keys, promising an array of values:
   *
   *     var [ a, b ] = await myLoader.loadMany([ 'a', 'b' ]);
   *
   * This is equivalent to the more verbose:
   *
   *     var [ a, b ] = await Promise.all([
   *       myLoader.load('a'),
   *       myLoader.load('b')
   *     ]);
   *
   */


  DataLoader.prototype.loadMany = function loadMany(keys) {
    var _this2 = this;

    if (!Array.isArray(keys)) {
      throw new TypeError('The loader.loadMany() function must be called with Array<key> ' + ('but got: ' + keys + '.'));
    }
    return Promise.all(keys.map(function (key) {
      return _this2.load(key);
    }));
  };

  /**
   * Clears the value at `key` from the cache, if it exists. Returns itself for
   * method chaining.
   */


  DataLoader.prototype.clear = function clear(key) {
    var cacheKeyFn = this._options && this._options.cacheKeyFn;
    var cacheKey = cacheKeyFn ? cacheKeyFn(key) : key;
    this._promiseCache.delete(cacheKey);
    return this;
  };

  /**
   * Clears the entire cache. To be used when some event results in unknown
   * invalidations across this particular `DataLoader`. Returns itself for
   * method chaining.
   */


  DataLoader.prototype.clearAll = function clearAll() {
    this._promiseCache.clear();
    return this;
  };

  /**
   * Adds the provided key and value to the cache. If the key already
   * exists, no change is made. Returns itself for method chaining.
   */


  DataLoader.prototype.prime = function prime(key, value) {
    var cacheKeyFn = this._options && this._options.cacheKeyFn;
    var cacheKey = cacheKeyFn ? cacheKeyFn(key) : key;

    // Only add the key if it does not already exist.
    if (this._promiseCache.get(cacheKey) === undefined) {
      // Cache a rejected promise if the value is an Error, in order to match
      // the behavior of load(key).
      var promise = value instanceof Error ? Promise.reject(value) : Promise.resolve(value);

      this._promiseCache.set(cacheKey, promise);
    }

    return this;
  };

  return DataLoader;
}();

// Private: Enqueue a Job to be executed after all "PromiseJobs" Jobs.
//
// ES6 JavaScript uses the concepts Job and JobQueue to schedule work to occur
// after the current execution context has completed:
// http://www.ecma-international.org/ecma-262/6.0/#sec-jobs-and-job-queues
//
// Node.js uses the `process.nextTick` mechanism to implement the concept of a
// Job, maintaining a global FIFO JobQueue for all Jobs, which is flushed after
// the current call stack ends.
//
// When calling `then` on a Promise, it enqueues a Job on a specific
// "PromiseJobs" JobQueue which is flushed in Node as a single Job on the
// global JobQueue.
//
// DataLoader batches all loads which occur in a single frame of execution, but
// should include in the batch all loads which occur during the flushing of the
// "PromiseJobs" JobQueue after that same execution frame.
//
// In order to avoid the DataLoader dispatch Job occuring before "PromiseJobs",
// A Promise Job is created with the sole purpose of enqueuing a global Job,
// ensuring that it always occurs after "PromiseJobs" ends.
//
// Node.js's job queue is unique. Browsers do not have an equivalent mechanism
// for enqueuing a job to be performed after promise microtasks and before the
// next macrotask. For browser environments, a macrotask is used (via
// setImmediate or setTimeout) at a potential performance penalty.


// If a custom cache is provided, it must be of this type (a subset of ES6 Map).

/**
 *  Copyright (c) 2015, Facebook, Inc.
 *  All rights reserved.
 *
 *  This source code is licensed under the BSD-style license found in the
 *  LICENSE file in the root directory of this source tree. An additional grant
 *  of patent rights can be found in the PATENTS file in the same directory.
 */

// A Function, which when given an Array of keys, returns a Promise of an Array
// of values or Errors.


var enqueuePostPromiseJob = typeof process === 'object' && typeof process.nextTick === 'function' ? function (fn) {
  if (!resolvedPromise) {
    resolvedPromise = Promise.resolve();
  }
  resolvedPromise.then(function () {
    return process.nextTick(fn);
  });
} : setImmediate || setTimeout;

// Private: cached resolved Promise instance
var resolvedPromise;

// Private: given the current state of a Loader instance, perform a batch load
// from its current queue.
function dispatchQueue(loader) {
  // Take the current loader queue, replacing it with an empty queue.
  var queue = loader._queue;
  loader._queue = [];

  // If a maxBatchSize was provided and the queue is longer, then segment the
  // queue into multiple batches, otherwise treat the queue as a single batch.
  var maxBatchSize = loader._options && loader._options.maxBatchSize;
  if (maxBatchSize && maxBatchSize > 0 && maxBatchSize < queue.length) {
    for (var i = 0; i < queue.length / maxBatchSize; i++) {
      dispatchQueueBatch(loader, queue.slice(i * maxBatchSize, (i + 1) * maxBatchSize));
    }
  } else {
    dispatchQueueBatch(loader, queue);
  }
}

function dispatchQueueBatch(loader, queue) {
  // Collect all keys to be loaded in this dispatch
  var keys = queue.map(function (_ref) {
    var key = _ref.key;
    return key;
  });

  // Call the provided batchLoadFn for this loader with the loader queue's keys.
  var batchLoadFn = loader._batchLoadFn;
  var batchPromise = batchLoadFn(keys);

  // Assert the expected response from batchLoadFn
  if (!batchPromise || typeof batchPromise.then !== 'function') {
    return failedDispatch(loader, queue, new TypeError('DataLoader must be constructed with a function which accepts ' + 'Array<key> and returns Promise<Array<value>>, but the function did ' + ('not return a Promise: ' + String(batchPromise) + '.')));
  }

  // Await the resolution of the call to batchLoadFn.
  batchPromise.then(function (values) {

    // Assert the expected resolution from batchLoadFn.
    if (!Array.isArray(values)) {
      throw new TypeError('DataLoader must be constructed with a function which accepts ' + 'Array<key> and returns Promise<Array<value>>, but the function did ' + ('not return a Promise of an Array: ' + String(values) + '.'));
    }
    if (values.length !== keys.length) {
      throw new TypeError('DataLoader must be constructed with a function which accepts ' + 'Array<key> and returns Promise<Array<value>>, but the function did ' + 'not return a Promise of an Array of the same length as the Array ' + 'of keys.' + ('\n\nKeys:\n' + String(keys)) + ('\n\nValues:\n' + String(values)));
    }

    // Step through the values, resolving or rejecting each Promise in the
    // loaded queue.
    queue.forEach(function (_ref2, index) {
      var resolve = _ref2.resolve,
          reject = _ref2.reject;

      var value = values[index];
      if (value instanceof Error) {
        reject(value);
      } else {
        resolve(value);
      }
    });
  }).catch(function (error) {
    return failedDispatch(loader, queue, error);
  });
}

// Private: do not cache individual loads if the entire batch dispatch fails,
// but still reject each request so they do not hang.
function failedDispatch(loader, queue, error) {
  queue.forEach(function (_ref3) {
    var key = _ref3.key,
        reject = _ref3.reject;

    loader.clear(key);
    reject(error);
  });
}

// Private: given the DataLoader's options, produce a CacheMap to be used.
function getValidCacheMap(options) {
  var cacheMap = options && options.cacheMap;
  if (!cacheMap) {
    return new Map();
  }
  var cacheFunctions = ['get', 'set', 'delete', 'clear'];
  var missingFunctions = cacheFunctions.filter(function (fnName) {
    return cacheMap && typeof cacheMap[fnName] !== 'function';
  });
  if (missingFunctions.length !== 0) {
    throw new TypeError('Custom cacheMap missing methods: ' + missingFunctions.join(', '));
  }
  return cacheMap;
}

// Private


var dataloader = DataLoader;

var swapiData = {
	"https://swapi.co/api/people/": {
	count: 87,
	next: "https://swapi.co/api/people/?page=2",
	previous: null,
	results: [
		{
			name: "Luke Skywalker",
			height: "172",
			mass: "77",
			hair_color: "blond",
			skin_color: "fair",
			eye_color: "blue",
			birth_year: "19BBY",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/1/",
			films: [
				"https://swapi.co/api/films/2/",
				"https://swapi.co/api/films/6/",
				"https://swapi.co/api/films/3/",
				"https://swapi.co/api/films/1/",
				"https://swapi.co/api/films/7/"
			],
			species: [
				"https://swapi.co/api/species/1/"
			],
			vehicles: [
				"https://swapi.co/api/vehicles/14/",
				"https://swapi.co/api/vehicles/30/"
			],
			starships: [
				"https://swapi.co/api/starships/12/",
				"https://swapi.co/api/starships/22/"
			],
			created: "2014-12-09T13:50:51.644000Z",
			edited: "2014-12-20T21:17:56.891000Z",
			url: "https://swapi.co/api/people/1/"
		},
		{
			name: "C-3PO",
			height: "167",
			mass: "75",
			hair_color: "n/a",
			skin_color: "gold",
			eye_color: "yellow",
			birth_year: "112BBY",
			gender: "n/a",
			homeworld: "https://swapi.co/api/planets/1/",
			films: [
				"https://swapi.co/api/films/2/",
				"https://swapi.co/api/films/5/",
				"https://swapi.co/api/films/4/",
				"https://swapi.co/api/films/6/",
				"https://swapi.co/api/films/3/",
				"https://swapi.co/api/films/1/"
			],
			species: [
				"https://swapi.co/api/species/2/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-10T15:10:51.357000Z",
			edited: "2014-12-20T21:17:50.309000Z",
			url: "https://swapi.co/api/people/2/"
		},
		{
			name: "R2-D2",
			height: "96",
			mass: "32",
			hair_color: "n/a",
			skin_color: "white, blue",
			eye_color: "red",
			birth_year: "33BBY",
			gender: "n/a",
			homeworld: "https://swapi.co/api/planets/8/",
			films: [
				"https://swapi.co/api/films/2/",
				"https://swapi.co/api/films/5/",
				"https://swapi.co/api/films/4/",
				"https://swapi.co/api/films/6/",
				"https://swapi.co/api/films/3/",
				"https://swapi.co/api/films/1/",
				"https://swapi.co/api/films/7/"
			],
			species: [
				"https://swapi.co/api/species/2/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-10T15:11:50.376000Z",
			edited: "2014-12-20T21:17:50.311000Z",
			url: "https://swapi.co/api/people/3/"
		},
		{
			name: "Darth Vader",
			height: "202",
			mass: "136",
			hair_color: "none",
			skin_color: "white",
			eye_color: "yellow",
			birth_year: "41.9BBY",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/1/",
			films: [
				"https://swapi.co/api/films/2/",
				"https://swapi.co/api/films/6/",
				"https://swapi.co/api/films/3/",
				"https://swapi.co/api/films/1/"
			],
			species: [
				"https://swapi.co/api/species/1/"
			],
			vehicles: [
			],
			starships: [
				"https://swapi.co/api/starships/13/"
			],
			created: "2014-12-10T15:18:20.704000Z",
			edited: "2014-12-20T21:17:50.313000Z",
			url: "https://swapi.co/api/people/4/"
		},
		{
			name: "Leia Organa",
			height: "150",
			mass: "49",
			hair_color: "brown",
			skin_color: "light",
			eye_color: "brown",
			birth_year: "19BBY",
			gender: "female",
			homeworld: "https://swapi.co/api/planets/2/",
			films: [
				"https://swapi.co/api/films/2/",
				"https://swapi.co/api/films/6/",
				"https://swapi.co/api/films/3/",
				"https://swapi.co/api/films/1/",
				"https://swapi.co/api/films/7/"
			],
			species: [
				"https://swapi.co/api/species/1/"
			],
			vehicles: [
				"https://swapi.co/api/vehicles/30/"
			],
			starships: [
			],
			created: "2014-12-10T15:20:09.791000Z",
			edited: "2014-12-20T21:17:50.315000Z",
			url: "https://swapi.co/api/people/5/"
		},
		{
			name: "Owen Lars",
			height: "178",
			mass: "120",
			hair_color: "brown, grey",
			skin_color: "light",
			eye_color: "blue",
			birth_year: "52BBY",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/1/",
			films: [
				"https://swapi.co/api/films/5/",
				"https://swapi.co/api/films/6/",
				"https://swapi.co/api/films/1/"
			],
			species: [
				"https://swapi.co/api/species/1/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-10T15:52:14.024000Z",
			edited: "2014-12-20T21:17:50.317000Z",
			url: "https://swapi.co/api/people/6/"
		},
		{
			name: "Beru Whitesun lars",
			height: "165",
			mass: "75",
			hair_color: "brown",
			skin_color: "light",
			eye_color: "blue",
			birth_year: "47BBY",
			gender: "female",
			homeworld: "https://swapi.co/api/planets/1/",
			films: [
				"https://swapi.co/api/films/5/",
				"https://swapi.co/api/films/6/",
				"https://swapi.co/api/films/1/"
			],
			species: [
				"https://swapi.co/api/species/1/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-10T15:53:41.121000Z",
			edited: "2014-12-20T21:17:50.319000Z",
			url: "https://swapi.co/api/people/7/"
		},
		{
			name: "R5-D4",
			height: "97",
			mass: "32",
			hair_color: "n/a",
			skin_color: "white, red",
			eye_color: "red",
			birth_year: "unknown",
			gender: "n/a",
			homeworld: "https://swapi.co/api/planets/1/",
			films: [
				"https://swapi.co/api/films/1/"
			],
			species: [
				"https://swapi.co/api/species/2/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-10T15:57:50.959000Z",
			edited: "2014-12-20T21:17:50.321000Z",
			url: "https://swapi.co/api/people/8/"
		},
		{
			name: "Biggs Darklighter",
			height: "183",
			mass: "84",
			hair_color: "black",
			skin_color: "light",
			eye_color: "brown",
			birth_year: "24BBY",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/1/",
			films: [
				"https://swapi.co/api/films/1/"
			],
			species: [
				"https://swapi.co/api/species/1/"
			],
			vehicles: [
			],
			starships: [
				"https://swapi.co/api/starships/12/"
			],
			created: "2014-12-10T15:59:50.509000Z",
			edited: "2014-12-20T21:17:50.323000Z",
			url: "https://swapi.co/api/people/9/"
		},
		{
			name: "Obi-Wan Kenobi",
			height: "182",
			mass: "77",
			hair_color: "auburn, white",
			skin_color: "fair",
			eye_color: "blue-gray",
			birth_year: "57BBY",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/20/",
			films: [
				"https://swapi.co/api/films/2/",
				"https://swapi.co/api/films/5/",
				"https://swapi.co/api/films/4/",
				"https://swapi.co/api/films/6/",
				"https://swapi.co/api/films/3/",
				"https://swapi.co/api/films/1/"
			],
			species: [
				"https://swapi.co/api/species/1/"
			],
			vehicles: [
				"https://swapi.co/api/vehicles/38/"
			],
			starships: [
				"https://swapi.co/api/starships/48/",
				"https://swapi.co/api/starships/59/",
				"https://swapi.co/api/starships/64/",
				"https://swapi.co/api/starships/65/",
				"https://swapi.co/api/starships/74/"
			],
			created: "2014-12-10T16:16:29.192000Z",
			edited: "2014-12-20T21:17:50.325000Z",
			url: "https://swapi.co/api/people/10/"
		}
	]
},
	"https://swapi.co/api/people/1/": {
	name: "Luke Skywalker",
	height: "172",
	mass: "77",
	hair_color: "blond",
	skin_color: "fair",
	eye_color: "blue",
	birth_year: "19BBY",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/1/",
	films: [
		"https://swapi.co/api/films/2/",
		"https://swapi.co/api/films/6/",
		"https://swapi.co/api/films/3/",
		"https://swapi.co/api/films/1/",
		"https://swapi.co/api/films/7/"
	],
	species: [
		"https://swapi.co/api/species/1/"
	],
	vehicles: [
		"https://swapi.co/api/vehicles/14/",
		"https://swapi.co/api/vehicles/30/"
	],
	starships: [
		"https://swapi.co/api/starships/12/",
		"https://swapi.co/api/starships/22/"
	],
	created: "2014-12-09T13:50:51.644000Z",
	edited: "2014-12-20T21:17:56.891000Z",
	url: "https://swapi.co/api/people/1/"
},
	"https://swapi.co/api/people/2/": {
	name: "C-3PO",
	height: "167",
	mass: "75",
	hair_color: "n/a",
	skin_color: "gold",
	eye_color: "yellow",
	birth_year: "112BBY",
	gender: "n/a",
	homeworld: "https://swapi.co/api/planets/1/",
	films: [
		"https://swapi.co/api/films/2/",
		"https://swapi.co/api/films/5/",
		"https://swapi.co/api/films/4/",
		"https://swapi.co/api/films/6/",
		"https://swapi.co/api/films/3/",
		"https://swapi.co/api/films/1/"
	],
	species: [
		"https://swapi.co/api/species/2/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-10T15:10:51.357000Z",
	edited: "2014-12-20T21:17:50.309000Z",
	url: "https://swapi.co/api/people/2/"
},
	"https://swapi.co/api/people/3/": {
	name: "R2-D2",
	height: "96",
	mass: "32",
	hair_color: "n/a",
	skin_color: "white, blue",
	eye_color: "red",
	birth_year: "33BBY",
	gender: "n/a",
	homeworld: "https://swapi.co/api/planets/8/",
	films: [
		"https://swapi.co/api/films/2/",
		"https://swapi.co/api/films/5/",
		"https://swapi.co/api/films/4/",
		"https://swapi.co/api/films/6/",
		"https://swapi.co/api/films/3/",
		"https://swapi.co/api/films/1/",
		"https://swapi.co/api/films/7/"
	],
	species: [
		"https://swapi.co/api/species/2/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-10T15:11:50.376000Z",
	edited: "2014-12-20T21:17:50.311000Z",
	url: "https://swapi.co/api/people/3/"
},
	"https://swapi.co/api/people/4/": {
	name: "Darth Vader",
	height: "202",
	mass: "136",
	hair_color: "none",
	skin_color: "white",
	eye_color: "yellow",
	birth_year: "41.9BBY",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/1/",
	films: [
		"https://swapi.co/api/films/2/",
		"https://swapi.co/api/films/6/",
		"https://swapi.co/api/films/3/",
		"https://swapi.co/api/films/1/"
	],
	species: [
		"https://swapi.co/api/species/1/"
	],
	vehicles: [
	],
	starships: [
		"https://swapi.co/api/starships/13/"
	],
	created: "2014-12-10T15:18:20.704000Z",
	edited: "2014-12-20T21:17:50.313000Z",
	url: "https://swapi.co/api/people/4/"
},
	"https://swapi.co/api/people/5/": {
	name: "Leia Organa",
	height: "150",
	mass: "49",
	hair_color: "brown",
	skin_color: "light",
	eye_color: "brown",
	birth_year: "19BBY",
	gender: "female",
	homeworld: "https://swapi.co/api/planets/2/",
	films: [
		"https://swapi.co/api/films/2/",
		"https://swapi.co/api/films/6/",
		"https://swapi.co/api/films/3/",
		"https://swapi.co/api/films/1/",
		"https://swapi.co/api/films/7/"
	],
	species: [
		"https://swapi.co/api/species/1/"
	],
	vehicles: [
		"https://swapi.co/api/vehicles/30/"
	],
	starships: [
	],
	created: "2014-12-10T15:20:09.791000Z",
	edited: "2014-12-20T21:17:50.315000Z",
	url: "https://swapi.co/api/people/5/"
},
	"https://swapi.co/api/people/6/": {
	name: "Owen Lars",
	height: "178",
	mass: "120",
	hair_color: "brown, grey",
	skin_color: "light",
	eye_color: "blue",
	birth_year: "52BBY",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/1/",
	films: [
		"https://swapi.co/api/films/5/",
		"https://swapi.co/api/films/6/",
		"https://swapi.co/api/films/1/"
	],
	species: [
		"https://swapi.co/api/species/1/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-10T15:52:14.024000Z",
	edited: "2014-12-20T21:17:50.317000Z",
	url: "https://swapi.co/api/people/6/"
},
	"https://swapi.co/api/people/7/": {
	name: "Beru Whitesun lars",
	height: "165",
	mass: "75",
	hair_color: "brown",
	skin_color: "light",
	eye_color: "blue",
	birth_year: "47BBY",
	gender: "female",
	homeworld: "https://swapi.co/api/planets/1/",
	films: [
		"https://swapi.co/api/films/5/",
		"https://swapi.co/api/films/6/",
		"https://swapi.co/api/films/1/"
	],
	species: [
		"https://swapi.co/api/species/1/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-10T15:53:41.121000Z",
	edited: "2014-12-20T21:17:50.319000Z",
	url: "https://swapi.co/api/people/7/"
},
	"https://swapi.co/api/people/8/": {
	name: "R5-D4",
	height: "97",
	mass: "32",
	hair_color: "n/a",
	skin_color: "white, red",
	eye_color: "red",
	birth_year: "unknown",
	gender: "n/a",
	homeworld: "https://swapi.co/api/planets/1/",
	films: [
		"https://swapi.co/api/films/1/"
	],
	species: [
		"https://swapi.co/api/species/2/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-10T15:57:50.959000Z",
	edited: "2014-12-20T21:17:50.321000Z",
	url: "https://swapi.co/api/people/8/"
},
	"https://swapi.co/api/people/9/": {
	name: "Biggs Darklighter",
	height: "183",
	mass: "84",
	hair_color: "black",
	skin_color: "light",
	eye_color: "brown",
	birth_year: "24BBY",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/1/",
	films: [
		"https://swapi.co/api/films/1/"
	],
	species: [
		"https://swapi.co/api/species/1/"
	],
	vehicles: [
	],
	starships: [
		"https://swapi.co/api/starships/12/"
	],
	created: "2014-12-10T15:59:50.509000Z",
	edited: "2014-12-20T21:17:50.323000Z",
	url: "https://swapi.co/api/people/9/"
},
	"https://swapi.co/api/people/10/": {
	name: "Obi-Wan Kenobi",
	height: "182",
	mass: "77",
	hair_color: "auburn, white",
	skin_color: "fair",
	eye_color: "blue-gray",
	birth_year: "57BBY",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/20/",
	films: [
		"https://swapi.co/api/films/2/",
		"https://swapi.co/api/films/5/",
		"https://swapi.co/api/films/4/",
		"https://swapi.co/api/films/6/",
		"https://swapi.co/api/films/3/",
		"https://swapi.co/api/films/1/"
	],
	species: [
		"https://swapi.co/api/species/1/"
	],
	vehicles: [
		"https://swapi.co/api/vehicles/38/"
	],
	starships: [
		"https://swapi.co/api/starships/48/",
		"https://swapi.co/api/starships/59/",
		"https://swapi.co/api/starships/64/",
		"https://swapi.co/api/starships/65/",
		"https://swapi.co/api/starships/74/"
	],
	created: "2014-12-10T16:16:29.192000Z",
	edited: "2014-12-20T21:17:50.325000Z",
	url: "https://swapi.co/api/people/10/"
},
	"https://swapi.co/api/people/?page=2": {
	count: 87,
	next: "https://swapi.co/api/people/?page=3",
	previous: "https://swapi.co/api/people/?page=1",
	results: [
		{
			name: "Anakin Skywalker",
			height: "188",
			mass: "84",
			hair_color: "blond",
			skin_color: "fair",
			eye_color: "blue",
			birth_year: "41.9BBY",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/1/",
			films: [
				"https://swapi.co/api/films/5/",
				"https://swapi.co/api/films/4/",
				"https://swapi.co/api/films/6/"
			],
			species: [
				"https://swapi.co/api/species/1/"
			],
			vehicles: [
				"https://swapi.co/api/vehicles/44/",
				"https://swapi.co/api/vehicles/46/"
			],
			starships: [
				"https://swapi.co/api/starships/59/",
				"https://swapi.co/api/starships/65/",
				"https://swapi.co/api/starships/39/"
			],
			created: "2014-12-10T16:20:44.310000Z",
			edited: "2014-12-20T21:17:50.327000Z",
			url: "https://swapi.co/api/people/11/"
		},
		{
			name: "Wilhuff Tarkin",
			height: "180",
			mass: "unknown",
			hair_color: "auburn, grey",
			skin_color: "fair",
			eye_color: "blue",
			birth_year: "64BBY",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/21/",
			films: [
				"https://swapi.co/api/films/6/",
				"https://swapi.co/api/films/1/"
			],
			species: [
				"https://swapi.co/api/species/1/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-10T16:26:56.138000Z",
			edited: "2014-12-20T21:17:50.330000Z",
			url: "https://swapi.co/api/people/12/"
		},
		{
			name: "Chewbacca",
			height: "228",
			mass: "112",
			hair_color: "brown",
			skin_color: "unknown",
			eye_color: "blue",
			birth_year: "200BBY",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/14/",
			films: [
				"https://swapi.co/api/films/2/",
				"https://swapi.co/api/films/6/",
				"https://swapi.co/api/films/3/",
				"https://swapi.co/api/films/1/",
				"https://swapi.co/api/films/7/"
			],
			species: [
				"https://swapi.co/api/species/3/"
			],
			vehicles: [
				"https://swapi.co/api/vehicles/19/"
			],
			starships: [
				"https://swapi.co/api/starships/10/",
				"https://swapi.co/api/starships/22/"
			],
			created: "2014-12-10T16:42:45.066000Z",
			edited: "2014-12-20T21:17:50.332000Z",
			url: "https://swapi.co/api/people/13/"
		},
		{
			name: "Han Solo",
			height: "180",
			mass: "80",
			hair_color: "brown",
			skin_color: "fair",
			eye_color: "brown",
			birth_year: "29BBY",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/22/",
			films: [
				"https://swapi.co/api/films/2/",
				"https://swapi.co/api/films/3/",
				"https://swapi.co/api/films/1/",
				"https://swapi.co/api/films/7/"
			],
			species: [
				"https://swapi.co/api/species/1/"
			],
			vehicles: [
			],
			starships: [
				"https://swapi.co/api/starships/10/",
				"https://swapi.co/api/starships/22/"
			],
			created: "2014-12-10T16:49:14.582000Z",
			edited: "2014-12-20T21:17:50.334000Z",
			url: "https://swapi.co/api/people/14/"
		},
		{
			name: "Greedo",
			height: "173",
			mass: "74",
			hair_color: "n/a",
			skin_color: "green",
			eye_color: "black",
			birth_year: "44BBY",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/23/",
			films: [
				"https://swapi.co/api/films/1/"
			],
			species: [
				"https://swapi.co/api/species/4/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-10T17:03:30.334000Z",
			edited: "2014-12-20T21:17:50.336000Z",
			url: "https://swapi.co/api/people/15/"
		},
		{
			name: "Jabba Desilijic Tiure",
			height: "175",
			mass: "1,358",
			hair_color: "n/a",
			skin_color: "green-tan, brown",
			eye_color: "orange",
			birth_year: "600BBY",
			gender: "hermaphrodite",
			homeworld: "https://swapi.co/api/planets/24/",
			films: [
				"https://swapi.co/api/films/4/",
				"https://swapi.co/api/films/3/",
				"https://swapi.co/api/films/1/"
			],
			species: [
				"https://swapi.co/api/species/5/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-10T17:11:31.638000Z",
			edited: "2014-12-20T21:17:50.338000Z",
			url: "https://swapi.co/api/people/16/"
		},
		{
			name: "Wedge Antilles",
			height: "170",
			mass: "77",
			hair_color: "brown",
			skin_color: "fair",
			eye_color: "hazel",
			birth_year: "21BBY",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/22/",
			films: [
				"https://swapi.co/api/films/2/",
				"https://swapi.co/api/films/3/",
				"https://swapi.co/api/films/1/"
			],
			species: [
				"https://swapi.co/api/species/1/"
			],
			vehicles: [
				"https://swapi.co/api/vehicles/14/"
			],
			starships: [
				"https://swapi.co/api/starships/12/"
			],
			created: "2014-12-12T11:08:06.469000Z",
			edited: "2014-12-20T21:17:50.341000Z",
			url: "https://swapi.co/api/people/18/"
		},
		{
			name: "Jek Tono Porkins",
			height: "180",
			mass: "110",
			hair_color: "brown",
			skin_color: "fair",
			eye_color: "blue",
			birth_year: "unknown",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/26/",
			films: [
				"https://swapi.co/api/films/1/"
			],
			species: [
				"https://swapi.co/api/species/1/"
			],
			vehicles: [
			],
			starships: [
				"https://swapi.co/api/starships/12/"
			],
			created: "2014-12-12T11:16:56.569000Z",
			edited: "2014-12-20T21:17:50.343000Z",
			url: "https://swapi.co/api/people/19/"
		},
		{
			name: "Yoda",
			height: "66",
			mass: "17",
			hair_color: "white",
			skin_color: "green",
			eye_color: "brown",
			birth_year: "896BBY",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/28/",
			films: [
				"https://swapi.co/api/films/2/",
				"https://swapi.co/api/films/5/",
				"https://swapi.co/api/films/4/",
				"https://swapi.co/api/films/6/",
				"https://swapi.co/api/films/3/"
			],
			species: [
				"https://swapi.co/api/species/6/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-15T12:26:01.042000Z",
			edited: "2014-12-20T21:17:50.345000Z",
			url: "https://swapi.co/api/people/20/"
		},
		{
			name: "Palpatine",
			height: "170",
			mass: "75",
			hair_color: "grey",
			skin_color: "pale",
			eye_color: "yellow",
			birth_year: "82BBY",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/8/",
			films: [
				"https://swapi.co/api/films/2/",
				"https://swapi.co/api/films/5/",
				"https://swapi.co/api/films/4/",
				"https://swapi.co/api/films/6/",
				"https://swapi.co/api/films/3/"
			],
			species: [
				"https://swapi.co/api/species/1/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-15T12:48:05.971000Z",
			edited: "2014-12-20T21:17:50.347000Z",
			url: "https://swapi.co/api/people/21/"
		}
	]
},
	"https://swapi.co/api/people/11/": {
	name: "Anakin Skywalker",
	height: "188",
	mass: "84",
	hair_color: "blond",
	skin_color: "fair",
	eye_color: "blue",
	birth_year: "41.9BBY",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/1/",
	films: [
		"https://swapi.co/api/films/5/",
		"https://swapi.co/api/films/4/",
		"https://swapi.co/api/films/6/"
	],
	species: [
		"https://swapi.co/api/species/1/"
	],
	vehicles: [
		"https://swapi.co/api/vehicles/44/",
		"https://swapi.co/api/vehicles/46/"
	],
	starships: [
		"https://swapi.co/api/starships/59/",
		"https://swapi.co/api/starships/65/",
		"https://swapi.co/api/starships/39/"
	],
	created: "2014-12-10T16:20:44.310000Z",
	edited: "2014-12-20T21:17:50.327000Z",
	url: "https://swapi.co/api/people/11/"
},
	"https://swapi.co/api/people/12/": {
	name: "Wilhuff Tarkin",
	height: "180",
	mass: "unknown",
	hair_color: "auburn, grey",
	skin_color: "fair",
	eye_color: "blue",
	birth_year: "64BBY",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/21/",
	films: [
		"https://swapi.co/api/films/6/",
		"https://swapi.co/api/films/1/"
	],
	species: [
		"https://swapi.co/api/species/1/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-10T16:26:56.138000Z",
	edited: "2014-12-20T21:17:50.330000Z",
	url: "https://swapi.co/api/people/12/"
},
	"https://swapi.co/api/people/13/": {
	name: "Chewbacca",
	height: "228",
	mass: "112",
	hair_color: "brown",
	skin_color: "unknown",
	eye_color: "blue",
	birth_year: "200BBY",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/14/",
	films: [
		"https://swapi.co/api/films/2/",
		"https://swapi.co/api/films/6/",
		"https://swapi.co/api/films/3/",
		"https://swapi.co/api/films/1/",
		"https://swapi.co/api/films/7/"
	],
	species: [
		"https://swapi.co/api/species/3/"
	],
	vehicles: [
		"https://swapi.co/api/vehicles/19/"
	],
	starships: [
		"https://swapi.co/api/starships/10/",
		"https://swapi.co/api/starships/22/"
	],
	created: "2014-12-10T16:42:45.066000Z",
	edited: "2014-12-20T21:17:50.332000Z",
	url: "https://swapi.co/api/people/13/"
},
	"https://swapi.co/api/people/14/": {
	name: "Han Solo",
	height: "180",
	mass: "80",
	hair_color: "brown",
	skin_color: "fair",
	eye_color: "brown",
	birth_year: "29BBY",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/22/",
	films: [
		"https://swapi.co/api/films/2/",
		"https://swapi.co/api/films/3/",
		"https://swapi.co/api/films/1/",
		"https://swapi.co/api/films/7/"
	],
	species: [
		"https://swapi.co/api/species/1/"
	],
	vehicles: [
	],
	starships: [
		"https://swapi.co/api/starships/10/",
		"https://swapi.co/api/starships/22/"
	],
	created: "2014-12-10T16:49:14.582000Z",
	edited: "2014-12-20T21:17:50.334000Z",
	url: "https://swapi.co/api/people/14/"
},
	"https://swapi.co/api/people/15/": {
	name: "Greedo",
	height: "173",
	mass: "74",
	hair_color: "n/a",
	skin_color: "green",
	eye_color: "black",
	birth_year: "44BBY",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/23/",
	films: [
		"https://swapi.co/api/films/1/"
	],
	species: [
		"https://swapi.co/api/species/4/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-10T17:03:30.334000Z",
	edited: "2014-12-20T21:17:50.336000Z",
	url: "https://swapi.co/api/people/15/"
},
	"https://swapi.co/api/people/16/": {
	name: "Jabba Desilijic Tiure",
	height: "175",
	mass: "1,358",
	hair_color: "n/a",
	skin_color: "green-tan, brown",
	eye_color: "orange",
	birth_year: "600BBY",
	gender: "hermaphrodite",
	homeworld: "https://swapi.co/api/planets/24/",
	films: [
		"https://swapi.co/api/films/4/",
		"https://swapi.co/api/films/3/",
		"https://swapi.co/api/films/1/"
	],
	species: [
		"https://swapi.co/api/species/5/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-10T17:11:31.638000Z",
	edited: "2014-12-20T21:17:50.338000Z",
	url: "https://swapi.co/api/people/16/"
},
	"https://swapi.co/api/people/18/": {
	name: "Wedge Antilles",
	height: "170",
	mass: "77",
	hair_color: "brown",
	skin_color: "fair",
	eye_color: "hazel",
	birth_year: "21BBY",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/22/",
	films: [
		"https://swapi.co/api/films/2/",
		"https://swapi.co/api/films/3/",
		"https://swapi.co/api/films/1/"
	],
	species: [
		"https://swapi.co/api/species/1/"
	],
	vehicles: [
		"https://swapi.co/api/vehicles/14/"
	],
	starships: [
		"https://swapi.co/api/starships/12/"
	],
	created: "2014-12-12T11:08:06.469000Z",
	edited: "2014-12-20T21:17:50.341000Z",
	url: "https://swapi.co/api/people/18/"
},
	"https://swapi.co/api/people/19/": {
	name: "Jek Tono Porkins",
	height: "180",
	mass: "110",
	hair_color: "brown",
	skin_color: "fair",
	eye_color: "blue",
	birth_year: "unknown",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/26/",
	films: [
		"https://swapi.co/api/films/1/"
	],
	species: [
		"https://swapi.co/api/species/1/"
	],
	vehicles: [
	],
	starships: [
		"https://swapi.co/api/starships/12/"
	],
	created: "2014-12-12T11:16:56.569000Z",
	edited: "2014-12-20T21:17:50.343000Z",
	url: "https://swapi.co/api/people/19/"
},
	"https://swapi.co/api/people/20/": {
	name: "Yoda",
	height: "66",
	mass: "17",
	hair_color: "white",
	skin_color: "green",
	eye_color: "brown",
	birth_year: "896BBY",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/28/",
	films: [
		"https://swapi.co/api/films/2/",
		"https://swapi.co/api/films/5/",
		"https://swapi.co/api/films/4/",
		"https://swapi.co/api/films/6/",
		"https://swapi.co/api/films/3/"
	],
	species: [
		"https://swapi.co/api/species/6/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-15T12:26:01.042000Z",
	edited: "2014-12-20T21:17:50.345000Z",
	url: "https://swapi.co/api/people/20/"
},
	"https://swapi.co/api/people/21/": {
	name: "Palpatine",
	height: "170",
	mass: "75",
	hair_color: "grey",
	skin_color: "pale",
	eye_color: "yellow",
	birth_year: "82BBY",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/8/",
	films: [
		"https://swapi.co/api/films/2/",
		"https://swapi.co/api/films/5/",
		"https://swapi.co/api/films/4/",
		"https://swapi.co/api/films/6/",
		"https://swapi.co/api/films/3/"
	],
	species: [
		"https://swapi.co/api/species/1/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-15T12:48:05.971000Z",
	edited: "2014-12-20T21:17:50.347000Z",
	url: "https://swapi.co/api/people/21/"
},
	"https://swapi.co/api/people/?page=3": {
	count: 87,
	next: "https://swapi.co/api/people/?page=4",
	previous: "https://swapi.co/api/people/?page=2",
	results: [
		{
			name: "Boba Fett",
			height: "183",
			mass: "78.2",
			hair_color: "black",
			skin_color: "fair",
			eye_color: "brown",
			birth_year: "31.5BBY",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/10/",
			films: [
				"https://swapi.co/api/films/2/",
				"https://swapi.co/api/films/5/",
				"https://swapi.co/api/films/3/"
			],
			species: [
				"https://swapi.co/api/species/1/"
			],
			vehicles: [
			],
			starships: [
				"https://swapi.co/api/starships/21/"
			],
			created: "2014-12-15T12:49:32.457000Z",
			edited: "2014-12-20T21:17:50.349000Z",
			url: "https://swapi.co/api/people/22/"
		},
		{
			name: "IG-88",
			height: "200",
			mass: "140",
			hair_color: "none",
			skin_color: "metal",
			eye_color: "red",
			birth_year: "15BBY",
			gender: "none",
			homeworld: "https://swapi.co/api/planets/28/",
			films: [
				"https://swapi.co/api/films/2/"
			],
			species: [
				"https://swapi.co/api/species/2/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-15T12:51:10.076000Z",
			edited: "2014-12-20T21:17:50.351000Z",
			url: "https://swapi.co/api/people/23/"
		},
		{
			name: "Bossk",
			height: "190",
			mass: "113",
			hair_color: "none",
			skin_color: "green",
			eye_color: "red",
			birth_year: "53BBY",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/29/",
			films: [
				"https://swapi.co/api/films/2/"
			],
			species: [
				"https://swapi.co/api/species/7/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-15T12:53:49.297000Z",
			edited: "2014-12-20T21:17:50.355000Z",
			url: "https://swapi.co/api/people/24/"
		},
		{
			name: "Lando Calrissian",
			height: "177",
			mass: "79",
			hair_color: "black",
			skin_color: "dark",
			eye_color: "brown",
			birth_year: "31BBY",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/30/",
			films: [
				"https://swapi.co/api/films/2/",
				"https://swapi.co/api/films/3/"
			],
			species: [
				"https://swapi.co/api/species/1/"
			],
			vehicles: [
			],
			starships: [
				"https://swapi.co/api/starships/10/"
			],
			created: "2014-12-15T12:56:32.683000Z",
			edited: "2014-12-20T21:17:50.357000Z",
			url: "https://swapi.co/api/people/25/"
		},
		{
			name: "Lobot",
			height: "175",
			mass: "79",
			hair_color: "none",
			skin_color: "light",
			eye_color: "blue",
			birth_year: "37BBY",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/6/",
			films: [
				"https://swapi.co/api/films/2/"
			],
			species: [
				"https://swapi.co/api/species/1/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-15T13:01:57.178000Z",
			edited: "2014-12-20T21:17:50.359000Z",
			url: "https://swapi.co/api/people/26/"
		},
		{
			name: "Ackbar",
			height: "180",
			mass: "83",
			hair_color: "none",
			skin_color: "brown mottle",
			eye_color: "orange",
			birth_year: "41BBY",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/31/",
			films: [
				"https://swapi.co/api/films/3/",
				"https://swapi.co/api/films/7/"
			],
			species: [
				"https://swapi.co/api/species/8/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-18T11:07:50.584000Z",
			edited: "2014-12-20T21:17:50.362000Z",
			url: "https://swapi.co/api/people/27/"
		},
		{
			name: "Mon Mothma",
			height: "150",
			mass: "unknown",
			hair_color: "auburn",
			skin_color: "fair",
			eye_color: "blue",
			birth_year: "48BBY",
			gender: "female",
			homeworld: "https://swapi.co/api/planets/32/",
			films: [
				"https://swapi.co/api/films/3/"
			],
			species: [
				"https://swapi.co/api/species/1/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-18T11:12:38.895000Z",
			edited: "2014-12-20T21:17:50.364000Z",
			url: "https://swapi.co/api/people/28/"
		},
		{
			name: "Arvel Crynyd",
			height: "unknown",
			mass: "unknown",
			hair_color: "brown",
			skin_color: "fair",
			eye_color: "brown",
			birth_year: "unknown",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/28/",
			films: [
				"https://swapi.co/api/films/3/"
			],
			species: [
				"https://swapi.co/api/species/1/"
			],
			vehicles: [
			],
			starships: [
				"https://swapi.co/api/starships/28/"
			],
			created: "2014-12-18T11:16:33.020000Z",
			edited: "2014-12-20T21:17:50.367000Z",
			url: "https://swapi.co/api/people/29/"
		},
		{
			name: "Wicket Systri Warrick",
			height: "88",
			mass: "20",
			hair_color: "brown",
			skin_color: "brown",
			eye_color: "brown",
			birth_year: "8BBY",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/7/",
			films: [
				"https://swapi.co/api/films/3/"
			],
			species: [
				"https://swapi.co/api/species/9/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-18T11:21:58.954000Z",
			edited: "2014-12-20T21:17:50.369000Z",
			url: "https://swapi.co/api/people/30/"
		},
		{
			name: "Nien Nunb",
			height: "160",
			mass: "68",
			hair_color: "none",
			skin_color: "grey",
			eye_color: "black",
			birth_year: "unknown",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/33/",
			films: [
				"https://swapi.co/api/films/3/"
			],
			species: [
				"https://swapi.co/api/species/10/"
			],
			vehicles: [
			],
			starships: [
				"https://swapi.co/api/starships/10/"
			],
			created: "2014-12-18T11:26:18.541000Z",
			edited: "2014-12-20T21:17:50.371000Z",
			url: "https://swapi.co/api/people/31/"
		}
	]
},
	"https://swapi.co/api/people/22/": {
	name: "Boba Fett",
	height: "183",
	mass: "78.2",
	hair_color: "black",
	skin_color: "fair",
	eye_color: "brown",
	birth_year: "31.5BBY",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/10/",
	films: [
		"https://swapi.co/api/films/2/",
		"https://swapi.co/api/films/5/",
		"https://swapi.co/api/films/3/"
	],
	species: [
		"https://swapi.co/api/species/1/"
	],
	vehicles: [
	],
	starships: [
		"https://swapi.co/api/starships/21/"
	],
	created: "2014-12-15T12:49:32.457000Z",
	edited: "2014-12-20T21:17:50.349000Z",
	url: "https://swapi.co/api/people/22/"
},
	"https://swapi.co/api/people/23/": {
	name: "IG-88",
	height: "200",
	mass: "140",
	hair_color: "none",
	skin_color: "metal",
	eye_color: "red",
	birth_year: "15BBY",
	gender: "none",
	homeworld: "https://swapi.co/api/planets/28/",
	films: [
		"https://swapi.co/api/films/2/"
	],
	species: [
		"https://swapi.co/api/species/2/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-15T12:51:10.076000Z",
	edited: "2014-12-20T21:17:50.351000Z",
	url: "https://swapi.co/api/people/23/"
},
	"https://swapi.co/api/people/24/": {
	name: "Bossk",
	height: "190",
	mass: "113",
	hair_color: "none",
	skin_color: "green",
	eye_color: "red",
	birth_year: "53BBY",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/29/",
	films: [
		"https://swapi.co/api/films/2/"
	],
	species: [
		"https://swapi.co/api/species/7/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-15T12:53:49.297000Z",
	edited: "2014-12-20T21:17:50.355000Z",
	url: "https://swapi.co/api/people/24/"
},
	"https://swapi.co/api/people/25/": {
	name: "Lando Calrissian",
	height: "177",
	mass: "79",
	hair_color: "black",
	skin_color: "dark",
	eye_color: "brown",
	birth_year: "31BBY",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/30/",
	films: [
		"https://swapi.co/api/films/2/",
		"https://swapi.co/api/films/3/"
	],
	species: [
		"https://swapi.co/api/species/1/"
	],
	vehicles: [
	],
	starships: [
		"https://swapi.co/api/starships/10/"
	],
	created: "2014-12-15T12:56:32.683000Z",
	edited: "2014-12-20T21:17:50.357000Z",
	url: "https://swapi.co/api/people/25/"
},
	"https://swapi.co/api/people/26/": {
	name: "Lobot",
	height: "175",
	mass: "79",
	hair_color: "none",
	skin_color: "light",
	eye_color: "blue",
	birth_year: "37BBY",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/6/",
	films: [
		"https://swapi.co/api/films/2/"
	],
	species: [
		"https://swapi.co/api/species/1/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-15T13:01:57.178000Z",
	edited: "2014-12-20T21:17:50.359000Z",
	url: "https://swapi.co/api/people/26/"
},
	"https://swapi.co/api/people/27/": {
	name: "Ackbar",
	height: "180",
	mass: "83",
	hair_color: "none",
	skin_color: "brown mottle",
	eye_color: "orange",
	birth_year: "41BBY",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/31/",
	films: [
		"https://swapi.co/api/films/3/",
		"https://swapi.co/api/films/7/"
	],
	species: [
		"https://swapi.co/api/species/8/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-18T11:07:50.584000Z",
	edited: "2014-12-20T21:17:50.362000Z",
	url: "https://swapi.co/api/people/27/"
},
	"https://swapi.co/api/people/28/": {
	name: "Mon Mothma",
	height: "150",
	mass: "unknown",
	hair_color: "auburn",
	skin_color: "fair",
	eye_color: "blue",
	birth_year: "48BBY",
	gender: "female",
	homeworld: "https://swapi.co/api/planets/32/",
	films: [
		"https://swapi.co/api/films/3/"
	],
	species: [
		"https://swapi.co/api/species/1/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-18T11:12:38.895000Z",
	edited: "2014-12-20T21:17:50.364000Z",
	url: "https://swapi.co/api/people/28/"
},
	"https://swapi.co/api/people/29/": {
	name: "Arvel Crynyd",
	height: "unknown",
	mass: "unknown",
	hair_color: "brown",
	skin_color: "fair",
	eye_color: "brown",
	birth_year: "unknown",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/28/",
	films: [
		"https://swapi.co/api/films/3/"
	],
	species: [
		"https://swapi.co/api/species/1/"
	],
	vehicles: [
	],
	starships: [
		"https://swapi.co/api/starships/28/"
	],
	created: "2014-12-18T11:16:33.020000Z",
	edited: "2014-12-20T21:17:50.367000Z",
	url: "https://swapi.co/api/people/29/"
},
	"https://swapi.co/api/people/30/": {
	name: "Wicket Systri Warrick",
	height: "88",
	mass: "20",
	hair_color: "brown",
	skin_color: "brown",
	eye_color: "brown",
	birth_year: "8BBY",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/7/",
	films: [
		"https://swapi.co/api/films/3/"
	],
	species: [
		"https://swapi.co/api/species/9/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-18T11:21:58.954000Z",
	edited: "2014-12-20T21:17:50.369000Z",
	url: "https://swapi.co/api/people/30/"
},
	"https://swapi.co/api/people/31/": {
	name: "Nien Nunb",
	height: "160",
	mass: "68",
	hair_color: "none",
	skin_color: "grey",
	eye_color: "black",
	birth_year: "unknown",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/33/",
	films: [
		"https://swapi.co/api/films/3/"
	],
	species: [
		"https://swapi.co/api/species/10/"
	],
	vehicles: [
	],
	starships: [
		"https://swapi.co/api/starships/10/"
	],
	created: "2014-12-18T11:26:18.541000Z",
	edited: "2014-12-20T21:17:50.371000Z",
	url: "https://swapi.co/api/people/31/"
},
	"https://swapi.co/api/people/?page=4": {
	count: 87,
	next: "https://swapi.co/api/people/?page=5",
	previous: "https://swapi.co/api/people/?page=3",
	results: [
		{
			name: "Qui-Gon Jinn",
			height: "193",
			mass: "89",
			hair_color: "brown",
			skin_color: "fair",
			eye_color: "blue",
			birth_year: "92BBY",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/28/",
			films: [
				"https://swapi.co/api/films/4/"
			],
			species: [
				"https://swapi.co/api/species/1/"
			],
			vehicles: [
				"https://swapi.co/api/vehicles/38/"
			],
			starships: [
			],
			created: "2014-12-19T16:54:53.618000Z",
			edited: "2014-12-20T21:17:50.375000Z",
			url: "https://swapi.co/api/people/32/"
		},
		{
			name: "Nute Gunray",
			height: "191",
			mass: "90",
			hair_color: "none",
			skin_color: "mottled green",
			eye_color: "red",
			birth_year: "unknown",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/18/",
			films: [
				"https://swapi.co/api/films/5/",
				"https://swapi.co/api/films/4/",
				"https://swapi.co/api/films/6/"
			],
			species: [
				"https://swapi.co/api/species/11/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-19T17:05:57.357000Z",
			edited: "2014-12-20T21:17:50.377000Z",
			url: "https://swapi.co/api/people/33/"
		},
		{
			name: "Finis Valorum",
			height: "170",
			mass: "unknown",
			hair_color: "blond",
			skin_color: "fair",
			eye_color: "blue",
			birth_year: "91BBY",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/9/",
			films: [
				"https://swapi.co/api/films/4/"
			],
			species: [
				"https://swapi.co/api/species/1/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-19T17:21:45.915000Z",
			edited: "2014-12-20T21:17:50.379000Z",
			url: "https://swapi.co/api/people/34/"
		},
		{
			name: "Jar Jar Binks",
			height: "196",
			mass: "66",
			hair_color: "none",
			skin_color: "orange",
			eye_color: "orange",
			birth_year: "52BBY",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/8/",
			films: [
				"https://swapi.co/api/films/5/",
				"https://swapi.co/api/films/4/"
			],
			species: [
				"https://swapi.co/api/species/12/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-19T17:29:32.489000Z",
			edited: "2014-12-20T21:17:50.383000Z",
			url: "https://swapi.co/api/people/36/"
		},
		{
			name: "Roos Tarpals",
			height: "224",
			mass: "82",
			hair_color: "none",
			skin_color: "grey",
			eye_color: "orange",
			birth_year: "unknown",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/8/",
			films: [
				"https://swapi.co/api/films/4/"
			],
			species: [
				"https://swapi.co/api/species/12/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-19T17:32:56.741000Z",
			edited: "2014-12-20T21:17:50.385000Z",
			url: "https://swapi.co/api/people/37/"
		},
		{
			name: "Rugor Nass",
			height: "206",
			mass: "unknown",
			hair_color: "none",
			skin_color: "green",
			eye_color: "orange",
			birth_year: "unknown",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/8/",
			films: [
				"https://swapi.co/api/films/4/"
			],
			species: [
				"https://swapi.co/api/species/12/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-19T17:33:38.909000Z",
			edited: "2014-12-20T21:17:50.388000Z",
			url: "https://swapi.co/api/people/38/"
		},
		{
			name: "Ric Olié",
			height: "183",
			mass: "unknown",
			hair_color: "brown",
			skin_color: "fair",
			eye_color: "blue",
			birth_year: "unknown",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/8/",
			films: [
				"https://swapi.co/api/films/4/"
			],
			species: [
			],
			vehicles: [
			],
			starships: [
				"https://swapi.co/api/starships/40/"
			],
			created: "2014-12-19T17:45:01.522000Z",
			edited: "2014-12-20T21:17:50.392000Z",
			url: "https://swapi.co/api/people/39/"
		},
		{
			name: "Watto",
			height: "137",
			mass: "unknown",
			hair_color: "black",
			skin_color: "blue, grey",
			eye_color: "yellow",
			birth_year: "unknown",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/34/",
			films: [
				"https://swapi.co/api/films/5/",
				"https://swapi.co/api/films/4/"
			],
			species: [
				"https://swapi.co/api/species/13/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-19T17:48:54.647000Z",
			edited: "2014-12-20T21:17:50.395000Z",
			url: "https://swapi.co/api/people/40/"
		},
		{
			name: "Sebulba",
			height: "112",
			mass: "40",
			hair_color: "none",
			skin_color: "grey, red",
			eye_color: "orange",
			birth_year: "unknown",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/35/",
			films: [
				"https://swapi.co/api/films/4/"
			],
			species: [
				"https://swapi.co/api/species/14/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-19T17:53:02.586000Z",
			edited: "2014-12-20T21:17:50.397000Z",
			url: "https://swapi.co/api/people/41/"
		},
		{
			name: "Quarsh Panaka",
			height: "183",
			mass: "unknown",
			hair_color: "black",
			skin_color: "dark",
			eye_color: "brown",
			birth_year: "62BBY",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/8/",
			films: [
				"https://swapi.co/api/films/4/"
			],
			species: [
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-19T17:55:43.348000Z",
			edited: "2014-12-20T21:17:50.399000Z",
			url: "https://swapi.co/api/people/42/"
		}
	]
},
	"https://swapi.co/api/people/32/": {
	name: "Qui-Gon Jinn",
	height: "193",
	mass: "89",
	hair_color: "brown",
	skin_color: "fair",
	eye_color: "blue",
	birth_year: "92BBY",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/28/",
	films: [
		"https://swapi.co/api/films/4/"
	],
	species: [
		"https://swapi.co/api/species/1/"
	],
	vehicles: [
		"https://swapi.co/api/vehicles/38/"
	],
	starships: [
	],
	created: "2014-12-19T16:54:53.618000Z",
	edited: "2014-12-20T21:17:50.375000Z",
	url: "https://swapi.co/api/people/32/"
},
	"https://swapi.co/api/people/33/": {
	name: "Nute Gunray",
	height: "191",
	mass: "90",
	hair_color: "none",
	skin_color: "mottled green",
	eye_color: "red",
	birth_year: "unknown",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/18/",
	films: [
		"https://swapi.co/api/films/5/",
		"https://swapi.co/api/films/4/",
		"https://swapi.co/api/films/6/"
	],
	species: [
		"https://swapi.co/api/species/11/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-19T17:05:57.357000Z",
	edited: "2014-12-20T21:17:50.377000Z",
	url: "https://swapi.co/api/people/33/"
},
	"https://swapi.co/api/people/34/": {
	name: "Finis Valorum",
	height: "170",
	mass: "unknown",
	hair_color: "blond",
	skin_color: "fair",
	eye_color: "blue",
	birth_year: "91BBY",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/9/",
	films: [
		"https://swapi.co/api/films/4/"
	],
	species: [
		"https://swapi.co/api/species/1/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-19T17:21:45.915000Z",
	edited: "2014-12-20T21:17:50.379000Z",
	url: "https://swapi.co/api/people/34/"
},
	"https://swapi.co/api/people/36/": {
	name: "Jar Jar Binks",
	height: "196",
	mass: "66",
	hair_color: "none",
	skin_color: "orange",
	eye_color: "orange",
	birth_year: "52BBY",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/8/",
	films: [
		"https://swapi.co/api/films/5/",
		"https://swapi.co/api/films/4/"
	],
	species: [
		"https://swapi.co/api/species/12/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-19T17:29:32.489000Z",
	edited: "2014-12-20T21:17:50.383000Z",
	url: "https://swapi.co/api/people/36/"
},
	"https://swapi.co/api/people/37/": {
	name: "Roos Tarpals",
	height: "224",
	mass: "82",
	hair_color: "none",
	skin_color: "grey",
	eye_color: "orange",
	birth_year: "unknown",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/8/",
	films: [
		"https://swapi.co/api/films/4/"
	],
	species: [
		"https://swapi.co/api/species/12/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-19T17:32:56.741000Z",
	edited: "2014-12-20T21:17:50.385000Z",
	url: "https://swapi.co/api/people/37/"
},
	"https://swapi.co/api/people/38/": {
	name: "Rugor Nass",
	height: "206",
	mass: "unknown",
	hair_color: "none",
	skin_color: "green",
	eye_color: "orange",
	birth_year: "unknown",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/8/",
	films: [
		"https://swapi.co/api/films/4/"
	],
	species: [
		"https://swapi.co/api/species/12/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-19T17:33:38.909000Z",
	edited: "2014-12-20T21:17:50.388000Z",
	url: "https://swapi.co/api/people/38/"
},
	"https://swapi.co/api/people/39/": {
	name: "Ric Olié",
	height: "183",
	mass: "unknown",
	hair_color: "brown",
	skin_color: "fair",
	eye_color: "blue",
	birth_year: "unknown",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/8/",
	films: [
		"https://swapi.co/api/films/4/"
	],
	species: [
	],
	vehicles: [
	],
	starships: [
		"https://swapi.co/api/starships/40/"
	],
	created: "2014-12-19T17:45:01.522000Z",
	edited: "2014-12-20T21:17:50.392000Z",
	url: "https://swapi.co/api/people/39/"
},
	"https://swapi.co/api/people/40/": {
	name: "Watto",
	height: "137",
	mass: "unknown",
	hair_color: "black",
	skin_color: "blue, grey",
	eye_color: "yellow",
	birth_year: "unknown",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/34/",
	films: [
		"https://swapi.co/api/films/5/",
		"https://swapi.co/api/films/4/"
	],
	species: [
		"https://swapi.co/api/species/13/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-19T17:48:54.647000Z",
	edited: "2014-12-20T21:17:50.395000Z",
	url: "https://swapi.co/api/people/40/"
},
	"https://swapi.co/api/people/41/": {
	name: "Sebulba",
	height: "112",
	mass: "40",
	hair_color: "none",
	skin_color: "grey, red",
	eye_color: "orange",
	birth_year: "unknown",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/35/",
	films: [
		"https://swapi.co/api/films/4/"
	],
	species: [
		"https://swapi.co/api/species/14/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-19T17:53:02.586000Z",
	edited: "2014-12-20T21:17:50.397000Z",
	url: "https://swapi.co/api/people/41/"
},
	"https://swapi.co/api/people/42/": {
	name: "Quarsh Panaka",
	height: "183",
	mass: "unknown",
	hair_color: "black",
	skin_color: "dark",
	eye_color: "brown",
	birth_year: "62BBY",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/8/",
	films: [
		"https://swapi.co/api/films/4/"
	],
	species: [
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-19T17:55:43.348000Z",
	edited: "2014-12-20T21:17:50.399000Z",
	url: "https://swapi.co/api/people/42/"
},
	"https://swapi.co/api/people/?page=5": {
	count: 87,
	next: "https://swapi.co/api/people/?page=6",
	previous: "https://swapi.co/api/people/?page=4",
	results: [
		{
			name: "Shmi Skywalker",
			height: "163",
			mass: "unknown",
			hair_color: "black",
			skin_color: "fair",
			eye_color: "brown",
			birth_year: "72BBY",
			gender: "female",
			homeworld: "https://swapi.co/api/planets/1/",
			films: [
				"https://swapi.co/api/films/5/",
				"https://swapi.co/api/films/4/"
			],
			species: [
				"https://swapi.co/api/species/1/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-19T17:57:41.191000Z",
			edited: "2014-12-20T21:17:50.401000Z",
			url: "https://swapi.co/api/people/43/"
		},
		{
			name: "Darth Maul",
			height: "175",
			mass: "80",
			hair_color: "none",
			skin_color: "red",
			eye_color: "yellow",
			birth_year: "54BBY",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/36/",
			films: [
				"https://swapi.co/api/films/4/"
			],
			species: [
				"https://swapi.co/api/species/22/"
			],
			vehicles: [
				"https://swapi.co/api/vehicles/42/"
			],
			starships: [
				"https://swapi.co/api/starships/41/"
			],
			created: "2014-12-19T18:00:41.929000Z",
			edited: "2014-12-20T21:17:50.403000Z",
			url: "https://swapi.co/api/people/44/"
		},
		{
			name: "Bib Fortuna",
			height: "180",
			mass: "unknown",
			hair_color: "none",
			skin_color: "pale",
			eye_color: "pink",
			birth_year: "unknown",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/37/",
			films: [
				"https://swapi.co/api/films/3/"
			],
			species: [
				"https://swapi.co/api/species/15/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-20T09:47:02.512000Z",
			edited: "2014-12-20T21:17:50.407000Z",
			url: "https://swapi.co/api/people/45/"
		},
		{
			name: "Ayla Secura",
			height: "178",
			mass: "55",
			hair_color: "none",
			skin_color: "blue",
			eye_color: "hazel",
			birth_year: "48BBY",
			gender: "female",
			homeworld: "https://swapi.co/api/planets/37/",
			films: [
				"https://swapi.co/api/films/5/",
				"https://swapi.co/api/films/4/",
				"https://swapi.co/api/films/6/"
			],
			species: [
				"https://swapi.co/api/species/15/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-20T09:48:01.172000Z",
			edited: "2014-12-20T21:17:50.409000Z",
			url: "https://swapi.co/api/people/46/"
		},
		{
			name: "Dud Bolt",
			height: "94",
			mass: "45",
			hair_color: "none",
			skin_color: "blue, grey",
			eye_color: "yellow",
			birth_year: "unknown",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/39/",
			films: [
				"https://swapi.co/api/films/4/"
			],
			species: [
				"https://swapi.co/api/species/17/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-20T09:57:31.858000Z",
			edited: "2014-12-20T21:17:50.414000Z",
			url: "https://swapi.co/api/people/48/"
		},
		{
			name: "Gasgano",
			height: "122",
			mass: "unknown",
			hair_color: "none",
			skin_color: "white, blue",
			eye_color: "black",
			birth_year: "unknown",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/40/",
			films: [
				"https://swapi.co/api/films/4/"
			],
			species: [
				"https://swapi.co/api/species/18/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-20T10:02:12.223000Z",
			edited: "2014-12-20T21:17:50.416000Z",
			url: "https://swapi.co/api/people/49/"
		},
		{
			name: "Ben Quadinaros",
			height: "163",
			mass: "65",
			hair_color: "none",
			skin_color: "grey, green, yellow",
			eye_color: "orange",
			birth_year: "unknown",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/41/",
			films: [
				"https://swapi.co/api/films/4/"
			],
			species: [
				"https://swapi.co/api/species/19/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-20T10:08:33.777000Z",
			edited: "2014-12-20T21:17:50.417000Z",
			url: "https://swapi.co/api/people/50/"
		},
		{
			name: "Mace Windu",
			height: "188",
			mass: "84",
			hair_color: "none",
			skin_color: "dark",
			eye_color: "brown",
			birth_year: "72BBY",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/42/",
			films: [
				"https://swapi.co/api/films/5/",
				"https://swapi.co/api/films/4/",
				"https://swapi.co/api/films/6/"
			],
			species: [
				"https://swapi.co/api/species/1/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-20T10:12:30.846000Z",
			edited: "2014-12-20T21:17:50.420000Z",
			url: "https://swapi.co/api/people/51/"
		},
		{
			name: "Ki-Adi-Mundi",
			height: "198",
			mass: "82",
			hair_color: "white",
			skin_color: "pale",
			eye_color: "yellow",
			birth_year: "92BBY",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/43/",
			films: [
				"https://swapi.co/api/films/5/",
				"https://swapi.co/api/films/4/",
				"https://swapi.co/api/films/6/"
			],
			species: [
				"https://swapi.co/api/species/20/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-20T10:15:32.293000Z",
			edited: "2014-12-20T21:17:50.422000Z",
			url: "https://swapi.co/api/people/52/"
		},
		{
			name: "Kit Fisto",
			height: "196",
			mass: "87",
			hair_color: "none",
			skin_color: "green",
			eye_color: "black",
			birth_year: "unknown",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/44/",
			films: [
				"https://swapi.co/api/films/5/",
				"https://swapi.co/api/films/4/",
				"https://swapi.co/api/films/6/"
			],
			species: [
				"https://swapi.co/api/species/21/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-20T10:18:57.202000Z",
			edited: "2014-12-20T21:17:50.424000Z",
			url: "https://swapi.co/api/people/53/"
		}
	]
},
	"https://swapi.co/api/people/43/": {
	name: "Shmi Skywalker",
	height: "163",
	mass: "unknown",
	hair_color: "black",
	skin_color: "fair",
	eye_color: "brown",
	birth_year: "72BBY",
	gender: "female",
	homeworld: "https://swapi.co/api/planets/1/",
	films: [
		"https://swapi.co/api/films/5/",
		"https://swapi.co/api/films/4/"
	],
	species: [
		"https://swapi.co/api/species/1/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-19T17:57:41.191000Z",
	edited: "2014-12-20T21:17:50.401000Z",
	url: "https://swapi.co/api/people/43/"
},
	"https://swapi.co/api/people/44/": {
	name: "Darth Maul",
	height: "175",
	mass: "80",
	hair_color: "none",
	skin_color: "red",
	eye_color: "yellow",
	birth_year: "54BBY",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/36/",
	films: [
		"https://swapi.co/api/films/4/"
	],
	species: [
		"https://swapi.co/api/species/22/"
	],
	vehicles: [
		"https://swapi.co/api/vehicles/42/"
	],
	starships: [
		"https://swapi.co/api/starships/41/"
	],
	created: "2014-12-19T18:00:41.929000Z",
	edited: "2014-12-20T21:17:50.403000Z",
	url: "https://swapi.co/api/people/44/"
},
	"https://swapi.co/api/people/45/": {
	name: "Bib Fortuna",
	height: "180",
	mass: "unknown",
	hair_color: "none",
	skin_color: "pale",
	eye_color: "pink",
	birth_year: "unknown",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/37/",
	films: [
		"https://swapi.co/api/films/3/"
	],
	species: [
		"https://swapi.co/api/species/15/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-20T09:47:02.512000Z",
	edited: "2014-12-20T21:17:50.407000Z",
	url: "https://swapi.co/api/people/45/"
},
	"https://swapi.co/api/people/46/": {
	name: "Ayla Secura",
	height: "178",
	mass: "55",
	hair_color: "none",
	skin_color: "blue",
	eye_color: "hazel",
	birth_year: "48BBY",
	gender: "female",
	homeworld: "https://swapi.co/api/planets/37/",
	films: [
		"https://swapi.co/api/films/5/",
		"https://swapi.co/api/films/4/",
		"https://swapi.co/api/films/6/"
	],
	species: [
		"https://swapi.co/api/species/15/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-20T09:48:01.172000Z",
	edited: "2014-12-20T21:17:50.409000Z",
	url: "https://swapi.co/api/people/46/"
},
	"https://swapi.co/api/people/48/": {
	name: "Dud Bolt",
	height: "94",
	mass: "45",
	hair_color: "none",
	skin_color: "blue, grey",
	eye_color: "yellow",
	birth_year: "unknown",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/39/",
	films: [
		"https://swapi.co/api/films/4/"
	],
	species: [
		"https://swapi.co/api/species/17/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-20T09:57:31.858000Z",
	edited: "2014-12-20T21:17:50.414000Z",
	url: "https://swapi.co/api/people/48/"
},
	"https://swapi.co/api/people/49/": {
	name: "Gasgano",
	height: "122",
	mass: "unknown",
	hair_color: "none",
	skin_color: "white, blue",
	eye_color: "black",
	birth_year: "unknown",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/40/",
	films: [
		"https://swapi.co/api/films/4/"
	],
	species: [
		"https://swapi.co/api/species/18/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-20T10:02:12.223000Z",
	edited: "2014-12-20T21:17:50.416000Z",
	url: "https://swapi.co/api/people/49/"
},
	"https://swapi.co/api/people/50/": {
	name: "Ben Quadinaros",
	height: "163",
	mass: "65",
	hair_color: "none",
	skin_color: "grey, green, yellow",
	eye_color: "orange",
	birth_year: "unknown",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/41/",
	films: [
		"https://swapi.co/api/films/4/"
	],
	species: [
		"https://swapi.co/api/species/19/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-20T10:08:33.777000Z",
	edited: "2014-12-20T21:17:50.417000Z",
	url: "https://swapi.co/api/people/50/"
},
	"https://swapi.co/api/people/51/": {
	name: "Mace Windu",
	height: "188",
	mass: "84",
	hair_color: "none",
	skin_color: "dark",
	eye_color: "brown",
	birth_year: "72BBY",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/42/",
	films: [
		"https://swapi.co/api/films/5/",
		"https://swapi.co/api/films/4/",
		"https://swapi.co/api/films/6/"
	],
	species: [
		"https://swapi.co/api/species/1/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-20T10:12:30.846000Z",
	edited: "2014-12-20T21:17:50.420000Z",
	url: "https://swapi.co/api/people/51/"
},
	"https://swapi.co/api/people/52/": {
	name: "Ki-Adi-Mundi",
	height: "198",
	mass: "82",
	hair_color: "white",
	skin_color: "pale",
	eye_color: "yellow",
	birth_year: "92BBY",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/43/",
	films: [
		"https://swapi.co/api/films/5/",
		"https://swapi.co/api/films/4/",
		"https://swapi.co/api/films/6/"
	],
	species: [
		"https://swapi.co/api/species/20/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-20T10:15:32.293000Z",
	edited: "2014-12-20T21:17:50.422000Z",
	url: "https://swapi.co/api/people/52/"
},
	"https://swapi.co/api/people/53/": {
	name: "Kit Fisto",
	height: "196",
	mass: "87",
	hair_color: "none",
	skin_color: "green",
	eye_color: "black",
	birth_year: "unknown",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/44/",
	films: [
		"https://swapi.co/api/films/5/",
		"https://swapi.co/api/films/4/",
		"https://swapi.co/api/films/6/"
	],
	species: [
		"https://swapi.co/api/species/21/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-20T10:18:57.202000Z",
	edited: "2014-12-20T21:17:50.424000Z",
	url: "https://swapi.co/api/people/53/"
},
	"https://swapi.co/api/people/?page=6": {
	count: 87,
	next: "https://swapi.co/api/people/?page=7",
	previous: "https://swapi.co/api/people/?page=5",
	results: [
		{
			name: "Eeth Koth",
			height: "171",
			mass: "unknown",
			hair_color: "black",
			skin_color: "brown",
			eye_color: "brown",
			birth_year: "unknown",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/45/",
			films: [
				"https://swapi.co/api/films/4/",
				"https://swapi.co/api/films/6/"
			],
			species: [
				"https://swapi.co/api/species/22/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-20T10:26:47.902000Z",
			edited: "2014-12-20T21:17:50.427000Z",
			url: "https://swapi.co/api/people/54/"
		},
		{
			name: "Adi Gallia",
			height: "184",
			mass: "50",
			hair_color: "none",
			skin_color: "dark",
			eye_color: "blue",
			birth_year: "unknown",
			gender: "female",
			homeworld: "https://swapi.co/api/planets/9/",
			films: [
				"https://swapi.co/api/films/4/",
				"https://swapi.co/api/films/6/"
			],
			species: [
				"https://swapi.co/api/species/23/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-20T10:29:11.661000Z",
			edited: "2014-12-20T21:17:50.432000Z",
			url: "https://swapi.co/api/people/55/"
		},
		{
			name: "Saesee Tiin",
			height: "188",
			mass: "unknown",
			hair_color: "none",
			skin_color: "pale",
			eye_color: "orange",
			birth_year: "unknown",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/47/",
			films: [
				"https://swapi.co/api/films/4/",
				"https://swapi.co/api/films/6/"
			],
			species: [
				"https://swapi.co/api/species/24/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-20T10:32:11.669000Z",
			edited: "2014-12-20T21:17:50.434000Z",
			url: "https://swapi.co/api/people/56/"
		},
		{
			name: "Yarael Poof",
			height: "264",
			mass: "unknown",
			hair_color: "none",
			skin_color: "white",
			eye_color: "yellow",
			birth_year: "unknown",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/48/",
			films: [
				"https://swapi.co/api/films/4/"
			],
			species: [
				"https://swapi.co/api/species/25/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-20T10:34:48.725000Z",
			edited: "2014-12-20T21:17:50.437000Z",
			url: "https://swapi.co/api/people/57/"
		},
		{
			name: "Plo Koon",
			height: "188",
			mass: "80",
			hair_color: "none",
			skin_color: "orange",
			eye_color: "black",
			birth_year: "22BBY",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/49/",
			films: [
				"https://swapi.co/api/films/5/",
				"https://swapi.co/api/films/4/",
				"https://swapi.co/api/films/6/"
			],
			species: [
				"https://swapi.co/api/species/26/"
			],
			vehicles: [
			],
			starships: [
				"https://swapi.co/api/starships/48/"
			],
			created: "2014-12-20T10:49:19.859000Z",
			edited: "2014-12-20T21:17:50.439000Z",
			url: "https://swapi.co/api/people/58/"
		},
		{
			name: "Mas Amedda",
			height: "196",
			mass: "unknown",
			hair_color: "none",
			skin_color: "blue",
			eye_color: "blue",
			birth_year: "unknown",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/50/",
			films: [
				"https://swapi.co/api/films/5/",
				"https://swapi.co/api/films/4/"
			],
			species: [
				"https://swapi.co/api/species/27/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-20T10:53:26.457000Z",
			edited: "2014-12-20T21:17:50.442000Z",
			url: "https://swapi.co/api/people/59/"
		},
		{
			name: "Gregar Typho",
			height: "185",
			mass: "85",
			hair_color: "black",
			skin_color: "dark",
			eye_color: "brown",
			birth_year: "unknown",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/8/",
			films: [
				"https://swapi.co/api/films/5/"
			],
			species: [
				"https://swapi.co/api/species/1/"
			],
			vehicles: [
			],
			starships: [
				"https://swapi.co/api/starships/39/"
			],
			created: "2014-12-20T11:10:10.381000Z",
			edited: "2014-12-20T21:17:50.445000Z",
			url: "https://swapi.co/api/people/60/"
		},
		{
			name: "Cordé",
			height: "157",
			mass: "unknown",
			hair_color: "brown",
			skin_color: "light",
			eye_color: "brown",
			birth_year: "unknown",
			gender: "female",
			homeworld: "https://swapi.co/api/planets/8/",
			films: [
				"https://swapi.co/api/films/5/"
			],
			species: [
				"https://swapi.co/api/species/1/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-20T11:11:39.630000Z",
			edited: "2014-12-20T21:17:50.449000Z",
			url: "https://swapi.co/api/people/61/"
		},
		{
			name: "Cliegg Lars",
			height: "183",
			mass: "unknown",
			hair_color: "brown",
			skin_color: "fair",
			eye_color: "blue",
			birth_year: "82BBY",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/1/",
			films: [
				"https://swapi.co/api/films/5/"
			],
			species: [
				"https://swapi.co/api/species/1/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-20T15:59:03.958000Z",
			edited: "2014-12-20T21:17:50.451000Z",
			url: "https://swapi.co/api/people/62/"
		},
		{
			name: "Poggle the Lesser",
			height: "183",
			mass: "80",
			hair_color: "none",
			skin_color: "green",
			eye_color: "yellow",
			birth_year: "unknown",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/11/",
			films: [
				"https://swapi.co/api/films/5/",
				"https://swapi.co/api/films/6/"
			],
			species: [
				"https://swapi.co/api/species/28/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-20T16:40:43.977000Z",
			edited: "2014-12-20T21:17:50.453000Z",
			url: "https://swapi.co/api/people/63/"
		}
	]
},
	"https://swapi.co/api/people/54/": {
	name: "Eeth Koth",
	height: "171",
	mass: "unknown",
	hair_color: "black",
	skin_color: "brown",
	eye_color: "brown",
	birth_year: "unknown",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/45/",
	films: [
		"https://swapi.co/api/films/4/",
		"https://swapi.co/api/films/6/"
	],
	species: [
		"https://swapi.co/api/species/22/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-20T10:26:47.902000Z",
	edited: "2014-12-20T21:17:50.427000Z",
	url: "https://swapi.co/api/people/54/"
},
	"https://swapi.co/api/people/55/": {
	name: "Adi Gallia",
	height: "184",
	mass: "50",
	hair_color: "none",
	skin_color: "dark",
	eye_color: "blue",
	birth_year: "unknown",
	gender: "female",
	homeworld: "https://swapi.co/api/planets/9/",
	films: [
		"https://swapi.co/api/films/4/",
		"https://swapi.co/api/films/6/"
	],
	species: [
		"https://swapi.co/api/species/23/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-20T10:29:11.661000Z",
	edited: "2014-12-20T21:17:50.432000Z",
	url: "https://swapi.co/api/people/55/"
},
	"https://swapi.co/api/people/56/": {
	name: "Saesee Tiin",
	height: "188",
	mass: "unknown",
	hair_color: "none",
	skin_color: "pale",
	eye_color: "orange",
	birth_year: "unknown",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/47/",
	films: [
		"https://swapi.co/api/films/4/",
		"https://swapi.co/api/films/6/"
	],
	species: [
		"https://swapi.co/api/species/24/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-20T10:32:11.669000Z",
	edited: "2014-12-20T21:17:50.434000Z",
	url: "https://swapi.co/api/people/56/"
},
	"https://swapi.co/api/people/57/": {
	name: "Yarael Poof",
	height: "264",
	mass: "unknown",
	hair_color: "none",
	skin_color: "white",
	eye_color: "yellow",
	birth_year: "unknown",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/48/",
	films: [
		"https://swapi.co/api/films/4/"
	],
	species: [
		"https://swapi.co/api/species/25/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-20T10:34:48.725000Z",
	edited: "2014-12-20T21:17:50.437000Z",
	url: "https://swapi.co/api/people/57/"
},
	"https://swapi.co/api/people/58/": {
	name: "Plo Koon",
	height: "188",
	mass: "80",
	hair_color: "none",
	skin_color: "orange",
	eye_color: "black",
	birth_year: "22BBY",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/49/",
	films: [
		"https://swapi.co/api/films/5/",
		"https://swapi.co/api/films/4/",
		"https://swapi.co/api/films/6/"
	],
	species: [
		"https://swapi.co/api/species/26/"
	],
	vehicles: [
	],
	starships: [
		"https://swapi.co/api/starships/48/"
	],
	created: "2014-12-20T10:49:19.859000Z",
	edited: "2014-12-20T21:17:50.439000Z",
	url: "https://swapi.co/api/people/58/"
},
	"https://swapi.co/api/people/59/": {
	name: "Mas Amedda",
	height: "196",
	mass: "unknown",
	hair_color: "none",
	skin_color: "blue",
	eye_color: "blue",
	birth_year: "unknown",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/50/",
	films: [
		"https://swapi.co/api/films/5/",
		"https://swapi.co/api/films/4/"
	],
	species: [
		"https://swapi.co/api/species/27/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-20T10:53:26.457000Z",
	edited: "2014-12-20T21:17:50.442000Z",
	url: "https://swapi.co/api/people/59/"
},
	"https://swapi.co/api/people/60/": {
	name: "Gregar Typho",
	height: "185",
	mass: "85",
	hair_color: "black",
	skin_color: "dark",
	eye_color: "brown",
	birth_year: "unknown",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/8/",
	films: [
		"https://swapi.co/api/films/5/"
	],
	species: [
		"https://swapi.co/api/species/1/"
	],
	vehicles: [
	],
	starships: [
		"https://swapi.co/api/starships/39/"
	],
	created: "2014-12-20T11:10:10.381000Z",
	edited: "2014-12-20T21:17:50.445000Z",
	url: "https://swapi.co/api/people/60/"
},
	"https://swapi.co/api/people/61/": {
	name: "Cordé",
	height: "157",
	mass: "unknown",
	hair_color: "brown",
	skin_color: "light",
	eye_color: "brown",
	birth_year: "unknown",
	gender: "female",
	homeworld: "https://swapi.co/api/planets/8/",
	films: [
		"https://swapi.co/api/films/5/"
	],
	species: [
		"https://swapi.co/api/species/1/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-20T11:11:39.630000Z",
	edited: "2014-12-20T21:17:50.449000Z",
	url: "https://swapi.co/api/people/61/"
},
	"https://swapi.co/api/people/62/": {
	name: "Cliegg Lars",
	height: "183",
	mass: "unknown",
	hair_color: "brown",
	skin_color: "fair",
	eye_color: "blue",
	birth_year: "82BBY",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/1/",
	films: [
		"https://swapi.co/api/films/5/"
	],
	species: [
		"https://swapi.co/api/species/1/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-20T15:59:03.958000Z",
	edited: "2014-12-20T21:17:50.451000Z",
	url: "https://swapi.co/api/people/62/"
},
	"https://swapi.co/api/people/63/": {
	name: "Poggle the Lesser",
	height: "183",
	mass: "80",
	hair_color: "none",
	skin_color: "green",
	eye_color: "yellow",
	birth_year: "unknown",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/11/",
	films: [
		"https://swapi.co/api/films/5/",
		"https://swapi.co/api/films/6/"
	],
	species: [
		"https://swapi.co/api/species/28/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-20T16:40:43.977000Z",
	edited: "2014-12-20T21:17:50.453000Z",
	url: "https://swapi.co/api/people/63/"
},
	"https://swapi.co/api/people/?page=7": {
	count: 87,
	next: "https://swapi.co/api/people/?page=8",
	previous: "https://swapi.co/api/people/?page=6",
	results: [
		{
			name: "Luminara Unduli",
			height: "170",
			mass: "56.2",
			hair_color: "black",
			skin_color: "yellow",
			eye_color: "blue",
			birth_year: "58BBY",
			gender: "female",
			homeworld: "https://swapi.co/api/planets/51/",
			films: [
				"https://swapi.co/api/films/5/",
				"https://swapi.co/api/films/6/"
			],
			species: [
				"https://swapi.co/api/species/29/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-20T16:45:53.668000Z",
			edited: "2014-12-20T21:17:50.455000Z",
			url: "https://swapi.co/api/people/64/"
		},
		{
			name: "Barriss Offee",
			height: "166",
			mass: "50",
			hair_color: "black",
			skin_color: "yellow",
			eye_color: "blue",
			birth_year: "40BBY",
			gender: "female",
			homeworld: "https://swapi.co/api/planets/51/",
			films: [
				"https://swapi.co/api/films/5/"
			],
			species: [
				"https://swapi.co/api/species/29/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-20T16:46:40.440000Z",
			edited: "2014-12-20T21:17:50.457000Z",
			url: "https://swapi.co/api/people/65/"
		},
		{
			name: "Dormé",
			height: "165",
			mass: "unknown",
			hair_color: "brown",
			skin_color: "light",
			eye_color: "brown",
			birth_year: "unknown",
			gender: "female",
			homeworld: "https://swapi.co/api/planets/8/",
			films: [
				"https://swapi.co/api/films/5/"
			],
			species: [
				"https://swapi.co/api/species/1/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-20T16:49:14.640000Z",
			edited: "2014-12-20T21:17:50.460000Z",
			url: "https://swapi.co/api/people/66/"
		},
		{
			name: "Dooku",
			height: "193",
			mass: "80",
			hair_color: "white",
			skin_color: "fair",
			eye_color: "brown",
			birth_year: "102BBY",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/52/",
			films: [
				"https://swapi.co/api/films/5/",
				"https://swapi.co/api/films/6/"
			],
			species: [
				"https://swapi.co/api/species/1/"
			],
			vehicles: [
				"https://swapi.co/api/vehicles/55/"
			],
			starships: [
			],
			created: "2014-12-20T16:52:14.726000Z",
			edited: "2014-12-20T21:17:50.462000Z",
			url: "https://swapi.co/api/people/67/"
		},
		{
			name: "Bail Prestor Organa",
			height: "191",
			mass: "unknown",
			hair_color: "black",
			skin_color: "tan",
			eye_color: "brown",
			birth_year: "67BBY",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/2/",
			films: [
				"https://swapi.co/api/films/5/",
				"https://swapi.co/api/films/6/"
			],
			species: [
				"https://swapi.co/api/species/1/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-20T16:53:08.575000Z",
			edited: "2014-12-20T21:17:50.463000Z",
			url: "https://swapi.co/api/people/68/"
		},
		{
			name: "Jango Fett",
			height: "183",
			mass: "79",
			hair_color: "black",
			skin_color: "tan",
			eye_color: "brown",
			birth_year: "66BBY",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/53/",
			films: [
				"https://swapi.co/api/films/5/"
			],
			species: [
				"https://swapi.co/api/species/1/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-20T16:54:41.620000Z",
			edited: "2014-12-20T21:17:50.465000Z",
			url: "https://swapi.co/api/people/69/"
		},
		{
			name: "Zam Wesell",
			height: "168",
			mass: "55",
			hair_color: "blonde",
			skin_color: "fair, green, yellow",
			eye_color: "yellow",
			birth_year: "unknown",
			gender: "female",
			homeworld: "https://swapi.co/api/planets/54/",
			films: [
				"https://swapi.co/api/films/5/"
			],
			species: [
				"https://swapi.co/api/species/30/"
			],
			vehicles: [
				"https://swapi.co/api/vehicles/45/"
			],
			starships: [
			],
			created: "2014-12-20T16:57:44.471000Z",
			edited: "2014-12-20T21:17:50.468000Z",
			url: "https://swapi.co/api/people/70/"
		},
		{
			name: "Dexter Jettster",
			height: "198",
			mass: "102",
			hair_color: "none",
			skin_color: "brown",
			eye_color: "yellow",
			birth_year: "unknown",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/55/",
			films: [
				"https://swapi.co/api/films/5/"
			],
			species: [
				"https://swapi.co/api/species/31/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-20T17:28:27.248000Z",
			edited: "2014-12-20T21:17:50.470000Z",
			url: "https://swapi.co/api/people/71/"
		},
		{
			name: "Lama Su",
			height: "229",
			mass: "88",
			hair_color: "none",
			skin_color: "grey",
			eye_color: "black",
			birth_year: "unknown",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/10/",
			films: [
				"https://swapi.co/api/films/5/"
			],
			species: [
				"https://swapi.co/api/species/32/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-20T17:30:50.416000Z",
			edited: "2014-12-20T21:17:50.473000Z",
			url: "https://swapi.co/api/people/72/"
		},
		{
			name: "Taun We",
			height: "213",
			mass: "unknown",
			hair_color: "none",
			skin_color: "grey",
			eye_color: "black",
			birth_year: "unknown",
			gender: "female",
			homeworld: "https://swapi.co/api/planets/10/",
			films: [
				"https://swapi.co/api/films/5/"
			],
			species: [
				"https://swapi.co/api/species/32/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-20T17:31:21.195000Z",
			edited: "2014-12-20T21:17:50.474000Z",
			url: "https://swapi.co/api/people/73/"
		}
	]
},
	"https://swapi.co/api/people/64/": {
	name: "Luminara Unduli",
	height: "170",
	mass: "56.2",
	hair_color: "black",
	skin_color: "yellow",
	eye_color: "blue",
	birth_year: "58BBY",
	gender: "female",
	homeworld: "https://swapi.co/api/planets/51/",
	films: [
		"https://swapi.co/api/films/5/",
		"https://swapi.co/api/films/6/"
	],
	species: [
		"https://swapi.co/api/species/29/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-20T16:45:53.668000Z",
	edited: "2014-12-20T21:17:50.455000Z",
	url: "https://swapi.co/api/people/64/"
},
	"https://swapi.co/api/people/65/": {
	name: "Barriss Offee",
	height: "166",
	mass: "50",
	hair_color: "black",
	skin_color: "yellow",
	eye_color: "blue",
	birth_year: "40BBY",
	gender: "female",
	homeworld: "https://swapi.co/api/planets/51/",
	films: [
		"https://swapi.co/api/films/5/"
	],
	species: [
		"https://swapi.co/api/species/29/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-20T16:46:40.440000Z",
	edited: "2014-12-20T21:17:50.457000Z",
	url: "https://swapi.co/api/people/65/"
},
	"https://swapi.co/api/people/66/": {
	name: "Dormé",
	height: "165",
	mass: "unknown",
	hair_color: "brown",
	skin_color: "light",
	eye_color: "brown",
	birth_year: "unknown",
	gender: "female",
	homeworld: "https://swapi.co/api/planets/8/",
	films: [
		"https://swapi.co/api/films/5/"
	],
	species: [
		"https://swapi.co/api/species/1/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-20T16:49:14.640000Z",
	edited: "2014-12-20T21:17:50.460000Z",
	url: "https://swapi.co/api/people/66/"
},
	"https://swapi.co/api/people/67/": {
	name: "Dooku",
	height: "193",
	mass: "80",
	hair_color: "white",
	skin_color: "fair",
	eye_color: "brown",
	birth_year: "102BBY",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/52/",
	films: [
		"https://swapi.co/api/films/5/",
		"https://swapi.co/api/films/6/"
	],
	species: [
		"https://swapi.co/api/species/1/"
	],
	vehicles: [
		"https://swapi.co/api/vehicles/55/"
	],
	starships: [
	],
	created: "2014-12-20T16:52:14.726000Z",
	edited: "2014-12-20T21:17:50.462000Z",
	url: "https://swapi.co/api/people/67/"
},
	"https://swapi.co/api/people/68/": {
	name: "Bail Prestor Organa",
	height: "191",
	mass: "unknown",
	hair_color: "black",
	skin_color: "tan",
	eye_color: "brown",
	birth_year: "67BBY",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/2/",
	films: [
		"https://swapi.co/api/films/5/",
		"https://swapi.co/api/films/6/"
	],
	species: [
		"https://swapi.co/api/species/1/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-20T16:53:08.575000Z",
	edited: "2014-12-20T21:17:50.463000Z",
	url: "https://swapi.co/api/people/68/"
},
	"https://swapi.co/api/people/69/": {
	name: "Jango Fett",
	height: "183",
	mass: "79",
	hair_color: "black",
	skin_color: "tan",
	eye_color: "brown",
	birth_year: "66BBY",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/53/",
	films: [
		"https://swapi.co/api/films/5/"
	],
	species: [
		"https://swapi.co/api/species/1/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-20T16:54:41.620000Z",
	edited: "2014-12-20T21:17:50.465000Z",
	url: "https://swapi.co/api/people/69/"
},
	"https://swapi.co/api/people/70/": {
	name: "Zam Wesell",
	height: "168",
	mass: "55",
	hair_color: "blonde",
	skin_color: "fair, green, yellow",
	eye_color: "yellow",
	birth_year: "unknown",
	gender: "female",
	homeworld: "https://swapi.co/api/planets/54/",
	films: [
		"https://swapi.co/api/films/5/"
	],
	species: [
		"https://swapi.co/api/species/30/"
	],
	vehicles: [
		"https://swapi.co/api/vehicles/45/"
	],
	starships: [
	],
	created: "2014-12-20T16:57:44.471000Z",
	edited: "2014-12-20T21:17:50.468000Z",
	url: "https://swapi.co/api/people/70/"
},
	"https://swapi.co/api/people/71/": {
	name: "Dexter Jettster",
	height: "198",
	mass: "102",
	hair_color: "none",
	skin_color: "brown",
	eye_color: "yellow",
	birth_year: "unknown",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/55/",
	films: [
		"https://swapi.co/api/films/5/"
	],
	species: [
		"https://swapi.co/api/species/31/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-20T17:28:27.248000Z",
	edited: "2014-12-20T21:17:50.470000Z",
	url: "https://swapi.co/api/people/71/"
},
	"https://swapi.co/api/people/72/": {
	name: "Lama Su",
	height: "229",
	mass: "88",
	hair_color: "none",
	skin_color: "grey",
	eye_color: "black",
	birth_year: "unknown",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/10/",
	films: [
		"https://swapi.co/api/films/5/"
	],
	species: [
		"https://swapi.co/api/species/32/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-20T17:30:50.416000Z",
	edited: "2014-12-20T21:17:50.473000Z",
	url: "https://swapi.co/api/people/72/"
},
	"https://swapi.co/api/people/73/": {
	name: "Taun We",
	height: "213",
	mass: "unknown",
	hair_color: "none",
	skin_color: "grey",
	eye_color: "black",
	birth_year: "unknown",
	gender: "female",
	homeworld: "https://swapi.co/api/planets/10/",
	films: [
		"https://swapi.co/api/films/5/"
	],
	species: [
		"https://swapi.co/api/species/32/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-20T17:31:21.195000Z",
	edited: "2014-12-20T21:17:50.474000Z",
	url: "https://swapi.co/api/people/73/"
},
	"https://swapi.co/api/people/?page=8": {
	count: 87,
	next: "https://swapi.co/api/people/?page=9",
	previous: "https://swapi.co/api/people/?page=7",
	results: [
		{
			name: "Jocasta Nu",
			height: "167",
			mass: "unknown",
			hair_color: "white",
			skin_color: "fair",
			eye_color: "blue",
			birth_year: "unknown",
			gender: "female",
			homeworld: "https://swapi.co/api/planets/9/",
			films: [
				"https://swapi.co/api/films/5/"
			],
			species: [
				"https://swapi.co/api/species/1/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-20T17:32:51.996000Z",
			edited: "2014-12-20T21:17:50.476000Z",
			url: "https://swapi.co/api/people/74/"
		},
		{
			name: "Ratts Tyerell",
			height: "79",
			mass: "15",
			hair_color: "none",
			skin_color: "grey, blue",
			eye_color: "unknown",
			birth_year: "unknown",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/38/",
			films: [
				"https://swapi.co/api/films/4/"
			],
			species: [
				"https://swapi.co/api/species/16/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-20T09:53:15.086000Z",
			edited: "2016-06-30T12:52:19.604868Z",
			url: "https://swapi.co/api/people/47/"
		},
		{
			name: "R4-P17",
			height: "96",
			mass: "unknown",
			hair_color: "none",
			skin_color: "silver, red",
			eye_color: "red, blue",
			birth_year: "unknown",
			gender: "female",
			homeworld: "https://swapi.co/api/planets/28/",
			films: [
				"https://swapi.co/api/films/5/",
				"https://swapi.co/api/films/6/"
			],
			species: [
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-20T17:43:36.409000Z",
			edited: "2014-12-20T21:17:50.478000Z",
			url: "https://swapi.co/api/people/75/"
		},
		{
			name: "Wat Tambor",
			height: "193",
			mass: "48",
			hair_color: "none",
			skin_color: "green, grey",
			eye_color: "unknown",
			birth_year: "unknown",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/56/",
			films: [
				"https://swapi.co/api/films/5/"
			],
			species: [
				"https://swapi.co/api/species/33/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-20T17:53:52.607000Z",
			edited: "2014-12-20T21:17:50.481000Z",
			url: "https://swapi.co/api/people/76/"
		},
		{
			name: "San Hill",
			height: "191",
			mass: "unknown",
			hair_color: "none",
			skin_color: "grey",
			eye_color: "gold",
			birth_year: "unknown",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/57/",
			films: [
				"https://swapi.co/api/films/5/"
			],
			species: [
				"https://swapi.co/api/species/34/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-20T17:58:17.049000Z",
			edited: "2014-12-20T21:17:50.484000Z",
			url: "https://swapi.co/api/people/77/"
		},
		{
			name: "Shaak Ti",
			height: "178",
			mass: "57",
			hair_color: "none",
			skin_color: "red, blue, white",
			eye_color: "black",
			birth_year: "unknown",
			gender: "female",
			homeworld: "https://swapi.co/api/planets/58/",
			films: [
				"https://swapi.co/api/films/5/",
				"https://swapi.co/api/films/6/"
			],
			species: [
				"https://swapi.co/api/species/35/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-20T18:44:01.103000Z",
			edited: "2014-12-20T21:17:50.486000Z",
			url: "https://swapi.co/api/people/78/"
		},
		{
			name: "Grievous",
			height: "216",
			mass: "159",
			hair_color: "none",
			skin_color: "brown, white",
			eye_color: "green, yellow",
			birth_year: "unknown",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/59/",
			films: [
				"https://swapi.co/api/films/6/"
			],
			species: [
				"https://swapi.co/api/species/36/"
			],
			vehicles: [
				"https://swapi.co/api/vehicles/60/"
			],
			starships: [
				"https://swapi.co/api/starships/74/"
			],
			created: "2014-12-20T19:43:53.348000Z",
			edited: "2014-12-20T21:17:50.488000Z",
			url: "https://swapi.co/api/people/79/"
		},
		{
			name: "Tarfful",
			height: "234",
			mass: "136",
			hair_color: "brown",
			skin_color: "brown",
			eye_color: "blue",
			birth_year: "unknown",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/14/",
			films: [
				"https://swapi.co/api/films/6/"
			],
			species: [
				"https://swapi.co/api/species/3/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-20T19:46:34.209000Z",
			edited: "2014-12-20T21:17:50.491000Z",
			url: "https://swapi.co/api/people/80/"
		},
		{
			name: "Raymus Antilles",
			height: "188",
			mass: "79",
			hair_color: "brown",
			skin_color: "light",
			eye_color: "brown",
			birth_year: "unknown",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/2/",
			films: [
				"https://swapi.co/api/films/6/",
				"https://swapi.co/api/films/1/"
			],
			species: [
				"https://swapi.co/api/species/1/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-20T19:49:35.583000Z",
			edited: "2014-12-20T21:17:50.493000Z",
			url: "https://swapi.co/api/people/81/"
		},
		{
			name: "Sly Moore",
			height: "178",
			mass: "48",
			hair_color: "none",
			skin_color: "pale",
			eye_color: "white",
			birth_year: "unknown",
			gender: "female",
			homeworld: "https://swapi.co/api/planets/60/",
			films: [
				"https://swapi.co/api/films/5/",
				"https://swapi.co/api/films/6/"
			],
			species: [
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-20T20:18:37.619000Z",
			edited: "2014-12-20T21:17:50.496000Z",
			url: "https://swapi.co/api/people/82/"
		}
	]
},
	"https://swapi.co/api/people/74/": {
	name: "Jocasta Nu",
	height: "167",
	mass: "unknown",
	hair_color: "white",
	skin_color: "fair",
	eye_color: "blue",
	birth_year: "unknown",
	gender: "female",
	homeworld: "https://swapi.co/api/planets/9/",
	films: [
		"https://swapi.co/api/films/5/"
	],
	species: [
		"https://swapi.co/api/species/1/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-20T17:32:51.996000Z",
	edited: "2014-12-20T21:17:50.476000Z",
	url: "https://swapi.co/api/people/74/"
},
	"https://swapi.co/api/people/47/": {
	name: "Ratts Tyerell",
	height: "79",
	mass: "15",
	hair_color: "none",
	skin_color: "grey, blue",
	eye_color: "unknown",
	birth_year: "unknown",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/38/",
	films: [
		"https://swapi.co/api/films/4/"
	],
	species: [
		"https://swapi.co/api/species/16/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-20T09:53:15.086000Z",
	edited: "2016-06-30T12:52:19.604868Z",
	url: "https://swapi.co/api/people/47/"
},
	"https://swapi.co/api/people/75/": {
	name: "R4-P17",
	height: "96",
	mass: "unknown",
	hair_color: "none",
	skin_color: "silver, red",
	eye_color: "red, blue",
	birth_year: "unknown",
	gender: "female",
	homeworld: "https://swapi.co/api/planets/28/",
	films: [
		"https://swapi.co/api/films/5/",
		"https://swapi.co/api/films/6/"
	],
	species: [
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-20T17:43:36.409000Z",
	edited: "2014-12-20T21:17:50.478000Z",
	url: "https://swapi.co/api/people/75/"
},
	"https://swapi.co/api/people/76/": {
	name: "Wat Tambor",
	height: "193",
	mass: "48",
	hair_color: "none",
	skin_color: "green, grey",
	eye_color: "unknown",
	birth_year: "unknown",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/56/",
	films: [
		"https://swapi.co/api/films/5/"
	],
	species: [
		"https://swapi.co/api/species/33/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-20T17:53:52.607000Z",
	edited: "2014-12-20T21:17:50.481000Z",
	url: "https://swapi.co/api/people/76/"
},
	"https://swapi.co/api/people/77/": {
	name: "San Hill",
	height: "191",
	mass: "unknown",
	hair_color: "none",
	skin_color: "grey",
	eye_color: "gold",
	birth_year: "unknown",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/57/",
	films: [
		"https://swapi.co/api/films/5/"
	],
	species: [
		"https://swapi.co/api/species/34/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-20T17:58:17.049000Z",
	edited: "2014-12-20T21:17:50.484000Z",
	url: "https://swapi.co/api/people/77/"
},
	"https://swapi.co/api/people/78/": {
	name: "Shaak Ti",
	height: "178",
	mass: "57",
	hair_color: "none",
	skin_color: "red, blue, white",
	eye_color: "black",
	birth_year: "unknown",
	gender: "female",
	homeworld: "https://swapi.co/api/planets/58/",
	films: [
		"https://swapi.co/api/films/5/",
		"https://swapi.co/api/films/6/"
	],
	species: [
		"https://swapi.co/api/species/35/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-20T18:44:01.103000Z",
	edited: "2014-12-20T21:17:50.486000Z",
	url: "https://swapi.co/api/people/78/"
},
	"https://swapi.co/api/people/79/": {
	name: "Grievous",
	height: "216",
	mass: "159",
	hair_color: "none",
	skin_color: "brown, white",
	eye_color: "green, yellow",
	birth_year: "unknown",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/59/",
	films: [
		"https://swapi.co/api/films/6/"
	],
	species: [
		"https://swapi.co/api/species/36/"
	],
	vehicles: [
		"https://swapi.co/api/vehicles/60/"
	],
	starships: [
		"https://swapi.co/api/starships/74/"
	],
	created: "2014-12-20T19:43:53.348000Z",
	edited: "2014-12-20T21:17:50.488000Z",
	url: "https://swapi.co/api/people/79/"
},
	"https://swapi.co/api/people/80/": {
	name: "Tarfful",
	height: "234",
	mass: "136",
	hair_color: "brown",
	skin_color: "brown",
	eye_color: "blue",
	birth_year: "unknown",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/14/",
	films: [
		"https://swapi.co/api/films/6/"
	],
	species: [
		"https://swapi.co/api/species/3/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-20T19:46:34.209000Z",
	edited: "2014-12-20T21:17:50.491000Z",
	url: "https://swapi.co/api/people/80/"
},
	"https://swapi.co/api/people/81/": {
	name: "Raymus Antilles",
	height: "188",
	mass: "79",
	hair_color: "brown",
	skin_color: "light",
	eye_color: "brown",
	birth_year: "unknown",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/2/",
	films: [
		"https://swapi.co/api/films/6/",
		"https://swapi.co/api/films/1/"
	],
	species: [
		"https://swapi.co/api/species/1/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-20T19:49:35.583000Z",
	edited: "2014-12-20T21:17:50.493000Z",
	url: "https://swapi.co/api/people/81/"
},
	"https://swapi.co/api/people/82/": {
	name: "Sly Moore",
	height: "178",
	mass: "48",
	hair_color: "none",
	skin_color: "pale",
	eye_color: "white",
	birth_year: "unknown",
	gender: "female",
	homeworld: "https://swapi.co/api/planets/60/",
	films: [
		"https://swapi.co/api/films/5/",
		"https://swapi.co/api/films/6/"
	],
	species: [
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-20T20:18:37.619000Z",
	edited: "2014-12-20T21:17:50.496000Z",
	url: "https://swapi.co/api/people/82/"
},
	"https://swapi.co/api/people/?page=9": {
	count: 87,
	next: null,
	previous: "https://swapi.co/api/people/?page=8",
	results: [
		{
			name: "Tion Medon",
			height: "206",
			mass: "80",
			hair_color: "none",
			skin_color: "grey",
			eye_color: "black",
			birth_year: "unknown",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/12/",
			films: [
				"https://swapi.co/api/films/6/"
			],
			species: [
				"https://swapi.co/api/species/37/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2014-12-20T20:35:04.260000Z",
			edited: "2014-12-20T21:17:50.498000Z",
			url: "https://swapi.co/api/people/83/"
		},
		{
			name: "Finn",
			height: "unknown",
			mass: "unknown",
			hair_color: "black",
			skin_color: "dark",
			eye_color: "dark",
			birth_year: "unknown",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/28/",
			films: [
				"https://swapi.co/api/films/7/"
			],
			species: [
				"https://swapi.co/api/species/1/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2015-04-17T06:52:40.793621Z",
			edited: "2015-04-17T06:52:40.793674Z",
			url: "https://swapi.co/api/people/84/"
		},
		{
			name: "Rey",
			height: "unknown",
			mass: "unknown",
			hair_color: "brown",
			skin_color: "light",
			eye_color: "hazel",
			birth_year: "unknown",
			gender: "female",
			homeworld: "https://swapi.co/api/planets/28/",
			films: [
				"https://swapi.co/api/films/7/"
			],
			species: [
				"https://swapi.co/api/species/1/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2015-04-17T06:54:01.495077Z",
			edited: "2015-04-17T06:54:01.495128Z",
			url: "https://swapi.co/api/people/85/"
		},
		{
			name: "Poe Dameron",
			height: "unknown",
			mass: "unknown",
			hair_color: "brown",
			skin_color: "light",
			eye_color: "brown",
			birth_year: "unknown",
			gender: "male",
			homeworld: "https://swapi.co/api/planets/28/",
			films: [
				"https://swapi.co/api/films/7/"
			],
			species: [
				"https://swapi.co/api/species/1/"
			],
			vehicles: [
			],
			starships: [
				"https://swapi.co/api/starships/77/"
			],
			created: "2015-04-17T06:55:21.622786Z",
			edited: "2015-04-17T06:55:21.622835Z",
			url: "https://swapi.co/api/people/86/"
		},
		{
			name: "BB8",
			height: "unknown",
			mass: "unknown",
			hair_color: "none",
			skin_color: "none",
			eye_color: "black",
			birth_year: "unknown",
			gender: "none",
			homeworld: "https://swapi.co/api/planets/28/",
			films: [
				"https://swapi.co/api/films/7/"
			],
			species: [
				"https://swapi.co/api/species/2/"
			],
			vehicles: [
			],
			starships: [
			],
			created: "2015-04-17T06:57:38.061346Z",
			edited: "2015-04-17T06:57:38.061453Z",
			url: "https://swapi.co/api/people/87/"
		},
		{
			name: "Captain Phasma",
			height: "unknown",
			mass: "unknown",
			hair_color: "unknown",
			skin_color: "unknown",
			eye_color: "unknown",
			birth_year: "unknown",
			gender: "female",
			homeworld: "https://swapi.co/api/planets/28/",
			films: [
				"https://swapi.co/api/films/7/"
			],
			species: [
			],
			vehicles: [
			],
			starships: [
			],
			created: "2015-10-13T10:35:39.229823Z",
			edited: "2015-10-13T10:35:39.229894Z",
			url: "https://swapi.co/api/people/88/"
		},
		{
			name: "Padmé Amidala",
			height: "165",
			mass: "45",
			hair_color: "brown",
			skin_color: "light",
			eye_color: "brown",
			birth_year: "46BBY",
			gender: "female",
			homeworld: "https://swapi.co/api/planets/8/",
			films: [
				"https://swapi.co/api/films/5/",
				"https://swapi.co/api/films/4/",
				"https://swapi.co/api/films/6/"
			],
			species: [
				"https://swapi.co/api/species/1/"
			],
			vehicles: [
			],
			starships: [
				"https://swapi.co/api/starships/49/",
				"https://swapi.co/api/starships/64/",
				"https://swapi.co/api/starships/39/"
			],
			created: "2014-12-19T17:28:26.926000Z",
			edited: "2016-04-20T17:06:31.502555Z",
			url: "https://swapi.co/api/people/35/"
		}
	]
},
	"https://swapi.co/api/people/83/": {
	name: "Tion Medon",
	height: "206",
	mass: "80",
	hair_color: "none",
	skin_color: "grey",
	eye_color: "black",
	birth_year: "unknown",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/12/",
	films: [
		"https://swapi.co/api/films/6/"
	],
	species: [
		"https://swapi.co/api/species/37/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2014-12-20T20:35:04.260000Z",
	edited: "2014-12-20T21:17:50.498000Z",
	url: "https://swapi.co/api/people/83/"
},
	"https://swapi.co/api/people/84/": {
	name: "Finn",
	height: "unknown",
	mass: "unknown",
	hair_color: "black",
	skin_color: "dark",
	eye_color: "dark",
	birth_year: "unknown",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/28/",
	films: [
		"https://swapi.co/api/films/7/"
	],
	species: [
		"https://swapi.co/api/species/1/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2015-04-17T06:52:40.793621Z",
	edited: "2015-04-17T06:52:40.793674Z",
	url: "https://swapi.co/api/people/84/"
},
	"https://swapi.co/api/people/85/": {
	name: "Rey",
	height: "unknown",
	mass: "unknown",
	hair_color: "brown",
	skin_color: "light",
	eye_color: "hazel",
	birth_year: "unknown",
	gender: "female",
	homeworld: "https://swapi.co/api/planets/28/",
	films: [
		"https://swapi.co/api/films/7/"
	],
	species: [
		"https://swapi.co/api/species/1/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2015-04-17T06:54:01.495077Z",
	edited: "2015-04-17T06:54:01.495128Z",
	url: "https://swapi.co/api/people/85/"
},
	"https://swapi.co/api/people/86/": {
	name: "Poe Dameron",
	height: "unknown",
	mass: "unknown",
	hair_color: "brown",
	skin_color: "light",
	eye_color: "brown",
	birth_year: "unknown",
	gender: "male",
	homeworld: "https://swapi.co/api/planets/28/",
	films: [
		"https://swapi.co/api/films/7/"
	],
	species: [
		"https://swapi.co/api/species/1/"
	],
	vehicles: [
	],
	starships: [
		"https://swapi.co/api/starships/77/"
	],
	created: "2015-04-17T06:55:21.622786Z",
	edited: "2015-04-17T06:55:21.622835Z",
	url: "https://swapi.co/api/people/86/"
},
	"https://swapi.co/api/people/87/": {
	name: "BB8",
	height: "unknown",
	mass: "unknown",
	hair_color: "none",
	skin_color: "none",
	eye_color: "black",
	birth_year: "unknown",
	gender: "none",
	homeworld: "https://swapi.co/api/planets/28/",
	films: [
		"https://swapi.co/api/films/7/"
	],
	species: [
		"https://swapi.co/api/species/2/"
	],
	vehicles: [
	],
	starships: [
	],
	created: "2015-04-17T06:57:38.061346Z",
	edited: "2015-04-17T06:57:38.061453Z",
	url: "https://swapi.co/api/people/87/"
},
	"https://swapi.co/api/people/88/": {
	name: "Captain Phasma",
	height: "unknown",
	mass: "unknown",
	hair_color: "unknown",
	skin_color: "unknown",
	eye_color: "unknown",
	birth_year: "unknown",
	gender: "female",
	homeworld: "https://swapi.co/api/planets/28/",
	films: [
		"https://swapi.co/api/films/7/"
	],
	species: [
	],
	vehicles: [
	],
	starships: [
	],
	created: "2015-10-13T10:35:39.229823Z",
	edited: "2015-10-13T10:35:39.229894Z",
	url: "https://swapi.co/api/people/88/"
},
	"https://swapi.co/api/people/35/": {
	name: "Padmé Amidala",
	height: "165",
	mass: "45",
	hair_color: "brown",
	skin_color: "light",
	eye_color: "brown",
	birth_year: "46BBY",
	gender: "female",
	homeworld: "https://swapi.co/api/planets/8/",
	films: [
		"https://swapi.co/api/films/5/",
		"https://swapi.co/api/films/4/",
		"https://swapi.co/api/films/6/"
	],
	species: [
		"https://swapi.co/api/species/1/"
	],
	vehicles: [
	],
	starships: [
		"https://swapi.co/api/starships/49/",
		"https://swapi.co/api/starships/64/",
		"https://swapi.co/api/starships/39/"
	],
	created: "2014-12-19T17:28:26.926000Z",
	edited: "2016-04-20T17:06:31.502555Z",
	url: "https://swapi.co/api/people/35/"
},
	"https://swapi.co/api/starships/": {
	count: 37,
	next: "https://swapi.co/api/starships/?page=2",
	previous: null,
	results: [
		{
			name: "Executor",
			model: "Executor-class star dreadnought",
			manufacturer: "Kuat Drive Yards, Fondor Shipyards",
			cost_in_credits: "1143350000",
			length: "19000",
			max_atmosphering_speed: "n/a",
			crew: "279144",
			passengers: "38000",
			cargo_capacity: "250000000",
			consumables: "6 years",
			hyperdrive_rating: "2.0",
			MGLT: "40",
			starship_class: "Star dreadnought",
			pilots: [
			],
			films: [
				"https://swapi.co/api/films/2/",
				"https://swapi.co/api/films/3/"
			],
			created: "2014-12-15T12:31:42.547000Z",
			edited: "2017-04-19T10:56:06.685592Z",
			url: "https://swapi.co/api/starships/15/"
		},
		{
			name: "Sentinel-class landing craft",
			model: "Sentinel-class landing craft",
			manufacturer: "Sienar Fleet Systems, Cyngus Spaceworks",
			cost_in_credits: "240000",
			length: "38",
			max_atmosphering_speed: "1000",
			crew: "5",
			passengers: "75",
			cargo_capacity: "180000",
			consumables: "1 month",
			hyperdrive_rating: "1.0",
			MGLT: "70",
			starship_class: "landing craft",
			pilots: [
			],
			films: [
				"https://swapi.co/api/films/1/"
			],
			created: "2014-12-10T15:48:00.586000Z",
			edited: "2014-12-22T17:35:44.431407Z",
			url: "https://swapi.co/api/starships/5/"
		},
		{
			name: "Death Star",
			model: "DS-1 Orbital Battle Station",
			manufacturer: "Imperial Department of Military Research, Sienar Fleet Systems",
			cost_in_credits: "1000000000000",
			length: "120000",
			max_atmosphering_speed: "n/a",
			crew: "342953",
			passengers: "843342",
			cargo_capacity: "1000000000000",
			consumables: "3 years",
			hyperdrive_rating: "4.0",
			MGLT: "10",
			starship_class: "Deep Space Mobile Battlestation",
			pilots: [
			],
			films: [
				"https://swapi.co/api/films/1/"
			],
			created: "2014-12-10T16:36:50.509000Z",
			edited: "2014-12-22T17:35:44.452589Z",
			url: "https://swapi.co/api/starships/9/"
		},
		{
			name: "Millennium Falcon",
			model: "YT-1300 light freighter",
			manufacturer: "Corellian Engineering Corporation",
			cost_in_credits: "100000",
			length: "34.37",
			max_atmosphering_speed: "1050",
			crew: "4",
			passengers: "6",
			cargo_capacity: "100000",
			consumables: "2 months",
			hyperdrive_rating: "0.5",
			MGLT: "75",
			starship_class: "Light freighter",
			pilots: [
				"https://swapi.co/api/people/13/",
				"https://swapi.co/api/people/14/",
				"https://swapi.co/api/people/25/",
				"https://swapi.co/api/people/31/"
			],
			films: [
				"https://swapi.co/api/films/2/",
				"https://swapi.co/api/films/7/",
				"https://swapi.co/api/films/3/",
				"https://swapi.co/api/films/1/"
			],
			created: "2014-12-10T16:59:45.094000Z",
			edited: "2014-12-22T17:35:44.464156Z",
			url: "https://swapi.co/api/starships/10/"
		},
		{
			name: "Y-wing",
			model: "BTL Y-wing",
			manufacturer: "Koensayr Manufacturing",
			cost_in_credits: "134999",
			length: "14",
			max_atmosphering_speed: "1000km",
			crew: "2",
			passengers: "0",
			cargo_capacity: "110",
			consumables: "1 week",
			hyperdrive_rating: "1.0",
			MGLT: "80",
			starship_class: "assault starfighter",
			pilots: [
			],
			films: [
				"https://swapi.co/api/films/2/",
				"https://swapi.co/api/films/3/",
				"https://swapi.co/api/films/1/"
			],
			created: "2014-12-12T11:00:39.817000Z",
			edited: "2014-12-22T17:35:44.479706Z",
			url: "https://swapi.co/api/starships/11/"
		},
		{
			name: "X-wing",
			model: "T-65 X-wing",
			manufacturer: "Incom Corporation",
			cost_in_credits: "149999",
			length: "12.5",
			max_atmosphering_speed: "1050",
			crew: "1",
			passengers: "0",
			cargo_capacity: "110",
			consumables: "1 week",
			hyperdrive_rating: "1.0",
			MGLT: "100",
			starship_class: "Starfighter",
			pilots: [
				"https://swapi.co/api/people/1/",
				"https://swapi.co/api/people/9/",
				"https://swapi.co/api/people/18/",
				"https://swapi.co/api/people/19/"
			],
			films: [
				"https://swapi.co/api/films/2/",
				"https://swapi.co/api/films/3/",
				"https://swapi.co/api/films/1/"
			],
			created: "2014-12-12T11:19:05.340000Z",
			edited: "2014-12-22T17:35:44.491233Z",
			url: "https://swapi.co/api/starships/12/"
		},
		{
			name: "TIE Advanced x1",
			model: "Twin Ion Engine Advanced x1",
			manufacturer: "Sienar Fleet Systems",
			cost_in_credits: "unknown",
			length: "9.2",
			max_atmosphering_speed: "1200",
			crew: "1",
			passengers: "0",
			cargo_capacity: "150",
			consumables: "5 days",
			hyperdrive_rating: "1.0",
			MGLT: "105",
			starship_class: "Starfighter",
			pilots: [
				"https://swapi.co/api/people/4/"
			],
			films: [
				"https://swapi.co/api/films/1/"
			],
			created: "2014-12-12T11:21:32.991000Z",
			edited: "2014-12-22T17:35:44.549047Z",
			url: "https://swapi.co/api/starships/13/"
		},
		{
			name: "Slave 1",
			model: "Firespray-31-class patrol and attack",
			manufacturer: "Kuat Systems Engineering",
			cost_in_credits: "unknown",
			length: "21.5",
			max_atmosphering_speed: "1000",
			crew: "1",
			passengers: "6",
			cargo_capacity: "70000",
			consumables: "1 month",
			hyperdrive_rating: "3.0",
			MGLT: "70",
			starship_class: "Patrol craft",
			pilots: [
				"https://swapi.co/api/people/22/"
			],
			films: [
				"https://swapi.co/api/films/2/",
				"https://swapi.co/api/films/5/"
			],
			created: "2014-12-15T13:00:56.332000Z",
			edited: "2014-12-22T17:35:44.716273Z",
			url: "https://swapi.co/api/starships/21/"
		},
		{
			name: "Imperial shuttle",
			model: "Lambda-class T-4a shuttle",
			manufacturer: "Sienar Fleet Systems",
			cost_in_credits: "240000",
			length: "20",
			max_atmosphering_speed: "850",
			crew: "6",
			passengers: "20",
			cargo_capacity: "80000",
			consumables: "2 months",
			hyperdrive_rating: "1.0",
			MGLT: "50",
			starship_class: "Armed government transport",
			pilots: [
				"https://swapi.co/api/people/1/",
				"https://swapi.co/api/people/13/",
				"https://swapi.co/api/people/14/"
			],
			films: [
				"https://swapi.co/api/films/2/",
				"https://swapi.co/api/films/3/"
			],
			created: "2014-12-15T13:04:47.235000Z",
			edited: "2014-12-22T17:35:44.795405Z",
			url: "https://swapi.co/api/starships/22/"
		},
		{
			name: "EF76 Nebulon-B escort frigate",
			model: "EF76 Nebulon-B escort frigate",
			manufacturer: "Kuat Drive Yards",
			cost_in_credits: "8500000",
			length: "300",
			max_atmosphering_speed: "800",
			crew: "854",
			passengers: "75",
			cargo_capacity: "6000000",
			consumables: "2 years",
			hyperdrive_rating: "2.0",
			MGLT: "40",
			starship_class: "Escort ship",
			pilots: [
			],
			films: [
				"https://swapi.co/api/films/2/",
				"https://swapi.co/api/films/3/"
			],
			created: "2014-12-15T13:06:30.813000Z",
			edited: "2014-12-22T17:35:44.848329Z",
			url: "https://swapi.co/api/starships/23/"
		}
	]
},
	"https://swapi.co/api/starships/15/": {
	name: "Executor",
	model: "Executor-class star dreadnought",
	manufacturer: "Kuat Drive Yards, Fondor Shipyards",
	cost_in_credits: "1143350000",
	length: "19000",
	max_atmosphering_speed: "n/a",
	crew: "279144",
	passengers: "38000",
	cargo_capacity: "250000000",
	consumables: "6 years",
	hyperdrive_rating: "2.0",
	MGLT: "40",
	starship_class: "Star dreadnought",
	pilots: [
	],
	films: [
		"https://swapi.co/api/films/2/",
		"https://swapi.co/api/films/3/"
	],
	created: "2014-12-15T12:31:42.547000Z",
	edited: "2017-04-19T10:56:06.685592Z",
	url: "https://swapi.co/api/starships/15/"
},
	"https://swapi.co/api/starships/5/": {
	name: "Sentinel-class landing craft",
	model: "Sentinel-class landing craft",
	manufacturer: "Sienar Fleet Systems, Cyngus Spaceworks",
	cost_in_credits: "240000",
	length: "38",
	max_atmosphering_speed: "1000",
	crew: "5",
	passengers: "75",
	cargo_capacity: "180000",
	consumables: "1 month",
	hyperdrive_rating: "1.0",
	MGLT: "70",
	starship_class: "landing craft",
	pilots: [
	],
	films: [
		"https://swapi.co/api/films/1/"
	],
	created: "2014-12-10T15:48:00.586000Z",
	edited: "2014-12-22T17:35:44.431407Z",
	url: "https://swapi.co/api/starships/5/"
},
	"https://swapi.co/api/starships/9/": {
	name: "Death Star",
	model: "DS-1 Orbital Battle Station",
	manufacturer: "Imperial Department of Military Research, Sienar Fleet Systems",
	cost_in_credits: "1000000000000",
	length: "120000",
	max_atmosphering_speed: "n/a",
	crew: "342953",
	passengers: "843342",
	cargo_capacity: "1000000000000",
	consumables: "3 years",
	hyperdrive_rating: "4.0",
	MGLT: "10",
	starship_class: "Deep Space Mobile Battlestation",
	pilots: [
	],
	films: [
		"https://swapi.co/api/films/1/"
	],
	created: "2014-12-10T16:36:50.509000Z",
	edited: "2014-12-22T17:35:44.452589Z",
	url: "https://swapi.co/api/starships/9/"
},
	"https://swapi.co/api/starships/10/": {
	name: "Millennium Falcon",
	model: "YT-1300 light freighter",
	manufacturer: "Corellian Engineering Corporation",
	cost_in_credits: "100000",
	length: "34.37",
	max_atmosphering_speed: "1050",
	crew: "4",
	passengers: "6",
	cargo_capacity: "100000",
	consumables: "2 months",
	hyperdrive_rating: "0.5",
	MGLT: "75",
	starship_class: "Light freighter",
	pilots: [
		"https://swapi.co/api/people/13/",
		"https://swapi.co/api/people/14/",
		"https://swapi.co/api/people/25/",
		"https://swapi.co/api/people/31/"
	],
	films: [
		"https://swapi.co/api/films/2/",
		"https://swapi.co/api/films/7/",
		"https://swapi.co/api/films/3/",
		"https://swapi.co/api/films/1/"
	],
	created: "2014-12-10T16:59:45.094000Z",
	edited: "2014-12-22T17:35:44.464156Z",
	url: "https://swapi.co/api/starships/10/"
},
	"https://swapi.co/api/starships/11/": {
	name: "Y-wing",
	model: "BTL Y-wing",
	manufacturer: "Koensayr Manufacturing",
	cost_in_credits: "134999",
	length: "14",
	max_atmosphering_speed: "1000km",
	crew: "2",
	passengers: "0",
	cargo_capacity: "110",
	consumables: "1 week",
	hyperdrive_rating: "1.0",
	MGLT: "80",
	starship_class: "assault starfighter",
	pilots: [
	],
	films: [
		"https://swapi.co/api/films/2/",
		"https://swapi.co/api/films/3/",
		"https://swapi.co/api/films/1/"
	],
	created: "2014-12-12T11:00:39.817000Z",
	edited: "2014-12-22T17:35:44.479706Z",
	url: "https://swapi.co/api/starships/11/"
},
	"https://swapi.co/api/starships/12/": {
	name: "X-wing",
	model: "T-65 X-wing",
	manufacturer: "Incom Corporation",
	cost_in_credits: "149999",
	length: "12.5",
	max_atmosphering_speed: "1050",
	crew: "1",
	passengers: "0",
	cargo_capacity: "110",
	consumables: "1 week",
	hyperdrive_rating: "1.0",
	MGLT: "100",
	starship_class: "Starfighter",
	pilots: [
		"https://swapi.co/api/people/1/",
		"https://swapi.co/api/people/9/",
		"https://swapi.co/api/people/18/",
		"https://swapi.co/api/people/19/"
	],
	films: [
		"https://swapi.co/api/films/2/",
		"https://swapi.co/api/films/3/",
		"https://swapi.co/api/films/1/"
	],
	created: "2014-12-12T11:19:05.340000Z",
	edited: "2014-12-22T17:35:44.491233Z",
	url: "https://swapi.co/api/starships/12/"
},
	"https://swapi.co/api/starships/13/": {
	name: "TIE Advanced x1",
	model: "Twin Ion Engine Advanced x1",
	manufacturer: "Sienar Fleet Systems",
	cost_in_credits: "unknown",
	length: "9.2",
	max_atmosphering_speed: "1200",
	crew: "1",
	passengers: "0",
	cargo_capacity: "150",
	consumables: "5 days",
	hyperdrive_rating: "1.0",
	MGLT: "105",
	starship_class: "Starfighter",
	pilots: [
		"https://swapi.co/api/people/4/"
	],
	films: [
		"https://swapi.co/api/films/1/"
	],
	created: "2014-12-12T11:21:32.991000Z",
	edited: "2014-12-22T17:35:44.549047Z",
	url: "https://swapi.co/api/starships/13/"
},
	"https://swapi.co/api/starships/21/": {
	name: "Slave 1",
	model: "Firespray-31-class patrol and attack",
	manufacturer: "Kuat Systems Engineering",
	cost_in_credits: "unknown",
	length: "21.5",
	max_atmosphering_speed: "1000",
	crew: "1",
	passengers: "6",
	cargo_capacity: "70000",
	consumables: "1 month",
	hyperdrive_rating: "3.0",
	MGLT: "70",
	starship_class: "Patrol craft",
	pilots: [
		"https://swapi.co/api/people/22/"
	],
	films: [
		"https://swapi.co/api/films/2/",
		"https://swapi.co/api/films/5/"
	],
	created: "2014-12-15T13:00:56.332000Z",
	edited: "2014-12-22T17:35:44.716273Z",
	url: "https://swapi.co/api/starships/21/"
},
	"https://swapi.co/api/starships/22/": {
	name: "Imperial shuttle",
	model: "Lambda-class T-4a shuttle",
	manufacturer: "Sienar Fleet Systems",
	cost_in_credits: "240000",
	length: "20",
	max_atmosphering_speed: "850",
	crew: "6",
	passengers: "20",
	cargo_capacity: "80000",
	consumables: "2 months",
	hyperdrive_rating: "1.0",
	MGLT: "50",
	starship_class: "Armed government transport",
	pilots: [
		"https://swapi.co/api/people/1/",
		"https://swapi.co/api/people/13/",
		"https://swapi.co/api/people/14/"
	],
	films: [
		"https://swapi.co/api/films/2/",
		"https://swapi.co/api/films/3/"
	],
	created: "2014-12-15T13:04:47.235000Z",
	edited: "2014-12-22T17:35:44.795405Z",
	url: "https://swapi.co/api/starships/22/"
},
	"https://swapi.co/api/starships/23/": {
	name: "EF76 Nebulon-B escort frigate",
	model: "EF76 Nebulon-B escort frigate",
	manufacturer: "Kuat Drive Yards",
	cost_in_credits: "8500000",
	length: "300",
	max_atmosphering_speed: "800",
	crew: "854",
	passengers: "75",
	cargo_capacity: "6000000",
	consumables: "2 years",
	hyperdrive_rating: "2.0",
	MGLT: "40",
	starship_class: "Escort ship",
	pilots: [
	],
	films: [
		"https://swapi.co/api/films/2/",
		"https://swapi.co/api/films/3/"
	],
	created: "2014-12-15T13:06:30.813000Z",
	edited: "2014-12-22T17:35:44.848329Z",
	url: "https://swapi.co/api/starships/23/"
},
	"https://swapi.co/api/starships/?page=2": {
	count: 37,
	next: "https://swapi.co/api/starships/?page=3",
	previous: "https://swapi.co/api/starships/?page=1",
	results: [
		{
			name: "Calamari Cruiser",
			model: "MC80 Liberty type Star Cruiser",
			manufacturer: "Mon Calamari shipyards",
			cost_in_credits: "104000000",
			length: "1200",
			max_atmosphering_speed: "n/a",
			crew: "5400",
			passengers: "1200",
			cargo_capacity: "unknown",
			consumables: "2 years",
			hyperdrive_rating: "1.0",
			MGLT: "60",
			starship_class: "Star Cruiser",
			pilots: [
			],
			films: [
				"https://swapi.co/api/films/3/"
			],
			created: "2014-12-18T10:54:57.804000Z",
			edited: "2014-12-22T17:35:44.957852Z",
			url: "https://swapi.co/api/starships/27/"
		},
		{
			name: "A-wing",
			model: "RZ-1 A-wing Interceptor",
			manufacturer: "Alliance Underground Engineering, Incom Corporation",
			cost_in_credits: "175000",
			length: "9.6",
			max_atmosphering_speed: "1300",
			crew: "1",
			passengers: "0",
			cargo_capacity: "40",
			consumables: "1 week",
			hyperdrive_rating: "1.0",
			MGLT: "120",
			starship_class: "Starfighter",
			pilots: [
				"https://swapi.co/api/people/29/"
			],
			films: [
				"https://swapi.co/api/films/3/"
			],
			created: "2014-12-18T11:16:34.542000Z",
			edited: "2014-12-22T17:35:44.978754Z",
			url: "https://swapi.co/api/starships/28/"
		},
		{
			name: "B-wing",
			model: "A/SF-01 B-wing starfighter",
			manufacturer: "Slayn & Korpil",
			cost_in_credits: "220000",
			length: "16.9",
			max_atmosphering_speed: "950",
			crew: "1",
			passengers: "0",
			cargo_capacity: "45",
			consumables: "1 week",
			hyperdrive_rating: "2.0",
			MGLT: "91",
			starship_class: "Assault Starfighter",
			pilots: [
			],
			films: [
				"https://swapi.co/api/films/3/"
			],
			created: "2014-12-18T11:18:04.763000Z",
			edited: "2014-12-22T17:35:45.011193Z",
			url: "https://swapi.co/api/starships/29/"
		},
		{
			name: "Republic Cruiser",
			model: "Consular-class cruiser",
			manufacturer: "Corellian Engineering Corporation",
			cost_in_credits: "unknown",
			length: "115",
			max_atmosphering_speed: "900",
			crew: "9",
			passengers: "16",
			cargo_capacity: "unknown",
			consumables: "unknown",
			hyperdrive_rating: "2.0",
			MGLT: "unknown",
			starship_class: "Space cruiser",
			pilots: [
			],
			films: [
				"https://swapi.co/api/films/4/"
			],
			created: "2014-12-19T17:01:31.488000Z",
			edited: "2014-12-22T17:35:45.027308Z",
			url: "https://swapi.co/api/starships/31/"
		},
		{
			name: "Naboo fighter",
			model: "N-1 starfighter",
			manufacturer: "Theed Palace Space Vessel Engineering Corps",
			cost_in_credits: "200000",
			length: "11",
			max_atmosphering_speed: "1100",
			crew: "1",
			passengers: "0",
			cargo_capacity: "65",
			consumables: "7 days",
			hyperdrive_rating: "1.0",
			MGLT: "unknown",
			starship_class: "Starfighter",
			pilots: [
				"https://swapi.co/api/people/11/",
				"https://swapi.co/api/people/60/",
				"https://swapi.co/api/people/35/"
			],
			films: [
				"https://swapi.co/api/films/5/",
				"https://swapi.co/api/films/4/"
			],
			created: "2014-12-19T17:39:17.582000Z",
			edited: "2014-12-22T17:35:45.079452Z",
			url: "https://swapi.co/api/starships/39/"
		},
		{
			name: "Naboo Royal Starship",
			model: "J-type 327 Nubian royal starship",
			manufacturer: "Theed Palace Space Vessel Engineering Corps, Nubia Star Drives",
			cost_in_credits: "unknown",
			length: "76",
			max_atmosphering_speed: "920",
			crew: "8",
			passengers: "unknown",
			cargo_capacity: "unknown",
			consumables: "unknown",
			hyperdrive_rating: "1.8",
			MGLT: "unknown",
			starship_class: "yacht",
			pilots: [
				"https://swapi.co/api/people/39/"
			],
			films: [
				"https://swapi.co/api/films/4/"
			],
			created: "2014-12-19T17:45:03.506000Z",
			edited: "2014-12-22T17:35:45.091925Z",
			url: "https://swapi.co/api/starships/40/"
		},
		{
			name: "Scimitar",
			model: "Star Courier",
			manufacturer: "Republic Sienar Systems",
			cost_in_credits: "55000000",
			length: "26.5",
			max_atmosphering_speed: "1180",
			crew: "1",
			passengers: "6",
			cargo_capacity: "2500000",
			consumables: "30 days",
			hyperdrive_rating: "1.5",
			MGLT: "unknown",
			starship_class: "Space Transport",
			pilots: [
				"https://swapi.co/api/people/44/"
			],
			films: [
				"https://swapi.co/api/films/4/"
			],
			created: "2014-12-20T09:39:56.116000Z",
			edited: "2014-12-22T17:35:45.105522Z",
			url: "https://swapi.co/api/starships/41/"
		},
		{
			name: "J-type diplomatic barge",
			model: "J-type diplomatic barge",
			manufacturer: "Theed Palace Space Vessel Engineering Corps, Nubia Star Drives",
			cost_in_credits: "2000000",
			length: "39",
			max_atmosphering_speed: "2000",
			crew: "5",
			passengers: "10",
			cargo_capacity: "unknown",
			consumables: "1 year",
			hyperdrive_rating: "0.7",
			MGLT: "unknown",
			starship_class: "Diplomatic barge",
			pilots: [
			],
			films: [
				"https://swapi.co/api/films/5/"
			],
			created: "2014-12-20T11:05:51.237000Z",
			edited: "2014-12-22T17:35:45.124386Z",
			url: "https://swapi.co/api/starships/43/"
		},
		{
			name: "AA-9 Coruscant freighter",
			model: "Botajef AA-9 Freighter-Liner",
			manufacturer: "Botajef Shipyards",
			cost_in_credits: "unknown",
			length: "390",
			max_atmosphering_speed: "unknown",
			crew: "unknown",
			passengers: "30000",
			cargo_capacity: "unknown",
			consumables: "unknown",
			hyperdrive_rating: "unknown",
			MGLT: "unknown",
			starship_class: "freighter",
			pilots: [
			],
			films: [
				"https://swapi.co/api/films/5/"
			],
			created: "2014-12-20T17:24:23.509000Z",
			edited: "2014-12-22T17:35:45.135987Z",
			url: "https://swapi.co/api/starships/47/"
		},
		{
			name: "Jedi starfighter",
			model: "Delta-7 Aethersprite-class interceptor",
			manufacturer: "Kuat Systems Engineering",
			cost_in_credits: "180000",
			length: "8",
			max_atmosphering_speed: "1150",
			crew: "1",
			passengers: "0",
			cargo_capacity: "60",
			consumables: "7 days",
			hyperdrive_rating: "1.0",
			MGLT: "unknown",
			starship_class: "Starfighter",
			pilots: [
				"https://swapi.co/api/people/10/",
				"https://swapi.co/api/people/58/"
			],
			films: [
				"https://swapi.co/api/films/5/",
				"https://swapi.co/api/films/6/"
			],
			created: "2014-12-20T17:35:23.906000Z",
			edited: "2014-12-22T17:35:45.147746Z",
			url: "https://swapi.co/api/starships/48/"
		}
	]
},
	"https://swapi.co/api/starships/27/": {
	name: "Calamari Cruiser",
	model: "MC80 Liberty type Star Cruiser",
	manufacturer: "Mon Calamari shipyards",
	cost_in_credits: "104000000",
	length: "1200",
	max_atmosphering_speed: "n/a",
	crew: "5400",
	passengers: "1200",
	cargo_capacity: "unknown",
	consumables: "2 years",
	hyperdrive_rating: "1.0",
	MGLT: "60",
	starship_class: "Star Cruiser",
	pilots: [
	],
	films: [
		"https://swapi.co/api/films/3/"
	],
	created: "2014-12-18T10:54:57.804000Z",
	edited: "2014-12-22T17:35:44.957852Z",
	url: "https://swapi.co/api/starships/27/"
},
	"https://swapi.co/api/starships/28/": {
	name: "A-wing",
	model: "RZ-1 A-wing Interceptor",
	manufacturer: "Alliance Underground Engineering, Incom Corporation",
	cost_in_credits: "175000",
	length: "9.6",
	max_atmosphering_speed: "1300",
	crew: "1",
	passengers: "0",
	cargo_capacity: "40",
	consumables: "1 week",
	hyperdrive_rating: "1.0",
	MGLT: "120",
	starship_class: "Starfighter",
	pilots: [
		"https://swapi.co/api/people/29/"
	],
	films: [
		"https://swapi.co/api/films/3/"
	],
	created: "2014-12-18T11:16:34.542000Z",
	edited: "2014-12-22T17:35:44.978754Z",
	url: "https://swapi.co/api/starships/28/"
},
	"https://swapi.co/api/starships/29/": {
	name: "B-wing",
	model: "A/SF-01 B-wing starfighter",
	manufacturer: "Slayn & Korpil",
	cost_in_credits: "220000",
	length: "16.9",
	max_atmosphering_speed: "950",
	crew: "1",
	passengers: "0",
	cargo_capacity: "45",
	consumables: "1 week",
	hyperdrive_rating: "2.0",
	MGLT: "91",
	starship_class: "Assault Starfighter",
	pilots: [
	],
	films: [
		"https://swapi.co/api/films/3/"
	],
	created: "2014-12-18T11:18:04.763000Z",
	edited: "2014-12-22T17:35:45.011193Z",
	url: "https://swapi.co/api/starships/29/"
},
	"https://swapi.co/api/starships/31/": {
	name: "Republic Cruiser",
	model: "Consular-class cruiser",
	manufacturer: "Corellian Engineering Corporation",
	cost_in_credits: "unknown",
	length: "115",
	max_atmosphering_speed: "900",
	crew: "9",
	passengers: "16",
	cargo_capacity: "unknown",
	consumables: "unknown",
	hyperdrive_rating: "2.0",
	MGLT: "unknown",
	starship_class: "Space cruiser",
	pilots: [
	],
	films: [
		"https://swapi.co/api/films/4/"
	],
	created: "2014-12-19T17:01:31.488000Z",
	edited: "2014-12-22T17:35:45.027308Z",
	url: "https://swapi.co/api/starships/31/"
},
	"https://swapi.co/api/starships/39/": {
	name: "Naboo fighter",
	model: "N-1 starfighter",
	manufacturer: "Theed Palace Space Vessel Engineering Corps",
	cost_in_credits: "200000",
	length: "11",
	max_atmosphering_speed: "1100",
	crew: "1",
	passengers: "0",
	cargo_capacity: "65",
	consumables: "7 days",
	hyperdrive_rating: "1.0",
	MGLT: "unknown",
	starship_class: "Starfighter",
	pilots: [
		"https://swapi.co/api/people/11/",
		"https://swapi.co/api/people/60/",
		"https://swapi.co/api/people/35/"
	],
	films: [
		"https://swapi.co/api/films/5/",
		"https://swapi.co/api/films/4/"
	],
	created: "2014-12-19T17:39:17.582000Z",
	edited: "2014-12-22T17:35:45.079452Z",
	url: "https://swapi.co/api/starships/39/"
},
	"https://swapi.co/api/starships/40/": {
	name: "Naboo Royal Starship",
	model: "J-type 327 Nubian royal starship",
	manufacturer: "Theed Palace Space Vessel Engineering Corps, Nubia Star Drives",
	cost_in_credits: "unknown",
	length: "76",
	max_atmosphering_speed: "920",
	crew: "8",
	passengers: "unknown",
	cargo_capacity: "unknown",
	consumables: "unknown",
	hyperdrive_rating: "1.8",
	MGLT: "unknown",
	starship_class: "yacht",
	pilots: [
		"https://swapi.co/api/people/39/"
	],
	films: [
		"https://swapi.co/api/films/4/"
	],
	created: "2014-12-19T17:45:03.506000Z",
	edited: "2014-12-22T17:35:45.091925Z",
	url: "https://swapi.co/api/starships/40/"
},
	"https://swapi.co/api/starships/41/": {
	name: "Scimitar",
	model: "Star Courier",
	manufacturer: "Republic Sienar Systems",
	cost_in_credits: "55000000",
	length: "26.5",
	max_atmosphering_speed: "1180",
	crew: "1",
	passengers: "6",
	cargo_capacity: "2500000",
	consumables: "30 days",
	hyperdrive_rating: "1.5",
	MGLT: "unknown",
	starship_class: "Space Transport",
	pilots: [
		"https://swapi.co/api/people/44/"
	],
	films: [
		"https://swapi.co/api/films/4/"
	],
	created: "2014-12-20T09:39:56.116000Z",
	edited: "2014-12-22T17:35:45.105522Z",
	url: "https://swapi.co/api/starships/41/"
},
	"https://swapi.co/api/starships/43/": {
	name: "J-type diplomatic barge",
	model: "J-type diplomatic barge",
	manufacturer: "Theed Palace Space Vessel Engineering Corps, Nubia Star Drives",
	cost_in_credits: "2000000",
	length: "39",
	max_atmosphering_speed: "2000",
	crew: "5",
	passengers: "10",
	cargo_capacity: "unknown",
	consumables: "1 year",
	hyperdrive_rating: "0.7",
	MGLT: "unknown",
	starship_class: "Diplomatic barge",
	pilots: [
	],
	films: [
		"https://swapi.co/api/films/5/"
	],
	created: "2014-12-20T11:05:51.237000Z",
	edited: "2014-12-22T17:35:45.124386Z",
	url: "https://swapi.co/api/starships/43/"
},
	"https://swapi.co/api/starships/47/": {
	name: "AA-9 Coruscant freighter",
	model: "Botajef AA-9 Freighter-Liner",
	manufacturer: "Botajef Shipyards",
	cost_in_credits: "unknown",
	length: "390",
	max_atmosphering_speed: "unknown",
	crew: "unknown",
	passengers: "30000",
	cargo_capacity: "unknown",
	consumables: "unknown",
	hyperdrive_rating: "unknown",
	MGLT: "unknown",
	starship_class: "freighter",
	pilots: [
	],
	films: [
		"https://swapi.co/api/films/5/"
	],
	created: "2014-12-20T17:24:23.509000Z",
	edited: "2014-12-22T17:35:45.135987Z",
	url: "https://swapi.co/api/starships/47/"
},
	"https://swapi.co/api/starships/48/": {
	name: "Jedi starfighter",
	model: "Delta-7 Aethersprite-class interceptor",
	manufacturer: "Kuat Systems Engineering",
	cost_in_credits: "180000",
	length: "8",
	max_atmosphering_speed: "1150",
	crew: "1",
	passengers: "0",
	cargo_capacity: "60",
	consumables: "7 days",
	hyperdrive_rating: "1.0",
	MGLT: "unknown",
	starship_class: "Starfighter",
	pilots: [
		"https://swapi.co/api/people/10/",
		"https://swapi.co/api/people/58/"
	],
	films: [
		"https://swapi.co/api/films/5/",
		"https://swapi.co/api/films/6/"
	],
	created: "2014-12-20T17:35:23.906000Z",
	edited: "2014-12-22T17:35:45.147746Z",
	url: "https://swapi.co/api/starships/48/"
},
	"https://swapi.co/api/starships/?page=3": {
	count: 37,
	next: "https://swapi.co/api/starships/?page=4",
	previous: "https://swapi.co/api/starships/?page=2",
	results: [
		{
			name: "H-type Nubian yacht",
			model: "H-type Nubian yacht",
			manufacturer: "Theed Palace Space Vessel Engineering Corps",
			cost_in_credits: "unknown",
			length: "47.9",
			max_atmosphering_speed: "8000",
			crew: "4",
			passengers: "unknown",
			cargo_capacity: "unknown",
			consumables: "unknown",
			hyperdrive_rating: "0.9",
			MGLT: "unknown",
			starship_class: "yacht",
			pilots: [
				"https://swapi.co/api/people/35/"
			],
			films: [
				"https://swapi.co/api/films/5/"
			],
			created: "2014-12-20T17:46:46.847000Z",
			edited: "2014-12-22T17:35:45.158969Z",
			url: "https://swapi.co/api/starships/49/"
		},
		{
			name: "Star Destroyer",
			model: "Imperial I-class Star Destroyer",
			manufacturer: "Kuat Drive Yards",
			cost_in_credits: "150000000",
			length: "1,600",
			max_atmosphering_speed: "975",
			crew: "47060",
			passengers: "0",
			cargo_capacity: "36000000",
			consumables: "2 years",
			hyperdrive_rating: "2.0",
			MGLT: "60",
			starship_class: "Star Destroyer",
			pilots: [
			],
			films: [
				"https://swapi.co/api/films/2/",
				"https://swapi.co/api/films/3/",
				"https://swapi.co/api/films/1/"
			],
			created: "2014-12-10T15:08:19.848000Z",
			edited: "2014-12-22T17:35:44.410941Z",
			url: "https://swapi.co/api/starships/3/"
		},
		{
			name: "Trade Federation cruiser",
			model: "Providence-class carrier/destroyer",
			manufacturer: "Rendili StarDrive, Free Dac Volunteers Engineering corps.",
			cost_in_credits: "125000000",
			length: "1088",
			max_atmosphering_speed: "1050",
			crew: "600",
			passengers: "48247",
			cargo_capacity: "50000000",
			consumables: "4 years",
			hyperdrive_rating: "1.5",
			MGLT: "unknown",
			starship_class: "capital ship",
			pilots: [
				"https://swapi.co/api/people/10/",
				"https://swapi.co/api/people/11/"
			],
			films: [
				"https://swapi.co/api/films/6/"
			],
			created: "2014-12-20T19:40:21.902000Z",
			edited: "2014-12-22T17:35:45.195165Z",
			url: "https://swapi.co/api/starships/59/"
		},
		{
			name: "Theta-class T-2c shuttle",
			model: "Theta-class T-2c shuttle",
			manufacturer: "Cygnus Spaceworks",
			cost_in_credits: "1000000",
			length: "18.5",
			max_atmosphering_speed: "2000",
			crew: "5",
			passengers: "16",
			cargo_capacity: "50000",
			consumables: "56 days",
			hyperdrive_rating: "1.0",
			MGLT: "unknown",
			starship_class: "transport",
			pilots: [
			],
			films: [
				"https://swapi.co/api/films/6/"
			],
			created: "2014-12-20T19:48:40.409000Z",
			edited: "2014-12-22T17:35:45.208584Z",
			url: "https://swapi.co/api/starships/61/"
		},
		{
			name: "T-70 X-wing fighter",
			model: "T-70 X-wing fighter",
			manufacturer: "Incom",
			cost_in_credits: "unknown",
			length: "unknown",
			max_atmosphering_speed: "unknown",
			crew: "1",
			passengers: "unknown",
			cargo_capacity: "unknown",
			consumables: "unknown",
			hyperdrive_rating: "unknown",
			MGLT: "unknown",
			starship_class: "fighter",
			pilots: [
				"https://swapi.co/api/people/86/"
			],
			films: [
				"https://swapi.co/api/films/7/"
			],
			created: "2015-04-17T06:58:50.614475Z",
			edited: "2015-04-17T06:58:50.614528Z",
			url: "https://swapi.co/api/starships/77/"
		},
		{
			name: "Rebel transport",
			model: "GR-75 medium transport",
			manufacturer: "Gallofree Yards, Inc.",
			cost_in_credits: "unknown",
			length: "90",
			max_atmosphering_speed: "650",
			crew: "6",
			passengers: "90",
			cargo_capacity: "19000000",
			consumables: "6 months",
			hyperdrive_rating: "4.0",
			MGLT: "20",
			starship_class: "Medium transport",
			pilots: [
			],
			films: [
				"https://swapi.co/api/films/2/",
				"https://swapi.co/api/films/3/"
			],
			created: "2014-12-15T12:34:52.264000Z",
			edited: "2014-12-22T17:35:44.680838Z",
			url: "https://swapi.co/api/starships/17/"
		},
		{
			name: "Droid control ship",
			model: "Lucrehulk-class Droid Control Ship",
			manufacturer: "Hoersch-Kessel Drive, Inc.",
			cost_in_credits: "unknown",
			length: "3170",
			max_atmosphering_speed: "n/a",
			crew: "175",
			passengers: "139000",
			cargo_capacity: "4000000000",
			consumables: "500 days",
			hyperdrive_rating: "2.0",
			MGLT: "unknown",
			starship_class: "Droid control ship",
			pilots: [
			],
			films: [
				"https://swapi.co/api/films/5/",
				"https://swapi.co/api/films/4/",
				"https://swapi.co/api/films/6/"
			],
			created: "2014-12-19T17:04:06.323000Z",
			edited: "2014-12-22T17:35:45.042900Z",
			url: "https://swapi.co/api/starships/32/"
		},
		{
			name: "Republic Assault ship",
			model: "Acclamator I-class assault ship",
			manufacturer: "Rothana Heavy Engineering",
			cost_in_credits: "unknown",
			length: "752",
			max_atmosphering_speed: "unknown",
			crew: "700",
			passengers: "16000",
			cargo_capacity: "11250000",
			consumables: "2 years",
			hyperdrive_rating: "0.6",
			MGLT: "unknown",
			starship_class: "assault ship",
			pilots: [
			],
			films: [
				"https://swapi.co/api/films/5/"
			],
			created: "2014-12-20T18:08:42.926000Z",
			edited: "2014-12-22T17:35:45.171653Z",
			url: "https://swapi.co/api/starships/52/"
		},
		{
			name: "Solar Sailer",
			model: "Punworcca 116-class interstellar sloop",
			manufacturer: "Huppla Pasa Tisc Shipwrights Collective",
			cost_in_credits: "35700",
			length: "15.2",
			max_atmosphering_speed: "1600",
			crew: "3",
			passengers: "11",
			cargo_capacity: "240",
			consumables: "7 days",
			hyperdrive_rating: "1.5",
			MGLT: "unknown",
			starship_class: "yacht",
			pilots: [
			],
			films: [
				"https://swapi.co/api/films/5/"
			],
			created: "2014-12-20T18:37:56.969000Z",
			edited: "2014-12-22T17:35:45.183075Z",
			url: "https://swapi.co/api/starships/58/"
		},
		{
			name: "Republic attack cruiser",
			model: "Senator-class Star Destroyer",
			manufacturer: "Kuat Drive Yards, Allanteen Six shipyards",
			cost_in_credits: "59000000",
			length: "1137",
			max_atmosphering_speed: "975",
			crew: "7400",
			passengers: "2000",
			cargo_capacity: "20000000",
			consumables: "2 years",
			hyperdrive_rating: "1.0",
			MGLT: "unknown",
			starship_class: "star destroyer",
			pilots: [
			],
			films: [
				"https://swapi.co/api/films/6/"
			],
			created: "2014-12-20T19:52:56.232000Z",
			edited: "2014-12-22T17:35:45.224540Z",
			url: "https://swapi.co/api/starships/63/"
		}
	]
},
	"https://swapi.co/api/starships/49/": {
	name: "H-type Nubian yacht",
	model: "H-type Nubian yacht",
	manufacturer: "Theed Palace Space Vessel Engineering Corps",
	cost_in_credits: "unknown",
	length: "47.9",
	max_atmosphering_speed: "8000",
	crew: "4",
	passengers: "unknown",
	cargo_capacity: "unknown",
	consumables: "unknown",
	hyperdrive_rating: "0.9",
	MGLT: "unknown",
	starship_class: "yacht",
	pilots: [
		"https://swapi.co/api/people/35/"
	],
	films: [
		"https://swapi.co/api/films/5/"
	],
	created: "2014-12-20T17:46:46.847000Z",
	edited: "2014-12-22T17:35:45.158969Z",
	url: "https://swapi.co/api/starships/49/"
},
	"https://swapi.co/api/starships/3/": {
	name: "Star Destroyer",
	model: "Imperial I-class Star Destroyer",
	manufacturer: "Kuat Drive Yards",
	cost_in_credits: "150000000",
	length: "1,600",
	max_atmosphering_speed: "975",
	crew: "47060",
	passengers: "0",
	cargo_capacity: "36000000",
	consumables: "2 years",
	hyperdrive_rating: "2.0",
	MGLT: "60",
	starship_class: "Star Destroyer",
	pilots: [
	],
	films: [
		"https://swapi.co/api/films/2/",
		"https://swapi.co/api/films/3/",
		"https://swapi.co/api/films/1/"
	],
	created: "2014-12-10T15:08:19.848000Z",
	edited: "2014-12-22T17:35:44.410941Z",
	url: "https://swapi.co/api/starships/3/"
},
	"https://swapi.co/api/starships/59/": {
	name: "Trade Federation cruiser",
	model: "Providence-class carrier/destroyer",
	manufacturer: "Rendili StarDrive, Free Dac Volunteers Engineering corps.",
	cost_in_credits: "125000000",
	length: "1088",
	max_atmosphering_speed: "1050",
	crew: "600",
	passengers: "48247",
	cargo_capacity: "50000000",
	consumables: "4 years",
	hyperdrive_rating: "1.5",
	MGLT: "unknown",
	starship_class: "capital ship",
	pilots: [
		"https://swapi.co/api/people/10/",
		"https://swapi.co/api/people/11/"
	],
	films: [
		"https://swapi.co/api/films/6/"
	],
	created: "2014-12-20T19:40:21.902000Z",
	edited: "2014-12-22T17:35:45.195165Z",
	url: "https://swapi.co/api/starships/59/"
},
	"https://swapi.co/api/starships/61/": {
	name: "Theta-class T-2c shuttle",
	model: "Theta-class T-2c shuttle",
	manufacturer: "Cygnus Spaceworks",
	cost_in_credits: "1000000",
	length: "18.5",
	max_atmosphering_speed: "2000",
	crew: "5",
	passengers: "16",
	cargo_capacity: "50000",
	consumables: "56 days",
	hyperdrive_rating: "1.0",
	MGLT: "unknown",
	starship_class: "transport",
	pilots: [
	],
	films: [
		"https://swapi.co/api/films/6/"
	],
	created: "2014-12-20T19:48:40.409000Z",
	edited: "2014-12-22T17:35:45.208584Z",
	url: "https://swapi.co/api/starships/61/"
},
	"https://swapi.co/api/starships/77/": {
	name: "T-70 X-wing fighter",
	model: "T-70 X-wing fighter",
	manufacturer: "Incom",
	cost_in_credits: "unknown",
	length: "unknown",
	max_atmosphering_speed: "unknown",
	crew: "1",
	passengers: "unknown",
	cargo_capacity: "unknown",
	consumables: "unknown",
	hyperdrive_rating: "unknown",
	MGLT: "unknown",
	starship_class: "fighter",
	pilots: [
		"https://swapi.co/api/people/86/"
	],
	films: [
		"https://swapi.co/api/films/7/"
	],
	created: "2015-04-17T06:58:50.614475Z",
	edited: "2015-04-17T06:58:50.614528Z",
	url: "https://swapi.co/api/starships/77/"
},
	"https://swapi.co/api/starships/17/": {
	name: "Rebel transport",
	model: "GR-75 medium transport",
	manufacturer: "Gallofree Yards, Inc.",
	cost_in_credits: "unknown",
	length: "90",
	max_atmosphering_speed: "650",
	crew: "6",
	passengers: "90",
	cargo_capacity: "19000000",
	consumables: "6 months",
	hyperdrive_rating: "4.0",
	MGLT: "20",
	starship_class: "Medium transport",
	pilots: [
	],
	films: [
		"https://swapi.co/api/films/2/",
		"https://swapi.co/api/films/3/"
	],
	created: "2014-12-15T12:34:52.264000Z",
	edited: "2014-12-22T17:35:44.680838Z",
	url: "https://swapi.co/api/starships/17/"
},
	"https://swapi.co/api/starships/32/": {
	name: "Droid control ship",
	model: "Lucrehulk-class Droid Control Ship",
	manufacturer: "Hoersch-Kessel Drive, Inc.",
	cost_in_credits: "unknown",
	length: "3170",
	max_atmosphering_speed: "n/a",
	crew: "175",
	passengers: "139000",
	cargo_capacity: "4000000000",
	consumables: "500 days",
	hyperdrive_rating: "2.0",
	MGLT: "unknown",
	starship_class: "Droid control ship",
	pilots: [
	],
	films: [
		"https://swapi.co/api/films/5/",
		"https://swapi.co/api/films/4/",
		"https://swapi.co/api/films/6/"
	],
	created: "2014-12-19T17:04:06.323000Z",
	edited: "2014-12-22T17:35:45.042900Z",
	url: "https://swapi.co/api/starships/32/"
},
	"https://swapi.co/api/starships/52/": {
	name: "Republic Assault ship",
	model: "Acclamator I-class assault ship",
	manufacturer: "Rothana Heavy Engineering",
	cost_in_credits: "unknown",
	length: "752",
	max_atmosphering_speed: "unknown",
	crew: "700",
	passengers: "16000",
	cargo_capacity: "11250000",
	consumables: "2 years",
	hyperdrive_rating: "0.6",
	MGLT: "unknown",
	starship_class: "assault ship",
	pilots: [
	],
	films: [
		"https://swapi.co/api/films/5/"
	],
	created: "2014-12-20T18:08:42.926000Z",
	edited: "2014-12-22T17:35:45.171653Z",
	url: "https://swapi.co/api/starships/52/"
},
	"https://swapi.co/api/starships/58/": {
	name: "Solar Sailer",
	model: "Punworcca 116-class interstellar sloop",
	manufacturer: "Huppla Pasa Tisc Shipwrights Collective",
	cost_in_credits: "35700",
	length: "15.2",
	max_atmosphering_speed: "1600",
	crew: "3",
	passengers: "11",
	cargo_capacity: "240",
	consumables: "7 days",
	hyperdrive_rating: "1.5",
	MGLT: "unknown",
	starship_class: "yacht",
	pilots: [
	],
	films: [
		"https://swapi.co/api/films/5/"
	],
	created: "2014-12-20T18:37:56.969000Z",
	edited: "2014-12-22T17:35:45.183075Z",
	url: "https://swapi.co/api/starships/58/"
},
	"https://swapi.co/api/starships/63/": {
	name: "Republic attack cruiser",
	model: "Senator-class Star Destroyer",
	manufacturer: "Kuat Drive Yards, Allanteen Six shipyards",
	cost_in_credits: "59000000",
	length: "1137",
	max_atmosphering_speed: "975",
	crew: "7400",
	passengers: "2000",
	cargo_capacity: "20000000",
	consumables: "2 years",
	hyperdrive_rating: "1.0",
	MGLT: "unknown",
	starship_class: "star destroyer",
	pilots: [
	],
	films: [
		"https://swapi.co/api/films/6/"
	],
	created: "2014-12-20T19:52:56.232000Z",
	edited: "2014-12-22T17:35:45.224540Z",
	url: "https://swapi.co/api/starships/63/"
},
	"https://swapi.co/api/starships/?page=4": {
	count: 37,
	next: null,
	previous: "https://swapi.co/api/starships/?page=3",
	results: [
		{
			name: "Naboo star skiff",
			model: "J-type star skiff",
			manufacturer: "Theed Palace Space Vessel Engineering Corps/Nubia Star Drives, Incorporated",
			cost_in_credits: "unknown",
			length: "29.2",
			max_atmosphering_speed: "1050",
			crew: "3",
			passengers: "3",
			cargo_capacity: "unknown",
			consumables: "unknown",
			hyperdrive_rating: "0.5",
			MGLT: "unknown",
			starship_class: "yacht",
			pilots: [
				"https://swapi.co/api/people/10/",
				"https://swapi.co/api/people/35/"
			],
			films: [
				"https://swapi.co/api/films/6/"
			],
			created: "2014-12-20T19:55:15.396000Z",
			edited: "2014-12-22T17:35:45.258859Z",
			url: "https://swapi.co/api/starships/64/"
		},
		{
			name: "Jedi Interceptor",
			model: "Eta-2 Actis-class light interceptor",
			manufacturer: "Kuat Systems Engineering",
			cost_in_credits: "320000",
			length: "5.47",
			max_atmosphering_speed: "1500",
			crew: "1",
			passengers: "0",
			cargo_capacity: "60",
			consumables: "2 days",
			hyperdrive_rating: "1.0",
			MGLT: "unknown",
			starship_class: "starfighter",
			pilots: [
				"https://swapi.co/api/people/10/",
				"https://swapi.co/api/people/11/"
			],
			films: [
				"https://swapi.co/api/films/6/"
			],
			created: "2014-12-20T19:56:57.468000Z",
			edited: "2014-12-22T17:35:45.272349Z",
			url: "https://swapi.co/api/starships/65/"
		},
		{
			name: "arc-170",
			model: "Aggressive Reconnaissance-170 starfighte",
			manufacturer: "Incom Corporation, Subpro Corporation",
			cost_in_credits: "155000",
			length: "14.5",
			max_atmosphering_speed: "1000",
			crew: "3",
			passengers: "0",
			cargo_capacity: "110",
			consumables: "5 days",
			hyperdrive_rating: "1.0",
			MGLT: "100",
			starship_class: "starfighter",
			pilots: [
			],
			films: [
				"https://swapi.co/api/films/6/"
			],
			created: "2014-12-20T20:03:48.603000Z",
			edited: "2014-12-22T17:35:45.287214Z",
			url: "https://swapi.co/api/starships/66/"
		},
		{
			name: "Belbullab-22 starfighter",
			model: "Belbullab-22 starfighter",
			manufacturer: "Feethan Ottraw Scalable Assemblies",
			cost_in_credits: "168000",
			length: "6.71",
			max_atmosphering_speed: "1100",
			crew: "1",
			passengers: "0",
			cargo_capacity: "140",
			consumables: "7 days",
			hyperdrive_rating: "6",
			MGLT: "unknown",
			starship_class: "starfighter",
			pilots: [
				"https://swapi.co/api/people/10/",
				"https://swapi.co/api/people/79/"
			],
			films: [
				"https://swapi.co/api/films/6/"
			],
			created: "2014-12-20T20:38:05.031000Z",
			edited: "2014-12-22T17:35:45.381900Z",
			url: "https://swapi.co/api/starships/74/"
		},
		{
			name: "V-wing",
			model: "Alpha-3 Nimbus-class V-wing starfighter",
			manufacturer: "Kuat Systems Engineering",
			cost_in_credits: "102500",
			length: "7.9",
			max_atmosphering_speed: "1050",
			crew: "1",
			passengers: "0",
			cargo_capacity: "60",
			consumables: "15 hours",
			hyperdrive_rating: "1.0",
			MGLT: "unknown",
			starship_class: "starfighter",
			pilots: [
			],
			films: [
				"https://swapi.co/api/films/6/"
			],
			created: "2014-12-20T20:43:04.349000Z",
			edited: "2014-12-22T17:35:45.396711Z",
			url: "https://swapi.co/api/starships/75/"
		},
		{
			name: "CR90 corvette",
			model: "CR90 corvette",
			manufacturer: "Corellian Engineering Corporation",
			cost_in_credits: "3500000",
			length: "150",
			max_atmosphering_speed: "950",
			crew: "165",
			passengers: "600",
			cargo_capacity: "3000000",
			consumables: "1 year",
			hyperdrive_rating: "2.0",
			MGLT: "60",
			starship_class: "corvette",
			pilots: [
			],
			films: [
				"https://swapi.co/api/films/6/",
				"https://swapi.co/api/films/3/",
				"https://swapi.co/api/films/1/"
			],
			created: "2014-12-10T14:20:33.369000Z",
			edited: "2014-12-22T17:35:45.408368Z",
			url: "https://swapi.co/api/starships/2/"
		},
		{
			name: "Banking clan frigate",
			model: "Munificent-class star frigate",
			manufacturer: "Hoersch-Kessel Drive, Inc, Gwori Revolutionary Industries",
			cost_in_credits: "57000000",
			length: "825",
			max_atmosphering_speed: "unknown",
			crew: "200",
			passengers: "unknown",
			cargo_capacity: "40000000",
			consumables: "2 years",
			hyperdrive_rating: "1.0",
			MGLT: "unknown",
			starship_class: "cruiser",
			pilots: [
			],
			films: [
				"https://swapi.co/api/films/6/"
			],
			created: "2014-12-20T20:07:11.538000Z",
			edited: "2017-04-19T10:53:32.700283Z",
			url: "https://swapi.co/api/starships/68/"
		}
	]
},
	"https://swapi.co/api/starships/64/": {
	name: "Naboo star skiff",
	model: "J-type star skiff",
	manufacturer: "Theed Palace Space Vessel Engineering Corps/Nubia Star Drives, Incorporated",
	cost_in_credits: "unknown",
	length: "29.2",
	max_atmosphering_speed: "1050",
	crew: "3",
	passengers: "3",
	cargo_capacity: "unknown",
	consumables: "unknown",
	hyperdrive_rating: "0.5",
	MGLT: "unknown",
	starship_class: "yacht",
	pilots: [
		"https://swapi.co/api/people/10/",
		"https://swapi.co/api/people/35/"
	],
	films: [
		"https://swapi.co/api/films/6/"
	],
	created: "2014-12-20T19:55:15.396000Z",
	edited: "2014-12-22T17:35:45.258859Z",
	url: "https://swapi.co/api/starships/64/"
},
	"https://swapi.co/api/starships/65/": {
	name: "Jedi Interceptor",
	model: "Eta-2 Actis-class light interceptor",
	manufacturer: "Kuat Systems Engineering",
	cost_in_credits: "320000",
	length: "5.47",
	max_atmosphering_speed: "1500",
	crew: "1",
	passengers: "0",
	cargo_capacity: "60",
	consumables: "2 days",
	hyperdrive_rating: "1.0",
	MGLT: "unknown",
	starship_class: "starfighter",
	pilots: [
		"https://swapi.co/api/people/10/",
		"https://swapi.co/api/people/11/"
	],
	films: [
		"https://swapi.co/api/films/6/"
	],
	created: "2014-12-20T19:56:57.468000Z",
	edited: "2014-12-22T17:35:45.272349Z",
	url: "https://swapi.co/api/starships/65/"
},
	"https://swapi.co/api/starships/66/": {
	name: "arc-170",
	model: "Aggressive Reconnaissance-170 starfighte",
	manufacturer: "Incom Corporation, Subpro Corporation",
	cost_in_credits: "155000",
	length: "14.5",
	max_atmosphering_speed: "1000",
	crew: "3",
	passengers: "0",
	cargo_capacity: "110",
	consumables: "5 days",
	hyperdrive_rating: "1.0",
	MGLT: "100",
	starship_class: "starfighter",
	pilots: [
	],
	films: [
		"https://swapi.co/api/films/6/"
	],
	created: "2014-12-20T20:03:48.603000Z",
	edited: "2014-12-22T17:35:45.287214Z",
	url: "https://swapi.co/api/starships/66/"
},
	"https://swapi.co/api/starships/74/": {
	name: "Belbullab-22 starfighter",
	model: "Belbullab-22 starfighter",
	manufacturer: "Feethan Ottraw Scalable Assemblies",
	cost_in_credits: "168000",
	length: "6.71",
	max_atmosphering_speed: "1100",
	crew: "1",
	passengers: "0",
	cargo_capacity: "140",
	consumables: "7 days",
	hyperdrive_rating: "6",
	MGLT: "unknown",
	starship_class: "starfighter",
	pilots: [
		"https://swapi.co/api/people/10/",
		"https://swapi.co/api/people/79/"
	],
	films: [
		"https://swapi.co/api/films/6/"
	],
	created: "2014-12-20T20:38:05.031000Z",
	edited: "2014-12-22T17:35:45.381900Z",
	url: "https://swapi.co/api/starships/74/"
},
	"https://swapi.co/api/starships/75/": {
	name: "V-wing",
	model: "Alpha-3 Nimbus-class V-wing starfighter",
	manufacturer: "Kuat Systems Engineering",
	cost_in_credits: "102500",
	length: "7.9",
	max_atmosphering_speed: "1050",
	crew: "1",
	passengers: "0",
	cargo_capacity: "60",
	consumables: "15 hours",
	hyperdrive_rating: "1.0",
	MGLT: "unknown",
	starship_class: "starfighter",
	pilots: [
	],
	films: [
		"https://swapi.co/api/films/6/"
	],
	created: "2014-12-20T20:43:04.349000Z",
	edited: "2014-12-22T17:35:45.396711Z",
	url: "https://swapi.co/api/starships/75/"
},
	"https://swapi.co/api/starships/2/": {
	name: "CR90 corvette",
	model: "CR90 corvette",
	manufacturer: "Corellian Engineering Corporation",
	cost_in_credits: "3500000",
	length: "150",
	max_atmosphering_speed: "950",
	crew: "165",
	passengers: "600",
	cargo_capacity: "3000000",
	consumables: "1 year",
	hyperdrive_rating: "2.0",
	MGLT: "60",
	starship_class: "corvette",
	pilots: [
	],
	films: [
		"https://swapi.co/api/films/6/",
		"https://swapi.co/api/films/3/",
		"https://swapi.co/api/films/1/"
	],
	created: "2014-12-10T14:20:33.369000Z",
	edited: "2014-12-22T17:35:45.408368Z",
	url: "https://swapi.co/api/starships/2/"
},
	"https://swapi.co/api/starships/68/": {
	name: "Banking clan frigate",
	model: "Munificent-class star frigate",
	manufacturer: "Hoersch-Kessel Drive, Inc, Gwori Revolutionary Industries",
	cost_in_credits: "57000000",
	length: "825",
	max_atmosphering_speed: "unknown",
	crew: "200",
	passengers: "unknown",
	cargo_capacity: "40000000",
	consumables: "2 years",
	hyperdrive_rating: "1.0",
	MGLT: "unknown",
	starship_class: "cruiser",
	pilots: [
	],
	films: [
		"https://swapi.co/api/films/6/"
	],
	created: "2014-12-20T20:07:11.538000Z",
	edited: "2017-04-19T10:53:32.700283Z",
	url: "https://swapi.co/api/starships/68/"
},
	"https://swapi.co/api/vehicles/": {
	count: 39,
	next: "https://swapi.co/api/vehicles/?page=2",
	previous: null,
	results: [
		{
			name: "Sand Crawler",
			model: "Digger Crawler",
			manufacturer: "Corellia Mining Corporation",
			cost_in_credits: "150000",
			length: "36.8",
			max_atmosphering_speed: "30",
			crew: "46",
			passengers: "30",
			cargo_capacity: "50000",
			consumables: "2 months",
			vehicle_class: "wheeled",
			pilots: [
			],
			films: [
				"https://swapi.co/api/films/5/",
				"https://swapi.co/api/films/1/"
			],
			created: "2014-12-10T15:36:25.724000Z",
			edited: "2014-12-22T18:21:15.523587Z",
			url: "https://swapi.co/api/vehicles/4/"
		},
		{
			name: "T-16 skyhopper",
			model: "T-16 skyhopper",
			manufacturer: "Incom Corporation",
			cost_in_credits: "14500",
			length: "10.4",
			max_atmosphering_speed: "1200",
			crew: "1",
			passengers: "1",
			cargo_capacity: "50",
			consumables: "0",
			vehicle_class: "repulsorcraft",
			pilots: [
			],
			films: [
				"https://swapi.co/api/films/1/"
			],
			created: "2014-12-10T16:01:52.434000Z",
			edited: "2014-12-22T18:21:15.552614Z",
			url: "https://swapi.co/api/vehicles/6/"
		},
		{
			name: "X-34 landspeeder",
			model: "X-34 landspeeder",
			manufacturer: "SoroSuub Corporation",
			cost_in_credits: "10550",
			length: "3.4",
			max_atmosphering_speed: "250",
			crew: "1",
			passengers: "1",
			cargo_capacity: "5",
			consumables: "unknown",
			vehicle_class: "repulsorcraft",
			pilots: [
			],
			films: [
				"https://swapi.co/api/films/1/"
			],
			created: "2014-12-10T16:13:52.586000Z",
			edited: "2014-12-22T18:21:15.583700Z",
			url: "https://swapi.co/api/vehicles/7/"
		},
		{
			name: "TIE/LN starfighter",
			model: "Twin Ion Engine/Ln Starfighter",
			manufacturer: "Sienar Fleet Systems",
			cost_in_credits: "unknown",
			length: "6.4",
			max_atmosphering_speed: "1200",
			crew: "1",
			passengers: "0",
			cargo_capacity: "65",
			consumables: "2 days",
			vehicle_class: "starfighter",
			pilots: [
			],
			films: [
				"https://swapi.co/api/films/2/",
				"https://swapi.co/api/films/3/",
				"https://swapi.co/api/films/1/"
			],
			created: "2014-12-10T16:33:52.860000Z",
			edited: "2014-12-22T18:21:15.606149Z",
			url: "https://swapi.co/api/vehicles/8/"
		},
		{
			name: "Snowspeeder",
			model: "t-47 airspeeder",
			manufacturer: "Incom corporation",
			cost_in_credits: "unknown",
			length: "4.5",
			max_atmosphering_speed: "650",
			crew: "2",
			passengers: "0",
			cargo_capacity: "10",
			consumables: "none",
			vehicle_class: "airspeeder",
			pilots: [
				"https://swapi.co/api/people/1/",
				"https://swapi.co/api/people/18/"
			],
			films: [
				"https://swapi.co/api/films/2/"
			],
			created: "2014-12-15T12:22:12Z",
			edited: "2014-12-22T18:21:15.623033Z",
			url: "https://swapi.co/api/vehicles/14/"
		},
		{
			name: "TIE bomber",
			model: "TIE/sa bomber",
			manufacturer: "Sienar Fleet Systems",
			cost_in_credits: "unknown",
			length: "7.8",
			max_atmosphering_speed: "850",
			crew: "1",
			passengers: "0",
			cargo_capacity: "none",
			consumables: "2 days",
			vehicle_class: "space/planetary bomber",
			pilots: [
			],
			films: [
				"https://swapi.co/api/films/2/",
				"https://swapi.co/api/films/3/"
			],
			created: "2014-12-15T12:33:15.838000Z",
			edited: "2014-12-22T18:21:15.667730Z",
			url: "https://swapi.co/api/vehicles/16/"
		},
		{
			name: "AT-AT",
			model: "All Terrain Armored Transport",
			manufacturer: "Kuat Drive Yards, Imperial Department of Military Research",
			cost_in_credits: "unknown",
			length: "20",
			max_atmosphering_speed: "60",
			crew: "5",
			passengers: "40",
			cargo_capacity: "1000",
			consumables: "unknown",
			vehicle_class: "assault walker",
			pilots: [
			],
			films: [
				"https://swapi.co/api/films/2/",
				"https://swapi.co/api/films/3/"
			],
			created: "2014-12-15T12:38:25.937000Z",
			edited: "2014-12-22T18:21:15.714673Z",
			url: "https://swapi.co/api/vehicles/18/"
		},
		{
			name: "AT-ST",
			model: "All Terrain Scout Transport",
			manufacturer: "Kuat Drive Yards, Imperial Department of Military Research",
			cost_in_credits: "unknown",
			length: "2",
			max_atmosphering_speed: "90",
			crew: "2",
			passengers: "0",
			cargo_capacity: "200",
			consumables: "none",
			vehicle_class: "walker",
			pilots: [
				"https://swapi.co/api/people/13/"
			],
			films: [
				"https://swapi.co/api/films/2/",
				"https://swapi.co/api/films/3/"
			],
			created: "2014-12-15T12:46:42.384000Z",
			edited: "2014-12-22T18:21:15.761584Z",
			url: "https://swapi.co/api/vehicles/19/"
		},
		{
			name: "Storm IV Twin-Pod cloud car",
			model: "Storm IV Twin-Pod",
			manufacturer: "Bespin Motors",
			cost_in_credits: "75000",
			length: "7",
			max_atmosphering_speed: "1500",
			crew: "2",
			passengers: "0",
			cargo_capacity: "10",
			consumables: "1 day",
			vehicle_class: "repulsorcraft",
			pilots: [
			],
			films: [
				"https://swapi.co/api/films/2/"
			],
			created: "2014-12-15T12:58:50.530000Z",
			edited: "2014-12-22T18:21:15.783232Z",
			url: "https://swapi.co/api/vehicles/20/"
		},
		{
			name: "Sail barge",
			model: "Modified Luxury Sail Barge",
			manufacturer: "Ubrikkian Industries Custom Vehicle Division",
			cost_in_credits: "285000",
			length: "30",
			max_atmosphering_speed: "100",
			crew: "26",
			passengers: "500",
			cargo_capacity: "2000000",
			consumables: "Live food tanks",
			vehicle_class: "sail barge",
			pilots: [
			],
			films: [
				"https://swapi.co/api/films/3/"
			],
			created: "2014-12-18T10:44:14.217000Z",
			edited: "2014-12-22T18:21:15.807906Z",
			url: "https://swapi.co/api/vehicles/24/"
		}
	]
},
	"https://swapi.co/api/vehicles/4/": {
	name: "Sand Crawler",
	model: "Digger Crawler",
	manufacturer: "Corellia Mining Corporation",
	cost_in_credits: "150000",
	length: "36.8",
	max_atmosphering_speed: "30",
	crew: "46",
	passengers: "30",
	cargo_capacity: "50000",
	consumables: "2 months",
	vehicle_class: "wheeled",
	pilots: [
	],
	films: [
		"https://swapi.co/api/films/5/",
		"https://swapi.co/api/films/1/"
	],
	created: "2014-12-10T15:36:25.724000Z",
	edited: "2014-12-22T18:21:15.523587Z",
	url: "https://swapi.co/api/vehicles/4/"
},
	"https://swapi.co/api/vehicles/6/": {
	name: "T-16 skyhopper",
	model: "T-16 skyhopper",
	manufacturer: "Incom Corporation",
	cost_in_credits: "14500",
	length: "10.4",
	max_atmosphering_speed: "1200",
	crew: "1",
	passengers: "1",
	cargo_capacity: "50",
	consumables: "0",
	vehicle_class: "repulsorcraft",
	pilots: [
	],
	films: [
		"https://swapi.co/api/films/1/"
	],
	created: "2014-12-10T16:01:52.434000Z",
	edited: "2014-12-22T18:21:15.552614Z",
	url: "https://swapi.co/api/vehicles/6/"
},
	"https://swapi.co/api/vehicles/7/": {
	name: "X-34 landspeeder",
	model: "X-34 landspeeder",
	manufacturer: "SoroSuub Corporation",
	cost_in_credits: "10550",
	length: "3.4",
	max_atmosphering_speed: "250",
	crew: "1",
	passengers: "1",
	cargo_capacity: "5",
	consumables: "unknown",
	vehicle_class: "repulsorcraft",
	pilots: [
	],
	films: [
		"https://swapi.co/api/films/1/"
	],
	created: "2014-12-10T16:13:52.586000Z",
	edited: "2014-12-22T18:21:15.583700Z",
	url: "https://swapi.co/api/vehicles/7/"
},
	"https://swapi.co/api/vehicles/8/": {
	name: "TIE/LN starfighter",
	model: "Twin Ion Engine/Ln Starfighter",
	manufacturer: "Sienar Fleet Systems",
	cost_in_credits: "unknown",
	length: "6.4",
	max_atmosphering_speed: "1200",
	crew: "1",
	passengers: "0",
	cargo_capacity: "65",
	consumables: "2 days",
	vehicle_class: "starfighter",
	pilots: [
	],
	films: [
		"https://swapi.co/api/films/2/",
		"https://swapi.co/api/films/3/",
		"https://swapi.co/api/films/1/"
	],
	created: "2014-12-10T16:33:52.860000Z",
	edited: "2014-12-22T18:21:15.606149Z",
	url: "https://swapi.co/api/vehicles/8/"
},
	"https://swapi.co/api/vehicles/14/": {
	name: "Snowspeeder",
	model: "t-47 airspeeder",
	manufacturer: "Incom corporation",
	cost_in_credits: "unknown",
	length: "4.5",
	max_atmosphering_speed: "650",
	crew: "2",
	passengers: "0",
	cargo_capacity: "10",
	consumables: "none",
	vehicle_class: "airspeeder",
	pilots: [
		"https://swapi.co/api/people/1/",
		"https://swapi.co/api/people/18/"
	],
	films: [
		"https://swapi.co/api/films/2/"
	],
	created: "2014-12-15T12:22:12Z",
	edited: "2014-12-22T18:21:15.623033Z",
	url: "https://swapi.co/api/vehicles/14/"
},
	"https://swapi.co/api/vehicles/16/": {
	name: "TIE bomber",
	model: "TIE/sa bomber",
	manufacturer: "Sienar Fleet Systems",
	cost_in_credits: "unknown",
	length: "7.8",
	max_atmosphering_speed: "850",
	crew: "1",
	passengers: "0",
	cargo_capacity: "none",
	consumables: "2 days",
	vehicle_class: "space/planetary bomber",
	pilots: [
	],
	films: [
		"https://swapi.co/api/films/2/",
		"https://swapi.co/api/films/3/"
	],
	created: "2014-12-15T12:33:15.838000Z",
	edited: "2014-12-22T18:21:15.667730Z",
	url: "https://swapi.co/api/vehicles/16/"
},
	"https://swapi.co/api/vehicles/18/": {
	name: "AT-AT",
	model: "All Terrain Armored Transport",
	manufacturer: "Kuat Drive Yards, Imperial Department of Military Research",
	cost_in_credits: "unknown",
	length: "20",
	max_atmosphering_speed: "60",
	crew: "5",
	passengers: "40",
	cargo_capacity: "1000",
	consumables: "unknown",
	vehicle_class: "assault walker",
	pilots: [
	],
	films: [
		"https://swapi.co/api/films/2/",
		"https://swapi.co/api/films/3/"
	],
	created: "2014-12-15T12:38:25.937000Z",
	edited: "2014-12-22T18:21:15.714673Z",
	url: "https://swapi.co/api/vehicles/18/"
},
	"https://swapi.co/api/vehicles/19/": {
	name: "AT-ST",
	model: "All Terrain Scout Transport",
	manufacturer: "Kuat Drive Yards, Imperial Department of Military Research",
	cost_in_credits: "unknown",
	length: "2",
	max_atmosphering_speed: "90",
	crew: "2",
	passengers: "0",
	cargo_capacity: "200",
	consumables: "none",
	vehicle_class: "walker",
	pilots: [
		"https://swapi.co/api/people/13/"
	],
	films: [
		"https://swapi.co/api/films/2/",
		"https://swapi.co/api/films/3/"
	],
	created: "2014-12-15T12:46:42.384000Z",
	edited: "2014-12-22T18:21:15.761584Z",
	url: "https://swapi.co/api/vehicles/19/"
},
	"https://swapi.co/api/vehicles/20/": {
	name: "Storm IV Twin-Pod cloud car",
	model: "Storm IV Twin-Pod",
	manufacturer: "Bespin Motors",
	cost_in_credits: "75000",
	length: "7",
	max_atmosphering_speed: "1500",
	crew: "2",
	passengers: "0",
	cargo_capacity: "10",
	consumables: "1 day",
	vehicle_class: "repulsorcraft",
	pilots: [
	],
	films: [
		"https://swapi.co/api/films/2/"
	],
	created: "2014-12-15T12:58:50.530000Z",
	edited: "2014-12-22T18:21:15.783232Z",
	url: "https://swapi.co/api/vehicles/20/"
},
	"https://swapi.co/api/vehicles/24/": {
	name: "Sail barge",
	model: "Modified Luxury Sail Barge",
	manufacturer: "Ubrikkian Industries Custom Vehicle Division",
	cost_in_credits: "285000",
	length: "30",
	max_atmosphering_speed: "100",
	crew: "26",
	passengers: "500",
	cargo_capacity: "2000000",
	consumables: "Live food tanks",
	vehicle_class: "sail barge",
	pilots: [
	],
	films: [
		"https://swapi.co/api/films/3/"
	],
	created: "2014-12-18T10:44:14.217000Z",
	edited: "2014-12-22T18:21:15.807906Z",
	url: "https://swapi.co/api/vehicles/24/"
},
	"https://swapi.co/api/vehicles/?page=2": {
	count: 39,
	next: "https://swapi.co/api/vehicles/?page=3",
	previous: "https://swapi.co/api/vehicles/?page=1",
	results: [
		{
			name: "Bantha-II cargo skiff",
			model: "Bantha-II",
			manufacturer: "Ubrikkian Industries",
			cost_in_credits: "8000",
			length: "9.5",
			max_atmosphering_speed: "250",
			crew: "5",
			passengers: "16",
			cargo_capacity: "135000",
			consumables: "1 day",
			vehicle_class: "repulsorcraft cargo skiff",
			pilots: [
			],
			films: [
				"https://swapi.co/api/films/3/"
			],
			created: "2014-12-18T10:48:03.208000Z",
			edited: "2014-12-22T18:21:15.845988Z",
			url: "https://swapi.co/api/vehicles/25/"
		},
		{
			name: "TIE/IN interceptor",
			model: "Twin Ion Engine Interceptor",
			manufacturer: "Sienar Fleet Systems",
			cost_in_credits: "unknown",
			length: "9.6",
			max_atmosphering_speed: "1250",
			crew: "1",
			passengers: "0",
			cargo_capacity: "75",
			consumables: "2 days",
			vehicle_class: "starfighter",
			pilots: [
			],
			films: [
				"https://swapi.co/api/films/3/"
			],
			created: "2014-12-18T10:50:28.225000Z",
			edited: "2014-12-22T18:21:15.882388Z",
			url: "https://swapi.co/api/vehicles/26/"
		},
		{
			name: "Imperial Speeder Bike",
			model: "74-Z speeder bike",
			manufacturer: "Aratech Repulsor Company",
			cost_in_credits: "8000",
			length: "3",
			max_atmosphering_speed: "360",
			crew: "1",
			passengers: "1",
			cargo_capacity: "4",
			consumables: "1 day",
			vehicle_class: "speeder",
			pilots: [
				"https://swapi.co/api/people/1/",
				"https://swapi.co/api/people/5/"
			],
			films: [
				"https://swapi.co/api/films/3/"
			],
			created: "2014-12-18T11:20:04.625000Z",
			edited: "2014-12-22T18:21:15.920537Z",
			url: "https://swapi.co/api/vehicles/30/"
		},
		{
			name: "Vulture Droid",
			model: "Vulture-class droid starfighter",
			manufacturer: "Haor Chall Engineering, Baktoid Armor Workshop",
			cost_in_credits: "unknown",
			length: "3.5",
			max_atmosphering_speed: "1200",
			crew: "0",
			passengers: "0",
			cargo_capacity: "0",
			consumables: "none",
			vehicle_class: "starfighter",
			pilots: [
			],
			films: [
				"https://swapi.co/api/films/4/",
				"https://swapi.co/api/films/6/"
			],
			created: "2014-12-19T17:09:53.584000Z",
			edited: "2014-12-22T18:21:15.953870Z",
			url: "https://swapi.co/api/vehicles/33/"
		},
		{
			name: "Multi-Troop Transport",
			model: "Multi-Troop Transport",
			manufacturer: "Baktoid Armor Workshop",
			cost_in_credits: "138000",
			length: "31",
			max_atmosphering_speed: "35",
			crew: "4",
			passengers: "112",
			cargo_capacity: "12000",
			consumables: "unknown",
			vehicle_class: "repulsorcraft",
			pilots: [
			],
			films: [
				"https://swapi.co/api/films/4/"
			],
			created: "2014-12-19T17:12:04.400000Z",
			edited: "2014-12-22T18:21:15.975171Z",
			url: "https://swapi.co/api/vehicles/34/"
		},
		{
			name: "Armored Assault Tank",
			model: "Armoured Assault Tank",
			manufacturer: "Baktoid Armor Workshop",
			cost_in_credits: "unknown",
			length: "9.75",
			max_atmosphering_speed: "55",
			crew: "4",
			passengers: "6",
			cargo_capacity: "unknown",
			consumables: "unknown",
			vehicle_class: "repulsorcraft",
			pilots: [
			],
			films: [
				"https://swapi.co/api/films/4/"
			],
			created: "2014-12-19T17:13:29.799000Z",
			edited: "2014-12-22T18:21:15.984817Z",
			url: "https://swapi.co/api/vehicles/35/"
		},
		{
			name: "Single Trooper Aerial Platform",
			model: "Single Trooper Aerial Platform",
			manufacturer: "Baktoid Armor Workshop",
			cost_in_credits: "2500",
			length: "2",
			max_atmosphering_speed: "400",
			crew: "1",
			passengers: "0",
			cargo_capacity: "none",
			consumables: "none",
			vehicle_class: "repulsorcraft",
			pilots: [
			],
			films: [
				"https://swapi.co/api/films/4/"
			],
			created: "2014-12-19T17:15:09.511000Z",
			edited: "2014-12-22T18:21:16.008594Z",
			url: "https://swapi.co/api/vehicles/36/"
		},
		{
			name: "C-9979 landing craft",
			model: "C-9979 landing craft",
			manufacturer: "Haor Chall Engineering",
			cost_in_credits: "200000",
			length: "210",
			max_atmosphering_speed: "587",
			crew: "140",
			passengers: "284",
			cargo_capacity: "1800000",
			consumables: "1 day",
			vehicle_class: "landing craft",
			pilots: [
			],
			films: [
				"https://swapi.co/api/films/4/"
			],
			created: "2014-12-19T17:20:36.373000Z",
			edited: "2014-12-22T18:21:16.033738Z",
			url: "https://swapi.co/api/vehicles/37/"
		},
		{
			name: "Tribubble bongo",
			model: "Tribubble bongo",
			manufacturer: "Otoh Gunga Bongameken Cooperative",
			cost_in_credits: "unknown",
			length: "15",
			max_atmosphering_speed: "85",
			crew: "1",
			passengers: "2",
			cargo_capacity: "1600",
			consumables: "unknown",
			vehicle_class: "submarine",
			pilots: [
				"https://swapi.co/api/people/10/",
				"https://swapi.co/api/people/32/"
			],
			films: [
				"https://swapi.co/api/films/4/"
			],
			created: "2014-12-19T17:37:37.924000Z",
			edited: "2014-12-22T18:21:16.072083Z",
			url: "https://swapi.co/api/vehicles/38/"
		},
		{
			name: "Sith speeder",
			model: "FC-20 speeder bike",
			manufacturer: "Razalon",
			cost_in_credits: "4000",
			length: "1.5",
			max_atmosphering_speed: "180",
			crew: "1",
			passengers: "0",
			cargo_capacity: "2",
			consumables: "unknown",
			vehicle_class: "speeder",
			pilots: [
				"https://swapi.co/api/people/44/"
			],
			films: [
				"https://swapi.co/api/films/4/"
			],
			created: "2014-12-20T10:09:56.095000Z",
			edited: "2014-12-22T18:21:16.095041Z",
			url: "https://swapi.co/api/vehicles/42/"
		}
	]
},
	"https://swapi.co/api/vehicles/25/": {
	name: "Bantha-II cargo skiff",
	model: "Bantha-II",
	manufacturer: "Ubrikkian Industries",
	cost_in_credits: "8000",
	length: "9.5",
	max_atmosphering_speed: "250",
	crew: "5",
	passengers: "16",
	cargo_capacity: "135000",
	consumables: "1 day",
	vehicle_class: "repulsorcraft cargo skiff",
	pilots: [
	],
	films: [
		"https://swapi.co/api/films/3/"
	],
	created: "2014-12-18T10:48:03.208000Z",
	edited: "2014-12-22T18:21:15.845988Z",
	url: "https://swapi.co/api/vehicles/25/"
},
	"https://swapi.co/api/vehicles/26/": {
	name: "TIE/IN interceptor",
	model: "Twin Ion Engine Interceptor",
	manufacturer: "Sienar Fleet Systems",
	cost_in_credits: "unknown",
	length: "9.6",
	max_atmosphering_speed: "1250",
	crew: "1",
	passengers: "0",
	cargo_capacity: "75",
	consumables: "2 days",
	vehicle_class: "starfighter",
	pilots: [
	],
	films: [
		"https://swapi.co/api/films/3/"
	],
	created: "2014-12-18T10:50:28.225000Z",
	edited: "2014-12-22T18:21:15.882388Z",
	url: "https://swapi.co/api/vehicles/26/"
},
	"https://swapi.co/api/vehicles/30/": {
	name: "Imperial Speeder Bike",
	model: "74-Z speeder bike",
	manufacturer: "Aratech Repulsor Company",
	cost_in_credits: "8000",
	length: "3",
	max_atmosphering_speed: "360",
	crew: "1",
	passengers: "1",
	cargo_capacity: "4",
	consumables: "1 day",
	vehicle_class: "speeder",
	pilots: [
		"https://swapi.co/api/people/1/",
		"https://swapi.co/api/people/5/"
	],
	films: [
		"https://swapi.co/api/films/3/"
	],
	created: "2014-12-18T11:20:04.625000Z",
	edited: "2014-12-22T18:21:15.920537Z",
	url: "https://swapi.co/api/vehicles/30/"
},
	"https://swapi.co/api/vehicles/33/": {
	name: "Vulture Droid",
	model: "Vulture-class droid starfighter",
	manufacturer: "Haor Chall Engineering, Baktoid Armor Workshop",
	cost_in_credits: "unknown",
	length: "3.5",
	max_atmosphering_speed: "1200",
	crew: "0",
	passengers: "0",
	cargo_capacity: "0",
	consumables: "none",
	vehicle_class: "starfighter",
	pilots: [
	],
	films: [
		"https://swapi.co/api/films/4/",
		"https://swapi.co/api/films/6/"
	],
	created: "2014-12-19T17:09:53.584000Z",
	edited: "2014-12-22T18:21:15.953870Z",
	url: "https://swapi.co/api/vehicles/33/"
},
	"https://swapi.co/api/vehicles/34/": {
	name: "Multi-Troop Transport",
	model: "Multi-Troop Transport",
	manufacturer: "Baktoid Armor Workshop",
	cost_in_credits: "138000",
	length: "31",
	max_atmosphering_speed: "35",
	crew: "4",
	passengers: "112",
	cargo_capacity: "12000",
	consumables: "unknown",
	vehicle_class: "repulsorcraft",
	pilots: [
	],
	films: [
		"https://swapi.co/api/films/4/"
	],
	created: "2014-12-19T17:12:04.400000Z",
	edited: "2014-12-22T18:21:15.975171Z",
	url: "https://swapi.co/api/vehicles/34/"
},
	"https://swapi.co/api/vehicles/35/": {
	name: "Armored Assault Tank",
	model: "Armoured Assault Tank",
	manufacturer: "Baktoid Armor Workshop",
	cost_in_credits: "unknown",
	length: "9.75",
	max_atmosphering_speed: "55",
	crew: "4",
	passengers: "6",
	cargo_capacity: "unknown",
	consumables: "unknown",
	vehicle_class: "repulsorcraft",
	pilots: [
	],
	films: [
		"https://swapi.co/api/films/4/"
	],
	created: "2014-12-19T17:13:29.799000Z",
	edited: "2014-12-22T18:21:15.984817Z",
	url: "https://swapi.co/api/vehicles/35/"
},
	"https://swapi.co/api/vehicles/36/": {
	name: "Single Trooper Aerial Platform",
	model: "Single Trooper Aerial Platform",
	manufacturer: "Baktoid Armor Workshop",
	cost_in_credits: "2500",
	length: "2",
	max_atmosphering_speed: "400",
	crew: "1",
	passengers: "0",
	cargo_capacity: "none",
	consumables: "none",
	vehicle_class: "repulsorcraft",
	pilots: [
	],
	films: [
		"https://swapi.co/api/films/4/"
	],
	created: "2014-12-19T17:15:09.511000Z",
	edited: "2014-12-22T18:21:16.008594Z",
	url: "https://swapi.co/api/vehicles/36/"
},
	"https://swapi.co/api/vehicles/37/": {
	name: "C-9979 landing craft",
	model: "C-9979 landing craft",
	manufacturer: "Haor Chall Engineering",
	cost_in_credits: "200000",
	length: "210",
	max_atmosphering_speed: "587",
	crew: "140",
	passengers: "284",
	cargo_capacity: "1800000",
	consumables: "1 day",
	vehicle_class: "landing craft",
	pilots: [
	],
	films: [
		"https://swapi.co/api/films/4/"
	],
	created: "2014-12-19T17:20:36.373000Z",
	edited: "2014-12-22T18:21:16.033738Z",
	url: "https://swapi.co/api/vehicles/37/"
},
	"https://swapi.co/api/vehicles/38/": {
	name: "Tribubble bongo",
	model: "Tribubble bongo",
	manufacturer: "Otoh Gunga Bongameken Cooperative",
	cost_in_credits: "unknown",
	length: "15",
	max_atmosphering_speed: "85",
	crew: "1",
	passengers: "2",
	cargo_capacity: "1600",
	consumables: "unknown",
	vehicle_class: "submarine",
	pilots: [
		"https://swapi.co/api/people/10/",
		"https://swapi.co/api/people/32/"
	],
	films: [
		"https://swapi.co/api/films/4/"
	],
	created: "2014-12-19T17:37:37.924000Z",
	edited: "2014-12-22T18:21:16.072083Z",
	url: "https://swapi.co/api/vehicles/38/"
},
	"https://swapi.co/api/vehicles/42/": {
	name: "Sith speeder",
	model: "FC-20 speeder bike",
	manufacturer: "Razalon",
	cost_in_credits: "4000",
	length: "1.5",
	max_atmosphering_speed: "180",
	crew: "1",
	passengers: "0",
	cargo_capacity: "2",
	consumables: "unknown",
	vehicle_class: "speeder",
	pilots: [
		"https://swapi.co/api/people/44/"
	],
	films: [
		"https://swapi.co/api/films/4/"
	],
	created: "2014-12-20T10:09:56.095000Z",
	edited: "2014-12-22T18:21:16.095041Z",
	url: "https://swapi.co/api/vehicles/42/"
},
	"https://swapi.co/api/vehicles/?page=3": {
	count: 39,
	next: "https://swapi.co/api/vehicles/?page=4",
	previous: "https://swapi.co/api/vehicles/?page=2",
	results: [
		{
			name: "Zephyr-G swoop bike",
			model: "Zephyr-G swoop bike",
			manufacturer: "Mobquet Swoops and Speeders",
			cost_in_credits: "5750",
			length: "3.68",
			max_atmosphering_speed: "350",
			crew: "1",
			passengers: "1",
			cargo_capacity: "200",
			consumables: "none",
			vehicle_class: "repulsorcraft",
			pilots: [
				"https://swapi.co/api/people/11/"
			],
			films: [
				"https://swapi.co/api/films/5/"
			],
			created: "2014-12-20T16:24:16.026000Z",
			edited: "2014-12-22T18:21:16.117652Z",
			url: "https://swapi.co/api/vehicles/44/"
		},
		{
			name: "Koro-2 Exodrive airspeeder",
			model: "Koro-2 Exodrive airspeeder",
			manufacturer: "Desler Gizh Outworld Mobility Corporation",
			cost_in_credits: "unknown",
			length: "6.6",
			max_atmosphering_speed: "800",
			crew: "1",
			passengers: "1",
			cargo_capacity: "80",
			consumables: "unknown",
			vehicle_class: "airspeeder",
			pilots: [
				"https://swapi.co/api/people/70/"
			],
			films: [
				"https://swapi.co/api/films/5/"
			],
			created: "2014-12-20T17:17:33.526000Z",
			edited: "2014-12-22T18:21:16.140018Z",
			url: "https://swapi.co/api/vehicles/45/"
		},
		{
			name: "XJ-6 airspeeder",
			model: "XJ-6 airspeeder",
			manufacturer: "Narglatch AirTech prefabricated kit",
			cost_in_credits: "unknown",
			length: "6.23",
			max_atmosphering_speed: "720",
			crew: "1",
			passengers: "1",
			cargo_capacity: "unknown",
			consumables: "unknown",
			vehicle_class: "airspeeder",
			pilots: [
				"https://swapi.co/api/people/11/"
			],
			films: [
				"https://swapi.co/api/films/5/"
			],
			created: "2014-12-20T17:19:19.991000Z",
			edited: "2014-12-22T18:21:16.150194Z",
			url: "https://swapi.co/api/vehicles/46/"
		},
		{
			name: "LAAT/i",
			model: "Low Altitude Assault Transport/infrantry",
			manufacturer: "Rothana Heavy Engineering",
			cost_in_credits: "unknown",
			length: "17.4",
			max_atmosphering_speed: "620",
			crew: "6",
			passengers: "30",
			cargo_capacity: "170",
			consumables: "unknown",
			vehicle_class: "gunship",
			pilots: [
			],
			films: [
				"https://swapi.co/api/films/5/",
				"https://swapi.co/api/films/6/"
			],
			created: "2014-12-20T18:01:21.014000Z",
			edited: "2014-12-22T18:21:16.181363Z",
			url: "https://swapi.co/api/vehicles/50/"
		},
		{
			name: "LAAT/c",
			model: "Low Altitude Assault Transport/carrier",
			manufacturer: "Rothana Heavy Engineering",
			cost_in_credits: "unknown",
			length: "28.82",
			max_atmosphering_speed: "620",
			crew: "1",
			passengers: "0",
			cargo_capacity: "40000",
			consumables: "unknown",
			vehicle_class: "gunship",
			pilots: [
			],
			films: [
				"https://swapi.co/api/films/5/"
			],
			created: "2014-12-20T18:02:46.802000Z",
			edited: "2014-12-22T18:21:16.229733Z",
			url: "https://swapi.co/api/vehicles/51/"
		},
		{
			name: "Tsmeu-6 personal wheel bike",
			model: "Tsmeu-6 personal wheel bike",
			manufacturer: "Z-Gomot Ternbuell Guppat Corporation",
			cost_in_credits: "15000",
			length: "3.5",
			max_atmosphering_speed: "330",
			crew: "1",
			passengers: "1",
			cargo_capacity: "10",
			consumables: "none",
			vehicle_class: "wheeled walker",
			pilots: [
				"https://swapi.co/api/people/79/"
			],
			films: [
				"https://swapi.co/api/films/6/"
			],
			created: "2014-12-20T19:43:54.870000Z",
			edited: "2014-12-22T18:21:16.422662Z",
			url: "https://swapi.co/api/vehicles/60/"
		},
		{
			name: "Emergency Firespeeder",
			model: "Fire suppression speeder",
			manufacturer: "unknown",
			cost_in_credits: "unknown",
			length: "unknown",
			max_atmosphering_speed: "unknown",
			crew: "2",
			passengers: "unknown",
			cargo_capacity: "unknown",
			consumables: "unknown",
			vehicle_class: "fire suppression ship",
			pilots: [
			],
			films: [
				"https://swapi.co/api/films/6/"
			],
			created: "2014-12-20T19:50:58.559000Z",
			edited: "2014-12-22T18:21:16.450655Z",
			url: "https://swapi.co/api/vehicles/62/"
		},
		{
			name: "Droid tri-fighter",
			model: "tri-fighter",
			manufacturer: "Colla Designs, Phlac-Arphocc Automata Industries",
			cost_in_credits: "20000",
			length: "5.4",
			max_atmosphering_speed: "1180",
			crew: "1",
			passengers: "0",
			cargo_capacity: "0",
			consumables: "none",
			vehicle_class: "droid starfighter",
			pilots: [
			],
			films: [
				"https://swapi.co/api/films/6/"
			],
			created: "2014-12-20T20:05:19.992000Z",
			edited: "2014-12-22T18:21:16.478901Z",
			url: "https://swapi.co/api/vehicles/67/"
		},
		{
			name: "Oevvaor jet catamaran",
			model: "Oevvaor jet catamaran",
			manufacturer: "Appazanna Engineering Works",
			cost_in_credits: "12125",
			length: "15.1",
			max_atmosphering_speed: "420",
			crew: "2",
			passengers: "2",
			cargo_capacity: "50",
			consumables: "3 days",
			vehicle_class: "airspeeder",
			pilots: [
			],
			films: [
				"https://swapi.co/api/films/6/"
			],
			created: "2014-12-20T20:20:53.931000Z",
			edited: "2014-12-22T18:21:16.517049Z",
			url: "https://swapi.co/api/vehicles/69/"
		},
		{
			name: "Raddaugh Gnasp fluttercraft",
			model: "Raddaugh Gnasp fluttercraft",
			manufacturer: "Appazanna Engineering Works",
			cost_in_credits: "14750",
			length: "7",
			max_atmosphering_speed: "310",
			crew: "2",
			passengers: "0",
			cargo_capacity: "20",
			consumables: "none",
			vehicle_class: "air speeder",
			pilots: [
			],
			films: [
				"https://swapi.co/api/films/6/"
			],
			created: "2014-12-20T20:21:55.648000Z",
			edited: "2014-12-22T18:21:16.547708Z",
			url: "https://swapi.co/api/vehicles/70/"
		}
	]
},
	"https://swapi.co/api/vehicles/44/": {
	name: "Zephyr-G swoop bike",
	model: "Zephyr-G swoop bike",
	manufacturer: "Mobquet Swoops and Speeders",
	cost_in_credits: "5750",
	length: "3.68",
	max_atmosphering_speed: "350",
	crew: "1",
	passengers: "1",
	cargo_capacity: "200",
	consumables: "none",
	vehicle_class: "repulsorcraft",
	pilots: [
		"https://swapi.co/api/people/11/"
	],
	films: [
		"https://swapi.co/api/films/5/"
	],
	created: "2014-12-20T16:24:16.026000Z",
	edited: "2014-12-22T18:21:16.117652Z",
	url: "https://swapi.co/api/vehicles/44/"
},
	"https://swapi.co/api/vehicles/45/": {
	name: "Koro-2 Exodrive airspeeder",
	model: "Koro-2 Exodrive airspeeder",
	manufacturer: "Desler Gizh Outworld Mobility Corporation",
	cost_in_credits: "unknown",
	length: "6.6",
	max_atmosphering_speed: "800",
	crew: "1",
	passengers: "1",
	cargo_capacity: "80",
	consumables: "unknown",
	vehicle_class: "airspeeder",
	pilots: [
		"https://swapi.co/api/people/70/"
	],
	films: [
		"https://swapi.co/api/films/5/"
	],
	created: "2014-12-20T17:17:33.526000Z",
	edited: "2014-12-22T18:21:16.140018Z",
	url: "https://swapi.co/api/vehicles/45/"
},
	"https://swapi.co/api/vehicles/46/": {
	name: "XJ-6 airspeeder",
	model: "XJ-6 airspeeder",
	manufacturer: "Narglatch AirTech prefabricated kit",
	cost_in_credits: "unknown",
	length: "6.23",
	max_atmosphering_speed: "720",
	crew: "1",
	passengers: "1",
	cargo_capacity: "unknown",
	consumables: "unknown",
	vehicle_class: "airspeeder",
	pilots: [
		"https://swapi.co/api/people/11/"
	],
	films: [
		"https://swapi.co/api/films/5/"
	],
	created: "2014-12-20T17:19:19.991000Z",
	edited: "2014-12-22T18:21:16.150194Z",
	url: "https://swapi.co/api/vehicles/46/"
},
	"https://swapi.co/api/vehicles/50/": {
	name: "LAAT/i",
	model: "Low Altitude Assault Transport/infrantry",
	manufacturer: "Rothana Heavy Engineering",
	cost_in_credits: "unknown",
	length: "17.4",
	max_atmosphering_speed: "620",
	crew: "6",
	passengers: "30",
	cargo_capacity: "170",
	consumables: "unknown",
	vehicle_class: "gunship",
	pilots: [
	],
	films: [
		"https://swapi.co/api/films/5/",
		"https://swapi.co/api/films/6/"
	],
	created: "2014-12-20T18:01:21.014000Z",
	edited: "2014-12-22T18:21:16.181363Z",
	url: "https://swapi.co/api/vehicles/50/"
},
	"https://swapi.co/api/vehicles/51/": {
	name: "LAAT/c",
	model: "Low Altitude Assault Transport/carrier",
	manufacturer: "Rothana Heavy Engineering",
	cost_in_credits: "unknown",
	length: "28.82",
	max_atmosphering_speed: "620",
	crew: "1",
	passengers: "0",
	cargo_capacity: "40000",
	consumables: "unknown",
	vehicle_class: "gunship",
	pilots: [
	],
	films: [
		"https://swapi.co/api/films/5/"
	],
	created: "2014-12-20T18:02:46.802000Z",
	edited: "2014-12-22T18:21:16.229733Z",
	url: "https://swapi.co/api/vehicles/51/"
},
	"https://swapi.co/api/vehicles/60/": {
	name: "Tsmeu-6 personal wheel bike",
	model: "Tsmeu-6 personal wheel bike",
	manufacturer: "Z-Gomot Ternbuell Guppat Corporation",
	cost_in_credits: "15000",
	length: "3.5",
	max_atmosphering_speed: "330",
	crew: "1",
	passengers: "1",
	cargo_capacity: "10",
	consumables: "none",
	vehicle_class: "wheeled walker",
	pilots: [
		"https://swapi.co/api/people/79/"
	],
	films: [
		"https://swapi.co/api/films/6/"
	],
	created: "2014-12-20T19:43:54.870000Z",
	edited: "2014-12-22T18:21:16.422662Z",
	url: "https://swapi.co/api/vehicles/60/"
},
	"https://swapi.co/api/vehicles/62/": {
	name: "Emergency Firespeeder",
	model: "Fire suppression speeder",
	manufacturer: "unknown",
	cost_in_credits: "unknown",
	length: "unknown",
	max_atmosphering_speed: "unknown",
	crew: "2",
	passengers: "unknown",
	cargo_capacity: "unknown",
	consumables: "unknown",
	vehicle_class: "fire suppression ship",
	pilots: [
	],
	films: [
		"https://swapi.co/api/films/6/"
	],
	created: "2014-12-20T19:50:58.559000Z",
	edited: "2014-12-22T18:21:16.450655Z",
	url: "https://swapi.co/api/vehicles/62/"
},
	"https://swapi.co/api/vehicles/67/": {
	name: "Droid tri-fighter",
	model: "tri-fighter",
	manufacturer: "Colla Designs, Phlac-Arphocc Automata Industries",
	cost_in_credits: "20000",
	length: "5.4",
	max_atmosphering_speed: "1180",
	crew: "1",
	passengers: "0",
	cargo_capacity: "0",
	consumables: "none",
	vehicle_class: "droid starfighter",
	pilots: [
	],
	films: [
		"https://swapi.co/api/films/6/"
	],
	created: "2014-12-20T20:05:19.992000Z",
	edited: "2014-12-22T18:21:16.478901Z",
	url: "https://swapi.co/api/vehicles/67/"
},
	"https://swapi.co/api/vehicles/69/": {
	name: "Oevvaor jet catamaran",
	model: "Oevvaor jet catamaran",
	manufacturer: "Appazanna Engineering Works",
	cost_in_credits: "12125",
	length: "15.1",
	max_atmosphering_speed: "420",
	crew: "2",
	passengers: "2",
	cargo_capacity: "50",
	consumables: "3 days",
	vehicle_class: "airspeeder",
	pilots: [
	],
	films: [
		"https://swapi.co/api/films/6/"
	],
	created: "2014-12-20T20:20:53.931000Z",
	edited: "2014-12-22T18:21:16.517049Z",
	url: "https://swapi.co/api/vehicles/69/"
},
	"https://swapi.co/api/vehicles/70/": {
	name: "Raddaugh Gnasp fluttercraft",
	model: "Raddaugh Gnasp fluttercraft",
	manufacturer: "Appazanna Engineering Works",
	cost_in_credits: "14750",
	length: "7",
	max_atmosphering_speed: "310",
	crew: "2",
	passengers: "0",
	cargo_capacity: "20",
	consumables: "none",
	vehicle_class: "air speeder",
	pilots: [
	],
	films: [
		"https://swapi.co/api/films/6/"
	],
	created: "2014-12-20T20:21:55.648000Z",
	edited: "2014-12-22T18:21:16.547708Z",
	url: "https://swapi.co/api/vehicles/70/"
},
	"https://swapi.co/api/vehicles/?page=4": {
	count: 39,
	next: null,
	previous: "https://swapi.co/api/vehicles/?page=3",
	results: [
		{
			name: "Clone turbo tank",
			model: "HAVw A6 Juggernaut",
			manufacturer: "Kuat Drive Yards",
			cost_in_credits: "350000",
			length: "49.4",
			max_atmosphering_speed: "160",
			crew: "20",
			passengers: "300",
			cargo_capacity: "30000",
			consumables: "20 days",
			vehicle_class: "wheeled walker",
			pilots: [
			],
			films: [
				"https://swapi.co/api/films/6/"
			],
			created: "2014-12-20T20:24:45.587000Z",
			edited: "2014-12-22T18:21:16.571079Z",
			url: "https://swapi.co/api/vehicles/71/"
		},
		{
			name: "Corporate Alliance tank droid",
			model: "NR-N99 Persuader-class droid enforcer",
			manufacturer: "Techno Union",
			cost_in_credits: "49000",
			length: "10.96",
			max_atmosphering_speed: "100",
			crew: "0",
			passengers: "4",
			cargo_capacity: "none",
			consumables: "none",
			vehicle_class: "droid tank",
			pilots: [
			],
			films: [
				"https://swapi.co/api/films/6/"
			],
			created: "2014-12-20T20:26:55.522000Z",
			edited: "2014-12-22T18:21:16.612902Z",
			url: "https://swapi.co/api/vehicles/72/"
		},
		{
			name: "Droid gunship",
			model: "HMP droid gunship",
			manufacturer: "Baktoid Fleet Ordnance, Haor Chall Engineering",
			cost_in_credits: "60000",
			length: "12.3",
			max_atmosphering_speed: "820",
			crew: "0",
			passengers: "0",
			cargo_capacity: "0",
			consumables: "none",
			vehicle_class: "airspeeder",
			pilots: [
			],
			films: [
				"https://swapi.co/api/films/6/"
			],
			created: "2014-12-20T20:32:05.687000Z",
			edited: "2014-12-22T18:21:16.643329Z",
			url: "https://swapi.co/api/vehicles/73/"
		},
		{
			name: "AT-RT",
			model: "All Terrain Recon Transport",
			manufacturer: "Kuat Drive Yards",
			cost_in_credits: "40000",
			length: "3.2",
			max_atmosphering_speed: "90",
			crew: "1",
			passengers: "0",
			cargo_capacity: "20",
			consumables: "1 day",
			vehicle_class: "walker",
			pilots: [
			],
			films: [
				"https://swapi.co/api/films/6/"
			],
			created: "2014-12-20T20:47:49.189000Z",
			edited: "2014-12-22T18:21:16.672821Z",
			url: "https://swapi.co/api/vehicles/76/"
		},
		{
			name: "AT-TE",
			model: "All Terrain Tactical Enforcer",
			manufacturer: "Rothana Heavy Engineering, Kuat Drive Yards",
			cost_in_credits: "unknown",
			length: "13.2",
			max_atmosphering_speed: "60",
			crew: "6",
			passengers: "36",
			cargo_capacity: "10000",
			consumables: "21 days",
			vehicle_class: "walker",
			pilots: [
			],
			films: [
				"https://swapi.co/api/films/5/",
				"https://swapi.co/api/films/6/"
			],
			created: "2014-12-20T18:10:07.560000Z",
			edited: "2014-12-22T18:21:16.293771Z",
			url: "https://swapi.co/api/vehicles/53/"
		},
		{
			name: "SPHA",
			model: "Self-Propelled Heavy Artillery",
			manufacturer: "Rothana Heavy Engineering",
			cost_in_credits: "unknown",
			length: "140",
			max_atmosphering_speed: "35",
			crew: "25",
			passengers: "30",
			cargo_capacity: "500",
			consumables: "7 days",
			vehicle_class: "walker",
			pilots: [
			],
			films: [
				"https://swapi.co/api/films/5/"
			],
			created: "2014-12-20T18:12:32.315000Z",
			edited: "2014-12-22T18:21:16.311761Z",
			url: "https://swapi.co/api/vehicles/54/"
		},
		{
			name: "Flitknot speeder",
			model: "Flitknot speeder",
			manufacturer: "Huppla Pasa Tisc Shipwrights Collective",
			cost_in_credits: "8000",
			length: "2",
			max_atmosphering_speed: "634",
			crew: "1",
			passengers: "0",
			cargo_capacity: "unknown",
			consumables: "unknown",
			vehicle_class: "speeder",
			pilots: [
				"https://swapi.co/api/people/67/"
			],
			films: [
				"https://swapi.co/api/films/5/"
			],
			created: "2014-12-20T18:15:20.312000Z",
			edited: "2014-12-22T18:21:16.335005Z",
			url: "https://swapi.co/api/vehicles/55/"
		},
		{
			name: "Neimoidian shuttle",
			model: "Sheathipede-class transport shuttle",
			manufacturer: "Haor Chall Engineering",
			cost_in_credits: "unknown",
			length: "20",
			max_atmosphering_speed: "880",
			crew: "2",
			passengers: "6",
			cargo_capacity: "1000",
			consumables: "7 days",
			vehicle_class: "transport",
			pilots: [
			],
			films: [
				"https://swapi.co/api/films/5/",
				"https://swapi.co/api/films/6/"
			],
			created: "2014-12-20T18:25:44.912000Z",
			edited: "2014-12-22T18:21:16.366134Z",
			url: "https://swapi.co/api/vehicles/56/"
		},
		{
			name: "Geonosian starfighter",
			model: "Nantex-class territorial defense",
			manufacturer: "Huppla Pasa Tisc Shipwrights Collective",
			cost_in_credits: "unknown",
			length: "9.8",
			max_atmosphering_speed: "20000",
			crew: "1",
			passengers: "0",
			cargo_capacity: "unknown",
			consumables: "unknown",
			vehicle_class: "starfighter",
			pilots: [
			],
			films: [
				"https://swapi.co/api/films/5/"
			],
			created: "2014-12-20T18:34:12.541000Z",
			edited: "2014-12-22T18:21:16.390980Z",
			url: "https://swapi.co/api/vehicles/57/"
		}
	]
},
	"https://swapi.co/api/vehicles/71/": {
	name: "Clone turbo tank",
	model: "HAVw A6 Juggernaut",
	manufacturer: "Kuat Drive Yards",
	cost_in_credits: "350000",
	length: "49.4",
	max_atmosphering_speed: "160",
	crew: "20",
	passengers: "300",
	cargo_capacity: "30000",
	consumables: "20 days",
	vehicle_class: "wheeled walker",
	pilots: [
	],
	films: [
		"https://swapi.co/api/films/6/"
	],
	created: "2014-12-20T20:24:45.587000Z",
	edited: "2014-12-22T18:21:16.571079Z",
	url: "https://swapi.co/api/vehicles/71/"
},
	"https://swapi.co/api/vehicles/72/": {
	name: "Corporate Alliance tank droid",
	model: "NR-N99 Persuader-class droid enforcer",
	manufacturer: "Techno Union",
	cost_in_credits: "49000",
	length: "10.96",
	max_atmosphering_speed: "100",
	crew: "0",
	passengers: "4",
	cargo_capacity: "none",
	consumables: "none",
	vehicle_class: "droid tank",
	pilots: [
	],
	films: [
		"https://swapi.co/api/films/6/"
	],
	created: "2014-12-20T20:26:55.522000Z",
	edited: "2014-12-22T18:21:16.612902Z",
	url: "https://swapi.co/api/vehicles/72/"
},
	"https://swapi.co/api/vehicles/73/": {
	name: "Droid gunship",
	model: "HMP droid gunship",
	manufacturer: "Baktoid Fleet Ordnance, Haor Chall Engineering",
	cost_in_credits: "60000",
	length: "12.3",
	max_atmosphering_speed: "820",
	crew: "0",
	passengers: "0",
	cargo_capacity: "0",
	consumables: "none",
	vehicle_class: "airspeeder",
	pilots: [
	],
	films: [
		"https://swapi.co/api/films/6/"
	],
	created: "2014-12-20T20:32:05.687000Z",
	edited: "2014-12-22T18:21:16.643329Z",
	url: "https://swapi.co/api/vehicles/73/"
},
	"https://swapi.co/api/vehicles/76/": {
	name: "AT-RT",
	model: "All Terrain Recon Transport",
	manufacturer: "Kuat Drive Yards",
	cost_in_credits: "40000",
	length: "3.2",
	max_atmosphering_speed: "90",
	crew: "1",
	passengers: "0",
	cargo_capacity: "20",
	consumables: "1 day",
	vehicle_class: "walker",
	pilots: [
	],
	films: [
		"https://swapi.co/api/films/6/"
	],
	created: "2014-12-20T20:47:49.189000Z",
	edited: "2014-12-22T18:21:16.672821Z",
	url: "https://swapi.co/api/vehicles/76/"
},
	"https://swapi.co/api/vehicles/53/": {
	name: "AT-TE",
	model: "All Terrain Tactical Enforcer",
	manufacturer: "Rothana Heavy Engineering, Kuat Drive Yards",
	cost_in_credits: "unknown",
	length: "13.2",
	max_atmosphering_speed: "60",
	crew: "6",
	passengers: "36",
	cargo_capacity: "10000",
	consumables: "21 days",
	vehicle_class: "walker",
	pilots: [
	],
	films: [
		"https://swapi.co/api/films/5/",
		"https://swapi.co/api/films/6/"
	],
	created: "2014-12-20T18:10:07.560000Z",
	edited: "2014-12-22T18:21:16.293771Z",
	url: "https://swapi.co/api/vehicles/53/"
},
	"https://swapi.co/api/vehicles/54/": {
	name: "SPHA",
	model: "Self-Propelled Heavy Artillery",
	manufacturer: "Rothana Heavy Engineering",
	cost_in_credits: "unknown",
	length: "140",
	max_atmosphering_speed: "35",
	crew: "25",
	passengers: "30",
	cargo_capacity: "500",
	consumables: "7 days",
	vehicle_class: "walker",
	pilots: [
	],
	films: [
		"https://swapi.co/api/films/5/"
	],
	created: "2014-12-20T18:12:32.315000Z",
	edited: "2014-12-22T18:21:16.311761Z",
	url: "https://swapi.co/api/vehicles/54/"
},
	"https://swapi.co/api/vehicles/55/": {
	name: "Flitknot speeder",
	model: "Flitknot speeder",
	manufacturer: "Huppla Pasa Tisc Shipwrights Collective",
	cost_in_credits: "8000",
	length: "2",
	max_atmosphering_speed: "634",
	crew: "1",
	passengers: "0",
	cargo_capacity: "unknown",
	consumables: "unknown",
	vehicle_class: "speeder",
	pilots: [
		"https://swapi.co/api/people/67/"
	],
	films: [
		"https://swapi.co/api/films/5/"
	],
	created: "2014-12-20T18:15:20.312000Z",
	edited: "2014-12-22T18:21:16.335005Z",
	url: "https://swapi.co/api/vehicles/55/"
},
	"https://swapi.co/api/vehicles/56/": {
	name: "Neimoidian shuttle",
	model: "Sheathipede-class transport shuttle",
	manufacturer: "Haor Chall Engineering",
	cost_in_credits: "unknown",
	length: "20",
	max_atmosphering_speed: "880",
	crew: "2",
	passengers: "6",
	cargo_capacity: "1000",
	consumables: "7 days",
	vehicle_class: "transport",
	pilots: [
	],
	films: [
		"https://swapi.co/api/films/5/",
		"https://swapi.co/api/films/6/"
	],
	created: "2014-12-20T18:25:44.912000Z",
	edited: "2014-12-22T18:21:16.366134Z",
	url: "https://swapi.co/api/vehicles/56/"
},
	"https://swapi.co/api/vehicles/57/": {
	name: "Geonosian starfighter",
	model: "Nantex-class territorial defense",
	manufacturer: "Huppla Pasa Tisc Shipwrights Collective",
	cost_in_credits: "unknown",
	length: "9.8",
	max_atmosphering_speed: "20000",
	crew: "1",
	passengers: "0",
	cargo_capacity: "unknown",
	consumables: "unknown",
	vehicle_class: "starfighter",
	pilots: [
	],
	films: [
		"https://swapi.co/api/films/5/"
	],
	created: "2014-12-20T18:34:12.541000Z",
	edited: "2014-12-22T18:21:16.390980Z",
	url: "https://swapi.co/api/vehicles/57/"
},
	"https://swapi.co/api/species/": {
	count: 37,
	next: "https://swapi.co/api/species/?page=2",
	previous: null,
	results: [
		{
			name: "Hutt",
			classification: "gastropod",
			designation: "sentient",
			average_height: "300",
			skin_colors: "green, brown, tan",
			hair_colors: "n/a",
			eye_colors: "yellow, red",
			average_lifespan: "1000",
			homeworld: "https://swapi.co/api/planets/24/",
			language: "Huttese",
			people: [
				"https://swapi.co/api/people/16/"
			],
			films: [
				"https://swapi.co/api/films/3/",
				"https://swapi.co/api/films/1/"
			],
			created: "2014-12-10T17:12:50.410000Z",
			edited: "2014-12-20T21:36:42.146000Z",
			url: "https://swapi.co/api/species/5/"
		},
		{
			name: "Yoda's species",
			classification: "mammal",
			designation: "sentient",
			average_height: "66",
			skin_colors: "green, yellow",
			hair_colors: "brown, white",
			eye_colors: "brown, green, yellow",
			average_lifespan: "900",
			homeworld: "https://swapi.co/api/planets/28/",
			language: "Galactic basic",
			people: [
				"https://swapi.co/api/people/20/"
			],
			films: [
				"https://swapi.co/api/films/2/",
				"https://swapi.co/api/films/5/",
				"https://swapi.co/api/films/4/",
				"https://swapi.co/api/films/6/",
				"https://swapi.co/api/films/3/"
			],
			created: "2014-12-15T12:27:22.877000Z",
			edited: "2014-12-20T21:36:42.148000Z",
			url: "https://swapi.co/api/species/6/"
		},
		{
			name: "Trandoshan",
			classification: "reptile",
			designation: "sentient",
			average_height: "200",
			skin_colors: "brown, green",
			hair_colors: "none",
			eye_colors: "yellow, orange",
			average_lifespan: "unknown",
			homeworld: "https://swapi.co/api/planets/29/",
			language: "Dosh",
			people: [
				"https://swapi.co/api/people/24/"
			],
			films: [
				"https://swapi.co/api/films/2/"
			],
			created: "2014-12-15T13:07:47.704000Z",
			edited: "2014-12-20T21:36:42.151000Z",
			url: "https://swapi.co/api/species/7/"
		},
		{
			name: "Mon Calamari",
			classification: "amphibian",
			designation: "sentient",
			average_height: "160",
			skin_colors: "red, blue, brown, magenta",
			hair_colors: "none",
			eye_colors: "yellow",
			average_lifespan: "unknown",
			homeworld: "https://swapi.co/api/planets/31/",
			language: "Mon Calamarian",
			people: [
				"https://swapi.co/api/people/27/"
			],
			films: [
				"https://swapi.co/api/films/3/"
			],
			created: "2014-12-18T11:09:52.263000Z",
			edited: "2014-12-20T21:36:42.153000Z",
			url: "https://swapi.co/api/species/8/"
		},
		{
			name: "Ewok",
			classification: "mammal",
			designation: "sentient",
			average_height: "100",
			skin_colors: "brown",
			hair_colors: "white, brown, black",
			eye_colors: "orange, brown",
			average_lifespan: "unknown",
			homeworld: "https://swapi.co/api/planets/7/",
			language: "Ewokese",
			people: [
				"https://swapi.co/api/people/30/"
			],
			films: [
				"https://swapi.co/api/films/3/"
			],
			created: "2014-12-18T11:22:00.285000Z",
			edited: "2014-12-20T21:36:42.155000Z",
			url: "https://swapi.co/api/species/9/"
		},
		{
			name: "Sullustan",
			classification: "mammal",
			designation: "sentient",
			average_height: "180",
			skin_colors: "pale",
			hair_colors: "none",
			eye_colors: "black",
			average_lifespan: "unknown",
			homeworld: "https://swapi.co/api/planets/33/",
			language: "Sullutese",
			people: [
				"https://swapi.co/api/people/31/"
			],
			films: [
				"https://swapi.co/api/films/3/"
			],
			created: "2014-12-18T11:26:20.103000Z",
			edited: "2014-12-20T21:36:42.157000Z",
			url: "https://swapi.co/api/species/10/"
		},
		{
			name: "Neimodian",
			classification: "unknown",
			designation: "sentient",
			average_height: "180",
			skin_colors: "grey, green",
			hair_colors: "none",
			eye_colors: "red, pink",
			average_lifespan: "unknown",
			homeworld: "https://swapi.co/api/planets/18/",
			language: "Neimoidia",
			people: [
				"https://swapi.co/api/people/33/"
			],
			films: [
				"https://swapi.co/api/films/4/"
			],
			created: "2014-12-19T17:07:31.319000Z",
			edited: "2014-12-20T21:36:42.160000Z",
			url: "https://swapi.co/api/species/11/"
		},
		{
			name: "Gungan",
			classification: "amphibian",
			designation: "sentient",
			average_height: "190",
			skin_colors: "brown, green",
			hair_colors: "none",
			eye_colors: "orange",
			average_lifespan: "unknown",
			homeworld: "https://swapi.co/api/planets/8/",
			language: "Gungan basic",
			people: [
				"https://swapi.co/api/people/36/",
				"https://swapi.co/api/people/37/",
				"https://swapi.co/api/people/38/"
			],
			films: [
				"https://swapi.co/api/films/5/",
				"https://swapi.co/api/films/4/"
			],
			created: "2014-12-19T17:30:37.341000Z",
			edited: "2014-12-20T21:36:42.163000Z",
			url: "https://swapi.co/api/species/12/"
		},
		{
			name: "Toydarian",
			classification: "mammal",
			designation: "sentient",
			average_height: "120",
			skin_colors: "blue, green, grey",
			hair_colors: "none",
			eye_colors: "yellow",
			average_lifespan: "91",
			homeworld: "https://swapi.co/api/planets/34/",
			language: "Toydarian",
			people: [
				"https://swapi.co/api/people/40/"
			],
			films: [
				"https://swapi.co/api/films/5/",
				"https://swapi.co/api/films/4/"
			],
			created: "2014-12-19T17:48:56.893000Z",
			edited: "2014-12-20T21:36:42.165000Z",
			url: "https://swapi.co/api/species/13/"
		},
		{
			name: "Dug",
			classification: "mammal",
			designation: "sentient",
			average_height: "100",
			skin_colors: "brown, purple, grey, red",
			hair_colors: "none",
			eye_colors: "yellow, blue",
			average_lifespan: "unknown",
			homeworld: "https://swapi.co/api/planets/35/",
			language: "Dugese",
			people: [
				"https://swapi.co/api/people/41/"
			],
			films: [
				"https://swapi.co/api/films/4/"
			],
			created: "2014-12-19T17:53:11.214000Z",
			edited: "2014-12-20T21:36:42.167000Z",
			url: "https://swapi.co/api/species/14/"
		}
	]
},
	"https://swapi.co/api/species/5/": {
	name: "Hutt",
	classification: "gastropod",
	designation: "sentient",
	average_height: "300",
	skin_colors: "green, brown, tan",
	hair_colors: "n/a",
	eye_colors: "yellow, red",
	average_lifespan: "1000",
	homeworld: "https://swapi.co/api/planets/24/",
	language: "Huttese",
	people: [
		"https://swapi.co/api/people/16/"
	],
	films: [
		"https://swapi.co/api/films/3/",
		"https://swapi.co/api/films/1/"
	],
	created: "2014-12-10T17:12:50.410000Z",
	edited: "2014-12-20T21:36:42.146000Z",
	url: "https://swapi.co/api/species/5/"
},
	"https://swapi.co/api/species/6/": {
	name: "Yoda's species",
	classification: "mammal",
	designation: "sentient",
	average_height: "66",
	skin_colors: "green, yellow",
	hair_colors: "brown, white",
	eye_colors: "brown, green, yellow",
	average_lifespan: "900",
	homeworld: "https://swapi.co/api/planets/28/",
	language: "Galactic basic",
	people: [
		"https://swapi.co/api/people/20/"
	],
	films: [
		"https://swapi.co/api/films/2/",
		"https://swapi.co/api/films/5/",
		"https://swapi.co/api/films/4/",
		"https://swapi.co/api/films/6/",
		"https://swapi.co/api/films/3/"
	],
	created: "2014-12-15T12:27:22.877000Z",
	edited: "2014-12-20T21:36:42.148000Z",
	url: "https://swapi.co/api/species/6/"
},
	"https://swapi.co/api/species/7/": {
	name: "Trandoshan",
	classification: "reptile",
	designation: "sentient",
	average_height: "200",
	skin_colors: "brown, green",
	hair_colors: "none",
	eye_colors: "yellow, orange",
	average_lifespan: "unknown",
	homeworld: "https://swapi.co/api/planets/29/",
	language: "Dosh",
	people: [
		"https://swapi.co/api/people/24/"
	],
	films: [
		"https://swapi.co/api/films/2/"
	],
	created: "2014-12-15T13:07:47.704000Z",
	edited: "2014-12-20T21:36:42.151000Z",
	url: "https://swapi.co/api/species/7/"
},
	"https://swapi.co/api/species/8/": {
	name: "Mon Calamari",
	classification: "amphibian",
	designation: "sentient",
	average_height: "160",
	skin_colors: "red, blue, brown, magenta",
	hair_colors: "none",
	eye_colors: "yellow",
	average_lifespan: "unknown",
	homeworld: "https://swapi.co/api/planets/31/",
	language: "Mon Calamarian",
	people: [
		"https://swapi.co/api/people/27/"
	],
	films: [
		"https://swapi.co/api/films/3/"
	],
	created: "2014-12-18T11:09:52.263000Z",
	edited: "2014-12-20T21:36:42.153000Z",
	url: "https://swapi.co/api/species/8/"
},
	"https://swapi.co/api/species/9/": {
	name: "Ewok",
	classification: "mammal",
	designation: "sentient",
	average_height: "100",
	skin_colors: "brown",
	hair_colors: "white, brown, black",
	eye_colors: "orange, brown",
	average_lifespan: "unknown",
	homeworld: "https://swapi.co/api/planets/7/",
	language: "Ewokese",
	people: [
		"https://swapi.co/api/people/30/"
	],
	films: [
		"https://swapi.co/api/films/3/"
	],
	created: "2014-12-18T11:22:00.285000Z",
	edited: "2014-12-20T21:36:42.155000Z",
	url: "https://swapi.co/api/species/9/"
},
	"https://swapi.co/api/species/10/": {
	name: "Sullustan",
	classification: "mammal",
	designation: "sentient",
	average_height: "180",
	skin_colors: "pale",
	hair_colors: "none",
	eye_colors: "black",
	average_lifespan: "unknown",
	homeworld: "https://swapi.co/api/planets/33/",
	language: "Sullutese",
	people: [
		"https://swapi.co/api/people/31/"
	],
	films: [
		"https://swapi.co/api/films/3/"
	],
	created: "2014-12-18T11:26:20.103000Z",
	edited: "2014-12-20T21:36:42.157000Z",
	url: "https://swapi.co/api/species/10/"
},
	"https://swapi.co/api/species/11/": {
	name: "Neimodian",
	classification: "unknown",
	designation: "sentient",
	average_height: "180",
	skin_colors: "grey, green",
	hair_colors: "none",
	eye_colors: "red, pink",
	average_lifespan: "unknown",
	homeworld: "https://swapi.co/api/planets/18/",
	language: "Neimoidia",
	people: [
		"https://swapi.co/api/people/33/"
	],
	films: [
		"https://swapi.co/api/films/4/"
	],
	created: "2014-12-19T17:07:31.319000Z",
	edited: "2014-12-20T21:36:42.160000Z",
	url: "https://swapi.co/api/species/11/"
},
	"https://swapi.co/api/species/12/": {
	name: "Gungan",
	classification: "amphibian",
	designation: "sentient",
	average_height: "190",
	skin_colors: "brown, green",
	hair_colors: "none",
	eye_colors: "orange",
	average_lifespan: "unknown",
	homeworld: "https://swapi.co/api/planets/8/",
	language: "Gungan basic",
	people: [
		"https://swapi.co/api/people/36/",
		"https://swapi.co/api/people/37/",
		"https://swapi.co/api/people/38/"
	],
	films: [
		"https://swapi.co/api/films/5/",
		"https://swapi.co/api/films/4/"
	],
	created: "2014-12-19T17:30:37.341000Z",
	edited: "2014-12-20T21:36:42.163000Z",
	url: "https://swapi.co/api/species/12/"
},
	"https://swapi.co/api/species/13/": {
	name: "Toydarian",
	classification: "mammal",
	designation: "sentient",
	average_height: "120",
	skin_colors: "blue, green, grey",
	hair_colors: "none",
	eye_colors: "yellow",
	average_lifespan: "91",
	homeworld: "https://swapi.co/api/planets/34/",
	language: "Toydarian",
	people: [
		"https://swapi.co/api/people/40/"
	],
	films: [
		"https://swapi.co/api/films/5/",
		"https://swapi.co/api/films/4/"
	],
	created: "2014-12-19T17:48:56.893000Z",
	edited: "2014-12-20T21:36:42.165000Z",
	url: "https://swapi.co/api/species/13/"
},
	"https://swapi.co/api/species/14/": {
	name: "Dug",
	classification: "mammal",
	designation: "sentient",
	average_height: "100",
	skin_colors: "brown, purple, grey, red",
	hair_colors: "none",
	eye_colors: "yellow, blue",
	average_lifespan: "unknown",
	homeworld: "https://swapi.co/api/planets/35/",
	language: "Dugese",
	people: [
		"https://swapi.co/api/people/41/"
	],
	films: [
		"https://swapi.co/api/films/4/"
	],
	created: "2014-12-19T17:53:11.214000Z",
	edited: "2014-12-20T21:36:42.167000Z",
	url: "https://swapi.co/api/species/14/"
},
	"https://swapi.co/api/species/?page=2": {
	count: 37,
	next: "https://swapi.co/api/species/?page=3",
	previous: "https://swapi.co/api/species/?page=1",
	results: [
		{
			name: "Twi'lek",
			classification: "mammals",
			designation: "sentient",
			average_height: "200",
			skin_colors: "orange, yellow, blue, green, pink, purple, tan",
			hair_colors: "none",
			eye_colors: "blue, brown, orange, pink",
			average_lifespan: "unknown",
			homeworld: "https://swapi.co/api/planets/37/",
			language: "Twi'leki",
			people: [
				"https://swapi.co/api/people/45/",
				"https://swapi.co/api/people/46/"
			],
			films: [
				"https://swapi.co/api/films/5/",
				"https://swapi.co/api/films/4/",
				"https://swapi.co/api/films/6/",
				"https://swapi.co/api/films/3/"
			],
			created: "2014-12-20T09:48:02.406000Z",
			edited: "2014-12-20T21:36:42.169000Z",
			url: "https://swapi.co/api/species/15/"
		},
		{
			name: "Aleena",
			classification: "reptile",
			designation: "sentient",
			average_height: "80",
			skin_colors: "blue, gray",
			hair_colors: "none",
			eye_colors: "unknown",
			average_lifespan: "79",
			homeworld: "https://swapi.co/api/planets/38/",
			language: "Aleena",
			people: [
				"https://swapi.co/api/people/47/"
			],
			films: [
				"https://swapi.co/api/films/4/"
			],
			created: "2014-12-20T09:53:16.481000Z",
			edited: "2014-12-20T21:36:42.171000Z",
			url: "https://swapi.co/api/species/16/"
		},
		{
			name: "Vulptereen",
			classification: "unknown",
			designation: "sentient",
			average_height: "100",
			skin_colors: "grey",
			hair_colors: "none",
			eye_colors: "yellow",
			average_lifespan: "unknown",
			homeworld: "https://swapi.co/api/planets/39/",
			language: "vulpterish",
			people: [
				"https://swapi.co/api/people/48/"
			],
			films: [
				"https://swapi.co/api/films/4/"
			],
			created: "2014-12-20T09:57:33.128000Z",
			edited: "2014-12-20T21:36:42.173000Z",
			url: "https://swapi.co/api/species/17/"
		},
		{
			name: "Xexto",
			classification: "unknown",
			designation: "sentient",
			average_height: "125",
			skin_colors: "grey, yellow, purple",
			hair_colors: "none",
			eye_colors: "black",
			average_lifespan: "unknown",
			homeworld: "https://swapi.co/api/planets/40/",
			language: "Xextese",
			people: [
				"https://swapi.co/api/people/49/"
			],
			films: [
				"https://swapi.co/api/films/4/"
			],
			created: "2014-12-20T10:02:13.915000Z",
			edited: "2014-12-20T21:36:42.175000Z",
			url: "https://swapi.co/api/species/18/"
		},
		{
			name: "Toong",
			classification: "unknown",
			designation: "sentient",
			average_height: "200",
			skin_colors: "grey, green, yellow",
			hair_colors: "none",
			eye_colors: "orange",
			average_lifespan: "unknown",
			homeworld: "https://swapi.co/api/planets/41/",
			language: "Tundan",
			people: [
				"https://swapi.co/api/people/50/"
			],
			films: [
				"https://swapi.co/api/films/4/",
				"https://swapi.co/api/films/6/"
			],
			created: "2014-12-20T10:08:36.795000Z",
			edited: "2014-12-20T21:36:42.177000Z",
			url: "https://swapi.co/api/species/19/"
		},
		{
			name: "Cerean",
			classification: "mammal",
			designation: "sentient",
			average_height: "200",
			skin_colors: "pale pink",
			hair_colors: "red, blond, black, white",
			eye_colors: "hazel",
			average_lifespan: "unknown",
			homeworld: "https://swapi.co/api/planets/43/",
			language: "Cerean",
			people: [
				"https://swapi.co/api/people/52/"
			],
			films: [
				"https://swapi.co/api/films/4/",
				"https://swapi.co/api/films/6/"
			],
			created: "2014-12-20T10:15:33.765000Z",
			edited: "2014-12-20T21:36:42.179000Z",
			url: "https://swapi.co/api/species/20/"
		},
		{
			name: "Nautolan",
			classification: "amphibian",
			designation: "sentient",
			average_height: "180",
			skin_colors: "green, blue, brown, red",
			hair_colors: "none",
			eye_colors: "black",
			average_lifespan: "70",
			homeworld: "https://swapi.co/api/planets/44/",
			language: "Nautila",
			people: [
				"https://swapi.co/api/people/53/"
			],
			films: [
				"https://swapi.co/api/films/4/"
			],
			created: "2014-12-20T10:18:58.610000Z",
			edited: "2014-12-20T21:36:42.181000Z",
			url: "https://swapi.co/api/species/21/"
		},
		{
			name: "Zabrak",
			classification: "mammal",
			designation: "sentient",
			average_height: "180",
			skin_colors: "pale, brown, red, orange, yellow",
			hair_colors: "black",
			eye_colors: "brown, orange",
			average_lifespan: "unknown",
			homeworld: "https://swapi.co/api/planets/45/",
			language: "Zabraki",
			people: [
				"https://swapi.co/api/people/44/",
				"https://swapi.co/api/people/54/"
			],
			films: [
				"https://swapi.co/api/films/4/"
			],
			created: "2014-12-20T10:26:59.894000Z",
			edited: "2014-12-20T21:36:42.183000Z",
			url: "https://swapi.co/api/species/22/"
		},
		{
			name: "Tholothian",
			classification: "mammal",
			designation: "sentient",
			average_height: "unknown",
			skin_colors: "dark",
			hair_colors: "unknown",
			eye_colors: "blue, indigo",
			average_lifespan: "unknown",
			homeworld: "https://swapi.co/api/planets/46/",
			language: "unknown",
			people: [
				"https://swapi.co/api/people/55/"
			],
			films: [
				"https://swapi.co/api/films/4/",
				"https://swapi.co/api/films/6/"
			],
			created: "2014-12-20T10:29:13.798000Z",
			edited: "2014-12-20T21:36:42.186000Z",
			url: "https://swapi.co/api/species/23/"
		},
		{
			name: "Iktotchi",
			classification: "unknown",
			designation: "sentient",
			average_height: "180",
			skin_colors: "pink",
			hair_colors: "none",
			eye_colors: "orange",
			average_lifespan: "unknown",
			homeworld: "https://swapi.co/api/planets/47/",
			language: "Iktotchese",
			people: [
				"https://swapi.co/api/people/56/"
			],
			films: [
				"https://swapi.co/api/films/4/",
				"https://swapi.co/api/films/6/"
			],
			created: "2014-12-20T10:32:13.046000Z",
			edited: "2014-12-20T21:36:42.188000Z",
			url: "https://swapi.co/api/species/24/"
		}
	]
},
	"https://swapi.co/api/species/15/": {
	name: "Twi'lek",
	classification: "mammals",
	designation: "sentient",
	average_height: "200",
	skin_colors: "orange, yellow, blue, green, pink, purple, tan",
	hair_colors: "none",
	eye_colors: "blue, brown, orange, pink",
	average_lifespan: "unknown",
	homeworld: "https://swapi.co/api/planets/37/",
	language: "Twi'leki",
	people: [
		"https://swapi.co/api/people/45/",
		"https://swapi.co/api/people/46/"
	],
	films: [
		"https://swapi.co/api/films/5/",
		"https://swapi.co/api/films/4/",
		"https://swapi.co/api/films/6/",
		"https://swapi.co/api/films/3/"
	],
	created: "2014-12-20T09:48:02.406000Z",
	edited: "2014-12-20T21:36:42.169000Z",
	url: "https://swapi.co/api/species/15/"
},
	"https://swapi.co/api/species/16/": {
	name: "Aleena",
	classification: "reptile",
	designation: "sentient",
	average_height: "80",
	skin_colors: "blue, gray",
	hair_colors: "none",
	eye_colors: "unknown",
	average_lifespan: "79",
	homeworld: "https://swapi.co/api/planets/38/",
	language: "Aleena",
	people: [
		"https://swapi.co/api/people/47/"
	],
	films: [
		"https://swapi.co/api/films/4/"
	],
	created: "2014-12-20T09:53:16.481000Z",
	edited: "2014-12-20T21:36:42.171000Z",
	url: "https://swapi.co/api/species/16/"
},
	"https://swapi.co/api/species/17/": {
	name: "Vulptereen",
	classification: "unknown",
	designation: "sentient",
	average_height: "100",
	skin_colors: "grey",
	hair_colors: "none",
	eye_colors: "yellow",
	average_lifespan: "unknown",
	homeworld: "https://swapi.co/api/planets/39/",
	language: "vulpterish",
	people: [
		"https://swapi.co/api/people/48/"
	],
	films: [
		"https://swapi.co/api/films/4/"
	],
	created: "2014-12-20T09:57:33.128000Z",
	edited: "2014-12-20T21:36:42.173000Z",
	url: "https://swapi.co/api/species/17/"
},
	"https://swapi.co/api/species/18/": {
	name: "Xexto",
	classification: "unknown",
	designation: "sentient",
	average_height: "125",
	skin_colors: "grey, yellow, purple",
	hair_colors: "none",
	eye_colors: "black",
	average_lifespan: "unknown",
	homeworld: "https://swapi.co/api/planets/40/",
	language: "Xextese",
	people: [
		"https://swapi.co/api/people/49/"
	],
	films: [
		"https://swapi.co/api/films/4/"
	],
	created: "2014-12-20T10:02:13.915000Z",
	edited: "2014-12-20T21:36:42.175000Z",
	url: "https://swapi.co/api/species/18/"
},
	"https://swapi.co/api/species/19/": {
	name: "Toong",
	classification: "unknown",
	designation: "sentient",
	average_height: "200",
	skin_colors: "grey, green, yellow",
	hair_colors: "none",
	eye_colors: "orange",
	average_lifespan: "unknown",
	homeworld: "https://swapi.co/api/planets/41/",
	language: "Tundan",
	people: [
		"https://swapi.co/api/people/50/"
	],
	films: [
		"https://swapi.co/api/films/4/",
		"https://swapi.co/api/films/6/"
	],
	created: "2014-12-20T10:08:36.795000Z",
	edited: "2014-12-20T21:36:42.177000Z",
	url: "https://swapi.co/api/species/19/"
},
	"https://swapi.co/api/species/20/": {
	name: "Cerean",
	classification: "mammal",
	designation: "sentient",
	average_height: "200",
	skin_colors: "pale pink",
	hair_colors: "red, blond, black, white",
	eye_colors: "hazel",
	average_lifespan: "unknown",
	homeworld: "https://swapi.co/api/planets/43/",
	language: "Cerean",
	people: [
		"https://swapi.co/api/people/52/"
	],
	films: [
		"https://swapi.co/api/films/4/",
		"https://swapi.co/api/films/6/"
	],
	created: "2014-12-20T10:15:33.765000Z",
	edited: "2014-12-20T21:36:42.179000Z",
	url: "https://swapi.co/api/species/20/"
},
	"https://swapi.co/api/species/21/": {
	name: "Nautolan",
	classification: "amphibian",
	designation: "sentient",
	average_height: "180",
	skin_colors: "green, blue, brown, red",
	hair_colors: "none",
	eye_colors: "black",
	average_lifespan: "70",
	homeworld: "https://swapi.co/api/planets/44/",
	language: "Nautila",
	people: [
		"https://swapi.co/api/people/53/"
	],
	films: [
		"https://swapi.co/api/films/4/"
	],
	created: "2014-12-20T10:18:58.610000Z",
	edited: "2014-12-20T21:36:42.181000Z",
	url: "https://swapi.co/api/species/21/"
},
	"https://swapi.co/api/species/22/": {
	name: "Zabrak",
	classification: "mammal",
	designation: "sentient",
	average_height: "180",
	skin_colors: "pale, brown, red, orange, yellow",
	hair_colors: "black",
	eye_colors: "brown, orange",
	average_lifespan: "unknown",
	homeworld: "https://swapi.co/api/planets/45/",
	language: "Zabraki",
	people: [
		"https://swapi.co/api/people/44/",
		"https://swapi.co/api/people/54/"
	],
	films: [
		"https://swapi.co/api/films/4/"
	],
	created: "2014-12-20T10:26:59.894000Z",
	edited: "2014-12-20T21:36:42.183000Z",
	url: "https://swapi.co/api/species/22/"
},
	"https://swapi.co/api/species/23/": {
	name: "Tholothian",
	classification: "mammal",
	designation: "sentient",
	average_height: "unknown",
	skin_colors: "dark",
	hair_colors: "unknown",
	eye_colors: "blue, indigo",
	average_lifespan: "unknown",
	homeworld: "https://swapi.co/api/planets/46/",
	language: "unknown",
	people: [
		"https://swapi.co/api/people/55/"
	],
	films: [
		"https://swapi.co/api/films/4/",
		"https://swapi.co/api/films/6/"
	],
	created: "2014-12-20T10:29:13.798000Z",
	edited: "2014-12-20T21:36:42.186000Z",
	url: "https://swapi.co/api/species/23/"
},
	"https://swapi.co/api/species/24/": {
	name: "Iktotchi",
	classification: "unknown",
	designation: "sentient",
	average_height: "180",
	skin_colors: "pink",
	hair_colors: "none",
	eye_colors: "orange",
	average_lifespan: "unknown",
	homeworld: "https://swapi.co/api/planets/47/",
	language: "Iktotchese",
	people: [
		"https://swapi.co/api/people/56/"
	],
	films: [
		"https://swapi.co/api/films/4/",
		"https://swapi.co/api/films/6/"
	],
	created: "2014-12-20T10:32:13.046000Z",
	edited: "2014-12-20T21:36:42.188000Z",
	url: "https://swapi.co/api/species/24/"
},
	"https://swapi.co/api/species/?page=3": {
	count: 37,
	next: "https://swapi.co/api/species/?page=4",
	previous: "https://swapi.co/api/species/?page=2",
	results: [
		{
			name: "Quermian",
			classification: "mammal",
			designation: "sentient",
			average_height: "240",
			skin_colors: "white",
			hair_colors: "none",
			eye_colors: "yellow",
			average_lifespan: "86",
			homeworld: "https://swapi.co/api/planets/48/",
			language: "Quermian",
			people: [
				"https://swapi.co/api/people/57/"
			],
			films: [
				"https://swapi.co/api/films/4/",
				"https://swapi.co/api/films/6/"
			],
			created: "2014-12-20T10:34:50.827000Z",
			edited: "2014-12-20T21:36:42.189000Z",
			url: "https://swapi.co/api/species/25/"
		},
		{
			name: "Kel Dor",
			classification: "unknown",
			designation: "sentient",
			average_height: "180",
			skin_colors: "peach, orange, red",
			hair_colors: "none",
			eye_colors: "black, silver",
			average_lifespan: "70",
			homeworld: "https://swapi.co/api/planets/49/",
			language: "Kel Dor",
			people: [
				"https://swapi.co/api/people/58/"
			],
			films: [
				"https://swapi.co/api/films/4/",
				"https://swapi.co/api/films/6/"
			],
			created: "2014-12-20T10:49:21.692000Z",
			edited: "2014-12-20T21:36:42.191000Z",
			url: "https://swapi.co/api/species/26/"
		},
		{
			name: "Chagrian",
			classification: "amphibian",
			designation: "sentient",
			average_height: "190",
			skin_colors: "blue",
			hair_colors: "none",
			eye_colors: "blue",
			average_lifespan: "unknown",
			homeworld: "https://swapi.co/api/planets/50/",
			language: "Chagria",
			people: [
				"https://swapi.co/api/people/59/"
			],
			films: [
				"https://swapi.co/api/films/4/",
				"https://swapi.co/api/films/6/"
			],
			created: "2014-12-20T10:53:28.795000Z",
			edited: "2014-12-20T21:36:42.193000Z",
			url: "https://swapi.co/api/species/27/"
		},
		{
			name: "Geonosian",
			classification: "insectoid",
			designation: "sentient",
			average_height: "178",
			skin_colors: "green, brown",
			hair_colors: "none",
			eye_colors: "green, hazel",
			average_lifespan: "unknown",
			homeworld: "https://swapi.co/api/planets/11/",
			language: "Geonosian",
			people: [
				"https://swapi.co/api/people/63/"
			],
			films: [
				"https://swapi.co/api/films/5/",
				"https://swapi.co/api/films/6/"
			],
			created: "2014-12-20T16:40:45.618000Z",
			edited: "2014-12-20T21:36:42.195000Z",
			url: "https://swapi.co/api/species/28/"
		},
		{
			name: "Mirialan",
			classification: "mammal",
			designation: "sentient",
			average_height: "180",
			skin_colors: "yellow, green",
			hair_colors: "black, brown",
			eye_colors: "blue, green, red, yellow, brown, orange",
			average_lifespan: "unknown",
			homeworld: "https://swapi.co/api/planets/51/",
			language: "Mirialan",
			people: [
				"https://swapi.co/api/people/64/",
				"https://swapi.co/api/people/65/"
			],
			films: [
				"https://swapi.co/api/films/5/",
				"https://swapi.co/api/films/6/"
			],
			created: "2014-12-20T16:46:48.290000Z",
			edited: "2014-12-20T21:36:42.197000Z",
			url: "https://swapi.co/api/species/29/"
		},
		{
			name: "Clawdite",
			classification: "reptilian",
			designation: "sentient",
			average_height: "180",
			skin_colors: "green, yellow",
			hair_colors: "none",
			eye_colors: "yellow",
			average_lifespan: "70",
			homeworld: "https://swapi.co/api/planets/54/",
			language: "Clawdite",
			people: [
				"https://swapi.co/api/people/70/"
			],
			films: [
				"https://swapi.co/api/films/5/",
				"https://swapi.co/api/films/6/"
			],
			created: "2014-12-20T16:57:46.171000Z",
			edited: "2014-12-20T21:36:42.199000Z",
			url: "https://swapi.co/api/species/30/"
		},
		{
			name: "Besalisk",
			classification: "amphibian",
			designation: "sentient",
			average_height: "178",
			skin_colors: "brown",
			hair_colors: "none",
			eye_colors: "yellow",
			average_lifespan: "75",
			homeworld: "https://swapi.co/api/planets/55/",
			language: "besalisk",
			people: [
				"https://swapi.co/api/people/71/"
			],
			films: [
				"https://swapi.co/api/films/5/"
			],
			created: "2014-12-20T17:28:28.821000Z",
			edited: "2014-12-20T21:36:42.200000Z",
			url: "https://swapi.co/api/species/31/"
		},
		{
			name: "Kaminoan",
			classification: "amphibian",
			designation: "sentient",
			average_height: "220",
			skin_colors: "grey, blue",
			hair_colors: "none",
			eye_colors: "black",
			average_lifespan: "80",
			homeworld: "https://swapi.co/api/planets/10/",
			language: "Kaminoan",
			people: [
				"https://swapi.co/api/people/72/",
				"https://swapi.co/api/people/73/"
			],
			films: [
				"https://swapi.co/api/films/5/"
			],
			created: "2014-12-20T17:31:24.838000Z",
			edited: "2014-12-20T21:36:42.202000Z",
			url: "https://swapi.co/api/species/32/"
		},
		{
			name: "Skakoan",
			classification: "mammal",
			designation: "sentient",
			average_height: "unknown",
			skin_colors: "grey, green",
			hair_colors: "none",
			eye_colors: "unknown",
			average_lifespan: "unknown",
			homeworld: "https://swapi.co/api/planets/56/",
			language: "Skakoan",
			people: [
				"https://swapi.co/api/people/76/"
			],
			films: [
				"https://swapi.co/api/films/5/",
				"https://swapi.co/api/films/6/"
			],
			created: "2014-12-20T17:53:54.515000Z",
			edited: "2014-12-20T21:36:42.204000Z",
			url: "https://swapi.co/api/species/33/"
		},
		{
			name: "Muun",
			classification: "mammal",
			designation: "sentient",
			average_height: "190",
			skin_colors: "grey, white",
			hair_colors: "none",
			eye_colors: "black",
			average_lifespan: "100",
			homeworld: "https://swapi.co/api/planets/57/",
			language: "Muun",
			people: [
				"https://swapi.co/api/people/77/"
			],
			films: [
				"https://swapi.co/api/films/5/",
				"https://swapi.co/api/films/6/"
			],
			created: "2014-12-20T17:58:19.088000Z",
			edited: "2014-12-20T21:36:42.207000Z",
			url: "https://swapi.co/api/species/34/"
		}
	]
},
	"https://swapi.co/api/species/25/": {
	name: "Quermian",
	classification: "mammal",
	designation: "sentient",
	average_height: "240",
	skin_colors: "white",
	hair_colors: "none",
	eye_colors: "yellow",
	average_lifespan: "86",
	homeworld: "https://swapi.co/api/planets/48/",
	language: "Quermian",
	people: [
		"https://swapi.co/api/people/57/"
	],
	films: [
		"https://swapi.co/api/films/4/",
		"https://swapi.co/api/films/6/"
	],
	created: "2014-12-20T10:34:50.827000Z",
	edited: "2014-12-20T21:36:42.189000Z",
	url: "https://swapi.co/api/species/25/"
},
	"https://swapi.co/api/species/26/": {
	name: "Kel Dor",
	classification: "unknown",
	designation: "sentient",
	average_height: "180",
	skin_colors: "peach, orange, red",
	hair_colors: "none",
	eye_colors: "black, silver",
	average_lifespan: "70",
	homeworld: "https://swapi.co/api/planets/49/",
	language: "Kel Dor",
	people: [
		"https://swapi.co/api/people/58/"
	],
	films: [
		"https://swapi.co/api/films/4/",
		"https://swapi.co/api/films/6/"
	],
	created: "2014-12-20T10:49:21.692000Z",
	edited: "2014-12-20T21:36:42.191000Z",
	url: "https://swapi.co/api/species/26/"
},
	"https://swapi.co/api/species/27/": {
	name: "Chagrian",
	classification: "amphibian",
	designation: "sentient",
	average_height: "190",
	skin_colors: "blue",
	hair_colors: "none",
	eye_colors: "blue",
	average_lifespan: "unknown",
	homeworld: "https://swapi.co/api/planets/50/",
	language: "Chagria",
	people: [
		"https://swapi.co/api/people/59/"
	],
	films: [
		"https://swapi.co/api/films/4/",
		"https://swapi.co/api/films/6/"
	],
	created: "2014-12-20T10:53:28.795000Z",
	edited: "2014-12-20T21:36:42.193000Z",
	url: "https://swapi.co/api/species/27/"
},
	"https://swapi.co/api/species/28/": {
	name: "Geonosian",
	classification: "insectoid",
	designation: "sentient",
	average_height: "178",
	skin_colors: "green, brown",
	hair_colors: "none",
	eye_colors: "green, hazel",
	average_lifespan: "unknown",
	homeworld: "https://swapi.co/api/planets/11/",
	language: "Geonosian",
	people: [
		"https://swapi.co/api/people/63/"
	],
	films: [
		"https://swapi.co/api/films/5/",
		"https://swapi.co/api/films/6/"
	],
	created: "2014-12-20T16:40:45.618000Z",
	edited: "2014-12-20T21:36:42.195000Z",
	url: "https://swapi.co/api/species/28/"
},
	"https://swapi.co/api/species/29/": {
	name: "Mirialan",
	classification: "mammal",
	designation: "sentient",
	average_height: "180",
	skin_colors: "yellow, green",
	hair_colors: "black, brown",
	eye_colors: "blue, green, red, yellow, brown, orange",
	average_lifespan: "unknown",
	homeworld: "https://swapi.co/api/planets/51/",
	language: "Mirialan",
	people: [
		"https://swapi.co/api/people/64/",
		"https://swapi.co/api/people/65/"
	],
	films: [
		"https://swapi.co/api/films/5/",
		"https://swapi.co/api/films/6/"
	],
	created: "2014-12-20T16:46:48.290000Z",
	edited: "2014-12-20T21:36:42.197000Z",
	url: "https://swapi.co/api/species/29/"
},
	"https://swapi.co/api/species/30/": {
	name: "Clawdite",
	classification: "reptilian",
	designation: "sentient",
	average_height: "180",
	skin_colors: "green, yellow",
	hair_colors: "none",
	eye_colors: "yellow",
	average_lifespan: "70",
	homeworld: "https://swapi.co/api/planets/54/",
	language: "Clawdite",
	people: [
		"https://swapi.co/api/people/70/"
	],
	films: [
		"https://swapi.co/api/films/5/",
		"https://swapi.co/api/films/6/"
	],
	created: "2014-12-20T16:57:46.171000Z",
	edited: "2014-12-20T21:36:42.199000Z",
	url: "https://swapi.co/api/species/30/"
},
	"https://swapi.co/api/species/31/": {
	name: "Besalisk",
	classification: "amphibian",
	designation: "sentient",
	average_height: "178",
	skin_colors: "brown",
	hair_colors: "none",
	eye_colors: "yellow",
	average_lifespan: "75",
	homeworld: "https://swapi.co/api/planets/55/",
	language: "besalisk",
	people: [
		"https://swapi.co/api/people/71/"
	],
	films: [
		"https://swapi.co/api/films/5/"
	],
	created: "2014-12-20T17:28:28.821000Z",
	edited: "2014-12-20T21:36:42.200000Z",
	url: "https://swapi.co/api/species/31/"
},
	"https://swapi.co/api/species/32/": {
	name: "Kaminoan",
	classification: "amphibian",
	designation: "sentient",
	average_height: "220",
	skin_colors: "grey, blue",
	hair_colors: "none",
	eye_colors: "black",
	average_lifespan: "80",
	homeworld: "https://swapi.co/api/planets/10/",
	language: "Kaminoan",
	people: [
		"https://swapi.co/api/people/72/",
		"https://swapi.co/api/people/73/"
	],
	films: [
		"https://swapi.co/api/films/5/"
	],
	created: "2014-12-20T17:31:24.838000Z",
	edited: "2014-12-20T21:36:42.202000Z",
	url: "https://swapi.co/api/species/32/"
},
	"https://swapi.co/api/species/33/": {
	name: "Skakoan",
	classification: "mammal",
	designation: "sentient",
	average_height: "unknown",
	skin_colors: "grey, green",
	hair_colors: "none",
	eye_colors: "unknown",
	average_lifespan: "unknown",
	homeworld: "https://swapi.co/api/planets/56/",
	language: "Skakoan",
	people: [
		"https://swapi.co/api/people/76/"
	],
	films: [
		"https://swapi.co/api/films/5/",
		"https://swapi.co/api/films/6/"
	],
	created: "2014-12-20T17:53:54.515000Z",
	edited: "2014-12-20T21:36:42.204000Z",
	url: "https://swapi.co/api/species/33/"
},
	"https://swapi.co/api/species/34/": {
	name: "Muun",
	classification: "mammal",
	designation: "sentient",
	average_height: "190",
	skin_colors: "grey, white",
	hair_colors: "none",
	eye_colors: "black",
	average_lifespan: "100",
	homeworld: "https://swapi.co/api/planets/57/",
	language: "Muun",
	people: [
		"https://swapi.co/api/people/77/"
	],
	films: [
		"https://swapi.co/api/films/5/",
		"https://swapi.co/api/films/6/"
	],
	created: "2014-12-20T17:58:19.088000Z",
	edited: "2014-12-20T21:36:42.207000Z",
	url: "https://swapi.co/api/species/34/"
},
	"https://swapi.co/api/species/?page=4": {
	count: 37,
	next: null,
	previous: "https://swapi.co/api/species/?page=3",
	results: [
		{
			name: "Togruta",
			classification: "mammal",
			designation: "sentient",
			average_height: "180",
			skin_colors: "red, white, orange, yellow, green, blue",
			hair_colors: "none",
			eye_colors: "red, orange, yellow, green, blue, black",
			average_lifespan: "94",
			homeworld: "https://swapi.co/api/planets/58/",
			language: "Togruti",
			people: [
				"https://swapi.co/api/people/78/"
			],
			films: [
				"https://swapi.co/api/films/5/",
				"https://swapi.co/api/films/6/"
			],
			created: "2014-12-20T18:44:03.246000Z",
			edited: "2014-12-20T21:36:42.209000Z",
			url: "https://swapi.co/api/species/35/"
		},
		{
			name: "Kaleesh",
			classification: "reptile",
			designation: "sentient",
			average_height: "170",
			skin_colors: "brown, orange, tan",
			hair_colors: "none",
			eye_colors: "yellow",
			average_lifespan: "80",
			homeworld: "https://swapi.co/api/planets/59/",
			language: "Kaleesh",
			people: [
				"https://swapi.co/api/people/79/"
			],
			films: [
				"https://swapi.co/api/films/6/"
			],
			created: "2014-12-20T19:45:42.537000Z",
			edited: "2014-12-20T21:36:42.210000Z",
			url: "https://swapi.co/api/species/36/"
		},
		{
			name: "Pau'an",
			classification: "mammal",
			designation: "sentient",
			average_height: "190",
			skin_colors: "grey",
			hair_colors: "none",
			eye_colors: "black",
			average_lifespan: "700",
			homeworld: "https://swapi.co/api/planets/12/",
			language: "Utapese",
			people: [
				"https://swapi.co/api/people/83/"
			],
			films: [
				"https://swapi.co/api/films/6/"
			],
			created: "2014-12-20T20:35:06.777000Z",
			edited: "2014-12-20T21:36:42.212000Z",
			url: "https://swapi.co/api/species/37/"
		},
		{
			name: "Wookiee",
			classification: "mammal",
			designation: "sentient",
			average_height: "210",
			skin_colors: "gray",
			hair_colors: "black, brown",
			eye_colors: "blue, green, yellow, brown, golden, red",
			average_lifespan: "400",
			homeworld: "https://swapi.co/api/planets/14/",
			language: "Shyriiwook",
			people: [
				"https://swapi.co/api/people/13/",
				"https://swapi.co/api/people/80/"
			],
			films: [
				"https://swapi.co/api/films/2/",
				"https://swapi.co/api/films/7/",
				"https://swapi.co/api/films/6/",
				"https://swapi.co/api/films/3/",
				"https://swapi.co/api/films/1/"
			],
			created: "2014-12-10T16:44:31.486000Z",
			edited: "2015-01-30T21:23:03.074598Z",
			url: "https://swapi.co/api/species/3/"
		},
		{
			name: "Droid",
			classification: "artificial",
			designation: "sentient",
			average_height: "n/a",
			skin_colors: "n/a",
			hair_colors: "n/a",
			eye_colors: "n/a",
			average_lifespan: "indefinite",
			homeworld: null,
			language: "n/a",
			people: [
				"https://swapi.co/api/people/2/",
				"https://swapi.co/api/people/3/",
				"https://swapi.co/api/people/8/",
				"https://swapi.co/api/people/23/",
				"https://swapi.co/api/people/87/"
			],
			films: [
				"https://swapi.co/api/films/2/",
				"https://swapi.co/api/films/7/",
				"https://swapi.co/api/films/5/",
				"https://swapi.co/api/films/4/",
				"https://swapi.co/api/films/6/",
				"https://swapi.co/api/films/3/",
				"https://swapi.co/api/films/1/"
			],
			created: "2014-12-10T15:16:16.259000Z",
			edited: "2015-04-17T06:59:43.869528Z",
			url: "https://swapi.co/api/species/2/"
		},
		{
			name: "Human",
			classification: "mammal",
			designation: "sentient",
			average_height: "180",
			skin_colors: "caucasian, black, asian, hispanic",
			hair_colors: "blonde, brown, black, red",
			eye_colors: "brown, blue, green, hazel, grey, amber",
			average_lifespan: "120",
			homeworld: "https://swapi.co/api/planets/9/",
			language: "Galactic Basic",
			people: [
				"https://swapi.co/api/people/1/",
				"https://swapi.co/api/people/4/",
				"https://swapi.co/api/people/5/",
				"https://swapi.co/api/people/6/",
				"https://swapi.co/api/people/7/",
				"https://swapi.co/api/people/9/",
				"https://swapi.co/api/people/10/",
				"https://swapi.co/api/people/11/",
				"https://swapi.co/api/people/12/",
				"https://swapi.co/api/people/14/",
				"https://swapi.co/api/people/18/",
				"https://swapi.co/api/people/19/",
				"https://swapi.co/api/people/21/",
				"https://swapi.co/api/people/22/",
				"https://swapi.co/api/people/25/",
				"https://swapi.co/api/people/26/",
				"https://swapi.co/api/people/28/",
				"https://swapi.co/api/people/29/",
				"https://swapi.co/api/people/32/",
				"https://swapi.co/api/people/34/",
				"https://swapi.co/api/people/43/",
				"https://swapi.co/api/people/51/",
				"https://swapi.co/api/people/60/",
				"https://swapi.co/api/people/61/",
				"https://swapi.co/api/people/62/",
				"https://swapi.co/api/people/66/",
				"https://swapi.co/api/people/67/",
				"https://swapi.co/api/people/68/",
				"https://swapi.co/api/people/69/",
				"https://swapi.co/api/people/74/",
				"https://swapi.co/api/people/81/",
				"https://swapi.co/api/people/84/",
				"https://swapi.co/api/people/85/",
				"https://swapi.co/api/people/86/",
				"https://swapi.co/api/people/35/"
			],
			films: [
				"https://swapi.co/api/films/2/",
				"https://swapi.co/api/films/7/",
				"https://swapi.co/api/films/5/",
				"https://swapi.co/api/films/4/",
				"https://swapi.co/api/films/6/",
				"https://swapi.co/api/films/3/",
				"https://swapi.co/api/films/1/"
			],
			created: "2014-12-10T13:52:11.567000Z",
			edited: "2015-04-17T06:59:55.850671Z",
			url: "https://swapi.co/api/species/1/"
		},
		{
			name: "Rodian",
			classification: "sentient",
			designation: "reptilian",
			average_height: "170",
			skin_colors: "green, blue",
			hair_colors: "n/a",
			eye_colors: "black",
			average_lifespan: "unknown",
			homeworld: "https://swapi.co/api/planets/23/",
			language: "Galactic Basic",
			people: [
				"https://swapi.co/api/people/15/"
			],
			films: [
				"https://swapi.co/api/films/1/"
			],
			created: "2014-12-10T17:05:26.471000Z",
			edited: "2016-07-19T13:27:03.156498Z",
			url: "https://swapi.co/api/species/4/"
		}
	]
},
	"https://swapi.co/api/species/35/": {
	name: "Togruta",
	classification: "mammal",
	designation: "sentient",
	average_height: "180",
	skin_colors: "red, white, orange, yellow, green, blue",
	hair_colors: "none",
	eye_colors: "red, orange, yellow, green, blue, black",
	average_lifespan: "94",
	homeworld: "https://swapi.co/api/planets/58/",
	language: "Togruti",
	people: [
		"https://swapi.co/api/people/78/"
	],
	films: [
		"https://swapi.co/api/films/5/",
		"https://swapi.co/api/films/6/"
	],
	created: "2014-12-20T18:44:03.246000Z",
	edited: "2014-12-20T21:36:42.209000Z",
	url: "https://swapi.co/api/species/35/"
},
	"https://swapi.co/api/species/36/": {
	name: "Kaleesh",
	classification: "reptile",
	designation: "sentient",
	average_height: "170",
	skin_colors: "brown, orange, tan",
	hair_colors: "none",
	eye_colors: "yellow",
	average_lifespan: "80",
	homeworld: "https://swapi.co/api/planets/59/",
	language: "Kaleesh",
	people: [
		"https://swapi.co/api/people/79/"
	],
	films: [
		"https://swapi.co/api/films/6/"
	],
	created: "2014-12-20T19:45:42.537000Z",
	edited: "2014-12-20T21:36:42.210000Z",
	url: "https://swapi.co/api/species/36/"
},
	"https://swapi.co/api/species/37/": {
	name: "Pau'an",
	classification: "mammal",
	designation: "sentient",
	average_height: "190",
	skin_colors: "grey",
	hair_colors: "none",
	eye_colors: "black",
	average_lifespan: "700",
	homeworld: "https://swapi.co/api/planets/12/",
	language: "Utapese",
	people: [
		"https://swapi.co/api/people/83/"
	],
	films: [
		"https://swapi.co/api/films/6/"
	],
	created: "2014-12-20T20:35:06.777000Z",
	edited: "2014-12-20T21:36:42.212000Z",
	url: "https://swapi.co/api/species/37/"
},
	"https://swapi.co/api/species/3/": {
	name: "Wookiee",
	classification: "mammal",
	designation: "sentient",
	average_height: "210",
	skin_colors: "gray",
	hair_colors: "black, brown",
	eye_colors: "blue, green, yellow, brown, golden, red",
	average_lifespan: "400",
	homeworld: "https://swapi.co/api/planets/14/",
	language: "Shyriiwook",
	people: [
		"https://swapi.co/api/people/13/",
		"https://swapi.co/api/people/80/"
	],
	films: [
		"https://swapi.co/api/films/2/",
		"https://swapi.co/api/films/7/",
		"https://swapi.co/api/films/6/",
		"https://swapi.co/api/films/3/",
		"https://swapi.co/api/films/1/"
	],
	created: "2014-12-10T16:44:31.486000Z",
	edited: "2015-01-30T21:23:03.074598Z",
	url: "https://swapi.co/api/species/3/"
},
	"https://swapi.co/api/species/2/": {
	name: "Droid",
	classification: "artificial",
	designation: "sentient",
	average_height: "n/a",
	skin_colors: "n/a",
	hair_colors: "n/a",
	eye_colors: "n/a",
	average_lifespan: "indefinite",
	homeworld: null,
	language: "n/a",
	people: [
		"https://swapi.co/api/people/2/",
		"https://swapi.co/api/people/3/",
		"https://swapi.co/api/people/8/",
		"https://swapi.co/api/people/23/",
		"https://swapi.co/api/people/87/"
	],
	films: [
		"https://swapi.co/api/films/2/",
		"https://swapi.co/api/films/7/",
		"https://swapi.co/api/films/5/",
		"https://swapi.co/api/films/4/",
		"https://swapi.co/api/films/6/",
		"https://swapi.co/api/films/3/",
		"https://swapi.co/api/films/1/"
	],
	created: "2014-12-10T15:16:16.259000Z",
	edited: "2015-04-17T06:59:43.869528Z",
	url: "https://swapi.co/api/species/2/"
},
	"https://swapi.co/api/species/1/": {
	name: "Human",
	classification: "mammal",
	designation: "sentient",
	average_height: "180",
	skin_colors: "caucasian, black, asian, hispanic",
	hair_colors: "blonde, brown, black, red",
	eye_colors: "brown, blue, green, hazel, grey, amber",
	average_lifespan: "120",
	homeworld: "https://swapi.co/api/planets/9/",
	language: "Galactic Basic",
	people: [
		"https://swapi.co/api/people/1/",
		"https://swapi.co/api/people/4/",
		"https://swapi.co/api/people/5/",
		"https://swapi.co/api/people/6/",
		"https://swapi.co/api/people/7/",
		"https://swapi.co/api/people/9/",
		"https://swapi.co/api/people/10/",
		"https://swapi.co/api/people/11/",
		"https://swapi.co/api/people/12/",
		"https://swapi.co/api/people/14/",
		"https://swapi.co/api/people/18/",
		"https://swapi.co/api/people/19/",
		"https://swapi.co/api/people/21/",
		"https://swapi.co/api/people/22/",
		"https://swapi.co/api/people/25/",
		"https://swapi.co/api/people/26/",
		"https://swapi.co/api/people/28/",
		"https://swapi.co/api/people/29/",
		"https://swapi.co/api/people/32/",
		"https://swapi.co/api/people/34/",
		"https://swapi.co/api/people/43/",
		"https://swapi.co/api/people/51/",
		"https://swapi.co/api/people/60/",
		"https://swapi.co/api/people/61/",
		"https://swapi.co/api/people/62/",
		"https://swapi.co/api/people/66/",
		"https://swapi.co/api/people/67/",
		"https://swapi.co/api/people/68/",
		"https://swapi.co/api/people/69/",
		"https://swapi.co/api/people/74/",
		"https://swapi.co/api/people/81/",
		"https://swapi.co/api/people/84/",
		"https://swapi.co/api/people/85/",
		"https://swapi.co/api/people/86/",
		"https://swapi.co/api/people/35/"
	],
	films: [
		"https://swapi.co/api/films/2/",
		"https://swapi.co/api/films/7/",
		"https://swapi.co/api/films/5/",
		"https://swapi.co/api/films/4/",
		"https://swapi.co/api/films/6/",
		"https://swapi.co/api/films/3/",
		"https://swapi.co/api/films/1/"
	],
	created: "2014-12-10T13:52:11.567000Z",
	edited: "2015-04-17T06:59:55.850671Z",
	url: "https://swapi.co/api/species/1/"
},
	"https://swapi.co/api/species/4/": {
	name: "Rodian",
	classification: "sentient",
	designation: "reptilian",
	average_height: "170",
	skin_colors: "green, blue",
	hair_colors: "n/a",
	eye_colors: "black",
	average_lifespan: "unknown",
	homeworld: "https://swapi.co/api/planets/23/",
	language: "Galactic Basic",
	people: [
		"https://swapi.co/api/people/15/"
	],
	films: [
		"https://swapi.co/api/films/1/"
	],
	created: "2014-12-10T17:05:26.471000Z",
	edited: "2016-07-19T13:27:03.156498Z",
	url: "https://swapi.co/api/species/4/"
},
	"https://swapi.co/api/planets/": {
	count: 61,
	next: "https://swapi.co/api/planets/?page=2",
	previous: null,
	results: [
		{
			name: "Alderaan",
			rotation_period: "24",
			orbital_period: "364",
			diameter: "12500",
			climate: "temperate",
			gravity: "1 standard",
			terrain: "grasslands, mountains",
			surface_water: "40",
			population: "2000000000",
			residents: [
				"https://swapi.co/api/people/5/",
				"https://swapi.co/api/people/68/",
				"https://swapi.co/api/people/81/"
			],
			films: [
				"https://swapi.co/api/films/6/",
				"https://swapi.co/api/films/1/"
			],
			created: "2014-12-10T11:35:48.479000Z",
			edited: "2014-12-20T20:58:18.420000Z",
			url: "https://swapi.co/api/planets/2/"
		},
		{
			name: "Yavin IV",
			rotation_period: "24",
			orbital_period: "4818",
			diameter: "10200",
			climate: "temperate, tropical",
			gravity: "1 standard",
			terrain: "jungle, rainforests",
			surface_water: "8",
			population: "1000",
			residents: [
			],
			films: [
				"https://swapi.co/api/films/1/"
			],
			created: "2014-12-10T11:37:19.144000Z",
			edited: "2014-12-20T20:58:18.421000Z",
			url: "https://swapi.co/api/planets/3/"
		},
		{
			name: "Hoth",
			rotation_period: "23",
			orbital_period: "549",
			diameter: "7200",
			climate: "frozen",
			gravity: "1.1 standard",
			terrain: "tundra, ice caves, mountain ranges",
			surface_water: "100",
			population: "unknown",
			residents: [
			],
			films: [
				"https://swapi.co/api/films/2/"
			],
			created: "2014-12-10T11:39:13.934000Z",
			edited: "2014-12-20T20:58:18.423000Z",
			url: "https://swapi.co/api/planets/4/"
		},
		{
			name: "Dagobah",
			rotation_period: "23",
			orbital_period: "341",
			diameter: "8900",
			climate: "murky",
			gravity: "N/A",
			terrain: "swamp, jungles",
			surface_water: "8",
			population: "unknown",
			residents: [
			],
			films: [
				"https://swapi.co/api/films/2/",
				"https://swapi.co/api/films/6/",
				"https://swapi.co/api/films/3/"
			],
			created: "2014-12-10T11:42:22.590000Z",
			edited: "2014-12-20T20:58:18.425000Z",
			url: "https://swapi.co/api/planets/5/"
		},
		{
			name: "Bespin",
			rotation_period: "12",
			orbital_period: "5110",
			diameter: "118000",
			climate: "temperate",
			gravity: "1.5 (surface), 1 standard (Cloud City)",
			terrain: "gas giant",
			surface_water: "0",
			population: "6000000",
			residents: [
				"https://swapi.co/api/people/26/"
			],
			films: [
				"https://swapi.co/api/films/2/"
			],
			created: "2014-12-10T11:43:55.240000Z",
			edited: "2014-12-20T20:58:18.427000Z",
			url: "https://swapi.co/api/planets/6/"
		},
		{
			name: "Endor",
			rotation_period: "18",
			orbital_period: "402",
			diameter: "4900",
			climate: "temperate",
			gravity: "0.85 standard",
			terrain: "forests, mountains, lakes",
			surface_water: "8",
			population: "30000000",
			residents: [
				"https://swapi.co/api/people/30/"
			],
			films: [
				"https://swapi.co/api/films/3/"
			],
			created: "2014-12-10T11:50:29.349000Z",
			edited: "2014-12-20T20:58:18.429000Z",
			url: "https://swapi.co/api/planets/7/"
		},
		{
			name: "Naboo",
			rotation_period: "26",
			orbital_period: "312",
			diameter: "12120",
			climate: "temperate",
			gravity: "1 standard",
			terrain: "grassy hills, swamps, forests, mountains",
			surface_water: "12",
			population: "4500000000",
			residents: [
				"https://swapi.co/api/people/3/",
				"https://swapi.co/api/people/21/",
				"https://swapi.co/api/people/36/",
				"https://swapi.co/api/people/37/",
				"https://swapi.co/api/people/38/",
				"https://swapi.co/api/people/39/",
				"https://swapi.co/api/people/42/",
				"https://swapi.co/api/people/60/",
				"https://swapi.co/api/people/61/",
				"https://swapi.co/api/people/66/",
				"https://swapi.co/api/people/35/"
			],
			films: [
				"https://swapi.co/api/films/5/",
				"https://swapi.co/api/films/4/",
				"https://swapi.co/api/films/6/",
				"https://swapi.co/api/films/3/"
			],
			created: "2014-12-10T11:52:31.066000Z",
			edited: "2014-12-20T20:58:18.430000Z",
			url: "https://swapi.co/api/planets/8/"
		},
		{
			name: "Coruscant",
			rotation_period: "24",
			orbital_period: "368",
			diameter: "12240",
			climate: "temperate",
			gravity: "1 standard",
			terrain: "cityscape, mountains",
			surface_water: "unknown",
			population: "1000000000000",
			residents: [
				"https://swapi.co/api/people/34/",
				"https://swapi.co/api/people/55/",
				"https://swapi.co/api/people/74/"
			],
			films: [
				"https://swapi.co/api/films/5/",
				"https://swapi.co/api/films/4/",
				"https://swapi.co/api/films/6/",
				"https://swapi.co/api/films/3/"
			],
			created: "2014-12-10T11:54:13.921000Z",
			edited: "2014-12-20T20:58:18.432000Z",
			url: "https://swapi.co/api/planets/9/"
		},
		{
			name: "Kamino",
			rotation_period: "27",
			orbital_period: "463",
			diameter: "19720",
			climate: "temperate",
			gravity: "1 standard",
			terrain: "ocean",
			surface_water: "100",
			population: "1000000000",
			residents: [
				"https://swapi.co/api/people/22/",
				"https://swapi.co/api/people/72/",
				"https://swapi.co/api/people/73/"
			],
			films: [
				"https://swapi.co/api/films/5/"
			],
			created: "2014-12-10T12:45:06.577000Z",
			edited: "2014-12-20T20:58:18.434000Z",
			url: "https://swapi.co/api/planets/10/"
		},
		{
			name: "Geonosis",
			rotation_period: "30",
			orbital_period: "256",
			diameter: "11370",
			climate: "temperate, arid",
			gravity: "0.9 standard",
			terrain: "rock, desert, mountain, barren",
			surface_water: "5",
			population: "100000000000",
			residents: [
				"https://swapi.co/api/people/63/"
			],
			films: [
				"https://swapi.co/api/films/5/"
			],
			created: "2014-12-10T12:47:22.350000Z",
			edited: "2014-12-20T20:58:18.437000Z",
			url: "https://swapi.co/api/planets/11/"
		}
	]
},
	"https://swapi.co/api/planets/2/": {
	name: "Alderaan",
	rotation_period: "24",
	orbital_period: "364",
	diameter: "12500",
	climate: "temperate",
	gravity: "1 standard",
	terrain: "grasslands, mountains",
	surface_water: "40",
	population: "2000000000",
	residents: [
		"https://swapi.co/api/people/5/",
		"https://swapi.co/api/people/68/",
		"https://swapi.co/api/people/81/"
	],
	films: [
		"https://swapi.co/api/films/6/",
		"https://swapi.co/api/films/1/"
	],
	created: "2014-12-10T11:35:48.479000Z",
	edited: "2014-12-20T20:58:18.420000Z",
	url: "https://swapi.co/api/planets/2/"
},
	"https://swapi.co/api/planets/3/": {
	name: "Yavin IV",
	rotation_period: "24",
	orbital_period: "4818",
	diameter: "10200",
	climate: "temperate, tropical",
	gravity: "1 standard",
	terrain: "jungle, rainforests",
	surface_water: "8",
	population: "1000",
	residents: [
	],
	films: [
		"https://swapi.co/api/films/1/"
	],
	created: "2014-12-10T11:37:19.144000Z",
	edited: "2014-12-20T20:58:18.421000Z",
	url: "https://swapi.co/api/planets/3/"
},
	"https://swapi.co/api/planets/4/": {
	name: "Hoth",
	rotation_period: "23",
	orbital_period: "549",
	diameter: "7200",
	climate: "frozen",
	gravity: "1.1 standard",
	terrain: "tundra, ice caves, mountain ranges",
	surface_water: "100",
	population: "unknown",
	residents: [
	],
	films: [
		"https://swapi.co/api/films/2/"
	],
	created: "2014-12-10T11:39:13.934000Z",
	edited: "2014-12-20T20:58:18.423000Z",
	url: "https://swapi.co/api/planets/4/"
},
	"https://swapi.co/api/planets/5/": {
	name: "Dagobah",
	rotation_period: "23",
	orbital_period: "341",
	diameter: "8900",
	climate: "murky",
	gravity: "N/A",
	terrain: "swamp, jungles",
	surface_water: "8",
	population: "unknown",
	residents: [
	],
	films: [
		"https://swapi.co/api/films/2/",
		"https://swapi.co/api/films/6/",
		"https://swapi.co/api/films/3/"
	],
	created: "2014-12-10T11:42:22.590000Z",
	edited: "2014-12-20T20:58:18.425000Z",
	url: "https://swapi.co/api/planets/5/"
},
	"https://swapi.co/api/planets/6/": {
	name: "Bespin",
	rotation_period: "12",
	orbital_period: "5110",
	diameter: "118000",
	climate: "temperate",
	gravity: "1.5 (surface), 1 standard (Cloud City)",
	terrain: "gas giant",
	surface_water: "0",
	population: "6000000",
	residents: [
		"https://swapi.co/api/people/26/"
	],
	films: [
		"https://swapi.co/api/films/2/"
	],
	created: "2014-12-10T11:43:55.240000Z",
	edited: "2014-12-20T20:58:18.427000Z",
	url: "https://swapi.co/api/planets/6/"
},
	"https://swapi.co/api/planets/7/": {
	name: "Endor",
	rotation_period: "18",
	orbital_period: "402",
	diameter: "4900",
	climate: "temperate",
	gravity: "0.85 standard",
	terrain: "forests, mountains, lakes",
	surface_water: "8",
	population: "30000000",
	residents: [
		"https://swapi.co/api/people/30/"
	],
	films: [
		"https://swapi.co/api/films/3/"
	],
	created: "2014-12-10T11:50:29.349000Z",
	edited: "2014-12-20T20:58:18.429000Z",
	url: "https://swapi.co/api/planets/7/"
},
	"https://swapi.co/api/planets/8/": {
	name: "Naboo",
	rotation_period: "26",
	orbital_period: "312",
	diameter: "12120",
	climate: "temperate",
	gravity: "1 standard",
	terrain: "grassy hills, swamps, forests, mountains",
	surface_water: "12",
	population: "4500000000",
	residents: [
		"https://swapi.co/api/people/3/",
		"https://swapi.co/api/people/21/",
		"https://swapi.co/api/people/36/",
		"https://swapi.co/api/people/37/",
		"https://swapi.co/api/people/38/",
		"https://swapi.co/api/people/39/",
		"https://swapi.co/api/people/42/",
		"https://swapi.co/api/people/60/",
		"https://swapi.co/api/people/61/",
		"https://swapi.co/api/people/66/",
		"https://swapi.co/api/people/35/"
	],
	films: [
		"https://swapi.co/api/films/5/",
		"https://swapi.co/api/films/4/",
		"https://swapi.co/api/films/6/",
		"https://swapi.co/api/films/3/"
	],
	created: "2014-12-10T11:52:31.066000Z",
	edited: "2014-12-20T20:58:18.430000Z",
	url: "https://swapi.co/api/planets/8/"
},
	"https://swapi.co/api/planets/9/": {
	name: "Coruscant",
	rotation_period: "24",
	orbital_period: "368",
	diameter: "12240",
	climate: "temperate",
	gravity: "1 standard",
	terrain: "cityscape, mountains",
	surface_water: "unknown",
	population: "1000000000000",
	residents: [
		"https://swapi.co/api/people/34/",
		"https://swapi.co/api/people/55/",
		"https://swapi.co/api/people/74/"
	],
	films: [
		"https://swapi.co/api/films/5/",
		"https://swapi.co/api/films/4/",
		"https://swapi.co/api/films/6/",
		"https://swapi.co/api/films/3/"
	],
	created: "2014-12-10T11:54:13.921000Z",
	edited: "2014-12-20T20:58:18.432000Z",
	url: "https://swapi.co/api/planets/9/"
},
	"https://swapi.co/api/planets/10/": {
	name: "Kamino",
	rotation_period: "27",
	orbital_period: "463",
	diameter: "19720",
	climate: "temperate",
	gravity: "1 standard",
	terrain: "ocean",
	surface_water: "100",
	population: "1000000000",
	residents: [
		"https://swapi.co/api/people/22/",
		"https://swapi.co/api/people/72/",
		"https://swapi.co/api/people/73/"
	],
	films: [
		"https://swapi.co/api/films/5/"
	],
	created: "2014-12-10T12:45:06.577000Z",
	edited: "2014-12-20T20:58:18.434000Z",
	url: "https://swapi.co/api/planets/10/"
},
	"https://swapi.co/api/planets/11/": {
	name: "Geonosis",
	rotation_period: "30",
	orbital_period: "256",
	diameter: "11370",
	climate: "temperate, arid",
	gravity: "0.9 standard",
	terrain: "rock, desert, mountain, barren",
	surface_water: "5",
	population: "100000000000",
	residents: [
		"https://swapi.co/api/people/63/"
	],
	films: [
		"https://swapi.co/api/films/5/"
	],
	created: "2014-12-10T12:47:22.350000Z",
	edited: "2014-12-20T20:58:18.437000Z",
	url: "https://swapi.co/api/planets/11/"
},
	"https://swapi.co/api/planets/?page=2": {
	count: 61,
	next: "https://swapi.co/api/planets/?page=3",
	previous: "https://swapi.co/api/planets/?page=1",
	results: [
		{
			name: "Utapau",
			rotation_period: "27",
			orbital_period: "351",
			diameter: "12900",
			climate: "temperate, arid, windy",
			gravity: "1 standard",
			terrain: "scrublands, savanna, canyons, sinkholes",
			surface_water: "0.9",
			population: "95000000",
			residents: [
				"https://swapi.co/api/people/83/"
			],
			films: [
				"https://swapi.co/api/films/6/"
			],
			created: "2014-12-10T12:49:01.491000Z",
			edited: "2014-12-20T20:58:18.439000Z",
			url: "https://swapi.co/api/planets/12/"
		},
		{
			name: "Mustafar",
			rotation_period: "36",
			orbital_period: "412",
			diameter: "4200",
			climate: "hot",
			gravity: "1 standard",
			terrain: "volcanoes, lava rivers, mountains, caves",
			surface_water: "0",
			population: "20000",
			residents: [
			],
			films: [
				"https://swapi.co/api/films/6/"
			],
			created: "2014-12-10T12:50:16.526000Z",
			edited: "2014-12-20T20:58:18.440000Z",
			url: "https://swapi.co/api/planets/13/"
		},
		{
			name: "Kashyyyk",
			rotation_period: "26",
			orbital_period: "381",
			diameter: "12765",
			climate: "tropical",
			gravity: "1 standard",
			terrain: "jungle, forests, lakes, rivers",
			surface_water: "60",
			population: "45000000",
			residents: [
				"https://swapi.co/api/people/13/",
				"https://swapi.co/api/people/80/"
			],
			films: [
				"https://swapi.co/api/films/6/"
			],
			created: "2014-12-10T13:32:00.124000Z",
			edited: "2014-12-20T20:58:18.442000Z",
			url: "https://swapi.co/api/planets/14/"
		},
		{
			name: "Polis Massa",
			rotation_period: "24",
			orbital_period: "590",
			diameter: "0",
			climate: "artificial temperate ",
			gravity: "0.56 standard",
			terrain: "airless asteroid",
			surface_water: "0",
			population: "1000000",
			residents: [
			],
			films: [
				"https://swapi.co/api/films/6/"
			],
			created: "2014-12-10T13:33:46.405000Z",
			edited: "2014-12-20T20:58:18.444000Z",
			url: "https://swapi.co/api/planets/15/"
		},
		{
			name: "Mygeeto",
			rotation_period: "12",
			orbital_period: "167",
			diameter: "10088",
			climate: "frigid",
			gravity: "1 standard",
			terrain: "glaciers, mountains, ice canyons",
			surface_water: "unknown",
			population: "19000000",
			residents: [
			],
			films: [
				"https://swapi.co/api/films/6/"
			],
			created: "2014-12-10T13:43:39.139000Z",
			edited: "2014-12-20T20:58:18.446000Z",
			url: "https://swapi.co/api/planets/16/"
		},
		{
			name: "Felucia",
			rotation_period: "34",
			orbital_period: "231",
			diameter: "9100",
			climate: "hot, humid",
			gravity: "0.75 standard",
			terrain: "fungus forests",
			surface_water: "unknown",
			population: "8500000",
			residents: [
			],
			films: [
				"https://swapi.co/api/films/6/"
			],
			created: "2014-12-10T13:44:50.397000Z",
			edited: "2014-12-20T20:58:18.447000Z",
			url: "https://swapi.co/api/planets/17/"
		},
		{
			name: "Cato Neimoidia",
			rotation_period: "25",
			orbital_period: "278",
			diameter: "0",
			climate: "temperate, moist",
			gravity: "1 standard",
			terrain: "mountains, fields, forests, rock arches",
			surface_water: "unknown",
			population: "10000000",
			residents: [
				"https://swapi.co/api/people/33/"
			],
			films: [
				"https://swapi.co/api/films/6/"
			],
			created: "2014-12-10T13:46:28.704000Z",
			edited: "2014-12-20T20:58:18.449000Z",
			url: "https://swapi.co/api/planets/18/"
		},
		{
			name: "Saleucami",
			rotation_period: "26",
			orbital_period: "392",
			diameter: "14920",
			climate: "hot",
			gravity: "unknown",
			terrain: "caves, desert, mountains, volcanoes",
			surface_water: "unknown",
			population: "1400000000",
			residents: [
			],
			films: [
				"https://swapi.co/api/films/6/"
			],
			created: "2014-12-10T13:47:46.874000Z",
			edited: "2014-12-20T20:58:18.450000Z",
			url: "https://swapi.co/api/planets/19/"
		},
		{
			name: "Stewjon",
			rotation_period: "unknown",
			orbital_period: "unknown",
			diameter: "0",
			climate: "temperate",
			gravity: "1 standard",
			terrain: "grass",
			surface_water: "unknown",
			population: "unknown",
			residents: [
				"https://swapi.co/api/people/10/"
			],
			films: [
			],
			created: "2014-12-10T16:16:26.566000Z",
			edited: "2014-12-20T20:58:18.452000Z",
			url: "https://swapi.co/api/planets/20/"
		},
		{
			name: "Eriadu",
			rotation_period: "24",
			orbital_period: "360",
			diameter: "13490",
			climate: "polluted",
			gravity: "1 standard",
			terrain: "cityscape",
			surface_water: "unknown",
			population: "22000000000",
			residents: [
				"https://swapi.co/api/people/12/"
			],
			films: [
			],
			created: "2014-12-10T16:26:54.384000Z",
			edited: "2014-12-20T20:58:18.454000Z",
			url: "https://swapi.co/api/planets/21/"
		}
	]
},
	"https://swapi.co/api/planets/12/": {
	name: "Utapau",
	rotation_period: "27",
	orbital_period: "351",
	diameter: "12900",
	climate: "temperate, arid, windy",
	gravity: "1 standard",
	terrain: "scrublands, savanna, canyons, sinkholes",
	surface_water: "0.9",
	population: "95000000",
	residents: [
		"https://swapi.co/api/people/83/"
	],
	films: [
		"https://swapi.co/api/films/6/"
	],
	created: "2014-12-10T12:49:01.491000Z",
	edited: "2014-12-20T20:58:18.439000Z",
	url: "https://swapi.co/api/planets/12/"
},
	"https://swapi.co/api/planets/13/": {
	name: "Mustafar",
	rotation_period: "36",
	orbital_period: "412",
	diameter: "4200",
	climate: "hot",
	gravity: "1 standard",
	terrain: "volcanoes, lava rivers, mountains, caves",
	surface_water: "0",
	population: "20000",
	residents: [
	],
	films: [
		"https://swapi.co/api/films/6/"
	],
	created: "2014-12-10T12:50:16.526000Z",
	edited: "2014-12-20T20:58:18.440000Z",
	url: "https://swapi.co/api/planets/13/"
},
	"https://swapi.co/api/planets/14/": {
	name: "Kashyyyk",
	rotation_period: "26",
	orbital_period: "381",
	diameter: "12765",
	climate: "tropical",
	gravity: "1 standard",
	terrain: "jungle, forests, lakes, rivers",
	surface_water: "60",
	population: "45000000",
	residents: [
		"https://swapi.co/api/people/13/",
		"https://swapi.co/api/people/80/"
	],
	films: [
		"https://swapi.co/api/films/6/"
	],
	created: "2014-12-10T13:32:00.124000Z",
	edited: "2014-12-20T20:58:18.442000Z",
	url: "https://swapi.co/api/planets/14/"
},
	"https://swapi.co/api/planets/15/": {
	name: "Polis Massa",
	rotation_period: "24",
	orbital_period: "590",
	diameter: "0",
	climate: "artificial temperate ",
	gravity: "0.56 standard",
	terrain: "airless asteroid",
	surface_water: "0",
	population: "1000000",
	residents: [
	],
	films: [
		"https://swapi.co/api/films/6/"
	],
	created: "2014-12-10T13:33:46.405000Z",
	edited: "2014-12-20T20:58:18.444000Z",
	url: "https://swapi.co/api/planets/15/"
},
	"https://swapi.co/api/planets/16/": {
	name: "Mygeeto",
	rotation_period: "12",
	orbital_period: "167",
	diameter: "10088",
	climate: "frigid",
	gravity: "1 standard",
	terrain: "glaciers, mountains, ice canyons",
	surface_water: "unknown",
	population: "19000000",
	residents: [
	],
	films: [
		"https://swapi.co/api/films/6/"
	],
	created: "2014-12-10T13:43:39.139000Z",
	edited: "2014-12-20T20:58:18.446000Z",
	url: "https://swapi.co/api/planets/16/"
},
	"https://swapi.co/api/planets/17/": {
	name: "Felucia",
	rotation_period: "34",
	orbital_period: "231",
	diameter: "9100",
	climate: "hot, humid",
	gravity: "0.75 standard",
	terrain: "fungus forests",
	surface_water: "unknown",
	population: "8500000",
	residents: [
	],
	films: [
		"https://swapi.co/api/films/6/"
	],
	created: "2014-12-10T13:44:50.397000Z",
	edited: "2014-12-20T20:58:18.447000Z",
	url: "https://swapi.co/api/planets/17/"
},
	"https://swapi.co/api/planets/18/": {
	name: "Cato Neimoidia",
	rotation_period: "25",
	orbital_period: "278",
	diameter: "0",
	climate: "temperate, moist",
	gravity: "1 standard",
	terrain: "mountains, fields, forests, rock arches",
	surface_water: "unknown",
	population: "10000000",
	residents: [
		"https://swapi.co/api/people/33/"
	],
	films: [
		"https://swapi.co/api/films/6/"
	],
	created: "2014-12-10T13:46:28.704000Z",
	edited: "2014-12-20T20:58:18.449000Z",
	url: "https://swapi.co/api/planets/18/"
},
	"https://swapi.co/api/planets/19/": {
	name: "Saleucami",
	rotation_period: "26",
	orbital_period: "392",
	diameter: "14920",
	climate: "hot",
	gravity: "unknown",
	terrain: "caves, desert, mountains, volcanoes",
	surface_water: "unknown",
	population: "1400000000",
	residents: [
	],
	films: [
		"https://swapi.co/api/films/6/"
	],
	created: "2014-12-10T13:47:46.874000Z",
	edited: "2014-12-20T20:58:18.450000Z",
	url: "https://swapi.co/api/planets/19/"
},
	"https://swapi.co/api/planets/20/": {
	name: "Stewjon",
	rotation_period: "unknown",
	orbital_period: "unknown",
	diameter: "0",
	climate: "temperate",
	gravity: "1 standard",
	terrain: "grass",
	surface_water: "unknown",
	population: "unknown",
	residents: [
		"https://swapi.co/api/people/10/"
	],
	films: [
	],
	created: "2014-12-10T16:16:26.566000Z",
	edited: "2014-12-20T20:58:18.452000Z",
	url: "https://swapi.co/api/planets/20/"
},
	"https://swapi.co/api/planets/21/": {
	name: "Eriadu",
	rotation_period: "24",
	orbital_period: "360",
	diameter: "13490",
	climate: "polluted",
	gravity: "1 standard",
	terrain: "cityscape",
	surface_water: "unknown",
	population: "22000000000",
	residents: [
		"https://swapi.co/api/people/12/"
	],
	films: [
	],
	created: "2014-12-10T16:26:54.384000Z",
	edited: "2014-12-20T20:58:18.454000Z",
	url: "https://swapi.co/api/planets/21/"
},
	"https://swapi.co/api/planets/?page=3": {
	count: 61,
	next: "https://swapi.co/api/planets/?page=4",
	previous: "https://swapi.co/api/planets/?page=2",
	results: [
		{
			name: "Corellia",
			rotation_period: "25",
			orbital_period: "329",
			diameter: "11000",
			climate: "temperate",
			gravity: "1 standard",
			terrain: "plains, urban, hills, forests",
			surface_water: "70",
			population: "3000000000",
			residents: [
				"https://swapi.co/api/people/14/",
				"https://swapi.co/api/people/18/"
			],
			films: [
			],
			created: "2014-12-10T16:49:12.453000Z",
			edited: "2014-12-20T20:58:18.456000Z",
			url: "https://swapi.co/api/planets/22/"
		},
		{
			name: "Rodia",
			rotation_period: "29",
			orbital_period: "305",
			diameter: "7549",
			climate: "hot",
			gravity: "1 standard",
			terrain: "jungles, oceans, urban, swamps",
			surface_water: "60",
			population: "1300000000",
			residents: [
				"https://swapi.co/api/people/15/"
			],
			films: [
			],
			created: "2014-12-10T17:03:28.110000Z",
			edited: "2014-12-20T20:58:18.458000Z",
			url: "https://swapi.co/api/planets/23/"
		},
		{
			name: "Nal Hutta",
			rotation_period: "87",
			orbital_period: "413",
			diameter: "12150",
			climate: "temperate",
			gravity: "1 standard",
			terrain: "urban, oceans, swamps, bogs",
			surface_water: "unknown",
			population: "7000000000",
			residents: [
				"https://swapi.co/api/people/16/"
			],
			films: [
			],
			created: "2014-12-10T17:11:29.452000Z",
			edited: "2014-12-20T20:58:18.460000Z",
			url: "https://swapi.co/api/planets/24/"
		},
		{
			name: "Dantooine",
			rotation_period: "25",
			orbital_period: "378",
			diameter: "9830",
			climate: "temperate",
			gravity: "1 standard",
			terrain: "oceans, savannas, mountains, grasslands",
			surface_water: "unknown",
			population: "1000",
			residents: [
			],
			films: [
			],
			created: "2014-12-10T17:23:29.896000Z",
			edited: "2014-12-20T20:58:18.461000Z",
			url: "https://swapi.co/api/planets/25/"
		},
		{
			name: "Bestine IV",
			rotation_period: "26",
			orbital_period: "680",
			diameter: "6400",
			climate: "temperate",
			gravity: "unknown",
			terrain: "rocky islands, oceans",
			surface_water: "98",
			population: "62000000",
			residents: [
				"https://swapi.co/api/people/19/"
			],
			films: [
			],
			created: "2014-12-12T11:16:55.078000Z",
			edited: "2014-12-20T20:58:18.463000Z",
			url: "https://swapi.co/api/planets/26/"
		},
		{
			name: "Ord Mantell",
			rotation_period: "26",
			orbital_period: "334",
			diameter: "14050",
			climate: "temperate",
			gravity: "1 standard",
			terrain: "plains, seas, mesas",
			surface_water: "10",
			population: "4000000000",
			residents: [
			],
			films: [
				"https://swapi.co/api/films/2/"
			],
			created: "2014-12-15T12:23:41.661000Z",
			edited: "2014-12-20T20:58:18.464000Z",
			url: "https://swapi.co/api/planets/27/"
		},
		{
			name: "unknown",
			rotation_period: "0",
			orbital_period: "0",
			diameter: "0",
			climate: "unknown",
			gravity: "unknown",
			terrain: "unknown",
			surface_water: "unknown",
			population: "unknown",
			residents: [
				"https://swapi.co/api/people/20/",
				"https://swapi.co/api/people/23/",
				"https://swapi.co/api/people/29/",
				"https://swapi.co/api/people/32/",
				"https://swapi.co/api/people/75/",
				"https://swapi.co/api/people/84/",
				"https://swapi.co/api/people/85/",
				"https://swapi.co/api/people/86/",
				"https://swapi.co/api/people/87/",
				"https://swapi.co/api/people/88/"
			],
			films: [
			],
			created: "2014-12-15T12:25:59.569000Z",
			edited: "2014-12-20T20:58:18.466000Z",
			url: "https://swapi.co/api/planets/28/"
		},
		{
			name: "Trandosha",
			rotation_period: "25",
			orbital_period: "371",
			diameter: "0",
			climate: "arid",
			gravity: "0.62 standard",
			terrain: "mountains, seas, grasslands, deserts",
			surface_water: "unknown",
			population: "42000000",
			residents: [
				"https://swapi.co/api/people/24/"
			],
			films: [
			],
			created: "2014-12-15T12:53:47.695000Z",
			edited: "2014-12-20T20:58:18.468000Z",
			url: "https://swapi.co/api/planets/29/"
		},
		{
			name: "Socorro",
			rotation_period: "20",
			orbital_period: "326",
			diameter: "0",
			climate: "arid",
			gravity: "1 standard",
			terrain: "deserts, mountains",
			surface_water: "unknown",
			population: "300000000",
			residents: [
				"https://swapi.co/api/people/25/"
			],
			films: [
			],
			created: "2014-12-15T12:56:31.121000Z",
			edited: "2014-12-20T20:58:18.469000Z",
			url: "https://swapi.co/api/planets/30/"
		},
		{
			name: "Mon Cala",
			rotation_period: "21",
			orbital_period: "398",
			diameter: "11030",
			climate: "temperate",
			gravity: "1",
			terrain: "oceans, reefs, islands",
			surface_water: "100",
			population: "27000000000",
			residents: [
				"https://swapi.co/api/people/27/"
			],
			films: [
			],
			created: "2014-12-18T11:07:01.792000Z",
			edited: "2014-12-20T20:58:18.471000Z",
			url: "https://swapi.co/api/planets/31/"
		}
	]
},
	"https://swapi.co/api/planets/22/": {
	name: "Corellia",
	rotation_period: "25",
	orbital_period: "329",
	diameter: "11000",
	climate: "temperate",
	gravity: "1 standard",
	terrain: "plains, urban, hills, forests",
	surface_water: "70",
	population: "3000000000",
	residents: [
		"https://swapi.co/api/people/14/",
		"https://swapi.co/api/people/18/"
	],
	films: [
	],
	created: "2014-12-10T16:49:12.453000Z",
	edited: "2014-12-20T20:58:18.456000Z",
	url: "https://swapi.co/api/planets/22/"
},
	"https://swapi.co/api/planets/23/": {
	name: "Rodia",
	rotation_period: "29",
	orbital_period: "305",
	diameter: "7549",
	climate: "hot",
	gravity: "1 standard",
	terrain: "jungles, oceans, urban, swamps",
	surface_water: "60",
	population: "1300000000",
	residents: [
		"https://swapi.co/api/people/15/"
	],
	films: [
	],
	created: "2014-12-10T17:03:28.110000Z",
	edited: "2014-12-20T20:58:18.458000Z",
	url: "https://swapi.co/api/planets/23/"
},
	"https://swapi.co/api/planets/24/": {
	name: "Nal Hutta",
	rotation_period: "87",
	orbital_period: "413",
	diameter: "12150",
	climate: "temperate",
	gravity: "1 standard",
	terrain: "urban, oceans, swamps, bogs",
	surface_water: "unknown",
	population: "7000000000",
	residents: [
		"https://swapi.co/api/people/16/"
	],
	films: [
	],
	created: "2014-12-10T17:11:29.452000Z",
	edited: "2014-12-20T20:58:18.460000Z",
	url: "https://swapi.co/api/planets/24/"
},
	"https://swapi.co/api/planets/25/": {
	name: "Dantooine",
	rotation_period: "25",
	orbital_period: "378",
	diameter: "9830",
	climate: "temperate",
	gravity: "1 standard",
	terrain: "oceans, savannas, mountains, grasslands",
	surface_water: "unknown",
	population: "1000",
	residents: [
	],
	films: [
	],
	created: "2014-12-10T17:23:29.896000Z",
	edited: "2014-12-20T20:58:18.461000Z",
	url: "https://swapi.co/api/planets/25/"
},
	"https://swapi.co/api/planets/26/": {
	name: "Bestine IV",
	rotation_period: "26",
	orbital_period: "680",
	diameter: "6400",
	climate: "temperate",
	gravity: "unknown",
	terrain: "rocky islands, oceans",
	surface_water: "98",
	population: "62000000",
	residents: [
		"https://swapi.co/api/people/19/"
	],
	films: [
	],
	created: "2014-12-12T11:16:55.078000Z",
	edited: "2014-12-20T20:58:18.463000Z",
	url: "https://swapi.co/api/planets/26/"
},
	"https://swapi.co/api/planets/27/": {
	name: "Ord Mantell",
	rotation_period: "26",
	orbital_period: "334",
	diameter: "14050",
	climate: "temperate",
	gravity: "1 standard",
	terrain: "plains, seas, mesas",
	surface_water: "10",
	population: "4000000000",
	residents: [
	],
	films: [
		"https://swapi.co/api/films/2/"
	],
	created: "2014-12-15T12:23:41.661000Z",
	edited: "2014-12-20T20:58:18.464000Z",
	url: "https://swapi.co/api/planets/27/"
},
	"https://swapi.co/api/planets/28/": {
	name: "unknown",
	rotation_period: "0",
	orbital_period: "0",
	diameter: "0",
	climate: "unknown",
	gravity: "unknown",
	terrain: "unknown",
	surface_water: "unknown",
	population: "unknown",
	residents: [
		"https://swapi.co/api/people/20/",
		"https://swapi.co/api/people/23/",
		"https://swapi.co/api/people/29/",
		"https://swapi.co/api/people/32/",
		"https://swapi.co/api/people/75/",
		"https://swapi.co/api/people/84/",
		"https://swapi.co/api/people/85/",
		"https://swapi.co/api/people/86/",
		"https://swapi.co/api/people/87/",
		"https://swapi.co/api/people/88/"
	],
	films: [
	],
	created: "2014-12-15T12:25:59.569000Z",
	edited: "2014-12-20T20:58:18.466000Z",
	url: "https://swapi.co/api/planets/28/"
},
	"https://swapi.co/api/planets/29/": {
	name: "Trandosha",
	rotation_period: "25",
	orbital_period: "371",
	diameter: "0",
	climate: "arid",
	gravity: "0.62 standard",
	terrain: "mountains, seas, grasslands, deserts",
	surface_water: "unknown",
	population: "42000000",
	residents: [
		"https://swapi.co/api/people/24/"
	],
	films: [
	],
	created: "2014-12-15T12:53:47.695000Z",
	edited: "2014-12-20T20:58:18.468000Z",
	url: "https://swapi.co/api/planets/29/"
},
	"https://swapi.co/api/planets/30/": {
	name: "Socorro",
	rotation_period: "20",
	orbital_period: "326",
	diameter: "0",
	climate: "arid",
	gravity: "1 standard",
	terrain: "deserts, mountains",
	surface_water: "unknown",
	population: "300000000",
	residents: [
		"https://swapi.co/api/people/25/"
	],
	films: [
	],
	created: "2014-12-15T12:56:31.121000Z",
	edited: "2014-12-20T20:58:18.469000Z",
	url: "https://swapi.co/api/planets/30/"
},
	"https://swapi.co/api/planets/31/": {
	name: "Mon Cala",
	rotation_period: "21",
	orbital_period: "398",
	diameter: "11030",
	climate: "temperate",
	gravity: "1",
	terrain: "oceans, reefs, islands",
	surface_water: "100",
	population: "27000000000",
	residents: [
		"https://swapi.co/api/people/27/"
	],
	films: [
	],
	created: "2014-12-18T11:07:01.792000Z",
	edited: "2014-12-20T20:58:18.471000Z",
	url: "https://swapi.co/api/planets/31/"
},
	"https://swapi.co/api/planets/?page=4": {
	count: 61,
	next: "https://swapi.co/api/planets/?page=5",
	previous: "https://swapi.co/api/planets/?page=3",
	results: [
		{
			name: "Chandrila",
			rotation_period: "20",
			orbital_period: "368",
			diameter: "13500",
			climate: "temperate",
			gravity: "1",
			terrain: "plains, forests",
			surface_water: "40",
			population: "1200000000",
			residents: [
				"https://swapi.co/api/people/28/"
			],
			films: [
			],
			created: "2014-12-18T11:11:51.872000Z",
			edited: "2014-12-20T20:58:18.472000Z",
			url: "https://swapi.co/api/planets/32/"
		},
		{
			name: "Sullust",
			rotation_period: "20",
			orbital_period: "263",
			diameter: "12780",
			climate: "superheated",
			gravity: "1",
			terrain: "mountains, volcanoes, rocky deserts",
			surface_water: "5",
			population: "18500000000",
			residents: [
				"https://swapi.co/api/people/31/"
			],
			films: [
			],
			created: "2014-12-18T11:25:40.243000Z",
			edited: "2014-12-20T20:58:18.474000Z",
			url: "https://swapi.co/api/planets/33/"
		},
		{
			name: "Toydaria",
			rotation_period: "21",
			orbital_period: "184",
			diameter: "7900",
			climate: "temperate",
			gravity: "1",
			terrain: "swamps, lakes",
			surface_water: "unknown",
			population: "11000000",
			residents: [
				"https://swapi.co/api/people/40/"
			],
			films: [
			],
			created: "2014-12-19T17:47:54.403000Z",
			edited: "2014-12-20T20:58:18.476000Z",
			url: "https://swapi.co/api/planets/34/"
		},
		{
			name: "Malastare",
			rotation_period: "26",
			orbital_period: "201",
			diameter: "18880",
			climate: "arid, temperate, tropical",
			gravity: "1.56",
			terrain: "swamps, deserts, jungles, mountains",
			surface_water: "unknown",
			population: "2000000000",
			residents: [
				"https://swapi.co/api/people/41/"
			],
			films: [
			],
			created: "2014-12-19T17:52:13.106000Z",
			edited: "2014-12-20T20:58:18.478000Z",
			url: "https://swapi.co/api/planets/35/"
		},
		{
			name: "Dathomir",
			rotation_period: "24",
			orbital_period: "491",
			diameter: "10480",
			climate: "temperate",
			gravity: "0.9",
			terrain: "forests, deserts, savannas",
			surface_water: "unknown",
			population: "5200",
			residents: [
				"https://swapi.co/api/people/44/"
			],
			films: [
			],
			created: "2014-12-19T18:00:40.142000Z",
			edited: "2014-12-20T20:58:18.480000Z",
			url: "https://swapi.co/api/planets/36/"
		},
		{
			name: "Ryloth",
			rotation_period: "30",
			orbital_period: "305",
			diameter: "10600",
			climate: "temperate, arid, subartic",
			gravity: "1",
			terrain: "mountains, valleys, deserts, tundra",
			surface_water: "5",
			population: "1500000000",
			residents: [
				"https://swapi.co/api/people/45/",
				"https://swapi.co/api/people/46/"
			],
			films: [
			],
			created: "2014-12-20T09:46:25.740000Z",
			edited: "2014-12-20T20:58:18.481000Z",
			url: "https://swapi.co/api/planets/37/"
		},
		{
			name: "Aleen Minor",
			rotation_period: "unknown",
			orbital_period: "unknown",
			diameter: "unknown",
			climate: "unknown",
			gravity: "unknown",
			terrain: "unknown",
			surface_water: "unknown",
			population: "unknown",
			residents: [
				"https://swapi.co/api/people/47/"
			],
			films: [
			],
			created: "2014-12-20T09:52:23.452000Z",
			edited: "2014-12-20T20:58:18.483000Z",
			url: "https://swapi.co/api/planets/38/"
		},
		{
			name: "Vulpter",
			rotation_period: "22",
			orbital_period: "391",
			diameter: "14900",
			climate: "temperate, artic",
			gravity: "1",
			terrain: "urban, barren",
			surface_water: "unknown",
			population: "421000000",
			residents: [
				"https://swapi.co/api/people/48/"
			],
			films: [
			],
			created: "2014-12-20T09:56:58.874000Z",
			edited: "2014-12-20T20:58:18.485000Z",
			url: "https://swapi.co/api/planets/39/"
		},
		{
			name: "Troiken",
			rotation_period: "unknown",
			orbital_period: "unknown",
			diameter: "unknown",
			climate: "unknown",
			gravity: "unknown",
			terrain: "desert, tundra, rainforests, mountains",
			surface_water: "unknown",
			population: "unknown",
			residents: [
				"https://swapi.co/api/people/49/"
			],
			films: [
			],
			created: "2014-12-20T10:01:37.395000Z",
			edited: "2014-12-20T20:58:18.487000Z",
			url: "https://swapi.co/api/planets/40/"
		},
		{
			name: "Tund",
			rotation_period: "48",
			orbital_period: "1770",
			diameter: "12190",
			climate: "unknown",
			gravity: "unknown",
			terrain: "barren, ash",
			surface_water: "unknown",
			population: "0",
			residents: [
				"https://swapi.co/api/people/50/"
			],
			films: [
			],
			created: "2014-12-20T10:07:29.578000Z",
			edited: "2014-12-20T20:58:18.489000Z",
			url: "https://swapi.co/api/planets/41/"
		}
	]
},
	"https://swapi.co/api/planets/32/": {
	name: "Chandrila",
	rotation_period: "20",
	orbital_period: "368",
	diameter: "13500",
	climate: "temperate",
	gravity: "1",
	terrain: "plains, forests",
	surface_water: "40",
	population: "1200000000",
	residents: [
		"https://swapi.co/api/people/28/"
	],
	films: [
	],
	created: "2014-12-18T11:11:51.872000Z",
	edited: "2014-12-20T20:58:18.472000Z",
	url: "https://swapi.co/api/planets/32/"
},
	"https://swapi.co/api/planets/33/": {
	name: "Sullust",
	rotation_period: "20",
	orbital_period: "263",
	diameter: "12780",
	climate: "superheated",
	gravity: "1",
	terrain: "mountains, volcanoes, rocky deserts",
	surface_water: "5",
	population: "18500000000",
	residents: [
		"https://swapi.co/api/people/31/"
	],
	films: [
	],
	created: "2014-12-18T11:25:40.243000Z",
	edited: "2014-12-20T20:58:18.474000Z",
	url: "https://swapi.co/api/planets/33/"
},
	"https://swapi.co/api/planets/34/": {
	name: "Toydaria",
	rotation_period: "21",
	orbital_period: "184",
	diameter: "7900",
	climate: "temperate",
	gravity: "1",
	terrain: "swamps, lakes",
	surface_water: "unknown",
	population: "11000000",
	residents: [
		"https://swapi.co/api/people/40/"
	],
	films: [
	],
	created: "2014-12-19T17:47:54.403000Z",
	edited: "2014-12-20T20:58:18.476000Z",
	url: "https://swapi.co/api/planets/34/"
},
	"https://swapi.co/api/planets/35/": {
	name: "Malastare",
	rotation_period: "26",
	orbital_period: "201",
	diameter: "18880",
	climate: "arid, temperate, tropical",
	gravity: "1.56",
	terrain: "swamps, deserts, jungles, mountains",
	surface_water: "unknown",
	population: "2000000000",
	residents: [
		"https://swapi.co/api/people/41/"
	],
	films: [
	],
	created: "2014-12-19T17:52:13.106000Z",
	edited: "2014-12-20T20:58:18.478000Z",
	url: "https://swapi.co/api/planets/35/"
},
	"https://swapi.co/api/planets/36/": {
	name: "Dathomir",
	rotation_period: "24",
	orbital_period: "491",
	diameter: "10480",
	climate: "temperate",
	gravity: "0.9",
	terrain: "forests, deserts, savannas",
	surface_water: "unknown",
	population: "5200",
	residents: [
		"https://swapi.co/api/people/44/"
	],
	films: [
	],
	created: "2014-12-19T18:00:40.142000Z",
	edited: "2014-12-20T20:58:18.480000Z",
	url: "https://swapi.co/api/planets/36/"
},
	"https://swapi.co/api/planets/37/": {
	name: "Ryloth",
	rotation_period: "30",
	orbital_period: "305",
	diameter: "10600",
	climate: "temperate, arid, subartic",
	gravity: "1",
	terrain: "mountains, valleys, deserts, tundra",
	surface_water: "5",
	population: "1500000000",
	residents: [
		"https://swapi.co/api/people/45/",
		"https://swapi.co/api/people/46/"
	],
	films: [
	],
	created: "2014-12-20T09:46:25.740000Z",
	edited: "2014-12-20T20:58:18.481000Z",
	url: "https://swapi.co/api/planets/37/"
},
	"https://swapi.co/api/planets/38/": {
	name: "Aleen Minor",
	rotation_period: "unknown",
	orbital_period: "unknown",
	diameter: "unknown",
	climate: "unknown",
	gravity: "unknown",
	terrain: "unknown",
	surface_water: "unknown",
	population: "unknown",
	residents: [
		"https://swapi.co/api/people/47/"
	],
	films: [
	],
	created: "2014-12-20T09:52:23.452000Z",
	edited: "2014-12-20T20:58:18.483000Z",
	url: "https://swapi.co/api/planets/38/"
},
	"https://swapi.co/api/planets/39/": {
	name: "Vulpter",
	rotation_period: "22",
	orbital_period: "391",
	diameter: "14900",
	climate: "temperate, artic",
	gravity: "1",
	terrain: "urban, barren",
	surface_water: "unknown",
	population: "421000000",
	residents: [
		"https://swapi.co/api/people/48/"
	],
	films: [
	],
	created: "2014-12-20T09:56:58.874000Z",
	edited: "2014-12-20T20:58:18.485000Z",
	url: "https://swapi.co/api/planets/39/"
},
	"https://swapi.co/api/planets/40/": {
	name: "Troiken",
	rotation_period: "unknown",
	orbital_period: "unknown",
	diameter: "unknown",
	climate: "unknown",
	gravity: "unknown",
	terrain: "desert, tundra, rainforests, mountains",
	surface_water: "unknown",
	population: "unknown",
	residents: [
		"https://swapi.co/api/people/49/"
	],
	films: [
	],
	created: "2014-12-20T10:01:37.395000Z",
	edited: "2014-12-20T20:58:18.487000Z",
	url: "https://swapi.co/api/planets/40/"
},
	"https://swapi.co/api/planets/41/": {
	name: "Tund",
	rotation_period: "48",
	orbital_period: "1770",
	diameter: "12190",
	climate: "unknown",
	gravity: "unknown",
	terrain: "barren, ash",
	surface_water: "unknown",
	population: "0",
	residents: [
		"https://swapi.co/api/people/50/"
	],
	films: [
	],
	created: "2014-12-20T10:07:29.578000Z",
	edited: "2014-12-20T20:58:18.489000Z",
	url: "https://swapi.co/api/planets/41/"
},
	"https://swapi.co/api/planets/?page=5": {
	count: 61,
	next: "https://swapi.co/api/planets/?page=6",
	previous: "https://swapi.co/api/planets/?page=4",
	results: [
		{
			name: "Haruun Kal",
			rotation_period: "25",
			orbital_period: "383",
			diameter: "10120",
			climate: "temperate",
			gravity: "0.98",
			terrain: "toxic cloudsea, plateaus, volcanoes",
			surface_water: "unknown",
			population: "705300",
			residents: [
				"https://swapi.co/api/people/51/"
			],
			films: [
			],
			created: "2014-12-20T10:12:28.980000Z",
			edited: "2014-12-20T20:58:18.491000Z",
			url: "https://swapi.co/api/planets/42/"
		},
		{
			name: "Cerea",
			rotation_period: "27",
			orbital_period: "386",
			diameter: "unknown",
			climate: "temperate",
			gravity: "1",
			terrain: "verdant",
			surface_water: "20",
			population: "450000000",
			residents: [
				"https://swapi.co/api/people/52/"
			],
			films: [
			],
			created: "2014-12-20T10:14:48.178000Z",
			edited: "2014-12-20T20:58:18.493000Z",
			url: "https://swapi.co/api/planets/43/"
		},
		{
			name: "Glee Anselm",
			rotation_period: "33",
			orbital_period: "206",
			diameter: "15600",
			climate: "tropical, temperate",
			gravity: "1",
			terrain: "lakes, islands, swamps, seas",
			surface_water: "80",
			population: "500000000",
			residents: [
				"https://swapi.co/api/people/53/"
			],
			films: [
			],
			created: "2014-12-20T10:18:26.110000Z",
			edited: "2014-12-20T20:58:18.495000Z",
			url: "https://swapi.co/api/planets/44/"
		},
		{
			name: "Iridonia",
			rotation_period: "29",
			orbital_period: "413",
			diameter: "unknown",
			climate: "unknown",
			gravity: "unknown",
			terrain: "rocky canyons, acid pools",
			surface_water: "unknown",
			population: "unknown",
			residents: [
				"https://swapi.co/api/people/54/"
			],
			films: [
			],
			created: "2014-12-20T10:26:05.788000Z",
			edited: "2014-12-20T20:58:18.497000Z",
			url: "https://swapi.co/api/planets/45/"
		},
		{
			name: "Tholoth",
			rotation_period: "unknown",
			orbital_period: "unknown",
			diameter: "unknown",
			climate: "unknown",
			gravity: "unknown",
			terrain: "unknown",
			surface_water: "unknown",
			population: "unknown",
			residents: [
			],
			films: [
			],
			created: "2014-12-20T10:28:31.117000Z",
			edited: "2014-12-20T20:58:18.498000Z",
			url: "https://swapi.co/api/planets/46/"
		},
		{
			name: "Iktotch",
			rotation_period: "22",
			orbital_period: "481",
			diameter: "unknown",
			climate: "arid, rocky, windy",
			gravity: "1",
			terrain: "rocky",
			surface_water: "unknown",
			population: "unknown",
			residents: [
				"https://swapi.co/api/people/56/"
			],
			films: [
			],
			created: "2014-12-20T10:31:32.413000Z",
			edited: "2014-12-20T20:58:18.500000Z",
			url: "https://swapi.co/api/planets/47/"
		},
		{
			name: "Quermia",
			rotation_period: "unknown",
			orbital_period: "unknown",
			diameter: "unknown",
			climate: "unknown",
			gravity: "unknown",
			terrain: "unknown",
			surface_water: "unknown",
			population: "unknown",
			residents: [
				"https://swapi.co/api/people/57/"
			],
			films: [
			],
			created: "2014-12-20T10:34:08.249000Z",
			edited: "2014-12-20T20:58:18.502000Z",
			url: "https://swapi.co/api/planets/48/"
		},
		{
			name: "Dorin",
			rotation_period: "22",
			orbital_period: "409",
			diameter: "13400",
			climate: "temperate",
			gravity: "1",
			terrain: "unknown",
			surface_water: "unknown",
			population: "unknown",
			residents: [
				"https://swapi.co/api/people/58/"
			],
			films: [
			],
			created: "2014-12-20T10:48:36.141000Z",
			edited: "2014-12-20T20:58:18.504000Z",
			url: "https://swapi.co/api/planets/49/"
		},
		{
			name: "Champala",
			rotation_period: "27",
			orbital_period: "318",
			diameter: "unknown",
			climate: "temperate",
			gravity: "1",
			terrain: "oceans, rainforests, plateaus",
			surface_water: "unknown",
			population: "3500000000",
			residents: [
				"https://swapi.co/api/people/59/"
			],
			films: [
			],
			created: "2014-12-20T10:52:51.524000Z",
			edited: "2014-12-20T20:58:18.506000Z",
			url: "https://swapi.co/api/planets/50/"
		},
		{
			name: "Mirial",
			rotation_period: "unknown",
			orbital_period: "unknown",
			diameter: "unknown",
			climate: "unknown",
			gravity: "unknown",
			terrain: "deserts",
			surface_water: "unknown",
			population: "unknown",
			residents: [
				"https://swapi.co/api/people/64/",
				"https://swapi.co/api/people/65/"
			],
			films: [
			],
			created: "2014-12-20T16:44:46.318000Z",
			edited: "2014-12-20T20:58:18.508000Z",
			url: "https://swapi.co/api/planets/51/"
		}
	]
},
	"https://swapi.co/api/planets/42/": {
	name: "Haruun Kal",
	rotation_period: "25",
	orbital_period: "383",
	diameter: "10120",
	climate: "temperate",
	gravity: "0.98",
	terrain: "toxic cloudsea, plateaus, volcanoes",
	surface_water: "unknown",
	population: "705300",
	residents: [
		"https://swapi.co/api/people/51/"
	],
	films: [
	],
	created: "2014-12-20T10:12:28.980000Z",
	edited: "2014-12-20T20:58:18.491000Z",
	url: "https://swapi.co/api/planets/42/"
},
	"https://swapi.co/api/planets/43/": {
	name: "Cerea",
	rotation_period: "27",
	orbital_period: "386",
	diameter: "unknown",
	climate: "temperate",
	gravity: "1",
	terrain: "verdant",
	surface_water: "20",
	population: "450000000",
	residents: [
		"https://swapi.co/api/people/52/"
	],
	films: [
	],
	created: "2014-12-20T10:14:48.178000Z",
	edited: "2014-12-20T20:58:18.493000Z",
	url: "https://swapi.co/api/planets/43/"
},
	"https://swapi.co/api/planets/44/": {
	name: "Glee Anselm",
	rotation_period: "33",
	orbital_period: "206",
	diameter: "15600",
	climate: "tropical, temperate",
	gravity: "1",
	terrain: "lakes, islands, swamps, seas",
	surface_water: "80",
	population: "500000000",
	residents: [
		"https://swapi.co/api/people/53/"
	],
	films: [
	],
	created: "2014-12-20T10:18:26.110000Z",
	edited: "2014-12-20T20:58:18.495000Z",
	url: "https://swapi.co/api/planets/44/"
},
	"https://swapi.co/api/planets/45/": {
	name: "Iridonia",
	rotation_period: "29",
	orbital_period: "413",
	diameter: "unknown",
	climate: "unknown",
	gravity: "unknown",
	terrain: "rocky canyons, acid pools",
	surface_water: "unknown",
	population: "unknown",
	residents: [
		"https://swapi.co/api/people/54/"
	],
	films: [
	],
	created: "2014-12-20T10:26:05.788000Z",
	edited: "2014-12-20T20:58:18.497000Z",
	url: "https://swapi.co/api/planets/45/"
},
	"https://swapi.co/api/planets/46/": {
	name: "Tholoth",
	rotation_period: "unknown",
	orbital_period: "unknown",
	diameter: "unknown",
	climate: "unknown",
	gravity: "unknown",
	terrain: "unknown",
	surface_water: "unknown",
	population: "unknown",
	residents: [
	],
	films: [
	],
	created: "2014-12-20T10:28:31.117000Z",
	edited: "2014-12-20T20:58:18.498000Z",
	url: "https://swapi.co/api/planets/46/"
},
	"https://swapi.co/api/planets/47/": {
	name: "Iktotch",
	rotation_period: "22",
	orbital_period: "481",
	diameter: "unknown",
	climate: "arid, rocky, windy",
	gravity: "1",
	terrain: "rocky",
	surface_water: "unknown",
	population: "unknown",
	residents: [
		"https://swapi.co/api/people/56/"
	],
	films: [
	],
	created: "2014-12-20T10:31:32.413000Z",
	edited: "2014-12-20T20:58:18.500000Z",
	url: "https://swapi.co/api/planets/47/"
},
	"https://swapi.co/api/planets/48/": {
	name: "Quermia",
	rotation_period: "unknown",
	orbital_period: "unknown",
	diameter: "unknown",
	climate: "unknown",
	gravity: "unknown",
	terrain: "unknown",
	surface_water: "unknown",
	population: "unknown",
	residents: [
		"https://swapi.co/api/people/57/"
	],
	films: [
	],
	created: "2014-12-20T10:34:08.249000Z",
	edited: "2014-12-20T20:58:18.502000Z",
	url: "https://swapi.co/api/planets/48/"
},
	"https://swapi.co/api/planets/49/": {
	name: "Dorin",
	rotation_period: "22",
	orbital_period: "409",
	diameter: "13400",
	climate: "temperate",
	gravity: "1",
	terrain: "unknown",
	surface_water: "unknown",
	population: "unknown",
	residents: [
		"https://swapi.co/api/people/58/"
	],
	films: [
	],
	created: "2014-12-20T10:48:36.141000Z",
	edited: "2014-12-20T20:58:18.504000Z",
	url: "https://swapi.co/api/planets/49/"
},
	"https://swapi.co/api/planets/50/": {
	name: "Champala",
	rotation_period: "27",
	orbital_period: "318",
	diameter: "unknown",
	climate: "temperate",
	gravity: "1",
	terrain: "oceans, rainforests, plateaus",
	surface_water: "unknown",
	population: "3500000000",
	residents: [
		"https://swapi.co/api/people/59/"
	],
	films: [
	],
	created: "2014-12-20T10:52:51.524000Z",
	edited: "2014-12-20T20:58:18.506000Z",
	url: "https://swapi.co/api/planets/50/"
},
	"https://swapi.co/api/planets/51/": {
	name: "Mirial",
	rotation_period: "unknown",
	orbital_period: "unknown",
	diameter: "unknown",
	climate: "unknown",
	gravity: "unknown",
	terrain: "deserts",
	surface_water: "unknown",
	population: "unknown",
	residents: [
		"https://swapi.co/api/people/64/",
		"https://swapi.co/api/people/65/"
	],
	films: [
	],
	created: "2014-12-20T16:44:46.318000Z",
	edited: "2014-12-20T20:58:18.508000Z",
	url: "https://swapi.co/api/planets/51/"
},
	"https://swapi.co/api/planets/?page=6": {
	count: 61,
	next: "https://swapi.co/api/planets/?page=7",
	previous: "https://swapi.co/api/planets/?page=5",
	results: [
		{
			name: "Serenno",
			rotation_period: "unknown",
			orbital_period: "unknown",
			diameter: "unknown",
			climate: "unknown",
			gravity: "unknown",
			terrain: "rainforests, rivers, mountains",
			surface_water: "unknown",
			population: "unknown",
			residents: [
				"https://swapi.co/api/people/67/"
			],
			films: [
			],
			created: "2014-12-20T16:52:13.357000Z",
			edited: "2014-12-20T20:58:18.510000Z",
			url: "https://swapi.co/api/planets/52/"
		},
		{
			name: "Concord Dawn",
			rotation_period: "unknown",
			orbital_period: "unknown",
			diameter: "unknown",
			climate: "unknown",
			gravity: "unknown",
			terrain: "jungles, forests, deserts",
			surface_water: "unknown",
			population: "unknown",
			residents: [
				"https://swapi.co/api/people/69/"
			],
			films: [
			],
			created: "2014-12-20T16:54:39.909000Z",
			edited: "2014-12-20T20:58:18.512000Z",
			url: "https://swapi.co/api/planets/53/"
		},
		{
			name: "Zolan",
			rotation_period: "unknown",
			orbital_period: "unknown",
			diameter: "unknown",
			climate: "unknown",
			gravity: "unknown",
			terrain: "unknown",
			surface_water: "unknown",
			population: "unknown",
			residents: [
				"https://swapi.co/api/people/70/"
			],
			films: [
			],
			created: "2014-12-20T16:56:37.250000Z",
			edited: "2014-12-20T20:58:18.514000Z",
			url: "https://swapi.co/api/planets/54/"
		},
		{
			name: "Ojom",
			rotation_period: "unknown",
			orbital_period: "unknown",
			diameter: "unknown",
			climate: "frigid",
			gravity: "unknown",
			terrain: "oceans, glaciers",
			surface_water: "100",
			population: "500000000",
			residents: [
				"https://swapi.co/api/people/71/"
			],
			films: [
			],
			created: "2014-12-20T17:27:41.286000Z",
			edited: "2014-12-20T20:58:18.516000Z",
			url: "https://swapi.co/api/planets/55/"
		},
		{
			name: "Skako",
			rotation_period: "27",
			orbital_period: "384",
			diameter: "unknown",
			climate: "temperate",
			gravity: "1",
			terrain: "urban, vines",
			surface_water: "unknown",
			population: "500000000000",
			residents: [
				"https://swapi.co/api/people/76/"
			],
			films: [
			],
			created: "2014-12-20T17:50:47.864000Z",
			edited: "2014-12-20T20:58:18.517000Z",
			url: "https://swapi.co/api/planets/56/"
		},
		{
			name: "Muunilinst",
			rotation_period: "28",
			orbital_period: "412",
			diameter: "13800",
			climate: "temperate",
			gravity: "1",
			terrain: "plains, forests, hills, mountains",
			surface_water: "25",
			population: "5000000000",
			residents: [
				"https://swapi.co/api/people/77/"
			],
			films: [
			],
			created: "2014-12-20T17:57:47.420000Z",
			edited: "2014-12-20T20:58:18.519000Z",
			url: "https://swapi.co/api/planets/57/"
		},
		{
			name: "Shili",
			rotation_period: "unknown",
			orbital_period: "unknown",
			diameter: "unknown",
			climate: "temperate",
			gravity: "1",
			terrain: "cities, savannahs, seas, plains",
			surface_water: "unknown",
			population: "unknown",
			residents: [
				"https://swapi.co/api/people/78/"
			],
			films: [
			],
			created: "2014-12-20T18:43:14.049000Z",
			edited: "2014-12-20T20:58:18.521000Z",
			url: "https://swapi.co/api/planets/58/"
		},
		{
			name: "Kalee",
			rotation_period: "23",
			orbital_period: "378",
			diameter: "13850",
			climate: "arid, temperate, tropical",
			gravity: "1",
			terrain: "rainforests, cliffs, canyons, seas",
			surface_water: "unknown",
			population: "4000000000",
			residents: [
				"https://swapi.co/api/people/79/"
			],
			films: [
			],
			created: "2014-12-20T19:43:51.278000Z",
			edited: "2014-12-20T20:58:18.523000Z",
			url: "https://swapi.co/api/planets/59/"
		},
		{
			name: "Umbara",
			rotation_period: "unknown",
			orbital_period: "unknown",
			diameter: "unknown",
			climate: "unknown",
			gravity: "unknown",
			terrain: "unknown",
			surface_water: "unknown",
			population: "unknown",
			residents: [
				"https://swapi.co/api/people/82/"
			],
			films: [
			],
			created: "2014-12-20T20:18:36.256000Z",
			edited: "2014-12-20T20:58:18.525000Z",
			url: "https://swapi.co/api/planets/60/"
		},
		{
			name: "Tatooine",
			rotation_period: "23",
			orbital_period: "304",
			diameter: "10465",
			climate: "arid",
			gravity: "1 standard",
			terrain: "desert",
			surface_water: "1",
			population: "200000",
			residents: [
				"https://swapi.co/api/people/1/",
				"https://swapi.co/api/people/2/",
				"https://swapi.co/api/people/4/",
				"https://swapi.co/api/people/6/",
				"https://swapi.co/api/people/7/",
				"https://swapi.co/api/people/8/",
				"https://swapi.co/api/people/9/",
				"https://swapi.co/api/people/11/",
				"https://swapi.co/api/people/43/",
				"https://swapi.co/api/people/62/"
			],
			films: [
				"https://swapi.co/api/films/5/",
				"https://swapi.co/api/films/4/",
				"https://swapi.co/api/films/6/",
				"https://swapi.co/api/films/3/",
				"https://swapi.co/api/films/1/"
			],
			created: "2014-12-09T13:50:49.641000Z",
			edited: "2014-12-21T20:48:04.175778Z",
			url: "https://swapi.co/api/planets/1/"
		}
	]
},
	"https://swapi.co/api/planets/52/": {
	name: "Serenno",
	rotation_period: "unknown",
	orbital_period: "unknown",
	diameter: "unknown",
	climate: "unknown",
	gravity: "unknown",
	terrain: "rainforests, rivers, mountains",
	surface_water: "unknown",
	population: "unknown",
	residents: [
		"https://swapi.co/api/people/67/"
	],
	films: [
	],
	created: "2014-12-20T16:52:13.357000Z",
	edited: "2014-12-20T20:58:18.510000Z",
	url: "https://swapi.co/api/planets/52/"
},
	"https://swapi.co/api/planets/53/": {
	name: "Concord Dawn",
	rotation_period: "unknown",
	orbital_period: "unknown",
	diameter: "unknown",
	climate: "unknown",
	gravity: "unknown",
	terrain: "jungles, forests, deserts",
	surface_water: "unknown",
	population: "unknown",
	residents: [
		"https://swapi.co/api/people/69/"
	],
	films: [
	],
	created: "2014-12-20T16:54:39.909000Z",
	edited: "2014-12-20T20:58:18.512000Z",
	url: "https://swapi.co/api/planets/53/"
},
	"https://swapi.co/api/planets/54/": {
	name: "Zolan",
	rotation_period: "unknown",
	orbital_period: "unknown",
	diameter: "unknown",
	climate: "unknown",
	gravity: "unknown",
	terrain: "unknown",
	surface_water: "unknown",
	population: "unknown",
	residents: [
		"https://swapi.co/api/people/70/"
	],
	films: [
	],
	created: "2014-12-20T16:56:37.250000Z",
	edited: "2014-12-20T20:58:18.514000Z",
	url: "https://swapi.co/api/planets/54/"
},
	"https://swapi.co/api/planets/55/": {
	name: "Ojom",
	rotation_period: "unknown",
	orbital_period: "unknown",
	diameter: "unknown",
	climate: "frigid",
	gravity: "unknown",
	terrain: "oceans, glaciers",
	surface_water: "100",
	population: "500000000",
	residents: [
		"https://swapi.co/api/people/71/"
	],
	films: [
	],
	created: "2014-12-20T17:27:41.286000Z",
	edited: "2014-12-20T20:58:18.516000Z",
	url: "https://swapi.co/api/planets/55/"
},
	"https://swapi.co/api/planets/56/": {
	name: "Skako",
	rotation_period: "27",
	orbital_period: "384",
	diameter: "unknown",
	climate: "temperate",
	gravity: "1",
	terrain: "urban, vines",
	surface_water: "unknown",
	population: "500000000000",
	residents: [
		"https://swapi.co/api/people/76/"
	],
	films: [
	],
	created: "2014-12-20T17:50:47.864000Z",
	edited: "2014-12-20T20:58:18.517000Z",
	url: "https://swapi.co/api/planets/56/"
},
	"https://swapi.co/api/planets/57/": {
	name: "Muunilinst",
	rotation_period: "28",
	orbital_period: "412",
	diameter: "13800",
	climate: "temperate",
	gravity: "1",
	terrain: "plains, forests, hills, mountains",
	surface_water: "25",
	population: "5000000000",
	residents: [
		"https://swapi.co/api/people/77/"
	],
	films: [
	],
	created: "2014-12-20T17:57:47.420000Z",
	edited: "2014-12-20T20:58:18.519000Z",
	url: "https://swapi.co/api/planets/57/"
},
	"https://swapi.co/api/planets/58/": {
	name: "Shili",
	rotation_period: "unknown",
	orbital_period: "unknown",
	diameter: "unknown",
	climate: "temperate",
	gravity: "1",
	terrain: "cities, savannahs, seas, plains",
	surface_water: "unknown",
	population: "unknown",
	residents: [
		"https://swapi.co/api/people/78/"
	],
	films: [
	],
	created: "2014-12-20T18:43:14.049000Z",
	edited: "2014-12-20T20:58:18.521000Z",
	url: "https://swapi.co/api/planets/58/"
},
	"https://swapi.co/api/planets/59/": {
	name: "Kalee",
	rotation_period: "23",
	orbital_period: "378",
	diameter: "13850",
	climate: "arid, temperate, tropical",
	gravity: "1",
	terrain: "rainforests, cliffs, canyons, seas",
	surface_water: "unknown",
	population: "4000000000",
	residents: [
		"https://swapi.co/api/people/79/"
	],
	films: [
	],
	created: "2014-12-20T19:43:51.278000Z",
	edited: "2014-12-20T20:58:18.523000Z",
	url: "https://swapi.co/api/planets/59/"
},
	"https://swapi.co/api/planets/60/": {
	name: "Umbara",
	rotation_period: "unknown",
	orbital_period: "unknown",
	diameter: "unknown",
	climate: "unknown",
	gravity: "unknown",
	terrain: "unknown",
	surface_water: "unknown",
	population: "unknown",
	residents: [
		"https://swapi.co/api/people/82/"
	],
	films: [
	],
	created: "2014-12-20T20:18:36.256000Z",
	edited: "2014-12-20T20:58:18.525000Z",
	url: "https://swapi.co/api/planets/60/"
},
	"https://swapi.co/api/planets/1/": {
	name: "Tatooine",
	rotation_period: "23",
	orbital_period: "304",
	diameter: "10465",
	climate: "arid",
	gravity: "1 standard",
	terrain: "desert",
	surface_water: "1",
	population: "200000",
	residents: [
		"https://swapi.co/api/people/1/",
		"https://swapi.co/api/people/2/",
		"https://swapi.co/api/people/4/",
		"https://swapi.co/api/people/6/",
		"https://swapi.co/api/people/7/",
		"https://swapi.co/api/people/8/",
		"https://swapi.co/api/people/9/",
		"https://swapi.co/api/people/11/",
		"https://swapi.co/api/people/43/",
		"https://swapi.co/api/people/62/"
	],
	films: [
		"https://swapi.co/api/films/5/",
		"https://swapi.co/api/films/4/",
		"https://swapi.co/api/films/6/",
		"https://swapi.co/api/films/3/",
		"https://swapi.co/api/films/1/"
	],
	created: "2014-12-09T13:50:49.641000Z",
	edited: "2014-12-21T20:48:04.175778Z",
	url: "https://swapi.co/api/planets/1/"
},
	"https://swapi.co/api/planets/?page=7": {
	count: 61,
	next: null,
	previous: "https://swapi.co/api/planets/?page=6",
	results: [
		{
			name: "Jakku",
			rotation_period: "unknown",
			orbital_period: "unknown",
			diameter: "unknown",
			climate: "unknown",
			gravity: "unknown",
			terrain: "deserts",
			surface_water: "unknown",
			population: "unknown",
			residents: [
			],
			films: [
				"https://swapi.co/api/films/7/"
			],
			created: "2015-04-17T06:55:57.556495Z",
			edited: "2015-04-17T06:55:57.556551Z",
			url: "https://swapi.co/api/planets/61/"
		}
	]
},
	"https://swapi.co/api/planets/61/": {
	name: "Jakku",
	rotation_period: "unknown",
	orbital_period: "unknown",
	diameter: "unknown",
	climate: "unknown",
	gravity: "unknown",
	terrain: "deserts",
	surface_water: "unknown",
	population: "unknown",
	residents: [
	],
	films: [
		"https://swapi.co/api/films/7/"
	],
	created: "2015-04-17T06:55:57.556495Z",
	edited: "2015-04-17T06:55:57.556551Z",
	url: "https://swapi.co/api/planets/61/"
},
	"https://swapi.co/api/films/": {
	count: 7,
	next: null,
	previous: null,
	results: [
		{
			title: "A New Hope",
			episode_id: 4,
			opening_crawl: "It is a period of civil war.\r\nRebel spaceships, striking\r\nfrom a hidden base, have won\r\ntheir first victory against\r\nthe evil Galactic Empire.\r\n\r\nDuring the battle, Rebel\r\nspies managed to steal secret\r\nplans to the Empire's\r\nultimate weapon, the DEATH\r\nSTAR, an armored space\r\nstation with enough power\r\nto destroy an entire planet.\r\n\r\nPursued by the Empire's\r\nsinister agents, Princess\r\nLeia races home aboard her\r\nstarship, custodian of the\r\nstolen plans that can save her\r\npeople and restore\r\nfreedom to the galaxy....",
			director: "George Lucas",
			producer: "Gary Kurtz, Rick McCallum",
			release_date: "1977-05-25",
			characters: [
				"https://swapi.co/api/people/1/",
				"https://swapi.co/api/people/2/",
				"https://swapi.co/api/people/3/",
				"https://swapi.co/api/people/4/",
				"https://swapi.co/api/people/5/",
				"https://swapi.co/api/people/6/",
				"https://swapi.co/api/people/7/",
				"https://swapi.co/api/people/8/",
				"https://swapi.co/api/people/9/",
				"https://swapi.co/api/people/10/",
				"https://swapi.co/api/people/12/",
				"https://swapi.co/api/people/13/",
				"https://swapi.co/api/people/14/",
				"https://swapi.co/api/people/15/",
				"https://swapi.co/api/people/16/",
				"https://swapi.co/api/people/18/",
				"https://swapi.co/api/people/19/",
				"https://swapi.co/api/people/81/"
			],
			planets: [
				"https://swapi.co/api/planets/2/",
				"https://swapi.co/api/planets/3/",
				"https://swapi.co/api/planets/1/"
			],
			starships: [
				"https://swapi.co/api/starships/2/",
				"https://swapi.co/api/starships/3/",
				"https://swapi.co/api/starships/5/",
				"https://swapi.co/api/starships/9/",
				"https://swapi.co/api/starships/10/",
				"https://swapi.co/api/starships/11/",
				"https://swapi.co/api/starships/12/",
				"https://swapi.co/api/starships/13/"
			],
			vehicles: [
				"https://swapi.co/api/vehicles/4/",
				"https://swapi.co/api/vehicles/6/",
				"https://swapi.co/api/vehicles/7/",
				"https://swapi.co/api/vehicles/8/"
			],
			species: [
				"https://swapi.co/api/species/5/",
				"https://swapi.co/api/species/3/",
				"https://swapi.co/api/species/2/",
				"https://swapi.co/api/species/1/",
				"https://swapi.co/api/species/4/"
			],
			created: "2014-12-10T14:23:31.880000Z",
			edited: "2015-04-11T09:46:52.774897Z",
			url: "https://swapi.co/api/films/1/"
		},
		{
			title: "Attack of the Clones",
			episode_id: 2,
			opening_crawl: "There is unrest in the Galactic\r\nSenate. Several thousand solar\r\nsystems have declared their\r\nintentions to leave the Republic.\r\n\r\nThis separatist movement,\r\nunder the leadership of the\r\nmysterious Count Dooku, has\r\nmade it difficult for the limited\r\nnumber of Jedi Knights to maintain \r\npeace and order in the galaxy.\r\n\r\nSenator Amidala, the former\r\nQueen of Naboo, is returning\r\nto the Galactic Senate to vote\r\non the critical issue of creating\r\nan ARMY OF THE REPUBLIC\r\nto assist the overwhelmed\r\nJedi....",
			director: "George Lucas",
			producer: "Rick McCallum",
			release_date: "2002-05-16",
			characters: [
				"https://swapi.co/api/people/2/",
				"https://swapi.co/api/people/3/",
				"https://swapi.co/api/people/6/",
				"https://swapi.co/api/people/7/",
				"https://swapi.co/api/people/10/",
				"https://swapi.co/api/people/11/",
				"https://swapi.co/api/people/20/",
				"https://swapi.co/api/people/21/",
				"https://swapi.co/api/people/22/",
				"https://swapi.co/api/people/33/",
				"https://swapi.co/api/people/36/",
				"https://swapi.co/api/people/40/",
				"https://swapi.co/api/people/43/",
				"https://swapi.co/api/people/46/",
				"https://swapi.co/api/people/51/",
				"https://swapi.co/api/people/52/",
				"https://swapi.co/api/people/53/",
				"https://swapi.co/api/people/58/",
				"https://swapi.co/api/people/59/",
				"https://swapi.co/api/people/60/",
				"https://swapi.co/api/people/61/",
				"https://swapi.co/api/people/62/",
				"https://swapi.co/api/people/63/",
				"https://swapi.co/api/people/64/",
				"https://swapi.co/api/people/65/",
				"https://swapi.co/api/people/66/",
				"https://swapi.co/api/people/67/",
				"https://swapi.co/api/people/68/",
				"https://swapi.co/api/people/69/",
				"https://swapi.co/api/people/70/",
				"https://swapi.co/api/people/71/",
				"https://swapi.co/api/people/72/",
				"https://swapi.co/api/people/73/",
				"https://swapi.co/api/people/74/",
				"https://swapi.co/api/people/75/",
				"https://swapi.co/api/people/76/",
				"https://swapi.co/api/people/77/",
				"https://swapi.co/api/people/78/",
				"https://swapi.co/api/people/82/",
				"https://swapi.co/api/people/35/"
			],
			planets: [
				"https://swapi.co/api/planets/8/",
				"https://swapi.co/api/planets/9/",
				"https://swapi.co/api/planets/10/",
				"https://swapi.co/api/planets/11/",
				"https://swapi.co/api/planets/1/"
			],
			starships: [
				"https://swapi.co/api/starships/21/",
				"https://swapi.co/api/starships/39/",
				"https://swapi.co/api/starships/43/",
				"https://swapi.co/api/starships/47/",
				"https://swapi.co/api/starships/48/",
				"https://swapi.co/api/starships/49/",
				"https://swapi.co/api/starships/32/",
				"https://swapi.co/api/starships/52/",
				"https://swapi.co/api/starships/58/"
			],
			vehicles: [
				"https://swapi.co/api/vehicles/4/",
				"https://swapi.co/api/vehicles/44/",
				"https://swapi.co/api/vehicles/45/",
				"https://swapi.co/api/vehicles/46/",
				"https://swapi.co/api/vehicles/50/",
				"https://swapi.co/api/vehicles/51/",
				"https://swapi.co/api/vehicles/53/",
				"https://swapi.co/api/vehicles/54/",
				"https://swapi.co/api/vehicles/55/",
				"https://swapi.co/api/vehicles/56/",
				"https://swapi.co/api/vehicles/57/"
			],
			species: [
				"https://swapi.co/api/species/32/",
				"https://swapi.co/api/species/33/",
				"https://swapi.co/api/species/2/",
				"https://swapi.co/api/species/35/",
				"https://swapi.co/api/species/6/",
				"https://swapi.co/api/species/1/",
				"https://swapi.co/api/species/12/",
				"https://swapi.co/api/species/34/",
				"https://swapi.co/api/species/13/",
				"https://swapi.co/api/species/15/",
				"https://swapi.co/api/species/28/",
				"https://swapi.co/api/species/29/",
				"https://swapi.co/api/species/30/",
				"https://swapi.co/api/species/31/"
			],
			created: "2014-12-20T10:57:57.886000Z",
			edited: "2015-04-11T09:45:01.623982Z",
			url: "https://swapi.co/api/films/5/"
		},
		{
			title: "The Phantom Menace",
			episode_id: 1,
			opening_crawl: "Turmoil has engulfed the\r\nGalactic Republic. The taxation\r\nof trade routes to outlying star\r\nsystems is in dispute.\r\n\r\nHoping to resolve the matter\r\nwith a blockade of deadly\r\nbattleships, the greedy Trade\r\nFederation has stopped all\r\nshipping to the small planet\r\nof Naboo.\r\n\r\nWhile the Congress of the\r\nRepublic endlessly debates\r\nthis alarming chain of events,\r\nthe Supreme Chancellor has\r\nsecretly dispatched two Jedi\r\nKnights, the guardians of\r\npeace and justice in the\r\ngalaxy, to settle the conflict....",
			director: "George Lucas",
			producer: "Rick McCallum",
			release_date: "1999-05-19",
			characters: [
				"https://swapi.co/api/people/2/",
				"https://swapi.co/api/people/3/",
				"https://swapi.co/api/people/10/",
				"https://swapi.co/api/people/11/",
				"https://swapi.co/api/people/16/",
				"https://swapi.co/api/people/20/",
				"https://swapi.co/api/people/21/",
				"https://swapi.co/api/people/32/",
				"https://swapi.co/api/people/33/",
				"https://swapi.co/api/people/34/",
				"https://swapi.co/api/people/36/",
				"https://swapi.co/api/people/37/",
				"https://swapi.co/api/people/38/",
				"https://swapi.co/api/people/39/",
				"https://swapi.co/api/people/40/",
				"https://swapi.co/api/people/41/",
				"https://swapi.co/api/people/42/",
				"https://swapi.co/api/people/43/",
				"https://swapi.co/api/people/44/",
				"https://swapi.co/api/people/46/",
				"https://swapi.co/api/people/48/",
				"https://swapi.co/api/people/49/",
				"https://swapi.co/api/people/50/",
				"https://swapi.co/api/people/51/",
				"https://swapi.co/api/people/52/",
				"https://swapi.co/api/people/53/",
				"https://swapi.co/api/people/54/",
				"https://swapi.co/api/people/55/",
				"https://swapi.co/api/people/56/",
				"https://swapi.co/api/people/57/",
				"https://swapi.co/api/people/58/",
				"https://swapi.co/api/people/59/",
				"https://swapi.co/api/people/47/",
				"https://swapi.co/api/people/35/"
			],
			planets: [
				"https://swapi.co/api/planets/8/",
				"https://swapi.co/api/planets/9/",
				"https://swapi.co/api/planets/1/"
			],
			starships: [
				"https://swapi.co/api/starships/40/",
				"https://swapi.co/api/starships/41/",
				"https://swapi.co/api/starships/31/",
				"https://swapi.co/api/starships/32/",
				"https://swapi.co/api/starships/39/"
			],
			vehicles: [
				"https://swapi.co/api/vehicles/33/",
				"https://swapi.co/api/vehicles/34/",
				"https://swapi.co/api/vehicles/35/",
				"https://swapi.co/api/vehicles/36/",
				"https://swapi.co/api/vehicles/37/",
				"https://swapi.co/api/vehicles/38/",
				"https://swapi.co/api/vehicles/42/"
			],
			species: [
				"https://swapi.co/api/species/1/",
				"https://swapi.co/api/species/2/",
				"https://swapi.co/api/species/6/",
				"https://swapi.co/api/species/11/",
				"https://swapi.co/api/species/12/",
				"https://swapi.co/api/species/13/",
				"https://swapi.co/api/species/14/",
				"https://swapi.co/api/species/15/",
				"https://swapi.co/api/species/16/",
				"https://swapi.co/api/species/17/",
				"https://swapi.co/api/species/18/",
				"https://swapi.co/api/species/19/",
				"https://swapi.co/api/species/20/",
				"https://swapi.co/api/species/21/",
				"https://swapi.co/api/species/22/",
				"https://swapi.co/api/species/23/",
				"https://swapi.co/api/species/24/",
				"https://swapi.co/api/species/25/",
				"https://swapi.co/api/species/26/",
				"https://swapi.co/api/species/27/"
			],
			created: "2014-12-19T16:52:55.740000Z",
			edited: "2015-04-11T09:45:18.689301Z",
			url: "https://swapi.co/api/films/4/"
		},
		{
			title: "Revenge of the Sith",
			episode_id: 3,
			opening_crawl: "War! The Republic is crumbling\r\nunder attacks by the ruthless\r\nSith Lord, Count Dooku.\r\nThere are heroes on both sides.\r\nEvil is everywhere.\r\n\r\nIn a stunning move, the\r\nfiendish droid leader, General\r\nGrievous, has swept into the\r\nRepublic capital and kidnapped\r\nChancellor Palpatine, leader of\r\nthe Galactic Senate.\r\n\r\nAs the Separatist Droid Army\r\nattempts to flee the besieged\r\ncapital with their valuable\r\nhostage, two Jedi Knights lead a\r\ndesperate mission to rescue the\r\ncaptive Chancellor....",
			director: "George Lucas",
			producer: "Rick McCallum",
			release_date: "2005-05-19",
			characters: [
				"https://swapi.co/api/people/1/",
				"https://swapi.co/api/people/2/",
				"https://swapi.co/api/people/3/",
				"https://swapi.co/api/people/4/",
				"https://swapi.co/api/people/5/",
				"https://swapi.co/api/people/6/",
				"https://swapi.co/api/people/7/",
				"https://swapi.co/api/people/10/",
				"https://swapi.co/api/people/11/",
				"https://swapi.co/api/people/12/",
				"https://swapi.co/api/people/13/",
				"https://swapi.co/api/people/20/",
				"https://swapi.co/api/people/21/",
				"https://swapi.co/api/people/33/",
				"https://swapi.co/api/people/46/",
				"https://swapi.co/api/people/51/",
				"https://swapi.co/api/people/52/",
				"https://swapi.co/api/people/53/",
				"https://swapi.co/api/people/54/",
				"https://swapi.co/api/people/55/",
				"https://swapi.co/api/people/56/",
				"https://swapi.co/api/people/58/",
				"https://swapi.co/api/people/63/",
				"https://swapi.co/api/people/64/",
				"https://swapi.co/api/people/67/",
				"https://swapi.co/api/people/68/",
				"https://swapi.co/api/people/75/",
				"https://swapi.co/api/people/78/",
				"https://swapi.co/api/people/79/",
				"https://swapi.co/api/people/80/",
				"https://swapi.co/api/people/81/",
				"https://swapi.co/api/people/82/",
				"https://swapi.co/api/people/83/",
				"https://swapi.co/api/people/35/"
			],
			planets: [
				"https://swapi.co/api/planets/2/",
				"https://swapi.co/api/planets/5/",
				"https://swapi.co/api/planets/8/",
				"https://swapi.co/api/planets/9/",
				"https://swapi.co/api/planets/12/",
				"https://swapi.co/api/planets/13/",
				"https://swapi.co/api/planets/14/",
				"https://swapi.co/api/planets/15/",
				"https://swapi.co/api/planets/16/",
				"https://swapi.co/api/planets/17/",
				"https://swapi.co/api/planets/18/",
				"https://swapi.co/api/planets/19/",
				"https://swapi.co/api/planets/1/"
			],
			starships: [
				"https://swapi.co/api/starships/48/",
				"https://swapi.co/api/starships/59/",
				"https://swapi.co/api/starships/61/",
				"https://swapi.co/api/starships/32/",
				"https://swapi.co/api/starships/63/",
				"https://swapi.co/api/starships/64/",
				"https://swapi.co/api/starships/65/",
				"https://swapi.co/api/starships/66/",
				"https://swapi.co/api/starships/74/",
				"https://swapi.co/api/starships/75/",
				"https://swapi.co/api/starships/2/",
				"https://swapi.co/api/starships/68/"
			],
			vehicles: [
				"https://swapi.co/api/vehicles/33/",
				"https://swapi.co/api/vehicles/50/",
				"https://swapi.co/api/vehicles/53/",
				"https://swapi.co/api/vehicles/56/",
				"https://swapi.co/api/vehicles/60/",
				"https://swapi.co/api/vehicles/62/",
				"https://swapi.co/api/vehicles/67/",
				"https://swapi.co/api/vehicles/69/",
				"https://swapi.co/api/vehicles/70/",
				"https://swapi.co/api/vehicles/71/",
				"https://swapi.co/api/vehicles/72/",
				"https://swapi.co/api/vehicles/73/",
				"https://swapi.co/api/vehicles/76/"
			],
			species: [
				"https://swapi.co/api/species/19/",
				"https://swapi.co/api/species/33/",
				"https://swapi.co/api/species/2/",
				"https://swapi.co/api/species/3/",
				"https://swapi.co/api/species/36/",
				"https://swapi.co/api/species/37/",
				"https://swapi.co/api/species/6/",
				"https://swapi.co/api/species/1/",
				"https://swapi.co/api/species/34/",
				"https://swapi.co/api/species/15/",
				"https://swapi.co/api/species/35/",
				"https://swapi.co/api/species/20/",
				"https://swapi.co/api/species/23/",
				"https://swapi.co/api/species/24/",
				"https://swapi.co/api/species/25/",
				"https://swapi.co/api/species/26/",
				"https://swapi.co/api/species/27/",
				"https://swapi.co/api/species/28/",
				"https://swapi.co/api/species/29/",
				"https://swapi.co/api/species/30/"
			],
			created: "2014-12-20T18:49:38.403000Z",
			edited: "2015-04-11T09:45:44.862122Z",
			url: "https://swapi.co/api/films/6/"
		},
		{
			title: "Return of the Jedi",
			episode_id: 6,
			opening_crawl: "Luke Skywalker has returned to\r\nhis home planet of Tatooine in\r\nan attempt to rescue his\r\nfriend Han Solo from the\r\nclutches of the vile gangster\r\nJabba the Hutt.\r\n\r\nLittle does Luke know that the\r\nGALACTIC EMPIRE has secretly\r\nbegun construction on a new\r\narmored space station even\r\nmore powerful than the first\r\ndreaded Death Star.\r\n\r\nWhen completed, this ultimate\r\nweapon will spell certain doom\r\nfor the small band of rebels\r\nstruggling to restore freedom\r\nto the galaxy...",
			director: "Richard Marquand",
			producer: "Howard G. Kazanjian, George Lucas, Rick McCallum",
			release_date: "1983-05-25",
			characters: [
				"https://swapi.co/api/people/1/",
				"https://swapi.co/api/people/2/",
				"https://swapi.co/api/people/3/",
				"https://swapi.co/api/people/4/",
				"https://swapi.co/api/people/5/",
				"https://swapi.co/api/people/10/",
				"https://swapi.co/api/people/13/",
				"https://swapi.co/api/people/14/",
				"https://swapi.co/api/people/16/",
				"https://swapi.co/api/people/18/",
				"https://swapi.co/api/people/20/",
				"https://swapi.co/api/people/21/",
				"https://swapi.co/api/people/22/",
				"https://swapi.co/api/people/25/",
				"https://swapi.co/api/people/27/",
				"https://swapi.co/api/people/28/",
				"https://swapi.co/api/people/29/",
				"https://swapi.co/api/people/30/",
				"https://swapi.co/api/people/31/",
				"https://swapi.co/api/people/45/"
			],
			planets: [
				"https://swapi.co/api/planets/5/",
				"https://swapi.co/api/planets/7/",
				"https://swapi.co/api/planets/8/",
				"https://swapi.co/api/planets/9/",
				"https://swapi.co/api/planets/1/"
			],
			starships: [
				"https://swapi.co/api/starships/15/",
				"https://swapi.co/api/starships/10/",
				"https://swapi.co/api/starships/11/",
				"https://swapi.co/api/starships/12/",
				"https://swapi.co/api/starships/22/",
				"https://swapi.co/api/starships/23/",
				"https://swapi.co/api/starships/27/",
				"https://swapi.co/api/starships/28/",
				"https://swapi.co/api/starships/29/",
				"https://swapi.co/api/starships/3/",
				"https://swapi.co/api/starships/17/",
				"https://swapi.co/api/starships/2/"
			],
			vehicles: [
				"https://swapi.co/api/vehicles/8/",
				"https://swapi.co/api/vehicles/16/",
				"https://swapi.co/api/vehicles/18/",
				"https://swapi.co/api/vehicles/19/",
				"https://swapi.co/api/vehicles/24/",
				"https://swapi.co/api/vehicles/25/",
				"https://swapi.co/api/vehicles/26/",
				"https://swapi.co/api/vehicles/30/"
			],
			species: [
				"https://swapi.co/api/species/1/",
				"https://swapi.co/api/species/2/",
				"https://swapi.co/api/species/3/",
				"https://swapi.co/api/species/5/",
				"https://swapi.co/api/species/6/",
				"https://swapi.co/api/species/8/",
				"https://swapi.co/api/species/9/",
				"https://swapi.co/api/species/10/",
				"https://swapi.co/api/species/15/"
			],
			created: "2014-12-18T10:39:33.255000Z",
			edited: "2015-04-11T09:46:05.220365Z",
			url: "https://swapi.co/api/films/3/"
		},
		{
			title: "The Empire Strikes Back",
			episode_id: 5,
			opening_crawl: "It is a dark time for the\r\nRebellion. Although the Death\r\nStar has been destroyed,\r\nImperial troops have driven the\r\nRebel forces from their hidden\r\nbase and pursued them across\r\nthe galaxy.\r\n\r\nEvading the dreaded Imperial\r\nStarfleet, a group of freedom\r\nfighters led by Luke Skywalker\r\nhas established a new secret\r\nbase on the remote ice world\r\nof Hoth.\r\n\r\nThe evil lord Darth Vader,\r\nobsessed with finding young\r\nSkywalker, has dispatched\r\nthousands of remote probes into\r\nthe far reaches of space....",
			director: "Irvin Kershner",
			producer: "Gary Kurtz, Rick McCallum",
			release_date: "1980-05-17",
			characters: [
				"https://swapi.co/api/people/1/",
				"https://swapi.co/api/people/2/",
				"https://swapi.co/api/people/3/",
				"https://swapi.co/api/people/4/",
				"https://swapi.co/api/people/5/",
				"https://swapi.co/api/people/10/",
				"https://swapi.co/api/people/13/",
				"https://swapi.co/api/people/14/",
				"https://swapi.co/api/people/18/",
				"https://swapi.co/api/people/20/",
				"https://swapi.co/api/people/21/",
				"https://swapi.co/api/people/22/",
				"https://swapi.co/api/people/23/",
				"https://swapi.co/api/people/24/",
				"https://swapi.co/api/people/25/",
				"https://swapi.co/api/people/26/"
			],
			planets: [
				"https://swapi.co/api/planets/4/",
				"https://swapi.co/api/planets/5/",
				"https://swapi.co/api/planets/6/",
				"https://swapi.co/api/planets/27/"
			],
			starships: [
				"https://swapi.co/api/starships/15/",
				"https://swapi.co/api/starships/10/",
				"https://swapi.co/api/starships/11/",
				"https://swapi.co/api/starships/12/",
				"https://swapi.co/api/starships/21/",
				"https://swapi.co/api/starships/22/",
				"https://swapi.co/api/starships/23/",
				"https://swapi.co/api/starships/3/",
				"https://swapi.co/api/starships/17/"
			],
			vehicles: [
				"https://swapi.co/api/vehicles/8/",
				"https://swapi.co/api/vehicles/14/",
				"https://swapi.co/api/vehicles/16/",
				"https://swapi.co/api/vehicles/18/",
				"https://swapi.co/api/vehicles/19/",
				"https://swapi.co/api/vehicles/20/"
			],
			species: [
				"https://swapi.co/api/species/6/",
				"https://swapi.co/api/species/7/",
				"https://swapi.co/api/species/3/",
				"https://swapi.co/api/species/2/",
				"https://swapi.co/api/species/1/"
			],
			created: "2014-12-12T11:26:24.656000Z",
			edited: "2017-04-19T10:57:29.544256Z",
			url: "https://swapi.co/api/films/2/"
		},
		{
			title: "The Force Awakens",
			episode_id: 7,
			opening_crawl: "Luke Skywalker has vanished.\r\nIn his absence, the sinister\r\nFIRST ORDER has risen from\r\nthe ashes of the Empire\r\nand will not rest until\r\nSkywalker, the last Jedi,\r\nhas been destroyed.\r\n \r\nWith the support of the\r\nREPUBLIC, General Leia Organa\r\nleads a brave RESISTANCE.\r\nShe is desperate to find her\r\nbrother Luke and gain his\r\nhelp in restoring peace and\r\njustice to the galaxy.\r\n \r\nLeia has sent her most daring\r\npilot on a secret mission\r\nto Jakku, where an old ally\r\nhas discovered a clue to\r\nLuke's whereabouts....",
			director: "J. J. Abrams",
			producer: "Kathleen Kennedy, J. J. Abrams, Bryan Burk",
			release_date: "2015-12-11",
			characters: [
				"https://swapi.co/api/people/1/",
				"https://swapi.co/api/people/3/",
				"https://swapi.co/api/people/5/",
				"https://swapi.co/api/people/13/",
				"https://swapi.co/api/people/14/",
				"https://swapi.co/api/people/27/",
				"https://swapi.co/api/people/84/",
				"https://swapi.co/api/people/85/",
				"https://swapi.co/api/people/86/",
				"https://swapi.co/api/people/87/",
				"https://swapi.co/api/people/88/"
			],
			planets: [
				"https://swapi.co/api/planets/61/"
			],
			starships: [
				"https://swapi.co/api/starships/77/",
				"https://swapi.co/api/starships/10/"
			],
			vehicles: [
			],
			species: [
				"https://swapi.co/api/species/3/",
				"https://swapi.co/api/species/2/",
				"https://swapi.co/api/species/1/"
			],
			created: "2015-04-17T06:51:30.504780Z",
			edited: "2015-12-17T14:31:47.617768Z",
			url: "https://swapi.co/api/films/7/"
		}
	]
},
	"https://swapi.co/api/films/1/": {
	title: "A New Hope",
	episode_id: 4,
	opening_crawl: "It is a period of civil war.\r\nRebel spaceships, striking\r\nfrom a hidden base, have won\r\ntheir first victory against\r\nthe evil Galactic Empire.\r\n\r\nDuring the battle, Rebel\r\nspies managed to steal secret\r\nplans to the Empire's\r\nultimate weapon, the DEATH\r\nSTAR, an armored space\r\nstation with enough power\r\nto destroy an entire planet.\r\n\r\nPursued by the Empire's\r\nsinister agents, Princess\r\nLeia races home aboard her\r\nstarship, custodian of the\r\nstolen plans that can save her\r\npeople and restore\r\nfreedom to the galaxy....",
	director: "George Lucas",
	producer: "Gary Kurtz, Rick McCallum",
	release_date: "1977-05-25",
	characters: [
		"https://swapi.co/api/people/1/",
		"https://swapi.co/api/people/2/",
		"https://swapi.co/api/people/3/",
		"https://swapi.co/api/people/4/",
		"https://swapi.co/api/people/5/",
		"https://swapi.co/api/people/6/",
		"https://swapi.co/api/people/7/",
		"https://swapi.co/api/people/8/",
		"https://swapi.co/api/people/9/",
		"https://swapi.co/api/people/10/",
		"https://swapi.co/api/people/12/",
		"https://swapi.co/api/people/13/",
		"https://swapi.co/api/people/14/",
		"https://swapi.co/api/people/15/",
		"https://swapi.co/api/people/16/",
		"https://swapi.co/api/people/18/",
		"https://swapi.co/api/people/19/",
		"https://swapi.co/api/people/81/"
	],
	planets: [
		"https://swapi.co/api/planets/2/",
		"https://swapi.co/api/planets/3/",
		"https://swapi.co/api/planets/1/"
	],
	starships: [
		"https://swapi.co/api/starships/2/",
		"https://swapi.co/api/starships/3/",
		"https://swapi.co/api/starships/5/",
		"https://swapi.co/api/starships/9/",
		"https://swapi.co/api/starships/10/",
		"https://swapi.co/api/starships/11/",
		"https://swapi.co/api/starships/12/",
		"https://swapi.co/api/starships/13/"
	],
	vehicles: [
		"https://swapi.co/api/vehicles/4/",
		"https://swapi.co/api/vehicles/6/",
		"https://swapi.co/api/vehicles/7/",
		"https://swapi.co/api/vehicles/8/"
	],
	species: [
		"https://swapi.co/api/species/5/",
		"https://swapi.co/api/species/3/",
		"https://swapi.co/api/species/2/",
		"https://swapi.co/api/species/1/",
		"https://swapi.co/api/species/4/"
	],
	created: "2014-12-10T14:23:31.880000Z",
	edited: "2015-04-11T09:46:52.774897Z",
	url: "https://swapi.co/api/films/1/"
},
	"https://swapi.co/api/films/5/": {
	title: "Attack of the Clones",
	episode_id: 2,
	opening_crawl: "There is unrest in the Galactic\r\nSenate. Several thousand solar\r\nsystems have declared their\r\nintentions to leave the Republic.\r\n\r\nThis separatist movement,\r\nunder the leadership of the\r\nmysterious Count Dooku, has\r\nmade it difficult for the limited\r\nnumber of Jedi Knights to maintain \r\npeace and order in the galaxy.\r\n\r\nSenator Amidala, the former\r\nQueen of Naboo, is returning\r\nto the Galactic Senate to vote\r\non the critical issue of creating\r\nan ARMY OF THE REPUBLIC\r\nto assist the overwhelmed\r\nJedi....",
	director: "George Lucas",
	producer: "Rick McCallum",
	release_date: "2002-05-16",
	characters: [
		"https://swapi.co/api/people/2/",
		"https://swapi.co/api/people/3/",
		"https://swapi.co/api/people/6/",
		"https://swapi.co/api/people/7/",
		"https://swapi.co/api/people/10/",
		"https://swapi.co/api/people/11/",
		"https://swapi.co/api/people/20/",
		"https://swapi.co/api/people/21/",
		"https://swapi.co/api/people/22/",
		"https://swapi.co/api/people/33/",
		"https://swapi.co/api/people/36/",
		"https://swapi.co/api/people/40/",
		"https://swapi.co/api/people/43/",
		"https://swapi.co/api/people/46/",
		"https://swapi.co/api/people/51/",
		"https://swapi.co/api/people/52/",
		"https://swapi.co/api/people/53/",
		"https://swapi.co/api/people/58/",
		"https://swapi.co/api/people/59/",
		"https://swapi.co/api/people/60/",
		"https://swapi.co/api/people/61/",
		"https://swapi.co/api/people/62/",
		"https://swapi.co/api/people/63/",
		"https://swapi.co/api/people/64/",
		"https://swapi.co/api/people/65/",
		"https://swapi.co/api/people/66/",
		"https://swapi.co/api/people/67/",
		"https://swapi.co/api/people/68/",
		"https://swapi.co/api/people/69/",
		"https://swapi.co/api/people/70/",
		"https://swapi.co/api/people/71/",
		"https://swapi.co/api/people/72/",
		"https://swapi.co/api/people/73/",
		"https://swapi.co/api/people/74/",
		"https://swapi.co/api/people/75/",
		"https://swapi.co/api/people/76/",
		"https://swapi.co/api/people/77/",
		"https://swapi.co/api/people/78/",
		"https://swapi.co/api/people/82/",
		"https://swapi.co/api/people/35/"
	],
	planets: [
		"https://swapi.co/api/planets/8/",
		"https://swapi.co/api/planets/9/",
		"https://swapi.co/api/planets/10/",
		"https://swapi.co/api/planets/11/",
		"https://swapi.co/api/planets/1/"
	],
	starships: [
		"https://swapi.co/api/starships/21/",
		"https://swapi.co/api/starships/39/",
		"https://swapi.co/api/starships/43/",
		"https://swapi.co/api/starships/47/",
		"https://swapi.co/api/starships/48/",
		"https://swapi.co/api/starships/49/",
		"https://swapi.co/api/starships/32/",
		"https://swapi.co/api/starships/52/",
		"https://swapi.co/api/starships/58/"
	],
	vehicles: [
		"https://swapi.co/api/vehicles/4/",
		"https://swapi.co/api/vehicles/44/",
		"https://swapi.co/api/vehicles/45/",
		"https://swapi.co/api/vehicles/46/",
		"https://swapi.co/api/vehicles/50/",
		"https://swapi.co/api/vehicles/51/",
		"https://swapi.co/api/vehicles/53/",
		"https://swapi.co/api/vehicles/54/",
		"https://swapi.co/api/vehicles/55/",
		"https://swapi.co/api/vehicles/56/",
		"https://swapi.co/api/vehicles/57/"
	],
	species: [
		"https://swapi.co/api/species/32/",
		"https://swapi.co/api/species/33/",
		"https://swapi.co/api/species/2/",
		"https://swapi.co/api/species/35/",
		"https://swapi.co/api/species/6/",
		"https://swapi.co/api/species/1/",
		"https://swapi.co/api/species/12/",
		"https://swapi.co/api/species/34/",
		"https://swapi.co/api/species/13/",
		"https://swapi.co/api/species/15/",
		"https://swapi.co/api/species/28/",
		"https://swapi.co/api/species/29/",
		"https://swapi.co/api/species/30/",
		"https://swapi.co/api/species/31/"
	],
	created: "2014-12-20T10:57:57.886000Z",
	edited: "2015-04-11T09:45:01.623982Z",
	url: "https://swapi.co/api/films/5/"
},
	"https://swapi.co/api/films/4/": {
	title: "The Phantom Menace",
	episode_id: 1,
	opening_crawl: "Turmoil has engulfed the\r\nGalactic Republic. The taxation\r\nof trade routes to outlying star\r\nsystems is in dispute.\r\n\r\nHoping to resolve the matter\r\nwith a blockade of deadly\r\nbattleships, the greedy Trade\r\nFederation has stopped all\r\nshipping to the small planet\r\nof Naboo.\r\n\r\nWhile the Congress of the\r\nRepublic endlessly debates\r\nthis alarming chain of events,\r\nthe Supreme Chancellor has\r\nsecretly dispatched two Jedi\r\nKnights, the guardians of\r\npeace and justice in the\r\ngalaxy, to settle the conflict....",
	director: "George Lucas",
	producer: "Rick McCallum",
	release_date: "1999-05-19",
	characters: [
		"https://swapi.co/api/people/2/",
		"https://swapi.co/api/people/3/",
		"https://swapi.co/api/people/10/",
		"https://swapi.co/api/people/11/",
		"https://swapi.co/api/people/16/",
		"https://swapi.co/api/people/20/",
		"https://swapi.co/api/people/21/",
		"https://swapi.co/api/people/32/",
		"https://swapi.co/api/people/33/",
		"https://swapi.co/api/people/34/",
		"https://swapi.co/api/people/36/",
		"https://swapi.co/api/people/37/",
		"https://swapi.co/api/people/38/",
		"https://swapi.co/api/people/39/",
		"https://swapi.co/api/people/40/",
		"https://swapi.co/api/people/41/",
		"https://swapi.co/api/people/42/",
		"https://swapi.co/api/people/43/",
		"https://swapi.co/api/people/44/",
		"https://swapi.co/api/people/46/",
		"https://swapi.co/api/people/48/",
		"https://swapi.co/api/people/49/",
		"https://swapi.co/api/people/50/",
		"https://swapi.co/api/people/51/",
		"https://swapi.co/api/people/52/",
		"https://swapi.co/api/people/53/",
		"https://swapi.co/api/people/54/",
		"https://swapi.co/api/people/55/",
		"https://swapi.co/api/people/56/",
		"https://swapi.co/api/people/57/",
		"https://swapi.co/api/people/58/",
		"https://swapi.co/api/people/59/",
		"https://swapi.co/api/people/47/",
		"https://swapi.co/api/people/35/"
	],
	planets: [
		"https://swapi.co/api/planets/8/",
		"https://swapi.co/api/planets/9/",
		"https://swapi.co/api/planets/1/"
	],
	starships: [
		"https://swapi.co/api/starships/40/",
		"https://swapi.co/api/starships/41/",
		"https://swapi.co/api/starships/31/",
		"https://swapi.co/api/starships/32/",
		"https://swapi.co/api/starships/39/"
	],
	vehicles: [
		"https://swapi.co/api/vehicles/33/",
		"https://swapi.co/api/vehicles/34/",
		"https://swapi.co/api/vehicles/35/",
		"https://swapi.co/api/vehicles/36/",
		"https://swapi.co/api/vehicles/37/",
		"https://swapi.co/api/vehicles/38/",
		"https://swapi.co/api/vehicles/42/"
	],
	species: [
		"https://swapi.co/api/species/1/",
		"https://swapi.co/api/species/2/",
		"https://swapi.co/api/species/6/",
		"https://swapi.co/api/species/11/",
		"https://swapi.co/api/species/12/",
		"https://swapi.co/api/species/13/",
		"https://swapi.co/api/species/14/",
		"https://swapi.co/api/species/15/",
		"https://swapi.co/api/species/16/",
		"https://swapi.co/api/species/17/",
		"https://swapi.co/api/species/18/",
		"https://swapi.co/api/species/19/",
		"https://swapi.co/api/species/20/",
		"https://swapi.co/api/species/21/",
		"https://swapi.co/api/species/22/",
		"https://swapi.co/api/species/23/",
		"https://swapi.co/api/species/24/",
		"https://swapi.co/api/species/25/",
		"https://swapi.co/api/species/26/",
		"https://swapi.co/api/species/27/"
	],
	created: "2014-12-19T16:52:55.740000Z",
	edited: "2015-04-11T09:45:18.689301Z",
	url: "https://swapi.co/api/films/4/"
},
	"https://swapi.co/api/films/6/": {
	title: "Revenge of the Sith",
	episode_id: 3,
	opening_crawl: "War! The Republic is crumbling\r\nunder attacks by the ruthless\r\nSith Lord, Count Dooku.\r\nThere are heroes on both sides.\r\nEvil is everywhere.\r\n\r\nIn a stunning move, the\r\nfiendish droid leader, General\r\nGrievous, has swept into the\r\nRepublic capital and kidnapped\r\nChancellor Palpatine, leader of\r\nthe Galactic Senate.\r\n\r\nAs the Separatist Droid Army\r\nattempts to flee the besieged\r\ncapital with their valuable\r\nhostage, two Jedi Knights lead a\r\ndesperate mission to rescue the\r\ncaptive Chancellor....",
	director: "George Lucas",
	producer: "Rick McCallum",
	release_date: "2005-05-19",
	characters: [
		"https://swapi.co/api/people/1/",
		"https://swapi.co/api/people/2/",
		"https://swapi.co/api/people/3/",
		"https://swapi.co/api/people/4/",
		"https://swapi.co/api/people/5/",
		"https://swapi.co/api/people/6/",
		"https://swapi.co/api/people/7/",
		"https://swapi.co/api/people/10/",
		"https://swapi.co/api/people/11/",
		"https://swapi.co/api/people/12/",
		"https://swapi.co/api/people/13/",
		"https://swapi.co/api/people/20/",
		"https://swapi.co/api/people/21/",
		"https://swapi.co/api/people/33/",
		"https://swapi.co/api/people/46/",
		"https://swapi.co/api/people/51/",
		"https://swapi.co/api/people/52/",
		"https://swapi.co/api/people/53/",
		"https://swapi.co/api/people/54/",
		"https://swapi.co/api/people/55/",
		"https://swapi.co/api/people/56/",
		"https://swapi.co/api/people/58/",
		"https://swapi.co/api/people/63/",
		"https://swapi.co/api/people/64/",
		"https://swapi.co/api/people/67/",
		"https://swapi.co/api/people/68/",
		"https://swapi.co/api/people/75/",
		"https://swapi.co/api/people/78/",
		"https://swapi.co/api/people/79/",
		"https://swapi.co/api/people/80/",
		"https://swapi.co/api/people/81/",
		"https://swapi.co/api/people/82/",
		"https://swapi.co/api/people/83/",
		"https://swapi.co/api/people/35/"
	],
	planets: [
		"https://swapi.co/api/planets/2/",
		"https://swapi.co/api/planets/5/",
		"https://swapi.co/api/planets/8/",
		"https://swapi.co/api/planets/9/",
		"https://swapi.co/api/planets/12/",
		"https://swapi.co/api/planets/13/",
		"https://swapi.co/api/planets/14/",
		"https://swapi.co/api/planets/15/",
		"https://swapi.co/api/planets/16/",
		"https://swapi.co/api/planets/17/",
		"https://swapi.co/api/planets/18/",
		"https://swapi.co/api/planets/19/",
		"https://swapi.co/api/planets/1/"
	],
	starships: [
		"https://swapi.co/api/starships/48/",
		"https://swapi.co/api/starships/59/",
		"https://swapi.co/api/starships/61/",
		"https://swapi.co/api/starships/32/",
		"https://swapi.co/api/starships/63/",
		"https://swapi.co/api/starships/64/",
		"https://swapi.co/api/starships/65/",
		"https://swapi.co/api/starships/66/",
		"https://swapi.co/api/starships/74/",
		"https://swapi.co/api/starships/75/",
		"https://swapi.co/api/starships/2/",
		"https://swapi.co/api/starships/68/"
	],
	vehicles: [
		"https://swapi.co/api/vehicles/33/",
		"https://swapi.co/api/vehicles/50/",
		"https://swapi.co/api/vehicles/53/",
		"https://swapi.co/api/vehicles/56/",
		"https://swapi.co/api/vehicles/60/",
		"https://swapi.co/api/vehicles/62/",
		"https://swapi.co/api/vehicles/67/",
		"https://swapi.co/api/vehicles/69/",
		"https://swapi.co/api/vehicles/70/",
		"https://swapi.co/api/vehicles/71/",
		"https://swapi.co/api/vehicles/72/",
		"https://swapi.co/api/vehicles/73/",
		"https://swapi.co/api/vehicles/76/"
	],
	species: [
		"https://swapi.co/api/species/19/",
		"https://swapi.co/api/species/33/",
		"https://swapi.co/api/species/2/",
		"https://swapi.co/api/species/3/",
		"https://swapi.co/api/species/36/",
		"https://swapi.co/api/species/37/",
		"https://swapi.co/api/species/6/",
		"https://swapi.co/api/species/1/",
		"https://swapi.co/api/species/34/",
		"https://swapi.co/api/species/15/",
		"https://swapi.co/api/species/35/",
		"https://swapi.co/api/species/20/",
		"https://swapi.co/api/species/23/",
		"https://swapi.co/api/species/24/",
		"https://swapi.co/api/species/25/",
		"https://swapi.co/api/species/26/",
		"https://swapi.co/api/species/27/",
		"https://swapi.co/api/species/28/",
		"https://swapi.co/api/species/29/",
		"https://swapi.co/api/species/30/"
	],
	created: "2014-12-20T18:49:38.403000Z",
	edited: "2015-04-11T09:45:44.862122Z",
	url: "https://swapi.co/api/films/6/"
},
	"https://swapi.co/api/films/3/": {
	title: "Return of the Jedi",
	episode_id: 6,
	opening_crawl: "Luke Skywalker has returned to\r\nhis home planet of Tatooine in\r\nan attempt to rescue his\r\nfriend Han Solo from the\r\nclutches of the vile gangster\r\nJabba the Hutt.\r\n\r\nLittle does Luke know that the\r\nGALACTIC EMPIRE has secretly\r\nbegun construction on a new\r\narmored space station even\r\nmore powerful than the first\r\ndreaded Death Star.\r\n\r\nWhen completed, this ultimate\r\nweapon will spell certain doom\r\nfor the small band of rebels\r\nstruggling to restore freedom\r\nto the galaxy...",
	director: "Richard Marquand",
	producer: "Howard G. Kazanjian, George Lucas, Rick McCallum",
	release_date: "1983-05-25",
	characters: [
		"https://swapi.co/api/people/1/",
		"https://swapi.co/api/people/2/",
		"https://swapi.co/api/people/3/",
		"https://swapi.co/api/people/4/",
		"https://swapi.co/api/people/5/",
		"https://swapi.co/api/people/10/",
		"https://swapi.co/api/people/13/",
		"https://swapi.co/api/people/14/",
		"https://swapi.co/api/people/16/",
		"https://swapi.co/api/people/18/",
		"https://swapi.co/api/people/20/",
		"https://swapi.co/api/people/21/",
		"https://swapi.co/api/people/22/",
		"https://swapi.co/api/people/25/",
		"https://swapi.co/api/people/27/",
		"https://swapi.co/api/people/28/",
		"https://swapi.co/api/people/29/",
		"https://swapi.co/api/people/30/",
		"https://swapi.co/api/people/31/",
		"https://swapi.co/api/people/45/"
	],
	planets: [
		"https://swapi.co/api/planets/5/",
		"https://swapi.co/api/planets/7/",
		"https://swapi.co/api/planets/8/",
		"https://swapi.co/api/planets/9/",
		"https://swapi.co/api/planets/1/"
	],
	starships: [
		"https://swapi.co/api/starships/15/",
		"https://swapi.co/api/starships/10/",
		"https://swapi.co/api/starships/11/",
		"https://swapi.co/api/starships/12/",
		"https://swapi.co/api/starships/22/",
		"https://swapi.co/api/starships/23/",
		"https://swapi.co/api/starships/27/",
		"https://swapi.co/api/starships/28/",
		"https://swapi.co/api/starships/29/",
		"https://swapi.co/api/starships/3/",
		"https://swapi.co/api/starships/17/",
		"https://swapi.co/api/starships/2/"
	],
	vehicles: [
		"https://swapi.co/api/vehicles/8/",
		"https://swapi.co/api/vehicles/16/",
		"https://swapi.co/api/vehicles/18/",
		"https://swapi.co/api/vehicles/19/",
		"https://swapi.co/api/vehicles/24/",
		"https://swapi.co/api/vehicles/25/",
		"https://swapi.co/api/vehicles/26/",
		"https://swapi.co/api/vehicles/30/"
	],
	species: [
		"https://swapi.co/api/species/1/",
		"https://swapi.co/api/species/2/",
		"https://swapi.co/api/species/3/",
		"https://swapi.co/api/species/5/",
		"https://swapi.co/api/species/6/",
		"https://swapi.co/api/species/8/",
		"https://swapi.co/api/species/9/",
		"https://swapi.co/api/species/10/",
		"https://swapi.co/api/species/15/"
	],
	created: "2014-12-18T10:39:33.255000Z",
	edited: "2015-04-11T09:46:05.220365Z",
	url: "https://swapi.co/api/films/3/"
},
	"https://swapi.co/api/films/2/": {
	title: "The Empire Strikes Back",
	episode_id: 5,
	opening_crawl: "It is a dark time for the\r\nRebellion. Although the Death\r\nStar has been destroyed,\r\nImperial troops have driven the\r\nRebel forces from their hidden\r\nbase and pursued them across\r\nthe galaxy.\r\n\r\nEvading the dreaded Imperial\r\nStarfleet, a group of freedom\r\nfighters led by Luke Skywalker\r\nhas established a new secret\r\nbase on the remote ice world\r\nof Hoth.\r\n\r\nThe evil lord Darth Vader,\r\nobsessed with finding young\r\nSkywalker, has dispatched\r\nthousands of remote probes into\r\nthe far reaches of space....",
	director: "Irvin Kershner",
	producer: "Gary Kurtz, Rick McCallum",
	release_date: "1980-05-17",
	characters: [
		"https://swapi.co/api/people/1/",
		"https://swapi.co/api/people/2/",
		"https://swapi.co/api/people/3/",
		"https://swapi.co/api/people/4/",
		"https://swapi.co/api/people/5/",
		"https://swapi.co/api/people/10/",
		"https://swapi.co/api/people/13/",
		"https://swapi.co/api/people/14/",
		"https://swapi.co/api/people/18/",
		"https://swapi.co/api/people/20/",
		"https://swapi.co/api/people/21/",
		"https://swapi.co/api/people/22/",
		"https://swapi.co/api/people/23/",
		"https://swapi.co/api/people/24/",
		"https://swapi.co/api/people/25/",
		"https://swapi.co/api/people/26/"
	],
	planets: [
		"https://swapi.co/api/planets/4/",
		"https://swapi.co/api/planets/5/",
		"https://swapi.co/api/planets/6/",
		"https://swapi.co/api/planets/27/"
	],
	starships: [
		"https://swapi.co/api/starships/15/",
		"https://swapi.co/api/starships/10/",
		"https://swapi.co/api/starships/11/",
		"https://swapi.co/api/starships/12/",
		"https://swapi.co/api/starships/21/",
		"https://swapi.co/api/starships/22/",
		"https://swapi.co/api/starships/23/",
		"https://swapi.co/api/starships/3/",
		"https://swapi.co/api/starships/17/"
	],
	vehicles: [
		"https://swapi.co/api/vehicles/8/",
		"https://swapi.co/api/vehicles/14/",
		"https://swapi.co/api/vehicles/16/",
		"https://swapi.co/api/vehicles/18/",
		"https://swapi.co/api/vehicles/19/",
		"https://swapi.co/api/vehicles/20/"
	],
	species: [
		"https://swapi.co/api/species/6/",
		"https://swapi.co/api/species/7/",
		"https://swapi.co/api/species/3/",
		"https://swapi.co/api/species/2/",
		"https://swapi.co/api/species/1/"
	],
	created: "2014-12-12T11:26:24.656000Z",
	edited: "2017-04-19T10:57:29.544256Z",
	url: "https://swapi.co/api/films/2/"
},
	"https://swapi.co/api/films/7/": {
	title: "The Force Awakens",
	episode_id: 7,
	opening_crawl: "Luke Skywalker has vanished.\r\nIn his absence, the sinister\r\nFIRST ORDER has risen from\r\nthe ashes of the Empire\r\nand will not rest until\r\nSkywalker, the last Jedi,\r\nhas been destroyed.\r\n \r\nWith the support of the\r\nREPUBLIC, General Leia Organa\r\nleads a brave RESISTANCE.\r\nShe is desperate to find her\r\nbrother Luke and gain his\r\nhelp in restoring peace and\r\njustice to the galaxy.\r\n \r\nLeia has sent her most daring\r\npilot on a secret mission\r\nto Jakku, where an old ally\r\nhas discovered a clue to\r\nLuke's whereabouts....",
	director: "J. J. Abrams",
	producer: "Kathleen Kennedy, J. J. Abrams, Bryan Burk",
	release_date: "2015-12-11",
	characters: [
		"https://swapi.co/api/people/1/",
		"https://swapi.co/api/people/3/",
		"https://swapi.co/api/people/5/",
		"https://swapi.co/api/people/13/",
		"https://swapi.co/api/people/14/",
		"https://swapi.co/api/people/27/",
		"https://swapi.co/api/people/84/",
		"https://swapi.co/api/people/85/",
		"https://swapi.co/api/people/86/",
		"https://swapi.co/api/people/87/",
		"https://swapi.co/api/people/88/"
	],
	planets: [
		"https://swapi.co/api/planets/61/"
	],
	starships: [
		"https://swapi.co/api/starships/77/",
		"https://swapi.co/api/starships/10/"
	],
	vehicles: [
	],
	species: [
		"https://swapi.co/api/species/3/",
		"https://swapi.co/api/species/2/",
		"https://swapi.co/api/species/1/"
	],
	created: "2015-04-17T06:51:30.504780Z",
	edited: "2015-12-17T14:31:47.617768Z",
	url: "https://swapi.co/api/films/7/"
}
};

/**
 * Copyright (c) 2015-present, Facebook, Inc.
 * All rights reserved.
 *
 * This source code is licensed under the license found in the
 * LICENSE-examples file in the root directory of this source tree.
 *
 * 
 */
/**
 * Given a URL of an object in the SWAPI, return the data
 * from our local cache.
 */

async function getFromLocalUrl(url) {
  const text = swapiData[url];

  if (!text) {
    throw new Error(`No entry in local cache for ${url}`);
  }

  if (process.env.NODE_ENV !== 'test') {
    // eslint-disable-next-line no-console
    console.log(`Hit the local cache for ${url}.`);
  }

  return text;
}

/**
 * Copyright (c) 2015-present, Facebook Inc.
 * All rights reserved.
 *
 * This source code is licensed under the license found in the
 * LICENSE-examples file in the root directory of this source tree.
 *
 * 
 */
const localUrlLoader = new dataloader(urls => Promise.all(urls.map(getFromLocalUrl)));
/**
 * Objects returned from SWAPI don't have an ID field, so add one.
 */

function objectWithId(obj) {
  obj.id = parseInt(obj.url.split('/')[5], 10);
  return obj;
}
/**
 * Given an object URL, fetch it, append the ID to it, and return it.
 */


async function getObjectFromUrl(url) {
  const data = await localUrlLoader.load(url);
  return objectWithId(data);
}
/**
 * Given a type and ID, get the object with the ID.
 */

async function getObjectFromTypeAndId(type, id) {
  return await getObjectFromUrl(`https://swapi.co/api/${type}/${id}/`);
}

/**
 * Given a type, fetch all of the pages, and join the objects together
 */
async function getObjectsByType(type) {
  let objects = [];
  let nextUrl = `https://swapi.co/api/${type}/`;

  while (nextUrl) {
    // eslint-disable-next-line no-await-in-loop
    const pageData = await localUrlLoader.load(nextUrl);
    objects = objects.concat(pageData.results.map(objectWithId));
    nextUrl = pageData.next;
  }

  objects = sortObjectsById(objects);
  return {
    objects,
    totalCount: objects.length
  };
}
async function getObjectsFromUrls(urls) {
  const array = await Promise.all(urls.map(getObjectFromUrl));
  return sortObjectsById(array);
}

function sortObjectsById(array) {
  return array.sort((a, b) => a.id - b.id);
}
/**
 * Given a string, convert it to a number
 */


function convertToNumber(value) {
  if (['unknown', 'n/a'].indexOf(value) !== -1) {
    return null;
  } // remove digit grouping


  const numberString = value.replace(/,/, '');
  return Number(numberString);
}

/**
 * Copyright (c) 2015-present, Facebook, Inc.
 * All rights reserved.
 *
 * This source code is licensed under the license found in the
 * LICENSE-examples file in the root directory of this source tree.
 *
 * 
 */

function createdField() {
  return {
    type: graphql.GraphQLString,
    description: 'The ISO 8601 date format of the time that this resource was created.'
  };
}
function editedField() {
  return {
    type: graphql.GraphQLString,
    description: 'The ISO 8601 date format of the time that this resource was edited.'
  };
}

/**
 * Copyright (c) 2015-present, Facebook, Inc.
 * All rights reserved.
 *
 * This source code is licensed under the license found in the
 * LICENSE-examples file in the root directory of this source tree.
 *
 * 
 */

/**
 * Constructs a GraphQL connection field config; it is assumed
 * that the object has a property named `prop`, and that property
 * contains a list of URLs.
 */
function connectionFromUrls(name, prop, type) {
  const {
    connectionType
  } = lib_3({
    name,
    nodeType: type,
    resolveNode: edge => edge.node,
    connectionFields: () => ({
      totalCount: {
        type: graphql.GraphQLInt,
        resolve: conn => conn.totalCount,
        description: `A count of the total number of objects in this connection, ignoring pagination.
This allows a client to fetch the first five objects by passing "5" as the
argument to "first", then fetch the total count so it could display "5 of 83",
for example.`
      },
      [prop]: {
        type: new graphql.GraphQLList(type),
        resolve: conn => conn.edges.map(edge => edge.node),
        description: `A list of all of the objects returned in the connection. This is a convenience
field provided for quickly exploring the API; rather than querying for
"{ edges { node } }" when no edge data is needed, this field can be be used
instead. Note that when clients like Relay need to fetch the "cursor" field on
the edge to enable efficient pagination, this shortcut cannot be used, and the
full "{ edges { node } }" version should be used instead.`
      }
    })
  });
  return {
    type: connectionType,
    args: lib_4,
    resolve: async (obj, args) => {
      const array = await getObjectsFromUrls(obj[prop] || []);
      return { ...lib_5(array, args),
        totalCount: array.length
      };
    }
  };
}

/**
 * Copyright (c) 2015-present, Facebook, Inc.
 * All rights reserved.
 *
 * This source code is licensed under the license found in the
 * LICENSE-examples file in the root directory of this source tree.
 *
 * 
 */
/**
 * The GraphQL type equivalent of the Planet resource
 */

const PlanetType = new graphql.GraphQLObjectType({
  name: 'Planet',
  description: `A large mass, planet or planetoid in the Star Wars Universe, at the time of
0 ABY.`,
  fields: () => ({
    name: {
      type: graphql.GraphQLString,
      description: 'The name of this planet.'
    },
    diameter: {
      type: graphql.GraphQLInt,
      resolve: planet => convertToNumber(planet.diameter),
      description: 'The diameter of this planet in kilometers.'
    },
    rotationPeriod: {
      type: graphql.GraphQLInt,
      resolve: planet => convertToNumber(planet.rotation_period),
      description: `The number of standard hours it takes for this planet to complete a single
rotation on its axis.`
    },
    orbitalPeriod: {
      type: graphql.GraphQLInt,
      resolve: planet => convertToNumber(planet.orbital_period),
      description: `The number of standard days it takes for this planet to complete a single orbit
of its local star.`
    },
    gravity: {
      type: graphql.GraphQLString,
      description: `A number denoting the gravity of this planet, where "1" is normal or 1 standard
G. "2" is twice or 2 standard Gs. "0.5" is half or 0.5 standard Gs.`
    },
    population: {
      type: graphql.GraphQLFloat,
      resolve: planet => convertToNumber(planet.population),
      description: 'The average population of sentient beings inhabiting this planet.'
    },
    climates: {
      type: new graphql.GraphQLList(graphql.GraphQLString),
      resolve: planet => {
        return planet.climate.split(',').map(s => s.trim());
      },
      description: 'The climates of this planet.'
    },
    terrains: {
      type: new graphql.GraphQLList(graphql.GraphQLString),
      resolve: planet => {
        return planet.terrain.split(',').map(s => s.trim());
      },
      description: 'The terrains of this planet.'
    },
    surfaceWater: {
      type: graphql.GraphQLFloat,
      resolve: planet => convertToNumber(planet.surface_water),
      description: `The percentage of the planet surface that is naturally occuring water or bodies
of water.`
    },
    residentConnection: connectionFromUrls('PlanetResidents', 'residents', PersonType),
    filmConnection: connectionFromUrls('PlanetFilms', 'films', FilmType),
    created: createdField(),
    edited: editedField(),
    id: lib_6('planets')
  }),
  interfaces: () => [nodeInterface]
});

/**
 * Copyright (c) 2015-present, Facebook, Inc.
 * All rights reserved.
 *
 * This source code is licensed under the license found in the
 * LICENSE-examples file in the root directory of this source tree.
 *
 * 
 */
/**
 * The GraphQL type equivalent of the Species resource
 */

const SpeciesType = new graphql.GraphQLObjectType({
  name: 'Species',
  description: 'A type of person or character within the Star Wars Universe.',
  fields: () => ({
    name: {
      type: graphql.GraphQLString,
      description: 'The name of this species.'
    },
    classification: {
      type: graphql.GraphQLString,
      description: 'The classification of this species, such as "mammal" or "reptile".'
    },
    designation: {
      type: graphql.GraphQLString,
      description: 'The designation of this species, such as "sentient".'
    },
    averageHeight: {
      type: graphql.GraphQLFloat,
      resolve: species => convertToNumber(species.average_height),
      description: 'The average height of this species in centimeters.'
    },
    averageLifespan: {
      type: graphql.GraphQLInt,
      resolve: species => convertToNumber(species.average_lifespan),
      description: 'The average lifespan of this species in years, null if unknown.'
    },
    eyeColors: {
      type: new graphql.GraphQLList(graphql.GraphQLString),
      resolve: species => {
        return species.eye_colors.split(',').map(s => s.trim());
      },
      description: `Common eye colors for this species, null if this species does not typically
have eyes.`
    },
    hairColors: {
      type: new graphql.GraphQLList(graphql.GraphQLString),
      resolve: species => {
        if (species.hair_colors === 'none') {
          return [];
        }

        return species.hair_colors.split(',').map(s => s.trim());
      },
      description: `Common hair colors for this species, null if this species does not typically
have hair.`
    },
    skinColors: {
      type: new graphql.GraphQLList(graphql.GraphQLString),
      resolve: species => {
        return species.skin_colors.split(',').map(s => s.trim());
      },
      description: `Common skin colors for this species, null if this species does not typically
have skin.`
    },
    language: {
      type: graphql.GraphQLString,
      description: 'The language commonly spoken by this species.'
    },
    homeworld: {
      type: PlanetType,
      resolve: species => species.homeworld ? getObjectFromUrl(species.homeworld) : null,
      description: 'A planet that this species originates from.'
    },
    personConnection: connectionFromUrls('SpeciesPeople', 'people', PersonType),
    filmConnection: connectionFromUrls('SpeciesFilms', 'films', FilmType),
    created: createdField(),
    edited: editedField(),
    id: lib_6('species')
  }),
  interfaces: () => [nodeInterface]
});

/**
 * Copyright (c) 2015-present, Facebook, Inc.
 * All rights reserved.
 *
 * This source code is licensed under the license found in the
 * LICENSE-examples file in the root directory of this source tree.
 *
 * 
 */
/**
 * The GraphQL type equivalent of the Starship resource
 */

const StarshipType = new graphql.GraphQLObjectType({
  name: 'Starship',
  description: 'A single transport craft that has hyperdrive capability.',
  fields: () => ({
    name: {
      type: graphql.GraphQLString,
      description: 'The name of this starship. The common name, such as "Death Star".'
    },
    model: {
      type: graphql.GraphQLString,
      description: `The model or official name of this starship. Such as "T-65 X-wing" or "DS-1
Orbital Battle Station".`
    },
    starshipClass: {
      type: graphql.GraphQLString,
      resolve: ship => ship.starship_class,
      description: `The class of this starship, such as "Starfighter" or "Deep Space Mobile
Battlestation"`
    },
    manufacturers: {
      type: new graphql.GraphQLList(graphql.GraphQLString),
      resolve: ship => {
        return ship.manufacturer.split(',').map(s => s.trim());
      },
      description: 'The manufacturers of this starship.'
    },
    costInCredits: {
      type: graphql.GraphQLFloat,
      resolve: ship => convertToNumber(ship.cost_in_credits),
      description: 'The cost of this starship new, in galactic credits.'
    },
    length: {
      type: graphql.GraphQLFloat,
      resolve: ship => convertToNumber(ship.length),
      description: 'The length of this starship in meters.'
    },
    crew: {
      type: graphql.GraphQLString,
      description: 'The number of personnel needed to run or pilot this starship.'
    },
    passengers: {
      type: graphql.GraphQLString,
      description: 'The number of non-essential people this starship can transport.'
    },
    maxAtmospheringSpeed: {
      type: graphql.GraphQLInt,
      resolve: ship => convertToNumber(ship.max_atmosphering_speed),
      description: `The maximum speed of this starship in atmosphere. null if this starship is
incapable of atmosphering flight.`
    },
    hyperdriveRating: {
      type: graphql.GraphQLFloat,
      resolve: ship => convertToNumber(ship.hyperdrive_rating),
      description: 'The class of this starships hyperdrive.'
    },
    MGLT: {
      type: graphql.GraphQLInt,
      resolve: ship => convertToNumber(ship.MGLT),
      description: `The Maximum number of Megalights this starship can travel in a standard hour.
A "Megalight" is a standard unit of distance and has never been defined before
within the Star Wars universe. This figure is only really useful for measuring
the difference in speed of starships. We can assume it is similar to AU, the
distance between our Sun (Sol) and Earth.`
    },
    cargoCapacity: {
      type: graphql.GraphQLFloat,
      resolve: ship => convertToNumber(ship.cargo_capacity),
      description: 'The maximum number of kilograms that this starship can transport.'
    },
    consumables: {
      type: graphql.GraphQLString,
      description: `The maximum length of time that this starship can provide consumables for its
entire crew without having to resupply.`
    },
    pilotConnection: connectionFromUrls('StarshipPilots', 'pilots', PersonType),
    filmConnection: connectionFromUrls('StarshipFilms', 'films', FilmType),
    created: createdField(),
    edited: editedField(),
    id: lib_6('starships')
  }),
  interfaces: () => [nodeInterface]
});

/**
 * Copyright (c) 2015-present, Facebook, Inc.
 * All rights reserved.
 *
 * This source code is licensed under the license found in the
 * LICENSE-examples file in the root directory of this source tree.
 *
 * 
 */
/**
 * The GraphQL type equivalent of the Vehicle resource
 */

const VehicleType = new graphql.GraphQLObjectType({
  name: 'Vehicle',
  description: 'A single transport craft that does not have hyperdrive capability',
  fields: () => ({
    name: {
      type: graphql.GraphQLString,
      description: `The name of this vehicle. The common name, such as "Sand Crawler" or "Speeder
bike".`
    },
    model: {
      type: graphql.GraphQLString,
      description: `The model or official name of this vehicle. Such as "All-Terrain Attack
Transport".`
    },
    vehicleClass: {
      type: graphql.GraphQLString,
      resolve: vehicle => vehicle.vehicle_class,
      description: 'The class of this vehicle, such as "Wheeled" or "Repulsorcraft".'
    },
    manufacturers: {
      type: new graphql.GraphQLList(graphql.GraphQLString),
      resolve: vehicle => {
        return vehicle.manufacturer.split(',').map(s => s.trim());
      },
      description: 'The manufacturers of this vehicle.'
    },
    costInCredits: {
      type: graphql.GraphQLFloat,
      resolve: vehicle => convertToNumber(vehicle.cost_in_credits),
      description: 'The cost of this vehicle new, in Galactic Credits.'
    },
    length: {
      type: graphql.GraphQLFloat,
      resolve: vehicle => convertToNumber(vehicle.length),
      description: 'The length of this vehicle in meters.'
    },
    crew: {
      type: graphql.GraphQLString,
      description: 'The number of personnel needed to run or pilot this vehicle.'
    },
    passengers: {
      type: graphql.GraphQLString,
      description: 'The number of non-essential people this vehicle can transport.'
    },
    maxAtmospheringSpeed: {
      type: graphql.GraphQLInt,
      resolve: vehicle => convertToNumber(vehicle.max_atmosphering_speed),
      description: 'The maximum speed of this vehicle in atmosphere.'
    },
    cargoCapacity: {
      type: graphql.GraphQLFloat,
      resolve: ship => convertToNumber(ship.cargo_capacity),
      description: 'The maximum number of kilograms that this vehicle can transport.'
    },
    consumables: {
      type: graphql.GraphQLString,
      description: `The maximum length of time that this vehicle can provide consumables for its
entire crew without having to resupply.`
    },
    pilotConnection: connectionFromUrls('VehiclePilots', 'pilots', PersonType),
    filmConnection: connectionFromUrls('VehicleFilms', 'films', FilmType),
    created: createdField(),
    edited: editedField(),
    id: lib_6('vehicles')
  }),
  interfaces: () => [nodeInterface]
});

/**
 * Copyright (c) 2015-present, Facebook, Inc.
 * All rights reserved.
 *
 * This source code is licensed under the license found in the
 * LICENSE-examples file in the root directory of this source tree.
 *
 * 
 */
/**
 * The GraphQL type equivalent of the People resource
 */

const PersonType = new graphql.GraphQLObjectType({
  name: 'Person',
  description: 'An individual person or character within the Star Wars universe.',
  fields: () => ({
    name: {
      type: graphql.GraphQLString,
      description: 'The name of this person.'
    },
    birthYear: {
      type: graphql.GraphQLString,
      resolve: person => person.birth_year,
      description: `The birth year of the person, using the in-universe standard of BBY or ABY -
Before the Battle of Yavin or After the Battle of Yavin. The Battle of Yavin is
a battle that occurs at the end of Star Wars episode IV: A New Hope.`
    },
    eyeColor: {
      type: graphql.GraphQLString,
      resolve: person => person.eye_color,
      description: `The eye color of this person. Will be "unknown" if not known or "n/a" if the
person does not have an eye.`
    },
    gender: {
      type: graphql.GraphQLString,
      description: `The gender of this person. Either "Male", "Female" or "unknown",
"n/a" if the person does not have a gender.`
    },
    hairColor: {
      type: graphql.GraphQLString,
      resolve: person => person.hair_color,
      description: `The hair color of this person. Will be "unknown" if not known or "n/a" if the
person does not have hair.`
    },
    height: {
      type: graphql.GraphQLInt,
      resolve: person => convertToNumber(person.height),
      description: 'The height of the person in centimeters.'
    },
    mass: {
      type: graphql.GraphQLFloat,
      resolve: person => convertToNumber(person.mass),
      description: 'The mass of the person in kilograms.'
    },
    skinColor: {
      type: graphql.GraphQLString,
      resolve: person => person.skin_color,
      description: 'The skin color of this person.'
    },
    homeworld: {
      type: PlanetType,
      resolve: person => person.homeworld ? getObjectFromUrl(person.homeworld) : null,
      description: 'A planet that this person was born on or inhabits.'
    },
    filmConnection: connectionFromUrls('PersonFilms', 'films', FilmType),
    species: {
      type: SpeciesType,
      resolve: person => {
        if (!person.species || person.species.length === 0) {
          return null;
        }

        return getObjectFromUrl(person.species[0]);
      },
      description: 'The species that this person belongs to, or null if unknown.'
    },
    starshipConnection: connectionFromUrls('PersonStarships', 'starships', StarshipType),
    vehicleConnection: connectionFromUrls('PersonVehicles', 'vehicles', VehicleType),
    created: createdField(),
    edited: editedField(),
    id: lib_6('people')
  }),
  interfaces: () => [nodeInterface]
});

/**
 * Copyright (c) 2015-present, Facebook, Inc.
 * All rights reserved.
 *
 * This source code is licensed under the license found in the
 * LICENSE-examples file in the root directory of this source tree.
 *
 * 
 */
/**
 * The GraphQL type equivalent of the Film resource
 */

const FilmType = new graphql.GraphQLObjectType({
  name: 'Film',
  description: 'A single film.',
  fields: () => ({
    title: {
      type: graphql.GraphQLString,
      description: 'The title of this film.'
    },
    episodeID: {
      type: graphql.GraphQLInt,
      resolve: film => film.episode_id,
      description: 'The episode number of this film.'
    },
    openingCrawl: {
      type: graphql.GraphQLString,
      resolve: film => film.opening_crawl,
      description: 'The opening paragraphs at the beginning of this film.'
    },
    director: {
      type: graphql.GraphQLString,
      description: 'The name of the director of this film.'
    },
    producers: {
      type: new graphql.GraphQLList(graphql.GraphQLString),
      resolve: film => {
        return film.producer.split(',').map(s => s.trim());
      },
      description: 'The name(s) of the producer(s) of this film.'
    },
    releaseDate: {
      type: graphql.GraphQLString,
      resolve: film => film.release_date,
      description: 'The ISO 8601 date format of film release at original creator country.'
    },
    speciesConnection: connectionFromUrls('FilmSpecies', 'species', SpeciesType),
    starshipConnection: connectionFromUrls('FilmStarships', 'starships', StarshipType),
    vehicleConnection: connectionFromUrls('FilmVehicles', 'vehicles', VehicleType),
    characterConnection: connectionFromUrls('FilmCharacters', 'characters', PersonType),
    planetConnection: connectionFromUrls('FilmPlanets', 'planets', PlanetType),
    created: createdField(),
    edited: editedField(),
    id: lib_6('films')
  }),
  interfaces: () => [nodeInterface]
});

/**
 * Copyright (c) 2015-present, Facebook, Inc.
 * All rights reserved.
 *
 * This source code is licensed under the license found in the
 * LICENSE-examples file in the root directory of this source tree.
 *
 * 
 */
/**
 * Given a "type" in SWAPI, returns the corresponding GraphQL type.
 */

function swapiTypeToGraphQLType(swapiType) {
  switch (swapiType) {
    case 'films':
      return FilmType;

    case 'people':
      return PersonType;

    case 'planets':
      return PlanetType;

    case 'starships':
      return StarshipType;

    case 'vehicles':
      return VehicleType;

    case 'species':
      return SpeciesType;

    default:
      throw new Error('Unrecognized type `' + swapiType + '`.');
  }
}
const {
  nodeInterface,
  nodeField
} = lib_1(globalId => {
  const {
    type,
    id
  } = lib_2(globalId);
  return getObjectFromTypeAndId(type, id);
}, obj => {
  const parts = obj.url.split('/');
  return swapiTypeToGraphQLType(parts[parts.length - 3]);
});

/**
 * Copyright (c) 2015-present, Facebook, Inc.
 * All rights reserved.
 *
 * This source code is licensed under the license found in the
 * LICENSE-examples file in the root directory of this source tree.
 *
 * 
 */
/**
 * Creates a root field to get an object of a given type.
 * Accepts either `id`, the globally unique ID used in GraphQL,
 * or `idName`, the per-type ID used in SWAPI.
 */

function rootFieldByID(idName, swapiType) {
  const getter = id => getObjectFromTypeAndId(swapiType, id);

  const argDefs = {};
  argDefs.id = {
    type: graphql.GraphQLID
  };
  argDefs[idName] = {
    type: graphql.GraphQLID
  };
  return {
    type: swapiTypeToGraphQLType(swapiType),
    args: argDefs,
    resolve: (_, args) => {
      if (args[idName] !== undefined && args[idName] !== null) {
        return getter(args[idName]);
      }

      if (args.id !== undefined && args.id !== null) {
        const globalId = lib_2(args.id);

        if (globalId.id === null || globalId.id === undefined || globalId.id === '') {
          throw new Error('No valid ID extracted from ' + args.id);
        }

        return getter(globalId.id);
      }

      throw new Error('must provide id or ' + idName);
    }
  };
}
/**
 * Creates a connection that will return all objects of the given
 * `swapiType`; the connection will be named using `name`.
 */


function rootConnection(name, swapiType) {
  const graphqlType = swapiTypeToGraphQLType(swapiType);
  const {
    connectionType
  } = lib_3({
    name,
    nodeType: graphqlType,
    connectionFields: () => ({
      totalCount: {
        type: graphql.GraphQLInt,
        resolve: conn => conn.totalCount,
        description: `A count of the total number of objects in this connection, ignoring pagination.
This allows a client to fetch the first five objects by passing "5" as the
argument to "first", then fetch the total count so it could display "5 of 83",
for example.`
      },
      [swapiType]: {
        type: new graphql.GraphQLList(graphqlType),
        resolve: conn => conn.edges.map(edge => edge.node),
        description: `A list of all of the objects returned in the connection. This is a convenience
field provided for quickly exploring the API; rather than querying for
"{ edges { node } }" when no edge data is needed, this field can be be used
instead. Note that when clients like Relay need to fetch the "cursor" field on
the edge to enable efficient pagination, this shortcut cannot be used, and the
full "{ edges { node } }" version should be used instead.`
      }
    })
  });
  return {
    type: connectionType,
    args: lib_4,
    resolve: async (_, args) => {
      const {
        objects,
        totalCount
      } = await getObjectsByType(swapiType);
      return { ...lib_5(objects, args),
        totalCount
      };
    }
  };
}
/**
 * The GraphQL type equivalent of the Root resource
 */


const rootType = new graphql.GraphQLObjectType({
  name: 'Root',
  fields: () => ({
    allFilms: rootConnection('Films', 'films'),
    film: rootFieldByID('filmID', 'films'),
    allPeople: rootConnection('People', 'people'),
    person: rootFieldByID('personID', 'people'),
    allPlanets: rootConnection('Planets', 'planets'),
    planet: rootFieldByID('planetID', 'planets'),
    allSpecies: rootConnection('Species', 'species'),
    species: rootFieldByID('speciesID', 'species'),
    allStarships: rootConnection('Starships', 'starships'),
    starship: rootFieldByID('starshipID', 'starships'),
    allVehicles: rootConnection('Vehicles', 'vehicles'),
    vehicle: rootFieldByID('vehicleID', 'vehicles'),
    node: nodeField
  })
});
var schema = new graphql.GraphQLSchema({
  query: rootType
});

module.exports = schema;
